=pod

=head1 NAME

RG::Liu::Euclid - Perl modules by J. Liu

=head1 SYNOPSIS

use RG::Liu::Euclid;

=head1 FUNCTIONS

See module source for description.

=over

=item get_function

=item get_keyword

=item euclid

=item read_dictionary

=item sorttest

=back

=head1 VARIABLES

=over

=back

=head1 AUTHOR

J. Liu

=head1 SEE ALSO

=over

=item Main website

L<https://rostlab.informatik.tu-muenchen.de/wiki/index.php/Slashdata:cubicmanpages>

=back

=cut

# this is just modified subroutines from orginal EUCLID script
# I/O part is redone, and convert into perl module
# Jinfeng Liu                11/06/2000
# CUBIC, Columbia University

# 
#                              EUCLID

#               Assignments of proteins in functional classes

#                    J. Tamames & A.Valencia, 1998.

# Licensed for adademic purposes.
# For other uses please contact Dr. Alfonso Valencia (valencia@cnb.uam.es)

package RG::Liu::Euclid;
require      Exporter;
@ISA       = qw(Exporter);
@EXPORT    = qw(euclid);

sub euclid {
    my ( $swissListRef ) = @_;
    my ( $file_dict, $valueRef, $kwdRef, $function );

    $file_dict = '/usr/pub/molbio/euclid/DZ.dictionary';
    if ( ! -f $file_dict ) { return "";}
    $valueRef = &read_dictionary($file_dict);
    $kwdRef = &get_keyword($swissListRef);
    $function = &get_function($kwdRef, $valueRef);
    return $function;
}

sub read_dictionary {
    my ( $file_dict ) = @_;
    my ( $ky, $ocs, $perc, $zsc, %values );

    open( DICT, $file_dict ) || return "";	
    while( <DICT>) {                                   
	chomp;                                       
	if($_=~/\n/) { next; }	# NEW DICTIONARY, Z-SCORES!!!
	next if ( $_ !~ /\S+/ );
	($ky,$ocs,$perc,$zsc)=split(/\t/,$_);          #  Javier, Aug 1997
	$values{$ky}=$zsc;
    }                                     #
    close DICT;                                      
    return \%values;
}


sub get_keyword {			
    my ( $swissListRef ) = @_;
    my ( $dirSwiss, $present_in_files, @kws, @final, $field );
    my ( $num_of_files, $numfil_kw, @swissList, $id, @tmp );
    my ( $org, $subDir, $filename, $fieldkw, $intermed,  $min_tres);
    my ( $rem1, %ocs, $ee );

    $dirSwiss = '/data/swissprot/current/';
    $present_in_files = 0.6;
    @kws=@final=();
    $field="";
    $num_of_files=$numfil_kw=0;      

    @swissList = @$swissListRef;

    foreach $id ( @swissList ) {   # Loop over swissprot files, start.
	@tmp = split /_/, $id;
	if ( ! defined $tmp[1] ) { die "$id seems not a swissId\n";}
	$org = $tmp[1];
	$subDir = substr($org,0,1);
	$filename = $dirSwiss.$subDir.'/'.$id;                                                      
	$fieldkw = $intermed = "";
	open( SWISS , $filename) ||  next;   # Read swiss files  
	# print "Using file ",$filename,"\n";
	$num_of_files++;
	
	while( <SWISS> )   {
	    if ($_=~/^KW/)      {
		$fieldkw=substr($_,5);
		chop $fieldkw;
		$intermed.=$fieldkw;            # KWs reading
	    }
	    
	}
	close SWISS;
	$intermed=~s/\; /\;/g;
	$intermed=~s/\./\;/g;
	if($intermed=~/\w/) {
	    $numfil_kw++;
	    $field.=$intermed;
	}

    }   # Loop over swissprot files, end.
    $field=~s/\.//g;
    @kws=split(/\;/,$field);

    $min_tres = $num_of_files*$present_in_files;   # Minimum number of occurrences to annotate the keyword
 
    foreach $rem1(@kws) { $ocs{$rem1}++; }

    foreach $ee(keys (%ocs)) {
        if ($ocs{$ee}>=$min_tres) { push(@final,$ee); }  # Store the keyword if its number of occurrences is enuf
    }
    
    # print "$num_of_files files\n";
    # print "Keywords: ";
    # print "@final\n";
    return \@final;
}				# 


########################## FUNCTIONAL CLASSES#########################################



sub get_function {		# NEW SUBROUTINE FOR FUNCTIONAL ASSIGNATION, 
				# USING NEW DICTIONARY

    my ( $kwdRef, $valueRef ) = @_;
    my @final = @$kwdRef;
    my %values = %$valueRef;

    my ( @clases, @toord, @listaord, $thisone, $clg, $clr );
    my ( $ksi, $asignt, $del );

    @clases=(
	 'Amino acid biosynthesis',
	 'Biosynthesis of cofactors, prosthetic groups, and carriers', # Functional classes
         'Cell envelope','Cellular processes',
         'Central intermediary metabolism','Energy metabolism',
         'Fatty acid and phospholipid metabolism','Other categories',
         'Purines, pyrimidines, nucleosides, and nucleotides','Regulatory functions',
         'Replication','Transcription','Translation',
	     'Transport and binding proteins');

    @toord=@listaord=();	# OF Z-SCORES  

    foreach $thisone(@final) {
	foreach $clg(@clases)      {
	    $clr=uc($thisone)."/".$clg;	# upper case, changed by Jinfeng(Columbia)
	    if($values{$clr}) { $storr{$clg}+=$values{$clr}; }
	}
    }

    foreach $ksi(keys(%storr)) { push(@toord,$ksi);}
    @listaord = sort sorttest @toord;                   
    $asignt = $listaord[0]; # Need a treshold here. Coming soon.
    if(!$asignt) { $asignt="Unknown"; }
    foreach $del(keys %storr) { delete $storr{$del}; }
    # print "\nFunction: $asignt\n";
    return $asignt;
}
				

sub sorttest   {		# SORT PROCEDURE
    $storr{$b}<=>$storr{$a};
}
              

1;
