=pod

=head1 NAME

RG::Liu::LibChop - Perl modules by J. Liu

=head1 SYNOPSIS

use RG::Liu::LibChop;

=head1 FUNCTIONS

See module source for description.

=over

=item appendFile

=item getFragInfo

=item getOrfInfo

=item isChop

=back

=head1 VARIABLES

=over

=back

=head1 AUTHOR

J. Liu

=head1 SEE ALSO

=over

=item Main website

L<https://rostlab.informatik.tu-muenchen.de/wiki/index.php/Slashdata:cubicmanpages>

=back

=cut

package      RG::Liu::LibChop;
require      Exporter;
@ISA       = qw(Exporter);
@EXPORT    = qw(appendFile getFragInfo getOrfInfo isChop);
#@EXPORT_OK = qw();



sub appendFile {
    my ($file1,$file2) = @_;
    my $sbr = "appendFile";
    $fh1 = "FH1_$sbr";
    $fh2 = "FH2_$sbr";

    open ($fh1,">>$file1") or return (0, "cannot open $file1 for appending:$!");
    open ($fh2,$file2) or return (0, "cannot open $file2 for reading:$!");
    while (<$fh2>) {
	print $fh1 $_;
    }
    close $fh2;
    close $fh1;
    return (1,"ok");
}


#============================================================
sub getFragInfo {
#-----------------------------------------------------------
# get general fragment info from the file
# in: frag file
# out: a hashRef with {$fragID}, 'org','orfId','orfLen','fragLen'..
#-----------------------------------------------------------
    my ( $fileIn ) = @_;
    my $sbr = "getFragInfo";
    my ($fhIn,@tmp,$id,$org,$orfId,$orfLen,$fragBeg,$source,$fragEnd);
    my ($clusters,%frag);

    $fhIn = "IN_$sbr";
    open ($fhIn,$fileIn) or die "cannot open $fileIn:$!";
    while (<$fhIn>) {
	next if ( /^\#/ );
	next if ( $_ !~ /\w+/ );
	chomp;
	@tmp = split /\t+/;
	($id,$org,$orfId,$orfLen,$fragBeg,$fragEnd,$source,$clusters) = @tmp[0..7];
	
	#$id = "chopFrag$id";
	$frag{$id}{'org'} = $org;
	$frag{$id}{'orfId'} = $orfId;
	$frag{$id}{'orfLen'} = $orfLen;
	$frag{$id}{'fragBeg'} = $fragBeg;
	$frag{$id}{'fragEnd'} = $fragEnd;
	$frag{$id}{'source'} = $source;
	if ( defined $clusters ) {
	    $clusters =~ s/\;/,/g;
	    $frag{$id}{'clusters'} = $clusters;
	}
	#print "xx $id\n";
    }
    close $fhIn;
    return {%frag};
}


#============================================================
sub getOrfInfo {
#-----------------------------------------------------------
# get general fragment info from the file
# in: frag file
# out: a hashRef with {$fragID}, 'org','orfId','orfLen','fragLen'..
#-----------------------------------------------------------
    my ( $fileIn ) = @_;
    my $sbr = "getOrfInfo";
    my ($fhIn,@tmp,$org,$orfId,$frags,%orf);


    $fhIn = "IN_$sbr";
    open ($fhIn,$fileIn) or die "cannot open $fileIn:$!";
    while (<$fhIn>) {
	next if ( /^\#/ );
	next if ( $_ !~ /\w+/ );
	chomp;
	@tmp = split /\t+/;
	($org,$orfId,$frags) = @tmp[0,1,4];
	$orf{$org}{$orfId} = $frags;
    }
    close $fhIn;
    return {%orf};
}



sub isChop {
    my ($fileIn) = @_;
    my $isChop = 0;
    my $sbr = "isChop";
    my $fh_chop = "CHOP_$sbr";

    return 0 if ( ! -e $fileIn);
    open ( $fh_chop, $fileIn) or die "cannot open $fileIn:$!";
    while (<$fh_chop>) {
        if (/^\/\//i) {
            $isChop = 1;
        }
    }
    close $fh_chop;
    return $isChop;
}

1;



