=pod

=head1 NAME

RG::Liu::LibDna - Perl modules by J. Liu

=head1 SYNOPSIS

use RG::Liu::LibDna;

=head1 FUNCTIONS

See module source for description.

=over

=item dna2peptide

=item translate_frame

=back

=head1 VARIABLES

=over

=item genetic_code

=back

=head1 AUTHOR

J. Liu

=head1 SEE ALSO

=over

=item Main website

L<https://rostlab.informatik.tu-muenchen.de/wiki/index.php/Slashdata:cubicmanpages>

=back

=cut

package      RG::Liu::LibDna;
require      Exporter;
@ISA       = qw(Exporter);
@EXPORT    = qw(genetic_code dna2peptide);


%genetic_code = 
    (
     'TCA' => 'S', 
     'TCC' => 'S', 
     'TCG' => 'S', 
     'TCT' => 'S',    # Serine
     'TTC' => 'F',    # Phenylalanine
     'TTT' => 'F',    # Phenylalanine
     'TTA' => 'L',    # Leucine
     'TTG' => 'L',    # Leucine
     'TAC' => 'Y',    # Tyrosine
     'TAT' => 'Y',    # Tyrosine
     'TAA' => '_',    # Stop
     'TAG' => '_',    # Stop
     'TGC' => 'C',    # Cysteine
     'TGT' => 'C',    # Cysteine
     'TGA' => '_',    # Stop
     'TGG' => 'W',    # Tryptophan
     'CTA' => 'L',    # Leucine
     'CTC' => 'L',    # Leucine
     'CTG' => 'L',    # Leucine
     'CTT' => 'L',    # Leucine
     'CCA' => 'P',    # Proline
     'CCC' => 'P',    # Proline
     'CCG' => 'P',    # Proline
     'CCT' => 'P',    # Proline
     'CAC' => 'H',    # Histidine
     'CAT' => 'H',    # Histidine
     'CAA' => 'Q',    # Glutamine
     'CAG' => 'Q',    # Glutamine
     'CGA' => 'R',    # Arginine
     'CGC' => 'R',    # Arginine
     'CGG' => 'R',    # Arginine
     'CGT' => 'R',    # Arginine
     'ATA' => 'I',    # Isoleucine
     'ATC' => 'I',    # Isoleucine
     'ATT' => 'I',    # Isoleucine
     'ATG' => 'M',    # Methionine
     'ACA' => 'T',    # Threonine
     'ACC' => 'T',    # Threonine
     'ACG' => 'T',    # Threonine
     'ACT' => 'T',    # Threonine
     'AAC' => 'N',    # Asparagine
     'AAT' => 'N',    # Asparagine
     'AAA' => 'K',    # Lysine
     'AAG' => 'K',    # Lysine
     'AGC' => 'S',    # Serine
     'AGT' => 'S',    # Serine
     'AGA' => 'R',    # Arginine
     'AGG' => 'R',    # Arginine
     'GTA' => 'V',    # Valine
     'GTC' => 'V',    # Valine
     'GTG' => 'V',    # Valine
     'GTT' => 'V',    # Valine
     'GCA' => 'A',    # Alanine
     'GCC' => 'A',    # Alanine
     'GCG' => 'A',    # Alanine
     'GCT' => 'A',    # Alanine
     'GAC' => 'D',    # Aspartic Acid
     'GAT' => 'D',    # Aspartic Acid
     'GAA' => 'E',    # Glutamic Acid
     'GAG' => 'E',    # Glutamic Acid
     'GGA' => 'G',    # Glycine
     'GGC' => 'G',    # Glycine
     'GGG' => 'G',    # Glycine
     'GGT' => 'G',    # Glycine
     );


sub dna2peptide {
    my ( $dna,$frame ) = @_;
    my ( $seq,$prot,$dna_frame );

    $frame = 1 if ( ! defined $frame );

    if ( $frame < 0 ) {	# get reverse complement
	$seq = reverse $dna;
	$seq =~ tr/ACGT/TGCA/;
    } else {
	$seq = $dna;
    }

    $seq =~ s/\s+//g;

    $seq = substr($seq,abs($frame)-1);
    ($prot,$dna_frame) = &translate_frame($seq);

    return ($prot,$dna_frame);
}

sub translate_frame {
    my ( $dna ) = @_;
    my ( $length,$begin,$triplet,$prot,$dna_frame );

    $length = length $dna;
    for ( $begin = 0; $begin < $length; $begin += 3 ) {
	$triplet = substr($dna,$begin,3);
	next if ( ! defined $triplet or length($triplet) < 3);
	if ( defined $genetic_code{$triplet} ) {
	    $prot .= $genetic_code{$triplet};
	} else {
	    print STDERR "*** ERROR: $triplet not a valid codon, translate into X\n";
	    $prot .= 'X';
	}
	if ( defined $genetic_code{$triplet} and $genetic_code{$triplet} eq '_' ) {
	    $dna_frame .= '_';
	} else {
	    $dna_frame .= $triplet;
	}
	
    }
    return ($prot,$dna_frame);
}


1;
