=pod

=head1 NAME

RG::Liu::LibFile - Perl modules by J. Liu

=head1 SYNOPSIS

use RG::Liu::LibFile;

=head1 FUNCTIONS

See module source for description.

=over

=item append

=item exist_zip

=item getcolumn

=item get_hash

=item get_exist_hash

=item open_gz

=item gunzip_file

=item gzip_file

=back

=head1 VARIABLES

=over

=back

=head1 AUTHOR

J. Liu

=head1 SEE ALSO

=over

=item Main website

L<https://rostlab.informatik.tu-muenchen.de/wiki/index.php/Slashdata:cubicmanpages>

=back

=cut

package      RG::Liu::LibFile;
require      Exporter;
@ISA       = qw(Exporter);
@EXPORT    = qw(append getcolumn get_hash get_exist_hash open_gz gzip_file 
		gunzip_file exist_zip );

sub append {
    my ($file1,$file2,$del_comment) = @_;
    my ($fh1,$fh2,$line) ;

    open ($fh1,">> $file1") or 
	return (0, "cannot open $file1 for appending:$!");
    open ($fh2,$file2) or 
	return (0, "cannot open $file2 for reading:$!");
    
    while ($line=<$fh2>) {
	next if ( $del_comment and $line =~ /^\#/ );
	print $fh1 $line;
    }
    close $fh2;
    close $fh1;
    return (1,"ok");
}

sub exist_zip {
    my ( $file ) = @_;
    my ( $file_zip, $file_unzip);

    $file_unzip = $file;
    if ( $file =~ /\.gz$/ ) {
	$file_unzip =~ s/\.gz$//;
	$file_zip = $file;
    } else {
	$file_zip = $file.'.gz';
    }
    if ( -s $file_zip or -s $file_unzip ) {
	return 1;
    } else {
	return 0;
    }
}

sub getcolumn {
    my ( $file, $column, $delim, $keep_comment ) = @_ ;
    $column = 0 if ( ! defined $column );
    $delim = "\t" if ( ! defined $delim );
 
    my ( $list,$fh,$line,@fields );

    return undef if ( ! -s $file or ! -r $file );

    $list = [ ];
    open ($fh,$file) or die "cannot open $file:$!";
    while ($line=<$fh>) {
	chomp $line;
	next if ( $line=~ /^\#/ and ! $keep_comment );
	next if ( $line !~ /\w+/ );

	@fields = split /$delim/, $line;
	push @$list, $fields[$column] if ( defined $fields[$column] );
    }
    close $fh;

    return $list;
}	

sub get_hash {
    my ( $file,$column_key,$column_value ) = @_;
    my ( $fh,$line,@tmp, $key,$value );

    if ( ! $file or ! -s $file ) {
	print STDERR "*** ERROR: input file not found\n";
	return undef;
    }

    $column_key = 0 if ( ! defined $column_key );
    $column_value = 1 if ( ! defined $column_value );

    my $hash = { };


    open ($fh,$file) or die "cannot open $file:$!";
    while ( $line = <$fh> ) {
	next if ( $line !~ /\w/ );
	next if ( $line =~ /^\#/ );
	chomp $line;
	@tmp = split /\t/,$line;
	next if ( ! defined $tmp[$column_key] or ! defined $tmp[$column_value] );
	$key = $tmp[$column_key];
	$value = $tmp[$column_value];
	$hash->{$key} = $value;
    }
    close $fh;

    return $hash;
}

sub get_exist_hash {
    my ( $file,$column_key,$value ) = @_;
    my ( $fh,$line,@tmp, $key );

    if ( ! $file or ! -s $file ) {
	print STDERR "*** ERROR: input file not found\n";
	return undef;
    }

    $column_key = 0 if ( ! defined $column_key );
    $value = 1 if ( ! defined $value );

    my $hash = { };

    open ($fh,$file) or die "cannot open $file:$!";
    while ( $line = <$fh> ) {
	next if ( $line !~ /\w/ );
	next if ( $line =~ /^\#/ );
	chomp $line;
	@tmp = split /\t/,$line;
	next if ( ! defined $tmp[$column_key] );
	$key = $tmp[$column_key];
	$hash->{$key} = $value;
    }
    close $fh;

    return $hash;
}

sub open_gz {
    my ( $file ) = @_;
    my ( $file_zip, $file_unzip, $fileopen );

    undef $fileopen;

    $file_unzip = $file;
    if ( $file =~ /\.gz$/ ) {
	$file_unzip =~ s/\.gz$//;
	$file_zip = $file;
    } else {
	$file_zip = $file.'.gz';
    }
    if ( -s $file_unzip ) {
	$fileopen = "< $file_unzip ";
    } elsif ( -s $file_zip ) {
	$fileopen = " gunzip -c $file_zip | ";
    }

    return $fileopen;
}

sub gunzip_file {
    my ( $file, $force ) = @_;
    my ( $file_zip, $file_unzip);

    $file_zip = $file;
    if ( $file =~ /\.gz$/ ) {
	$file_unzip =~ s/\.gz$//;
    } else {
	$file_unzip = $file;
	$file_zip = $file.'.gz';
    }

    return 0 if ( ! -s $file_zip );
    if ( $force ) {
	system "gunzip -f $file_zip";
	return 2;
    }

    if ( -s $file_unzip ) {
	if ( -M $file_unzip > -M $file_zip ) {
	    system "gunzip -f $file_zip";
	} else {
	    unlink $file_zip;
	}
	return 2;
    } else {
	system "gunzip $file_zip";
    }

    return 1;
}

sub gzip_file {
    my ( $file, $force ) = @_;
    my ( $file_zip, $file_unzip);

    $file_unzip = $file;
    if ( $file =~ /\.gz$/ ) {
	$file_unzip =~ s/\.gz$//;
	$file_zip = $file;
    } else {
	$file_zip = $file.'.gz';
    }

    return 0 if ( ! -s $file_unzip );
    if ( $force ) {
	system "gzip -f $file_unzip";
	return 2;
    }

    if ( -s $file_zip ) {
	if ( -M $file_zip > -M $file_unzip ) {
	    system "gzip -f $file_unzip";
	} else {
	    unlink $file_unzip;
	}
	return 2;
    } else {
	system "gzip $file_unzip";
    }

    return 1;
}

1;
