=pod

=head1 NAME

RG::Liu::LibGenome - Perl modules by J. Liu

=head1 SYNOPSIS

use RG::Liu::LibGenome;

=head1 FUNCTIONS

See module source for description.

=over

=item aaCompFromList

=item calcMW

=item get_seq_info

=item getIdHash

=item getIdList

=item getOverlap

=item getPepEntry

=item getPepEntry_md5

=item getSeq

=item pep2hash

=item regionOverlap

=back

=head1 VARIABLES

=over

=item %aa_pdb

=item %aa2flex

=item %aa2mw

=item %aa3to1

=item @commClass

=item @euclidClasses14

=item @euclidClasses3

=item @energyClass

=item @fullOrgList

=item %genus2class

=item @infoClass

=item %name_latin

=item %name_latin_short

=item %org2kingdom

=back

=head1 AUTHOR

J. Liu

=head1 SEE ALSO

=over

=item Main website

L<https://rostlab.informatik.tu-muenchen.de/wiki/index.php/Slashdata:cubicmanpages>

=back

=cut

package      RG::Liu::LibGenome;
require      Exporter;
@ISA       = qw(Exporter);
@EXPORT    = qw(@fullOrgList getIdList getIdHash);
@EXPORT_OK = qw(%name_latin_short %name_latin %org2kingdom @euclidClasses14
		@euclidClasses3 @energyClass @infoClass @commClass
		%aa3to1 %aa2mw %aa2flex %aa_pdb %genus2class
		aaCompFromList calcMW getSeq pep2hash getPepEntry_md5
		getPepEntry regionOverlap getOverlap get_seq_info );



@fullOrgList=qw ( aerpe arcfu haln1 metac metja metka metmp mettm pyrab 
		  pyrfu pyrho sulso sulto theac thevo
		  agrt5 aquae bacsu biflo borbu brume camje caucr chlpn 
		  chlte chltr cloab clope deira ecoli entfa fusnu geosu
		  haein helpy lacla lepin 
		  lisin lismo mycge mycle mycpn myctu neime oceih
		  pasmu pseae psesm
		  riccn ricpr rhilo rhopa staau straw strco strpy synel syny3 
		  thema trepa ureur vibch xanci xylfa
		  arath caeel drome enccu yeast mouse human
		  hcmva bacaa wolsu schpo yerpe chlcv coxbu pholu
		  clote bacce xancp xanac strmu staep sheon salty
		  borpa borpe haedu 
		  niteu porgi psepu ralso
		  agrtu bachd strag
		  bactn borbr chrvo cordi desvh lacpl vibpa mycbo
		  aciad barhe barqu bdeba canbf braja bucbp bucap bucai
		  chlmu coref corgl erwca glovi helhe lacjo leixx lepic
		  achfl metth mycav mycga mycms mycpe mycpu naneq
		  neima neimb onype paruw promp promm proac rat chick
		  baccr bacfr bachk peccc halma legpn salch
		  );

%name_latin_short = ( 
		      'aciad' => "A sp ADP1",
		      'achfl' => "A (M) florum",
		      'aerpe' => "A pernix K1",
		      'agrt5' => "A tumefaciens",
		      'agrtu' => "A tumefaciens",
		      'aquae' => "A aeolicus",
		      'arath' => "A thaliana",
		      'arcfu' => "A fulgidus",
		      'bacaa' => "B anthracis_Ames",
		      'bacce' => "B cereus (ATCC 14579)",
		      'baccr' => "B cereus (ATCC 14579 / DSM 31)",
		      'bacfr' => "B fragilis",
		      'bachd' => "B halodurans",
		      'bachk' => "B thuringiensis (subsp. konkukian)",
		      'bacsu' => "B subtilis",
		      'bactn' => "B thetaiotaomicron VPI-5482",
		      'barhe' => "B henselae Houston-1",
		      'barqu' => "B quintana Toulouse",
		      'bdeba' => "B bacteriovorus",
		      'biflo' => "B longum",
		      'borbr' => "B bronchiseptica RB50",
		      'borpa' => "B parapertussis",
		      'borpe' => "B pertussis",
		      'borbu' => "B burgdorferi",
		      'braja' => "B japonicum",
		      'brume' => "B melitensis",
		      'bucai' => "B aphidicola (subsp. Acyrthosiphon pisum)",
		      'bucap' => "B aphidicola (subsp. Schizaphis graminum)",
		      'bucbp' => "B aphidicola (subsp. Baizongia pistaciae)",
		      'caeel' => "C elegans",
		      'camje' => "C jejuni",
		      'canbf' => "C Blochmannia floridanus",
		      'caucr' => "C crescentus",
		      'chick' => "G gallus",
		      'chlcv' => "C caviae",
		      'chlmu' => "C muridarum",
		      'chlpn' => "C pneumoniae",
		      'chlte' => "C tepidum",
		      'chltr' => "C trachomatis",
		      'chrvo' => "C violaceum ATCC 12472",
		      'cloab' => "C acetobutylicum",
		      'clope' => "C perfringens",
		      'clote' => "C tetani",
		      'cordi' => "C diphtheriae NCTC 13129",
		      'coref' => "C efficiens",
		      'corgl' => "C glutamicum",
		      'coxbu' => "C burnetii",
		      'deira' => "D radiodurans",
		      'desvh' => "D vulgaris subsp. vulgaris str. Hildenborough",
		      'drome' => "D melanogaster",
		      'ecoli' => "E coli",
		      'enccu' => "E cuniculi",
		      'entfa' => "E faecalis",
		      'erwca' => "E carotovora",
		      'fusnu' => "F nucleatum",
		      'geosu' => "G sulfurreducens",
		      'glovi' => "G violaceus",
		      'haedu' => "H ducreyi",
		      'haein' => "H influenzae",
		      'halma' => "H marismortui",
		      'haln1' => "H sp. (strain NRC-1)",
		      'hcmva' => "H cytomegalovirus (strain AD169)",
		      'helhe' => "H heilmannii",
		      'helpy' => "H pylori",
		      'human' => "H sapiens",
		      'lacjo' => "L johnsonii",
		      'lacla' => "L lactis (subsp. lactis)",
		      'lacpl' => "L plantarum WCFS1",
		      'legph' => "L pneumophila",
		      'legpn' => "L pneumophila",
		      'leixx' => "L xyli (subsp. xyli)",
		      'lepic' => "L interrogans (serogroup Icterohaemorrhagiae / serovar Copenhageni)",
		      'lepin' => "L interrogans",
		      'lisin' => "L innocua",
		      'lismo' => "L monocytogenes",
		      'metac' => "M acetivorans",
		      'metja' => "M jannaschii",
		      'metka' => "M kandleri",
		      'metma' => "M mazei",
		      'metmp' => "M maripaludis",
		      'metth' => "M thermoautotrophicum",
		      'mettm' => "M thermoautotrophicum (strain Marburg / DSM 2133)",
		      'mouse' => "M musculus",
		      'muhv4' => "Murine herpesvirus 68 strain WUMS",
		      'mycav' => "M avium",
		      'mycbo' => "M bovis AF2122/97",
		      'mycga' => "M gallisepticum",
		      'mycge' => "M genitalium",
		      'mycle' => "M leprae",
		      'mycms' => "M mycoides (subsp. mycoides SC)",
		      'mycpe' => "M penetrans",
		      'mycpn' => "M pneumoniae",
		      'mycpu' => "M pulmonis",
		      'myctu' => "M tuberculosis",
		      'niteu' => "N europaea",
		      'naneq' => "N equitans",
		      'neima' => "N meningitidis (serogroup A)",
		      'neimb' => "N meningitidis (serogroup B)",
		      'neime' => "N meningitidis",
		      'oceih' => "O iheyensis",
		      'onype' => "O yellows phytoplasma",
		      'paruw' => "P sp. (strain UWE25) (subsp. Acanthamoeba sp.)",
		      'pasmu' => "P multocida",
		      'peccc' => "P carotovorum",
		      'pholu' => "P luminescens",
		      'porgi' => "P gingivalis",
		      'proac' => "Propionibacterium acnes",
		      'promm' => "P marinus (strain MIT 9313)",
		      'promp' => "P marinus subsp. pastoris (strain CCMP 1378 / MED4)",
		      'pseae' => "P aeruginosa",
		      'psesm' => "P syringae",
		      'psepu' => "P putida",
		      'pyrab' => "P abyssi",
		      'pyrfu' => "P furiosus",
		      'pyrho' => "P horikoshii",
		      'ralso' => "R solanacearum",
		      'rat'   => "R norvegicus",
		      'rhilo' => "R loti",
		      'rhime' => "R meliloti",
		      'rhopa' => "R palustris",
		      'riccn' => "R conorii",
		      'ricpr' => "R prowazekii",
		      'salch' => "S cholerae-suis",
		      'salty' => "S typhimurium LT2",
		      'sheon' => "S oneidensis",
		      'staau' => "S aureus",
		      'staaw' => "S aureus (strain MW2)",
		      'staep' => "S epidermidis",
		      'shifl' => "S flexneri",
		      'strag' => "S agalactiae",
		      'straw' => "S avermitilis",
		      'strco' => "S coelicolor",
		      'strmu' => "S mutans",
		      'strpn' => "S pneumoniae",
		      'strpy' => "S pyogenes",
		      'sulso' => "S solfataricus",
		      'sulto' => "S tokodaii",
		      'synel' => "S elongatus",
		      'syny3' => "S PCC6803",
		      'theac' => "T acidophilum",
		      'thema' => "T maritima",
		      'thevo' => "T volcanium",
		      'trepa' => "T pallidum",
		      'ureur' => "U urealyticum",
		      'vibch' => "V cholerae",
		      'vibpa' => "V parahaemolyticus RIMD 2210633",
		      'wolsu' => "W succinogenes",
		      'schpo' => "S pombe",
		      'xanci' => "X campestris (pv. citri)",
		      'xylfa' => "X fastidiosa",
		      'yeast' => "S cerevisiae",
		      'yerpe' => "Y pestis",
		      'xanac' => "X axonopodis (pv. citri)",
		      'xancp' => "X campestris",
		      );


%name_latin = ( 'aciad' => "Acinetobacter sp (strain ADP1)",
		'achfl' => "Acholeplasma florum (Mesoplasma florum)",
		'aerpe' => "Aeropyrum pernix K1",
		'agrt5' => "Agrobacterium tumefaciens (strain C58 / ATCC 33970)",
		'agrtu' => "Agrobacterium tumefaciens",
		'aquae' => "Aquifex aeolicus",
		'arath' => "Arabidopsis thaliana",
		'arcfu' => "Achaeoglobus fulgidus",
		'bacaa' => "Bacillus anthracis (strain Ames)",
		'bacce' => "Bacillus cereus (ATCC 14579)",
		'baccr' => "Bacillus cereus (ATCC 14579 / DSM 31)",
		'bacfr' => "Bacteroides fragilis",
		'bachk' => "Bacillus thuringiensis (subsp. konkukian)",
		'bachd' => "Bacillus halodurans",
		'bacsu' => "Bacillus subtilis",
		'bactn' => "Bacteroides thetaiotaomicron VPI-5482",
		'barhe' => "Bartonella henselae (Houston-1)",
		'barqu' => "Bartonella quintana (Toulouse)",
		'bdeba' => "Bdellovibrio bacteriovorus",
		'biflo' => "Bifidobacterium longum",
		'borbr' => "Bordetella bronchiseptica RB50",
		'borpa' => "Bordetella parapertussis",
		'borpe' => "Bordetella pertussis",
		'borbu' => "Borrelia burgdorferi",
		'braja' => "Bradyrhizobium japonicum",
		'brume' => "Brucella melitensis",
		'bucai' => "Buchnera aphidicola (subsp. Acyrthosiphon pisum)",
		'bucap' => "Buchnera aphidicola (subsp. Schizaphis graminum)",
		'bucbp' => "Buchnera aphidicola (subsp. Baizongia pistaciae)",
		'caeel' => "Caenorhabditis elegans",
		'camje' => "Campylobacter jejuni",
		'canbf' => "Candidatus Blochmannia floridanus",
		'caucr' => "Caulobacter crescentus",
		'chick' => "Gallus gallus",
		'chlcv' => "Chlamydophila caviae",
		'chlmu' => "Chlamydia muridarum",
		'chlpn' => "Chlamydia pneumoniae",
		'chlte' => "Chlorobium tepidum",
		'chltr'	=> "Chlamydia trachomatis",
		'chrvo'	=> "Chromobacterium violaceum ATCC 12472",
		'cloab' => "Clostridium acetobutylicum",
		'clope' => "Clostridium perfringens",
		'clote' => "Clostridium tetani",
		'cordi' => "Corynebacterium diphtheriae NCTC 13129",
		'coref' => "Corynebacterium efficiens",
		'corgl' => "Corynebacterium glutamicum",
		'coxbu' => "Coxiella burnetii",
		'deira' => "Deinococcus radiodurans",
		'desvh' => "Desulfovibrio vulgaris subsp. vulgaris str. Hildenborough",
		'drome' => "Drosophila melanogaster",
		'ecoli' => "Escherichia coli",
		'enccu' => "Encephalitozoon cuniculi",
		'entfa' => "Enterococcus faecalis",
		'erwca' => "Erwinia carotovora",
		'erwct' => "Erwinia carotovora subsp. atroseptica SCRI1043",
		'fusnu' => "Fusobacterium nucleatum",
		'geosu' => "Geobacter  sulfurreducens",
		'glovi' => "Gloeobacter violaceus",
		'haedu' => "Haemophilus ducreyi",
		'haein' => "Haemophilus influenzae",
		'halma' => "Haloarcula marismortui",
		'haln1' => "Halobacterium sp. (strain NRC-1)",
		'hcmva' => "Human cytomegalovirus (strain AD169)",
		'helhe' => "Helicobacter heilmannii",
		'helpy' => "Helicobacter pylori",
		'human' => "Homo sapiens",
		'lacjo' => "Lactobacillus johnsonii",
		'lacla' => "Lactococcus lactis (subsp. lactis)",
		'lacpl' => "Lactobacillus plantarum WCFS1",
		'legph' => "Legionella pneumophila subsp. pneumophila (strain Philadelphi 1 / ATCC 33152)",
		'legpn' => "Legionella pneumophila",
		'leixx' => "Leifsonia xyli (subsp. xyli)",
		'lepic' => "Leptospira interrogans (serogroup Icterohaemorrhagiae / serovar Copenhageni)",
		'lepin' => "Leptospira interrogans",
		'lisin' => "Listeria innocua",
		'lismo' => "Listeria monocytogenes",
		'metac' => "Methanosarcina acetivorans",
		'metja' => "Methanococcus jannaschii",
		'metka' => "Methanopyrus kandleri",
		'metma' => "Methanosarcina mazei",
		'metmp' => "Methanococcus maripaludis",
		'metth' => "Methanobacterium thermoautotrophicum",
		'mettm' => "Methanobacterium thermoautotrophicum (strain Marburg / DSM 2133)",
		'mouse' => "Mus musculus",
		'muhv4' => "Murine herpesvirus 68 strain WUMS",
		'mycav' => "Mycobacterium avium",
		'mycbo' => "Mycobacterium bovis AF2122/97",
		'mycga' => "Mycoplasma gallisepticum",
		'mycge' => "Mycoplasma genitalium",
		'mycle' => "Mycobacterium leprae",
		'mycms' => "Mycoplasma mycoides (subsp. mycoides SC)",
		'mycpe' => "Mycoplasma penetrans",
		'mycpn' => "Mycoplasma pneumoniae",
		'mycpu' => "Mycoplasma pulmonis",
		'myctu' => "Mycobacterium tuberculosis",
		'naneq' => "Nanoarchaeum equitans",
		'neima' => "Neisseria meningitidis (serogroup A)",
		'neimb' => "Neisseria meningitidis (serogroup B)",
		'neime' => "Neisseria meningitidis",
		'niteu' => "Nitrosomonas europaea",
		'oceih' => "Oceanobacillus iheyensis",
		'onype' => "Onion yellows phytoplasma",
		'paruw' => "Parachlamydia sp. (strain UWE25) (subsp. Acanthamoeba sp.)",
		'pasmu' => "Pasteurella multocida",
		'peccc' => "Pectobacterium carotovorum",
		'pholu' => "Photorhabdus luminescens",
		'porgi' => "Porphyromonas gingivalis",
		'proac' => "Propionibacterium acnes",
		'promm' => "Prochlorococcus marinus (strain MIT 9313)",
		'promp' => "Prochlorococcus marinus subsp. pastoris (strain CCMP 1378 / MED4)",
		'pseae' => "Pseudomonas aeruginosa",
		'psepk' => "Pseudomonas putida KT2440",
		'psesm' => "Pseudomonas syringae (pv. tomato)",
		'psepu' => "Pseudomonas putida",
		'pyrab' => "Pyrococcus abyssi",
		'pyrfu' => "Pyrococcus furiosus",
		'pyrho' => "Pyrococcus horikoshii",
		'ralso' => "Ralstonia solanacearum",
		'rat'   => "Rattus norvegicus",
		'rhime' => "Rhizobium meliloti",
		'rhopa' => "Rhodopseudomonas palustris",
		'riccn' => "Rickettsia conorii",
		'ricpr' => "Rickettsia prowazekii",
		'rhilo' => "Rhizobium loti",
		'salch' => "Salmonella cholerae-suis",
		'salet' => "Salmonella enterica subsp. enterica serovar Paratyphi A str. ATCC 9150",
		'salty' => "Salmonella typhimurium LT2",
		'schpo' => "Schizosaccharomyces pombe",
		'sheon' => "Shewanella oneidensis",
		'staep' => "Staphylococcus epidermidis",
		'staes' => "Staphylococcus epidermidis ATCC 12228",
		'staau' => "Staphylococcus aureus",
		'staaw' => "Staphylococcus aureus (strain MW2)",
		'shifl' => "Shigella flexneri",
		'strag' => "Streptococcus agalactiae",
		'stra5' => "Streptococcus agalactiae 2603V/R",
		'straw' => "Streptomyces avermitilis",
		'strco' => "Streptococcus agalactiae",
		'strco' => "Streptomyces coelicolor",
		'strmu' => "Streptococcus mutans",
		'strp8' => "Streptococcus pyogenes MGAS8232",
		'strpn' => "Streptococcus pneumoniae",
		'strpy' => "Streptococcus pyogenes",
		'sulso' => "Sulfolobus solfataricus",
		'sulto' => "Sulfolobus tokodaii",
		'synel' => "Synechococcus elongatus",
		'syny3' => "Synechocystis PCC6803",
		'theac' => "Thermoplasma acidophilum",
		'thema' => "Thermotoga maritima",
		'thet2' => "Thermus thermophilus HB27",
		'thevo' => "Thermoplasma volcanium",
		'trepa' => "Treponema pallidum",
		'urepa' => "Ureaplasma parvum serovar 3 str. ATCC 700970",
		'ureur' => "Ureaplasma urealyticum",
		'vibch' => "Vibrio cholerae",
		'vibpa' => "Vibrio parahaemolyticus RIMD 2210633",
		'wolsu' => "Wolinella succinogenes",
		'xanac' => "Xanthomonas axonopodis (pv. citri)",
		'xanci' => "Xanthomonas campestris (pv. citri)",
		'xancp' => "Xanthomonas campestris",
		'xylfa' => "Xylella fastidiosa",
		'yeast' => "Saccharomyces cerevisiae",
		'yerpe' => "Yersinia pestis",
		'colp3' => 'Colwellia psychrerythraea 34H',
                'corgl' => 'Corynebacterium glutamicum ATCC 13032',
                'geome' => 'Geobacter metallireducens GS-15',
                'halma' => 'Haloarcula marismortui ATCC 43049',
                'lacjo' => 'Lactobacillus johnsonii NCC 533',
                'lisin' => 'Listeria innocua',
                'metca' => 'Methylococcus capsulatus str. Bath',
                'neig1' => 'Neisseria gonorrhoeae FA 1090',
                'anasp' => 'Nostoc sp. PCC 7120; Anabaena sp. (strain PCC 7120)',
                'psef5' => 'Pseudomonas fluorescens Pf-5 / ATCC BAA-477',
                'proac' => 'Propionibacterium acnes KPA171202',
                'rhosh' => 'Rhodobacter sphaeroides 2.4.1',
                'silpo' => 'Silicibacter pomeroyi DSS-3',
                'stahj' => 'Staphylococcus haemolyticus JCSC1435',
                'stas1' => 'Staphylococcus saprophyticus subsp. saprophyticus ATCC 15305',
                'strt2' => 'Streptococcus thermophilus (strain ATCC BAA-250 / LMG 18311)',
                'vibf1' => 'Vibrio fischeri (strain ATCC 700601 / ES114)',
                'xanor' => 'Xanthomonas oryzae pv. oryzae KACC10331',
                '9sphi' => 'Salinibacter ruber DSM 13855',
                'halsa' => 'Halobacterium sp. NRC-1',
		);

%org2kingdom = 
    ('aerpe' => "Archae",
     'arcfu' => "Archae",
     'haln1' => "Archae",
     'metca' => "Archae",
     'metma' => "Archae",
     'metja' => "Archae",
     'metka' => "Archae",
     'metmp' => "Archae",
     'metth' => "Archae",
     'mettm' => "Archae",
     'naneq' => "Archae",
     'pyrab' => "Archae",
     'pyrfu' => "Archae",
     'pyrho' => "Archae",
     'sulso' => "Archae",	
     'sulto' => "Archae",
     'theac' => "Archae",
     'thevo' => "Archae",
     'aciad' => "Prokaryote",
     'achfl' => "Prokaryote",
     'agrt5' => "Prokaryote",
     'agrtu' => "Prokaryote",
     'aquae' => "Prokaryote",
     'bacaa' => "Prokaryote",
     'bacce' => "Prokaryote",
     'baccr' => "Prokaryote",
     'bacfr' => "Prokaryote",
     'bachd' => "Prokaryote",
     'bachk' => "Prokaryote",
     'bacsu' => "Prokaryote",
     'bactn' => "Prokaryote",
     'barhe' => "Prokaryote",
     'barqu' => "Prokaryote",
     'bdeba' => "Prokaryote",
     'biflo' => "Prokaryote",
     'borbr' => "Prokaryote",
     'borpa' => "Prokaryote",
     'borpe' => "Prokaryote",
     'borbu' => "Prokaryote",
     'braja' => "Prokaryote",
     'brume' => "Prokaryote",
     'bucai' => "Prokaryote",
     'bucap' => "Prokaryote",
     'bucbp' => "Prokaryote",
     'camje' => "Prokaryote",
     'canbf' => "Prokaryote",
     'caucr' => "Prokaryote",
     'chlcv' => "Prokaryote",
     'chlmu' => "Prokaryote",
     'chlpn' => "Prokaryote",
     'chlte' => "Prokaryote",
     'chltr' => "Prokaryote",
     'chrvo' => "Prokaryote",
     'cloab' => "Prokaryote",
     'clope' => "Prokaryote",
     'clote' => "Prokaryote",
     'cordi' => "Prokaryote",
     'coref' => "Prokaryote",
     'corgl' => "Prokaryote",
     'coxbu' => "Prokaryote",
     'deira' => "Prokaryote",
     'desvh' => "Prokaryote",
     'ecoli' => "Prokaryote",
     'entfa' => "Prokaryote",
     'erwca' => "Prokaryote",
     'fusnu' => "Prokaryote",
     'geosu' => "Prokaryote",
     'glovi' => "Prokaryote",
     'haedu' => "Prokaryote",
     'haein' => "Prokaryote",
     'halma' => "Prokaryote",
     'helhe' => "Prokaryote",
     'helpy' => "Prokaryote",
     'lacjo' => "Prokaryote",
     'lacla' => "Prokaryote",
     'lacpl' => "Prokaryote",
     'legpn' => "Prokaryote",
     'leixx' => "Prokaryote",
     'lepic' => "Prokaryote",
     'lepin' => "Prokaryote",
     'lisin' => "Prokaryote",
     'lismo' => "Prokaryote",
     'mycav' => "Prokaryote",
     'mycbo' => "Prokaryote",
     'mycga' => "Prokaryote",
     'mycge' => "Prokaryote",
     'mycle' => "Prokaryote",
     'mycms' => "Prokaryote",
     'mycpe' => "Prokaryote",
     'mycpn' => "Prokaryote",
     'mycpu' => "Prokaryote",
     'myctu' => "Prokaryote",
     'niteu' => "Prokaryote",
     'neima' => "Prokaryote",
     'neimb' => "Prokaryote",
     'neime' => "Prokaryote",
     'oceih' => "Prokaryote",
     'onype' => "Prokaryote",
     'paruw' => "Prokaryote",
     'pasmu' => "Prokaryote",
     'peccc' => "Prokaryote",
     'pholu' => "Prokaryote",
     'porgi' => "Prokaryote",
     'proac' => "Prokaryote",
     'promm' => "Prokaryote",
     'promp' => "Prokaryote",
     'pseae' => "Prokaryote",
     'psepu' => "Prokaryote",
     'psesm' => "Prokaryote",
     'ralso' => "Prokaryote",
     'rhopa' => "Prokaryote",
     'riccn' => "Prokaryote",
     'ricpr' => "Prokaryote",
     'rhilo' => "Prokaryote",
     'shifl' => "Prokaryote",
     'salch' => "Prokaryote",
     'salty' => "Prokaryote",
     'sheon' => "Prokaryote",
     'staep' => "Prokaryote",
     'staau' => "Prokaryote",
     'strag' => "Prokaryote",
     'straw' => "Prokaryote",
     'strco' => "Prokaryote",
     'strmu' => "Prokaryote",
     'strpn' => "Prokaryote",
     'strpy' => "Prokaryote",
     'synel' => "Prokaryote",
     'syny3' => "Prokaryote",
     'thema' => "Prokaryote",
     'trepa' => "Prokaryote",
     'ureur' => "Prokaryote",	
     'vibch' => "Prokaryote",	
     'vibpa' => "Prokaryote",	
     'wolsu' => "Prokaryote",	
     'xanac' => "Prokaryote",
     'xanci' => "Prokaryote",	
     'xancp' => "Prokaryote",
     'xylfa' => "Prokaryote",
     'yerpe' => "Prokaryote",
     'arath' => "Eukaryote",
     'caeel' => "Eukaryote",
     'chick' => "Eukaryote",
     'drome' => "Eukaryote",
     'enccu' => "Eukaryote",
     'yeast' => "Eukaryote",
     'mouse' => "Eukaryote",
     'human' => "Eukaryote",
     'rat'   => "Eukaryote",
     'schpo' => "Eukaryote",	
     'hcmva' => "virus",
     'muhv4' => "virus");

%genus2class = (
	"achaeoglobus" => "archae",
	"acholeplasma" => "gram+",
	"acinetobacter" => "gram-",
	"aeropyrum" => "archae",
	"agrobacterium" => "gram-",
	"aquifex" => "gram-",
	"arabidopsis" => "euk",
	"archaeglobus" => "archae",
	"bacillus" => "gram+",
	"bacteroides" => "gram-",
	"bartonella" => "gram-",
	"bdellovibrio" => "gram-",
	"bifidobacterium" => "gram-",
	"bordetella" => "gram-",
	"borrelia" => "gram-",
	"bos" => "euk",
	"bradyrhizobium" => "gram-",
	"brucella" => "gram-",
	"buchnera" => "gram-",
	"caenorhabditis" => "euk",
	"campylobacter" => "gram-",
	"candidatus" => "gram-",
	"caulobacter" => "gram-",
	"chlamydia" => "gram-",
	"chlamydophila" => "gram-",
	"chlorobium" => "gram-",
	"chromobacterium" => "gram-",
	"clostridium" => "gram+",
	"colwellia" => "gram-",
	"corynebacterium" => "gram-",
	"coxiella" => "gram-",
	"deinococcus" => "gram-",
	"desulfovibrio" => "gram-",
	"drosophila" => "euka",
	"encephalitozoon" => "euk",
	"enterococcus" => "gram+",
	"erwinia" => "gram-",
	"escherichia" => "gram-",
	"fusobacterium" => "gram-",
        "gallus" => "euk",
	"geobacter" => "gram-",
	"gloeobacter" => "gram-",
	"haemophilus" => "gram-",
	"halobacterium" => "archae",
	"helicobacter" => "gram-",
	"homo" => "euk",
	"human" => "virus",
	"lactobacillus" => "gram+",
	"lactococcus" => "gram+",
	"legionella" => "gram-",
	"leifsonia" => "gram-",
	"leptospira" => "gram-",
	"listeria" => "gram+",
	"mesorhizobium" => "gram-",
	"methanobacterium" => "archae",
	"methanococcus" => "archae",
	"methanopyrus" => "archae",
	"methanosarcina" => "archae",
	"mus" => "euk",
	"mycobacterium" => "gram+",
	"mycoplasma" => "gram+",
	"neisseria" => "gram-",
	"nitrosomonas" => "gram-",
	"oceanobacillus" => "gram+",
	"pasteurella" => "gram-",
	"photorhabdus" => "gram-",
	"porphyromonas" => "gram-",
        "propionibacterium" => "gram+",
	"pseudomonas" => "gram-",
	"pyrococcus" => "archae",
	"ralstonia" => "gram-",
	"rattus" => "euka",
	"rhizobium" => "gram-",
	"rhodopseudomonas" => "gram-",
	"rickettsia" => "gram-",
	"saccharomyces" => "euk",
	"salinibacter" => "gram-",
	"salmonella" => "gram-",
	"schizosaccharomyces" => "euk",
	"shewanella" => "gram-",
        "shigella" => "gram-",
        "silicibacter" => "gram-",
	"staphylococcus" => "gram+",
	"streptococcus" => "gram+",
	"streptomyces" => "gram-",
	"sulfolobus" => "archae",
	"synechococcus" => "gram-",
	"synechocystis" => "gram-",
	"thermoplasma" => "archae",
	"thermotoga" => "gram-",
	"thermosynechococcus" => "gram-",
        "thermus" => "gram-",
	"treponema" => "gram-",
	"ureaplasma" => "gram+",
	"vibrio" => "gram-",
	"wolinella" => "gram-",
	"xanthomonas" => "gram-",
	"xylella" => "gram-",
	"yersinia" => "gram-",
		);


@euclidClasses14 = (
		    'Amino acid biosynthesis',
		    'Biosynthesis of cofactors, prosthetic groups, and carriers',
		    'Cell envelope','Cellular processes',
		    'Central intermediary metabolism','Energy metabolism',
		    'Fatty acid and phospholipid metabolism','Other categories',
		    'Purines, pyrimidines, nucleosides, and nucleotides','Regulatory functions',
		    'Replication','Transcription','Translation',
		    'Transport and binding proteins',
		    'Unclassified');

@euclidClasses3 = ( 'Energy', 'Communication','Information',
		'Other categories','Unclassified');

@energyClass = ( 'Amino acid biosynthesis',
		 'Biosynthesis of cofactors, prosthetic groups, and carriers',
		 'Central intermediary metabolism','Energy metabolism',
		 'Energy metabolism',
		 'Fatty acid and phospholipid metabolism',
		 'Purines, pyrimidines, nucleosides, and nucleotides',
		 'Transport and binding proteins');
@infoClass = ( 'Replication','Transcription','Translation');
@commClass = ( 'Cell envelope','Cellular processes','Regulatory functions');



%aa3to1 = 
    ( 'Ala' => 'A',
      'Arg' => 'R',
      'Asn' => 'N',
      'Asp' => 'D',
      'Cys' => 'C',
      'Gln' => 'Q',
      'Glu' => 'E',
      'Gly' => 'G',
      'His' => 'H',
      'Ile' => 'I',
      'Leu' => 'L',
      'Lys' => 'K',
      'Met' => 'M',
      'Phe' => 'F',
      'Pro' => 'P',
      'Ser' => 'S',
      'Thr' => 'T',
      'Trp' => 'W',
      'Tyr' => 'Y',
      'Val' => 'V',
      );


%aa2mw = 
    ( 'A' => 89.09,
      'C' => 121.15,
      'D' => 133.10,
      'E' => 147.13,
      'F' => 165.19,
      'G' => 75.07,
      'H' => 155.16,
      'I' => 131.17,
      'K' => 146.19,
      'L' => 131.17,
      'M' => 149.21,
      'N' => 132.12,
      'P' => 115.13,
      'Q' => 146.15,
      'R' => 174.20,
      'S' => 105.09,
      'T' => 119.12,
      'V' => 117.15,
      'W' => 204.23,
      'Y' => 181.19
      );



#=========================================================
# Vihinen's flexibility index
#
# Normalized flexibility parameters (B-values), average (Vihinen et al., 1994)
# A Vihinen, M., Torkkila, E. and Riikonen, P.
# Accuracy of protein flexibility predictions
# Proteins 19, 141-149 (1994)
#I    A/L     R/K     N/M     D/F     C/P     Q/S     E/T     G/W     H/Y     I/V
#   0.984   1.008   1.048   1.068   0.906   1.037   1.094   1.031   0.950   0.927
#   0.935   1.102   0.952   0.915   1.049   1.046   0.997   0.904   0.929   0.931
%aa2flex =
    ( 'A' => 40,
      'C' => 1,
      'D' => 82,
      'E' => 95,
      'F' => 5,
      'G' => 64,
      'H' => 23,
      'I' => 11,
      'K' => 100,
      'L' => 15,
      'M' => 24,
      'N' => 72,
      'P' => 73,
      'Q' => 67,
      'R' => 52,
      'S' => 71,
      'T' => 46,
      'V' => 13,
      'W' => 0,
      'X' => 50,		# modified unknown aa
      'Y' => 12
      );

%aa_pdb = 
    ('A' => 7.81,
     'C' => 2.23,
     'D' => 5.73,
     'E' => 6.62,
     'F' => 3.87,
     'G' => 7.58,
     'H' => 2.25,
     'I' => 5.31,
     'K' => 6.73,
     'L' => 8.32,
     'M' => 2.11,
     'N' => 4.48,
     'P' => 4.53,
     'Q' => 3.89,
     'R' => 4.89,
     'S' => 6.15,
     'T' => 5.82,
     'V' => 6.75,
     'W' => 1.44,
     'Y' => 3.52
     );


sub aaCompFromList {
#======================================================
# take a fasta list file as input and spit out the aa compostion
# for all the sequences in the list
#=======================================================
    my ( $fileList ) = @_;
    my %aa = ();
    my $errMsg = "";


    my ( @letters, $aa, %isAA, @tmp, $ctTotal );
    if ( ! -e $fileList ) {
	$errMsg .=  "file list $fileList not found, exiting..\n";
	return ({%aa}, 0, $errMsg);
    }

    @letters = qw( A C D E F G H I K L M N P Q R S T V W Y );
    foreach $aa ( @letters ) {
	$isAA{$aa} = 1;
    }


    $ctTotal = 0;
    open (LIST, $fileList) or die "cannot open $fileList:$!";
    while (<LIST>) {
	next if ( /^\s*\>/ );
	s/\s+//g;
	@tmp = split //;
	foreach $aa ( @tmp ) {
	    next if ( ! $isAA{$aa} );
	    $aa{$aa}{'ct'}++;
	    $ctTotal++;
	}
    }
    close LIST;
    
    

    foreach $aa ( @letters ) {
	$aa{$aa}{'freq'} = $aa{$aa}{'ct'}/$ctTotal*100;
    }


    return ( {%aa}, 1, "ok" );
}


sub calcMW {
    my ( $seqRef ) = @_;
    my ( @seq, $seqLen, $mw, $aa );
    
    @seq = split //, uc($$seqRef);
    $seqLen = 0;
    $mw = 0;
    foreach $aa ( @seq ) {
	if ( ! defined $aa2mw{$aa} ) {
	    print STDERR "MW for aa $aa not found, skip..\n";
	    next;
	}
	$seqLen++;
	$mw += $aa2mw{$aa};
    }
				# substract the peptide bond water
    $mw = $mw - 18.015 * ( $seqLen - 1 );
    #$mw = $mw/1000;		# use kDa as unit
    return $mw;
}

#========================================================
sub get_seq_info {
    my ($fileFasta) = @_;
    my ( $id,$seq,$seqLen );
    my ( $nameSub, $fhSeq_sub );
#--------------------------------------------------------

    $nameSub = 'get_seq_info';
    $fhSeq_sub = $nameSub."_SEQ";

    $seq = "";
    open ($fhSeq_sub,$fileFasta) or die "cannot open $fileFasta:$!";
    while (<$fhSeq_sub>) {
	chomp;
	if ( /^\s*\>/ ) {
	    $id = $_;
	    $id =~ s/^\s*\>\s*//g;
	    $id =~ s/\s+.*//g;
	    if ( $id =~ /\bgi\|(\d+)\|/i ) { # if we have a GI number
                $id = $1;
	    } elsif ( $id =~ /\|(\w+)$/ ) {
		$id =~ s/.*\|//g;
	    } else {		# we just take the file name
		$id = $fileFasta;
		$id =~ s/.*\///g;
		$id =~ s/\..*//g;
	    }
	    next;
	} 
	$seq .= $_;
    }
    close $fhSeq_sub;
    $seq =~ s/\s+//g;
    $seqLen = length $seq;
    return ($id,$seqLen,$seq);
}				# END of SUB get_seq_info

	
sub getIdList {
    my $sbr = "getIdList";
    my ( $fileList, $keep_suffix ) = @_;
    my ( $fhList,$id );

    return () if ( ! -f $fileList );
    my $idList = [ ];

    $fhList = "LIST_$sbr";
    open ( $fhList, $fileList) or die "cannot open $fileList:$!";
    while (<$fhList>) {
	next if ( $_ !~ /\w+/ );
        next if ( /^\#/ );
	chomp($id=$_);
	$id =~ s/^\s+//g;
        $id =~ s/\s+.*//g;
	$id =~ s/\..*//g if ( ! $keep_suffix ) ;
	push @$idList, $id if ( $id ne '' );
    }
    close $fhList;
    return $idList;
}

sub getSeq {
    my $sbr = "getSeq";
    my ( $fileSeq ) = @_;
    my ($seq,$fhSeq);
   
    return "" if ( ! -f $fileSeq );
    $seq = "";
    $fhSeq = "SEQ_$sbr";
    open ($fhSeq,$fileSeq) or die "cannot open $fileSeq:$!";
    while (<$fhSeq>) {
	next if ( /^\s*\>/ );
	s/\W+//g;
	$seq .= $_;
    }
    close $fhSeq;
    return $seq;
}

sub pep2hash {
    my $sbr = "pep2hash";
    my ($filePep,$listId,$listField) = @_;
    my (%data,$id,%id2list,$field,%field2list,$fhPep);
    my ($toRead,$value);


    return undef if ( ! -f $filePep );
    
    undef %data;
    if ( $listId ne 'ALL' ) {
	foreach $id ( @$listId ) {
	    $id2list{$id} = 1;
	}
    }

    if ( $listField ne 'ALL' ) {
	foreach $field ( @$listField ) {
	    $field2list{$field} = 1;
	}
    }

    $fhPep = "PEP_$sbr";
    open ($fhPep,$filePep) or die "cannot open $filePep:$!";
    $toRead = 0;
    while (<$fhPep>) {
	chomp;
	if ( /^\>/ ) {
	    $id = $_;
	    $id =~ s/^\>//;
	    $id =~ s/\s+.*//g;
	    $toRead = ( $listId eq 'ALL' or $id2list{$id} );
	    next;
	}
	if ( /^\/\// ) {
	    $toRead = 0;
	    next;
	}
	    
	next if ( ! $toRead );
	($field,$value) = split /\t+/,$_,2;
	next if ( $listField ne 'ALL' and ! $field2list{$field} );
	if ( $field eq 'SEQ' ) {
	    $value = <$fhPep>;
	    $value =~ s/\W+//g;
	}
	#print "xx id=$id,field=$field\n";
	$data{$id}{$field} = $value;
    }
    close $fhPep;

    return {%data};
}


sub getPepEntry {
    my $sbr = "getPepEntry";
    my ( $org,$id,$type,$dirGenome) = @_;
    my ($dirOrg,$dirSrs,$fileSrs,$fhSrs,$entry);

    $dirGenome = '/data/genome/' if ( ! $dirGenome );
    $dirOrg = $dirGenome.$org.'/';
    $dirSrs = $dirOrg.'srs/'.substr($id,-1,1).'/';
    $fileSrs = $dirSrs.$id.'/'.$id.".$type";

    #print STDERR "$fileSrs\n";
    if ( ! -f $fileSrs ) {
	return undef;
    }

    $entry = "";
    $fhSrs = "SRS_$sbr";
    open ($fhSrs,$fileSrs) or die "cannot open $fileSrs:$!";
    while (<$fhSrs>) {
	$entry .= $_;
    }
    close $fhSrs;
    $entry =~ s/\n+$//g;
    return $entry;
}


sub getPepEntry_md5 {
    my $sbr = "getPepEntry";
    my ( $id,$type,$dirGenome) = @_;
    my ( $dirSrs,$fileSrs,$fhSrs,$entry);

    $dirGenome = '/data/genome/md5/' if ( ! $dirGenome );
    $dirSrs = $dirGenome.substr($id,0,3).'/'.$id.'/srs/';
    $fileSrs = $dirSrs.$id.".$type";

    #print STDERR "$fileSrs\n";
    if ( ! -f $fileSrs ) {
	return undef;
    }

    $entry = "";
    $fhSrs = "SRS_$sbr";
    open ($fhSrs,$fileSrs) or die "cannot open $fileSrs:$!";
    while (<$fhSrs>) {
	$entry .= $_;
    }
    close $fhSrs;
    $entry =~ s/\n+$//g;
    return $entry;
}

    
sub regionOverlap {
				# check how much of reg2 is covered by reg1
    my ( $beg1,$end1,$beg2,$end2) = @_;
    my ( $len1,$len2,$i,@seq,$ctOverlap,$overlap1,$overlap2,$min,$max );

    $len2 = $end2-$beg2+1;
    $len1 = $end1-$beg1+1;

    return undef if ( $len2 < 2 or $len1 < 2 );

    if ( $beg1 < $beg2 ) {
	$min = $beg1;
    } else {
	$min = $beg2;
    }
    if ( $end1 > $end2 ) {
	$max = $end1;
    } else {
	$max = $end2;
    }


    for $i ( $beg1..$end1 ) {
	$seq[$i]++;
    }
    for $i ( $beg2..$end2 ) {
	$seq[$i]++;
    }
    
    $ctOverlap = 0;
    for $i ( $min..$max ) {
	$ctOverlap++ if ( $seq[$i] && $seq[$i] == 2 );
    }
    $overlap1 = $ctOverlap/$len1;
    $overlap2 = $ctOverlap/$len2;

    #print "xx $beg1,$end1,$beg2,$end2,$overlap1,$overlap2\n";
    return ($overlap1,$overlap2);
}


sub getOverlap {
    my ( $reg1,$reg2 ) = @_;
    my ( @array,$beg1,$beg2,$beg,$end1,$end2,$end );
    ($beg1,$end1) = split /-/,$reg1;
    ($beg2,$end2) = split /-/,$reg2;
    if ( $beg1 > $beg2 ) {
	$beg = $beg1;
    } else {
	$beg = $beg2;
    }

    if ( $end1 > $end2 ) {
	$end = $end2;
    } else {
	$end = $end1;
    }
    
    if ( $end - $beg > 0 ) {
	return "$beg-$end";
    } else {
	return "";
    }
}


sub getIdHash {
    my $sbr = "getIdHash";
    my ( $fileList ) = @_;
    my ( $fhList,$id,%idHash );

    return () if ( ! -f $fileList );
    $fhList = "LIST_$sbr";
    open ( $fhList, $fileList) or die "cannot open $fileList:$!";
    while (<$fhList>) {
	next if ( $_ !~ /\w+/ );
        next if ( /^\#/ );
	chomp($id=$_);
	$id =~ s/^\s+//g;
        $id =~ s/\s+.*//g;
	$id =~ s/\..*//g;
	$idHash{$id} = 1 if( $id );
    }
    close $fhList;
    return %idHash;
}

1;









