=pod

=head1 NAME

RG::Liu::LibHmmer - Perl modules by J. Liu

=head1 SYNOPSIS

use RG::Liu::LibHmmer;

=head1 FUNCTIONS

See module source for description.

=over

=item hmmSymbol2bool

=item isHmmer

=item parseHmmer

=back

=head1 VARIABLES

=over

=back

=head1 AUTHOR

J. Liu

=head1 SEE ALSO

=over

=item Main website

L<https://rostlab.informatik.tu-muenchen.de/wiki/index.php/Slashdata:cubicmanpages>

=back

=cut

package      RG::Liu::LibHmmer;
require      Exporter;
@ISA       = qw(Exporter);
@EXPORT    = qw(isHmmer);
@EXPORT_OK = qw(parseHmmer);

#use strict;

#=================================================================
# subroutines to parse HMMER output
#=================================================================

sub isHmmer {
    my ( $fileIn ) = @_;
    return 0 if ( ! -f $fileIn );
    my ( $foundHmm, $foundEnd );
    $foundHmm = $foundEnd = 0;
    
    my $fh;

    open ($fh, $fileIn) or die "cannot open $fileIn:$!";

    while (<$fh>) {
        $foundHmm = 1 if ( /^HMMER/ );
        $foundEnd = 1 if ( /^\/\// );
    }
    close $fh;
    return ( $foundHmm and $foundEnd );
}


sub parseHmmer {
    my ( $fileHmm ) = @_;
    return undef if ( ! -e $fileHmm );

    local ($model,$seq_f,$seq_t,$seq_isBegin,$seq_isEnd);
    local ($hmm_f,$hmm_t,$hmm_isBegin,$hmm_isEnd,$score,$expect);
    my (@hmmFields,$f,%theHmm,@hmms,@tmp);

    undef %theHmm;
    undef @hmms;

    @hmmFields = ( 'model','seq_f','seq_t','seq_isBegin','seq_isEnd',
		   'hmm_f','hmm_t','hmm_isBegin','hmm_isEnd','score',
		   'expect' );

    my $fh = \*HMM_parseHmmer;
    open ($fh,$fileHmm) or die "cannot open $fileHmm:$!";
    while (<$fh>) {
	next if ( $_ !~ /^Parsed for domains/ );
	last;
    }
    while (<$fh>) {
	last if ( /^Alignments/ );
	next if ( /^(Model|Sequence)\s+/);
	next if ( /^------/ );
	next if ( $_ !~ /\w+/ );
	last if ( /^\s*\[no hits above thresholds\]/ );
	chomp;
	
	#print $_."\n";
	s/^\s+|\s+$//g;
	@tmp = split /\s+/;
	($model,$seq_f,$seq_t,$hmm_f,$hmm_t,$score,$expect) 
	    = @tmp[0,2,3,5,6,8,9];
	
	
	$seq_isBegin = &hmmSymbol2bool(substr($tmp[4],0,1));
	$seq_isEnd = &hmmSymbol2bool(substr($tmp[4],1,1));
	
	$hmm_isBegin = &hmmSymbol2bool(substr($tmp[7],0,1));
	$hmm_isEnd = &hmmSymbol2bool(substr($tmp[7],1,1));
	
	
	foreach $f ( @hmmFields ) {
	    #print "xx field=$f\n";
	    #print "xx model=$model\n";
	    #print "xx $$f\n";
	    if ( ! defined $$f ) {
		print "xx $f not defined\n";
		die;
	    }
	    $theHmm{$f} = $$f;
	    #next if ( $f eq 'model' and $$f !~ /^PF/);
	    $theHmm{$f} =~ s/\s+//g;
	}
	push @hmms, {%theHmm};
    }
    close $fh;
    if ( @hmms ) {
	return [@hmms];
    } else {
	return undef;
    }
}

sub hmmSymbol2bool {
    my ( $sym ) = @_;
    if ( $sym eq '.' ) {
	return 0;
    } elsif ( $sym eq ']' or $sym eq '[' ) {
	return 1;
    } else {
	die "'$sym' is not a valid HMM symbol, should be either [] or .\n";
    }
}
 
1;
