=pod

=head1 NAME

RG::Liu::LibList - Perl modules by J. Liu

=head1 SYNOPSIS

use RG::Liu::LibList;

=head1 FUNCTIONS

See module source for description.

=over

=item intersection

=item listDiff

=item max

=item mean

=item median

=item min

=item pearson_correlation

=item random_permute

=item sse

=item sum

=item sum_square

=item union

=item uniqueList

=back

=head1 VARIABLES

=over

=back

=head1 AUTHOR

J. Liu

=head1 SEE ALSO

=over

=item Main website

L<https://rostlab.informatik.tu-muenchen.de/wiki/index.php/Slashdata:cubicmanpages>

=back

=cut

package      RG::Liu::LibList;
require      Exporter;
@ISA       = qw(Exporter);
@EXPORT    = qw(min max uniqueList);
@EXPORT_OK = qw(listDiff intersection mean median sse sum sum_square 
		union pearson_correlation random_permute );
#================================================================
# libraries of some list opearation
# listDiff() return the difference of two lists
# min()
# max()
# intersection()
# union()
# uniqueList()
# sum()
# mean()
# sse()  sum of squared error
# median() 
# pearson_correlation(list1,list2)
#=================================================================

use strict;


sub listDiff {
    my ( $aRef, $bRef ) = @_;
    my @aOnly = ();
    my @bOnly = ();
    my %aSeen = ();
    my %bSeen = ();
    my $item;

    foreach $item ( @$aRef ) {
	$aSeen{$item} = 1;
    }
    foreach $item ( @$bRef ) {
	$bSeen{$item} = 1;
    }

    foreach $item ( @$aRef ) {
	push @aOnly, $item if ( ! $bSeen{$item} );
    }
    foreach $item ( @$bRef ) {
	push @bOnly, $item if ( ! $aSeen{$item} );
    }
    return ([@aOnly], [@bOnly]);
}
    


sub intersection {
    my @lists = @_;
    my ( @uniqueLists, $list,$ctList,$listUnion,$item, %ct,@isect);

    $ctList = scalar ( @lists );
    return  if ( $ctList == 0 );
    
				# first get unique lists
    foreach $list ( @lists ) {
	push @uniqueLists, &uniqueList($list); 
    }
    return  $uniqueLists[0]  if ( $ctList == 1 );
    
    %ct = ();
    @isect = ();
				# count the occurence of items
    foreach $list ( @uniqueLists ) {
	foreach $item ( @$list ) {
	    $ct{$item}++;
	}
    }

    $listUnion = &union(@uniqueLists);
    foreach $item ( @$listUnion ) {
	next if ( ! defined $ct{$item} );
				# check the occurence of the item against 
				# the number of lists
	if ( $ct{$item} == $ctList ) {
	    push @isect, $item;
	}
    }
    return [@isect];
}


	    
sub max {
    my ( $listRef )  = @_;
    my ( $item );
    return if ( ! @$listRef );
    my $max = $listRef->[0];
    foreach $item ( @$listRef ) {
	$max = $item if ( $item > $max );
    }

    return $max;
}


sub mean {
    my ( $listRef ) = @_;
    my ( $item );
    return if ( ! @$listRef );

    my $ctItem = scalar ( @$listRef );
    my $sum = &sum($listRef);
    return $sum/$ctItem;
}

sub median {
    my ( $listRef ) = @_;
    my ( $list_sorted,$ct,$median,$m1,$m2);

    @$list_sorted = sort { $a <=> $b } @$listRef;
    $ct = scalar @$listRef;
    if ( $ct % 2 == 1 ) {
	$median = $list_sorted->[($ct+1)/2-1];
    } else {
	$m1 = $list_sorted->[$ct/2-1];
	$m2 = $list_sorted->[$ct/2];
	$median = ($m1+$m2)/2;
    }

    return $median;
}

sub min {
    my ( $listRef )  = @_;
    my ( $item );
    return if ( ! @$listRef );
    my $min = $listRef->[0];
    foreach $item ( @$listRef ) {
	$min = $item if ( $item < $min );
    }

    return $min;
}


sub pearson_correlation {
    my ( $list_ref1,$list_ref2 ) = @_;
    my ( $sum_x,$sum_y,$sum_x2,$sum_y2,$n,$sum_xy,$r,$i );
   
    if ( scalar(@$list_ref1) != scalar(@$list_ref2) ) {
	return undef;
    }
    
    $sum_x = &sum($list_ref1);
    $sum_y = &sum($list_ref2);

    $sum_x2 = &sum_square($list_ref1);
    $sum_y2 = &sum_square($list_ref2);
    
    $n = scalar(@$list_ref1);

    $sum_xy = 0;
    for $i ( 0..$n-1 ) {
	$sum_xy += $list_ref1->[$i] * $list_ref2->[$i];
    }

    $r = ($sum_xy - $sum_x*$sum_y/$n)/
	sqrt(($sum_x2-$sum_x*$sum_x/$n)*($sum_y2-$sum_y*$sum_y/$n));
    return $r;
}

sub random_permute {
    				# fisher_yates_shuffle
    				# taken from perl cookbook
    my $array = shift;
    my $i;
    for ($i = @$array; --$i; ) {
        my $j = int rand ($i+1);
        next if $i == $j;
        @$array[$i,$j] = @$array[$j,$i];
    }
}

sub sse {
    my ($listRef ) = @_;
    my ($item,$mean,$sse);
    return if ( ! @$listRef );

    $mean = &mean($listRef);
    $sse = 0;
    foreach $item ( @$listRef ) {
	$sse += ( $item - $mean) * ( $item - $mean );
    }
    return $sse;
}

sub sum {
    my ( $listRef ) = @_;
    my ( $item );
    return if ( ! @$listRef );

    my $sum = 0;
    foreach $item ( @$listRef ) {
	$sum += $item;
    }
    return $sum;
}

sub sum_square {
    my ( $listRef ) = @_;
    my ( $item );
    return undef if ( ! @$listRef );

    my $sum = 0;
    foreach $item ( @$listRef ) {
	$sum += $item * $item;
    }
    return $sum;
}



sub union {
    my (@lists) = @_;
    
    my @union =  ();
    my %union =  ();	
    my ($list,$item);

    foreach $list ( @lists ) {
	foreach $item ( @$list ) {
	    $union{$item} = 1;
	}
    }
    @union = keys %union;
    return [@union];
}


sub uniqueList {
    my ( $listRef ) = @_;
    my @unique =  ();
    my %unique =  ();	
    my $item;

    foreach $item ( @$listRef ) {
	$unique{$item} = 1;
    }
    @unique = keys %unique;

    return [ @unique ];
}


1;




