=pod

=head1 NAME

RG::Liu::LibNesg - Perl modules by J. Liu

=head1 SYNOPSIS

use RG::Liu::LibNesg;

=head1 FUNCTIONS

See module source for description.

=over

=back

=head1 VARIABLES

=over

=item @consortia

=item %consortia_long2short

=item %consortia_short2long

=item %nesg_org2latin

=item %nesg_org2taxon

=item %nesg2org

=item %nesg2swiss

=item %status2score

=back

=head1 AUTHOR

J. Liu

=head1 SEE ALSO

=over

=item Main website

L<https://rostlab.informatik.tu-muenchen.de/wiki/index.php/Slashdata:cubicmanpages>

=back

=cut

package RG::Liu::LibNesg;
require      Exporter;
@ISA       = qw(Exporter);
@EXPORT    = qw(@consortia %consortia_long2short
		%consortia_short2long %nesg2org %nesg2swiss %nesg2swiss_good
		%nesg_org2taxon %nesg_org2latin %status2score);
   


%status2score =
    ( 'Not selected' => -1,
      'Selected' => 1,
      'Cloned' => 2,
      'Expressed' => 3,
      'Soluble' => 4,
      'Purified' => 5,
      'Mass spec verified' => 5,
      'Crystallized' => 6,
      'HSQC' => 6,
      'Diffraction-quality Crystals' => 7,
      'Good HSQC' => 7,
      'Native diffraction-data' => 8,
      'Phasing diffraction-data' => 8,
      'Diffraction' => 8,
      'NMR Assigned' => 8,
      'Crystal Structure' => 9,
      'NMR Structure' => 9,
      'In PDB' => 10,
      'In BMRB' => 10,
      'Work Stopped' => 0,
      );



@consortia =qw(bsgc cesg jcsg mcsg nesgc nysgrc secsg sgpp tb 
	       s2f bigs bsgi psf riken spine-eu );

%consortia_long2short =
    (
     "Berkeley Structural Genomics Center" => "bsgc",
     "Berlin Protein structure factory" => 'psf',
     "Montreal-Kingston Bacterial Structural Genomics Initiative" => "bsgi",
     "Center for Eukaryotic Structural Genomics" => "cesg",
     'CESG' => 'cesg',
     "Joint Center for Structural Genomics" => "jcsg",
     'JCSG' => 'jcsg',
     'Laboratory of Structural & Genomic Information' => 'bigs',
     "Midwest Center for Structural Genomics" => "mcsg",
     "Northeast Structural Genomics Consortium" => "nesg",
     "New York Structural Genomics Research Consortium" => "nysgxrc",
     'NYSGRC' =>  'nysgxrc',
     'NYSGXRC' => 'nysgxrc',
     "RIKEN Structural Genomics Initiative" => "riken",
     'RSGI' => 'riken',
     "Structure to Function Project" => "s2f",
     "S2F" => 's2f',
     "Southeast Collaboratory of Structural Genomics" => "secsg",
     "Southeast Collaboratory for Structural Genomics" => "secsg",
     'SECSG' => 'secsg',
     "Structural Genomics of Pathogenic Protozoa" => "sgpp",
     "Tuberculosis Structural Genomics Consortium" => "tbsgc",
     'TBSGC' => 'tbsgc',
     "Yeast Structural Genomics" => "ysg",
     "SPINE-EU" => 'spine-eu',
     "Israel Structural Proteomics Center" => 'ispc',
     'Weizmann Structural Proteomics Center' => 'ispc',
     "Marseilles Structural Genomics Program" => 'msgp',
     "OPPF" => 'oppf',
     "Paris Yeast Structural Genomics" => 'ysg',
     'UCLA' => 'isfi',
     'University of Chicago' => 'isfi',
     'University of Virginia' => 'isfi',
     'Los Alamos National Laboratory' => 'isfi',
     'Lawrence Berkeley National Laboratory' => 'isfi',
     'ISFI' => 'isfi',
     'SGC, University of Oxford' => 'sgc',
     'The EMBL Hamburg Outstation' => 'xmtb',
     'MPI for Structural Molecularbiologie' => 'xmtb',
     
     );      

%consortia_short2long = 
      (
       'bigs' => 'Laboratory of Structural & Genomic Information',
       "bsgc" =>  "Berkeley Structural Genomics Center",
       "bsgi" =>  "Montreal-Kingston Bacterial Structural Genomics Initiative",
       "cesg" =>   "Center for Eukaryotic Structural Genomics",
       "jcsg" =>   "Joint Center for Structural Genomics",
       'isfi' =>   "Integrated Center for Structure and Function Innovation",
       "mcsg" =>   "Midwest Center for Structural Genomics",
       "nesg" =>  "Northeast Structural Genomics Consortium",
       "nysgxrc" =>  "New York Structural Genomics Research Consortium",
       'psf' => "Berlin Protein structure factory",
       "riken" =>  "RIKEN Structural Genomics Initiative",
       "s2f" =>    "Structure to Function Project",
       "secsg" =>  "Southeast Collaboratory of Structural Genomics",
       'sgc' => "Structural Genomics Consortium",
       "sgpp" =>   "Structural Genomics of Pathogenic Protozoa",
       'spine-eu' => "Structural Proteomics in Europe",
       "tbsgc" =>     "Tuberculosis Structural Genomics Consortium",
       'xmtb' => 'Mycobacterium Tuberculosis Structural Proteomics Project',
       "ysg" =>    "Paris Yeast Structural Genomics",
       
       );

%nesg2org = (
	'A' => 'Arabidopsis thaliana',
	'As' => 'Acinetobacter sp. ADP1',
	'At' => 'Agrobacterium tumefaciens str. C58',
	'B' => 'Campylobacter jejuni subsp. jejuni NCTC 11168',
	'Bb' => 'Borrelia burgdorferi B31',
	'Bc' => 'Bacillus cereus ATCC 14579',
	'Be' => 'Bordetella pertussis Tohama I',
	'Bf' => 'Bacteroides fragilis NCTC 9343',
	'Bh' => 'Bacillus halodurans C-125',
	'Bn' => 'Bartonella henselae (Houston-1)',
	'Bo' => 'Bordetella bronchiseptica RB50',
	'Bp' => 'Bordetella parapertussis 12822',
	'Bt' => 'Bacteroides thetaiotaomicron VPI-5482',
	'Bu' => 'Bacillus thuringiensis serovar konkukian str.',
	'Ca' => 'Clostridium acetobutylicum ATCC 824',
	'Cc' => 'Caulobacter crescentus CB15',
	'Cd' => 'Corynebacterium diphtheriae NCTC 13129',
	'Cg' => 'Corynebacterium glutamicum ATCC 13032',
	'Cp' => 'Clostridium perfringens str. 13',
	'Cs' => 'Colwellia psychrerythraea 34H',
	'Ct' => 'Chlorobium tepidum TLS',
	'Cv' => 'Chromobacterium violaceum ATCC 12472',
	'D' => 'Streptococcus pyogenes M1 GAS',
	'Dr' => 'Deinococcus radiodurans R1',
	'Dv' => 'Desulfovibrio vulgaris subsp. vulgaris str. Hildenborough',
	'E' => 'Escherichia coli str. K12',
	'Ef' => 'Enterococcus faecalis V583',
	'Ew' => 'Erwinia carotovora subsp. atroseptica SCRI1043',
	'F' => 'Drosophila melanogaster',
	'G' => 'Archaeoglobus fulgidus DSM 4304',
	'Gm' => 'Geobacter metallireducens GS-15',
	'Gs' => 'Geobacter sulfurreducens PCA',
	'H' => 'Homo sapiens',
	'Hd' => 'Haemophilus ducreyi 35000HP',
	'Hm' => 'Haloarcula marismortui ATCC 43049',
	'Hs' => 'Halobacterium sp. NRC-1',
	'I' => 'Haemophilus influenzae Rd KW20',
	'J' => 'Pyrococcus horikoshii OT3',
	'K' => 'Lactococcus lactis',
	'La' => 'Lactobacillus acidophilus NCFM',
	'Lg' => 'Legionella pneumophila subsp. pneumophila str. Philadelphia 1',
	'Lk' => 'Listeria innocua Clip11262',
	'Lm' => 'Listeria monocytogenes EGD-e',
	'Lp' => 'Lactobacillus plantarum WCFS1',
	'M' => 'Neisseria meningitidis MC58',
	'Ma' => 'Methanosarcina mazei Go1',
	'Mb' => 'Mycobacterium bovis AF2122/97',
	'Mc' => 'Methylococcus capsulatus str. Bath',
	'Mg' => 'Mycoplasma genitalium G37',
	'Mj' => 'Methanocaldococcus jannaschii DSM 2661',
	'Mp' => 'Mycoplasma pneumoniae M129',
	'Mr' => 'Methanococcus maripaludis S2',
	'Ne' => 'Nitrosomonas europaea ATCC 19718',
	'Ng' => 'Neisseria gonorrhoeae FA 1090',
	'Ns' => 'Nostoc sp. PCC 7120; Anabaena sp. (strain PCC 7120)',
	'P' => 'Helicobacter pylori 26695',
	'Pa' => 'Pseudomonas aeruginosa PAO1',
	'Pc' => 'Propionibacterium acnes KPA171202',
	'Pf' => 'Pyrococcus furiosus DSM 3638',
	'Pg' => 'Porphyromonas gingivalis W83',
	'Pl' => 'Pseudomonas fluorescens Pf-5 / ATCC BAA-477',
	'Pp' => 'Pseudomonas putida KT2440',
	'Ps' => 'Pseudomonas syringae pv. tomato str. DC3000',
	'R' => 'Streptomyces coelicolor A3(2)',
	'Rh' => 'Rhodobacter sphaeroides 2.4.1',
	'Rp' => 'Rhodopseudomonas palustris CGA009',
	'Rs' => 'Ralstonia solanacearum GMI1000',
	'S' => 'Bacillus subtilis subsp. subtilis str. 168',
	'Sa' => 'Streptococcus agalactiae 2603V/R',
	'Sc' => 'Salmonella enterica subsp. enterica serovar Paratyphi A str. ATCC 9150',
	'Se' => 'Staphylococcus epidermidis ATCC 12228',
	'Sf' => 'Shigella flexneri 2a str. 2457T',
	'Sh' => 'Staphylococcus haemolyticus JCSC1435',
	'Si' => 'Silicibacter pomeroyi DSS-3',
	'Sm' => 'Streptococcus mutans UA159',
	'So' => 'Shewanella oneidensis MR-1',
	'Sp' => 'Streptococcus pneumoniae TIGR4',
	'Sr' => 'Salinibacter ruber DSM 13855',
	'Ss' => 'Sulfolobus solfataricus P2',
	'St' => 'Salmonella typhimurium LT2',
	'Su' => 'Streptococcus thermophilus (strain ATCC BAA-250 / LMG 18311)',
	'Sv' => 'Streptomyces avermitilis MA-4680',
	'Sy' => 'Staphylococcus saprophyticus subsp. saprophyticus ATCC 15305',
	'T' => 'Methanothermobacter thermautotrophicus str. Delta H',
	'Ta' => 'Thermoplasma acidophilum',
	'Tv' => 'Thermoplasma volcanium GSS1',
	'U' => 'Thermus thermophilus HB27',
	'Uu' => 'Ureaplasma parvum serovar 3 str. ATCC 700970',
	'V' => 'Thermotoga maritima MSB8',
	'Vc' => 'Vibrio cholerae O1 biovar eltor str. N16961',
	'Vf' => 'Vibrio fischeri (strain ATCC 700601 / ES114)',
	'Vp' => 'Vibrio parahaemolyticus RIMD 2210633',
	'X' => 'Aeropyrum pernix K1',
	'Xa' => 'Xanthomonas axonopodis pv. citri str. 306',
	'Xc' => 'Xanthomonas campestris pv. campestris str. ATCC 33913',
	'Xf' => 'Xylella fastidiosa Temecula1',
	'Xo' => 'Xanthomonas oryzae pv. oryzae KACC10331',
	'Y' => 'Saccharomyces cerevisiae',
	'Z' => 'Staphylococcus aureus subsp. aureus Mu50',
);

%nesg2swiss = (
	'A' => 'arath',
	'As' => 'aciad',
	'At' => 'agrt5',
	'B' => 'camje',
	'Bb' => 'borbu',
	'Bc' => 'baccr',
	'Be' => 'borpe',
	'Bf' => 'bacfn',
	'Bh' => 'bachd',
	'Bn' => 'barhe',
	'Bo' => 'borbr',
	'Bp' => 'borpa',
	'Bt' => 'bactn',
	'Bu' => 'bachk',
	'Ca' => 'cloab',
	'Cc' => 'caucr',
	'Cd' => 'cordi',
	'Cg' => 'corgl',
	'Cp' => 'clope',
	'Cs' => 'colp3',
	'Ct' => 'chlte',
	'Cv' => 'chrvo',
	'D' => 'strp1',
	'Dr' => 'deira',
	'Dv' => 'desvh',
	'E' => 'ecoli',
	'Ef' => 'entfa',
	'Eu' => 'enccu',
	'Ew' => 'erwct',
	'F' => 'drome',
	'G' => 'arcfu',
	'Gm' => 'geome',
	'Gs' => 'geosl',	# 
	'H' => 'human',
	'Hd' => 'haedu',
	'Hm' => 'halma',
	'Hs' => 'haln1',
	'I' => 'haein',
	'J' => 'pyrho',
	'K' => 'lacla',
	'La' => 'lacac',
	'Lg' => 'legph',
	'Lk' => 'lisin',
	'Lm' => 'lismo',
	'Lp' => 'lacpl',
	'M' => 'neimb',
	'Ma' => 'metma',
	'Mb' => 'mycbo',
	'Mc' => 'metca',
	'Mg' => 'mycge',
	'Mj' => 'metja',
	'Mp' => 'mycpn',
	'Mr' => 'metmp',
	'Ne' => 'niteu',
	'Ng' => 'neig1',
	'Ns' => 'anasp',
	'P' => 'helpy',
	'Pa' => 'pseae',
	'Pc' => 'proac',
	'Pf' => 'pyrfu',
	'Pg' => 'porgi',
	'Pl' => 'psef5',
	'Pp' => 'psepk',
	'Ps' => 'psesm',
	'R' => 'strco',
	'Rh' => 'rhosh',
	'Rp' => 'rhopa',
	'Rs' => 'ralso',
	'S' => 'bacsu',
	'Sa' => 'stra5',
	'Sc' => 'salet',
	'Se' => 'staes',
	'Sf' => 'shifl',
	'Sh' => 'stahj',
	'Si' => 'silpo',
	'Sm' => 'strmu',
	'So' => 'sheon',
	'Sp' => 'strpn',
	'Sr' => 'salrd',
	'Ss' => 'sulso',
	'St' => 'salty',
	'Su' => 'strt2',
	'Sv' => 'straw',
	'Sy' => 'stas1',
	'T' => 'metth',
	'Ta' => 'theac',
	'Tv' => 'thevo',
	'U' => 'thet2',
	'Uu' => 'urepa',
	'V' => 'thema',
	'Vc' => 'vibch',
	'Vf' => 'vibf1',
	'Vp' => 'vibpa',
	'X' => 'aerpe',
	'Xa' => 'xanac',
	'Xc' => 'xancp',
	'Xf' => 'xylft',
	'Xo' => 'xanor',
	'Y' => 'yeast',
	'Z' => 'staam',
);

%nesg_org2taxon = (
	'aciad' => '62977',
	'aerpe' => '272557',
	'agrt5' => '176299',
	'anasp' => '103690',
	'arath' => '3702',
	'arcfu' => '224325',
	'baccr' => '226900',
	'bacfn' => '272559',
	'bachd' => '272558',
	'bachk' => '281309',
	'bacsu' => '224308',
	'bactn' => '226186',
	'barhe' => '283166',
	'borbr' => '257310',
	'borbu' => '224326',
	'borpa' => '257311',
	'borpe' => '257313',
	'braja' => '224911',
	'caeel' => '6239',
	'camje' => '192222',
	'caucr' => '190650',
	'chlte' => '194439',
	'chrvo' => '243365',
	'cloab' => '272562',
	'clope' => '195102',
	'colp3' => '167879',
	'cordi' => '257309',
	'corgl' => '196627',
	'deira' => '243230',
	'desvh' => '882',
	'drome' => '7227',
	'ecoli' => '83333',
	'entfa' => '226185',
	'erwct' => '218491',
	'geome' => '269799',
	'geosl' => '243231',
	'haedu' => '233412',
	'haein' => '71421',
	'halma' => '272569',
	'halsa' => '64091',
	'helpy' => '85962',
	'human' => '9606',
	'lacac' => '272621',
	'lacla' => '272623',
	'lacpl' => '220668',
	'legph' => '272624',
	'lisin' => '272626',
	'lismo' => '169963',
	'metca' => '243233',
	'metja' => '243232',
	'metma' => '192952',
	'metmp' => '267377',
	'metth' => '187420',
        'mouse' => '10090',
	'mycbo' => '233413',
	'mycge' => '243273',
	'mycpn' => '272634',
	'neig1' => '242231',
	'neimb' => '122586',
	'niteu' => '228410',
	'porgi' => '242619',
	'proac' => '267747',
	'pseae' => '208964',
	'psef5' => '220664',
	'psepk' => '160488',
	'psesm' => '223283',
	'pyrfu' => '186497',
	'pyrho' => '70601',
	'ralso' => '267608',
	'rat'   => '10116',
	'rhilo' => '266835',
	'rhopa' => '258594',
	'rhort' => '269796',
	'rhosh' => '272943',
	'salet' => '295319',
	'salrd' => '309807',
	'salty' => '99287',
	'sheon' => '211586',
	'shibs' => '300268',
	'shifl' => '198215',
	'silpo' => '246200',
	'staam' => '158878',
	'staes' => '176280',
	'stahj' => '279808',
	'stas1' => '342451',
	'stra5' => '208435',
	'straw' => '227882',
	'strco' => '100226',
	'strmu' => '210007',
	'strp1' => '160490',
	'strpn' => '170187',
	'strt2' => '264199',
	'sulso' => '273057',
	'synel' => '197221',
	'synp6' => '269084',
	'syny3' => '1148',
	'theac' => '2303',
	'thema' => '243274',
	'thet2' => '262724',
	'thevo' => '273116',
	'urepa' => '273119',
	'vibch' => '243277',
	'vibf1' => '312309',
	'vibpa' => '223926',
	'xanac' => '190486',
	'xancp' => '190485',
	'xanor' => '291331',
	'xylft' => '183190',
	'yeast' => '4932',
);

%nesg_org2latin = (
	'aciad' => 'Acinetobacter sp. ADP1',
	'aerpe' => 'Aeropyrum pernix K1',
	'agrt5' => 'Agrobacterium tumefaciens str. C58',
	'anasp' => 'Nostoc sp. PCC 7120; Anabaena sp. (strain PCC 7120)',
	'arath' => 'Arabidopsis thaliana',
	'arcfu' => 'Archaeoglobus fulgidus DSM 4304',
	'baccr' => 'Bacillus cereus ATCC 14579',
	'bacfn' => 'Bacteroides fragilis NCTC 9343',
	'bachd' => 'Bacillus halodurans C-125',
	'bachk' => 'Bacillus thuringiensis serovar konkukian str.',
	'bacsu' => 'Bacillus subtilis subsp. subtilis str. 168',
	'bactn' => 'Bacteroides thetaiotaomicron VPI-5482',
	'barhe' => 'Bartonella henselae (Houston-1)',
	'borbr' => 'Bordetella bronchiseptica RB50',
	'borbu' => 'Borrelia burgdorferi B31',
	'borpa' => 'Bordetella parapertussis 12822',
	'borpe' => 'Bordetella pertussis Tohama I',
	'braja' => 'Bradyrhizobium japonicum USDA110',
	'camje' => 'Campylobacter jejuni subsp. jejuni NCTC 11168',
	'caucr' => 'Caulobacter crescentus CB15',
	'chlte' => 'Chlorobium tepidum TLS',
	'chrvo' => 'Chromobacterium violaceum ATCC 12472',
	'cloab' => 'Clostridium acetobutylicum ATCC 824',
	'clope' => 'Clostridium perfringens str. 13',
	'colp3' => 'Colwellia psychrerythraea 34H',
	'cordi' => 'Corynebacterium diphtheriae NCTC 13129',
	'corgl' => 'Corynebacterium glutamicum ATCC 13032',
	'deira' => 'Deinococcus radiodurans R1',
	'desvh' => 'Desulfovibrio vulgaris subsp. vulgaris str. Hildenborough',
	'drome' => 'Drosophila melanogaster',
	'ecoli' => 'Escherichia coli str. K12',
	'entfa' => 'Enterococcus faecalis V583',
	'erwct' => 'Erwinia carotovora subsp. atroseptica SCRI1043',
	'geome' => 'Geobacter metallireducens GS-15',
	'geosl' => 'Geobacter sulfurreducens PCA',
	'haedu' => 'Haemophilus ducreyi 35000HP',
	'haein' => 'Haemophilus influenzae Rd KW20',
	'halma' => 'Haloarcula marismortui ATCC 43049',
	'halsa' => 'Halobacterium sp. NRC-1',
	'helpy' => 'Helicobacter pylori 26695',
	'human' => 'Homo sapiens',
	'lacac' => 'Lactobacillus acidophilus NCFM',
	'lacla' => 'Lactococcus lactis',
	'lacpl' => 'Lactobacillus plantarum WCFS1',
	'legph' => 'Legionella pneumophila subsp. pneumophila str. Philadelphia 1',
	'lisin' => 'Listeria innocua Clip11262',
	'lismo' => 'Listeria monocytogenes EGD-e',
	'metca' => 'Methylococcus capsulatus str. Bath',
	'metja' => 'Methanocaldococcus jannaschii DSM 2661',
	'metma' => 'Methanosarcina mazei Go1',
	'metmp' => 'Methanococcus maripaludis S2',
	'metth' => 'Methanothermobacter thermautotrophicus str. Delta H',
	'mycbo' => 'Mycobacterium bovis AF2122/97',
	'mycge' => 'Mycoplasma genitalium G37',
	'mycpn' => 'Mycoplasma pneumoniae M129',
	'neig1' => 'Neisseria gonorrhoeae FA 1090',
	'neimb' => 'Neisseria meningitidis MC58',
	'niteu' => 'Nitrosomonas europaea ATCC 19718',
	'porgi' => 'Porphyromonas gingivalis W83',
	'proac' => 'Propionibacterium acnes KPA171202',
	'pseae' => 'Pseudomonas aeruginosa PAO1',
	'psef5' => 'Pseudomonas fluorescens Pf-5 / ATCC BAA-477',
	'psepk' => 'Pseudomonas putida KT2440',
	'psesm' => 'Pseudomonas syringae pv. tomato str. DC3000',
	'pyrfu' => 'Pyrococcus furiosus DSM 3638',
	'pyrho' => 'Pyrococcus horikoshii OT3',
	'ralso' => 'Ralstonia solanacearum GMI1000',
	'rhilo' => 'Mesorhizobium loti',
	'rhopa' => 'Rhodopseudomonas palustris CGA009',
	'rhort' => 'Rhodospirillum rubrum ATCC 11170',
	'rhosh' => 'Rhodobacter sphaeroides 2.4.1',
	'salet' => 'Salmonella enterica subsp. enterica serovar Paratyphi A str. ATCC 9150',
	'salrd' => 'Salinibacter ruber DSM 13855',
	'salty' => 'Salmonella typhimurium LT2',
	'sheon' => 'Shewanella oneidensis MR-1',
	'shibs' => 'Shigella boydii Sb227',
	'shifl' => 'Shigella flexneri 2a str. 2457T',
	'silpo' => 'Silicibacter pomeroyi DSS-3',
	'staam' => 'Staphylococcus aureus subsp. aureus Mu50',
	'staes' => 'Staphylococcus epidermidis ATCC 12228',
	'stahj' => 'Staphylococcus haemolyticus JCSC1435',
	'stas1' => 'Staphylococcus saprophyticus subsp. saprophyticus ATCC 15305',
	'stra5' => 'Streptococcus agalactiae 2603V/R',
	'straw' => 'Streptomyces avermitilis MA-4680',
	'strco' => 'Streptomyces coelicolor A3(2)',
	'strmu' => 'Streptococcus mutans UA159',
	'strp1' => 'Streptococcus pyogenes M1 GAS',
	'strpn' => 'Streptococcus pneumoniae TIGR4',
	'strt2' => 'Streptococcus thermophilus (strain ATCC BAA-250 / LMG 18311)',
	'sulso' => 'Sulfolobus solfataricus P2',
	'synel' => 'Thermosynechococcus elongatus strain BP-1',
	'synp6' => 'Synechococcus elongatus PCC6301',
	'syny3' => 'Synechocystis sp. PCC 6803',
	'theac' => 'Thermoplasma acidophilum',
	'thema' => 'Thermotoga maritima MSB8',
	'thet2' => 'Thermus thermophilus HB27',
	'thevo' => 'Thermoplasma volcanium GSS1',
	'urepa' => 'Ureaplasma parvum serovar 3 str. ATCC 700970',
	'vibch' => 'Vibrio cholerae O1 biovar eltor str. N16961',
	'vibf1' => 'Vibrio fischeri (strain ATCC 700601 / ES114)',
	'vibpa' => 'Vibrio parahaemolyticus RIMD 2210633',
	'xanac' => 'Xanthomonas axonopodis pv. citri str. 306',
	'xancp' => 'Xanthomonas campestris pv. campestris str. ATCC 33913',
	'xanor' => 'Xanthomonas oryzae pv. oryzae KACC10331',
	'xylft' => 'Xylella fastidiosa Temecula1',
	'yeast' => 'Saccharomyces cerevisiae',
);



1;

