=pod

=head1 NAME

RG::Liu::LibNors - Perl modules by J. Liu

=head1 SYNOPSIS

use RG::Liu::LibNors;

=head1 FUNCTIONS

See module source for description.

=over

=item calcSecContent

=item getAllSec

=item hasNsrAcc

=item hasNsrPhd

=item isCollagen

=item isNors

=item isNors_genome

=item isNors_md5

=item norsCheckCoils

=item norsCheckHtm

=item norsCheckPhd

=item readSeq

=back

=head1 VARIABLES

=over

=back

=head1 AUTHOR

J. Liu

=head1 SEE ALSO

=over

=item Main website

L<https://rostlab.informatik.tu-muenchen.de/wiki/index.php/Slashdata:cubicmanpages>

=back

=cut

package      RG::Liu::LibNors;
require      Exporter;
@ISA       = qw(Exporter);
@EXPORT    = qw(&isNors_genome &isNors_md5);



sub isNors_genome {
    my ( $org,$id,$dir_genome ) = @_;
    my ( $dir_org,$dir_hssp,$dir_phd,$dir_coils,$dir_htm );
    my ( $ext_phd,$ext_coils,$ext_htm,$ext_hssp);
    my ( $file_coils,$file_phd,$file_htm,$file_hssp );
    my ( $Lok,$norsRegion,$msg,$is_nors );

    $dir_org = $dir_genome.$org.'/';
    $dir_hssp = $dir_org.'hssp4phd/';
    $dir_phd = $dir_org.'prof/';
    $dir_coils = $dir_org.'coils/';
    $dir_htm = $dir_org.'phdHtm/';

    $ext_phd = '.rdbProf';
    $ext_coils = '.coils';
    $ext_htm = '.rdbHtm';
    $ext_hssp = '.hsspFil';

    $file_phd = $dir_phd.$id.$ext_phd;
    if ( ! -f $filePhd ) {
	return (0,"NULL","no PHD file $file_phd found");
    }
	
    $file_coils = $dir_coils.$id.$ext_coils;
    $file_htm = $dir_htm.$id.$ext_htm;
    $file_hssp = $dir_hssp.$id.$ext_hssp;

    (undef,$norsRegion,$msg) =
	&isNors($file_hssp,$file_phd,$file_htm,$file_coils);
    if ( $norsRegion eq 'NULL' ) {
	$is_nors = 0;
    } else {
	$is_nors = 1;
    }
    return ($is_nors,$norsRegion,$msg);

}

sub isNors_md5 {
    my ( $id,$dir_genome ) = @_;
    my ( $ext_phd,$ext_coils,$ext_htm,$ext_hssp,$dir_res);
    my ( $file_coils,$file_phd,$file_htm,$file_hssp );
    my ( $Lok,$norsRegion,$msg,$is_nors );

    $dir_genome .= '/' if ( $dir_genome !~ /\/$/ );
    $dir_res = $dir_genome.substr($id,0,3).'/'.$id.'/';

    $ext_phd = '.rdbProf';
    $ext_coils = '.coils';
    $ext_htm = '.rdbHtm';
    $ext_hssp = '.hsspFil';

    $file_phd = $dir_res.$id.$ext_phd;
    if ( ! -f $file_phd ) {
	return (0,"NULL","no PHD file $file_phd found");
    }
	
    $file_coils = $dir_res.$id.$ext_coils;
    $file_htm = $dir_res.$id.$ext_htm;
    $file_hssp = $dir_res.$id.$ext_hssp;

    (undef,$norsRegion,$msg) =
	&isNors($file_hssp,$file_phd,$file_htm,$file_coils);

    if ( $norsRegion eq 'NULL' ) {
	$is_nors = 0;
    } else {
	$is_nors = 1;
    }
    return ($is_nors,$norsRegion,$msg);

}



sub isNors {
    my ($fileHssp,$filePhd,$filePhdHtm,$fileCoils) = @_;
    my ( $window,$secCut,$accLen,$collagenCutoff );
    my ($maxLen,$beg);
    my ($seq,$acc,$seqLen,$isCollagen,$msgCollagen,$end);
    my ($contentPhd,$ctPhdNsr,$nsrBeg,$nsrEnd,$ctNsr,$i,$nsrReg);

    $window = 70;			# the window of the non-struc. length
    $secCut = 12;			# the cutoff the SS percentage
    $accLen = 10;			# at least have continuous 10 exposed residue
    $collagenCutoff = 0.3;		# sequence identity to indicate a collagen

    $minAcc = 16;		# acc threshold for exposed residue

    $maxLen = 0;
    $beg = $window/2;
			       
    ($sec,$acc) = &norsCheckPhd($filePhd);
    $seqLen = scalar @$sec - 1;
    if ( $seqLen < $window ) {
	return (2,"NULL","seqLen=$seqLen, smaller than window size $window",$sec,undef,undef,$acc);
    }

    ( $isCollagen,$msgCollagen ) =  &isCollagen($fileHssp,$collagenCutoff);
    if ( $isCollagen ) {
	return (2,"NULL", "is collagen homolog.",$sec,undef,undef,$acc);
    }

    $coils = &norsCheckCoils($fileCoils);
    $htm = &norsCheckHtm($filePhdHtm);
    $allSec = &getAllSec($seqLen,$sec,$coils,$htm);
    if ( $opt_debug ) {
	print STDERR "sec=\n";
	for $i (1..$seqLen) {
	    print STDERR 
		$allSec->[$i];
	}
	print STDERR "\n";
    }

    $end = $seqLen - $window/2;
    $maxLen = $end if ( $end > $maxLen );
    $contentPhd = &calcSecContent($allSec,$window,$beg,$end);


    ($ctPhdNsr,$nsrBeg,$nsrEnd) = &hasNsrPhd($window,$secCut,$contentPhd,$beg,$end);
    if ( ! $ctPhdNsr ) {
	return(2,"NULL","no NORS after PHD",$sec,$coils,$htm,$acc);
    }
				 
    ($ctNsr,$nsrBeg,$nsrEnd) = &hasNsrAcc($accLen,$ctPhdNsr,$acc,$nsrBeg,$nsrEnd);
    #print STDERR "$org,$id,ctNst=$ctNsr\n";
    if (! $ctNsr ) {
	return(2,"NULL","no NORS after ACC",$sec,$coils,$htm,$acc);
    }

    #print STDERR "$org,$id,ctNst=$ctNsr\n";
    $nsrReg = "";
    for $i ( 1..$ctNsr ) {
	$nsrReg .= $nsrBeg->[$i].'-'.$nsrEnd->[$i].',';
    }
    $nsrReg =~ s/,$//g;
    return (1,$nsrReg,"ok",$sec,$coils,$htm,$acc);

}


sub calcSecContent {
    my $sbr = "calcSecContent";
    my ($sec,$window,$beg,$end) = @_;
    my ($ctStrut,$i,@contentPhd,$winEnd,$preWin,$current );

    $ctStrut = 0;
    for $i (1..$window) {	# 
	$ctStrut++ if ( $sec->[$i]  );
    }
    $contentPhd[$beg] = $ctStrut/$window;
	
    for $i ( $beg+1..$end) {
	$winEnd = $i + $window/2;
	$preWin = $i - $window/2;
	    
	if ( $sec->[$winEnd]  ) {
	    if ( $sec->[$preWin]  ) {
		$current = $contentPhd[$i-1];
	    } else {
		$current = $contentPhd[$i-1] + 1/$window;
	    }
	} else {
	    if ( $sec->[$preWin] ) {
		if ( ! defined $contentPhd[$i-1] ) {
		    print STDERR "content for pos $i not defined.\n";
		    die;
		}
		$current = $contentPhd[$i-1] - 1/$window;
	    } else {
		$current = $contentPhd[$i-1];
	    }
	}
	$contentPhd[$i] = $current;   
    }
#   for $i ( $beg..$end ) {
#	printf "%.2f,",$contentPhd[$i];
#    }
#    print "\n";
    return [@contentPhd];
}


sub getAllSec {
    my ($seqLen,$sec,$coils,$htm) = @_;
    my ( $i, $allSec );

    for $i ( 1..$seqLen ) {
	if ( $sec->[$i] =~ /[he]/i or $coils->[$i] or $htm->[$i] ) {
	    $allSec->[$i] = 1;
	} else {
	    $allSec->[$i] = 0;
	}
    }
    return $allSec;
}
    

sub norsCheckCoils {
    my $sbr = "checkCoils";
    my ($coilFile) = @_;
    my $fhCoils = "COILS_$sbr";
    my ($ctCoil,@tmpCoil,$pos,$score,$coilsRef);
    
    
#    if ( -s $notcoilFile ) {	# no coils
#	return undef;
#    }

    undef $coilsRef;

    return undef if ( ! -s $coilFile );
    open ( $fhCoils, $coilFile ) or die "cannot open $coilFile:$!";
    $ctCoil = 0;
    while ( <$fhCoils> ) {
	s/^\s+//g;
	s/\s+$//g;
	if ( $_ !~ /^\d+/ ) {
	    next;
	}
	
	@tmpCoil = split /\s+/;
	$pos = $tmpCoil[0];
	$score = $tmpCoil[4];
	if ( $score >= 0.9 ) {
	    $coilsRef->[$pos] = 1;
	    $ctCoil++;
	}
    }
    close $fhCoils;
#    if ( $ctCoil < 14 ) { # error
#	warn "wrong parsing coil file??\nctCoils=$ctCoil\n";
#    }

    return $coilsRef;
}



sub norsCheckHtm {
    my $sbr = "checkHtm";
    my ($file_htm) = @_;
    my $fhHtm = "HTM_$sbr";
    my ($file_notHtm,$ctHtm,@htmBeg,@htmEnd);
    my (@tmpHtm,$htmReg,$i,$h);

    $file_notHtm = $file_htm;
    $file_notHtm =~ s/\.[^.]+$//;
    $file_notHtm .= '.notHtm';

    if ( ! -s $file_htm or (-s $file_htm) < 50 or -f $file_notHtm ) {	# no HTM
	return undef;
    }
				# phdHtm
    open ( $fhHtm, $file_htm ) or die "cannot open $file_htm:$!";
    $ctHtm = 0;
    undef @htmBeg;
    undef @htmEnd;
    while ( <$fhHtm> ) {
	if ( $_ !~ /^\#/ ) {
	    last;
	}
	if ( $_ !~ /^\# (MODEL_DAT|VALUE\s+HTM_MODEL_DAT)/ ) {
	    next;
	}
	
	@tmpHtm = split /,/;
	$htmReg = $tmpHtm[-1];
	$htmReg =~ s/\s+//g;
	if ( $htmReg !~ /^\d+-\d+$/ ) {
	    die "wrong htm format??\n$_\n";
	}
	
	$ctHtm++;
	($htmBeg[$ctHtm], $htmEnd[$ctHtm] ) = split /-/, $htmReg;
    }
    close $fhHtm;
    if ( $ctHtm == 0 ) {
	#warn "wrong parsin htm file??\nctHtm=$ctHtm\n";
    }
	    
    for ( $i = 1; $i <= $ctHtm; $i++ ) {
	for ( $h = $htmBeg[$i]; $h <= $htmEnd[$i]; $h++ ) {
	    $htmRef->[$h] = 1;
	}
    }

    return $htmRef;
}


sub norsCheckPhd {
    my $sbr = "checkPhd";
    my ($filePhd) = @_;
    my $fhPhd = "PHD_$sbr";
    my (@cols,$colPhdNo,$i,$colAccNo,@tmp,$strut,$acc,$pos,@sec,@acc);
    
    
    open ( $fhPhd, $filePhd ) or die "cannot open $filePhd:$!";
    while ( <$fhPhd> ) {	 
	next if ( /^\#/ ) ;     
	s/^\s+|\s+$//g;
	if ( /^No/ ) {
	    @cols= split /\t/;
	    for $i ( 0..$#cols ) {
		if ( $cols[$i] eq "PHEL" ) {
		    $colPhdNo = $i;
		} elsif ( $cols[$i] eq "PREL" ) { # accessibility
		    $colAccNo = $i;
		}
	    }
	    if (! defined $colPhdNo or ! defined $colAccNo ) {
		die "column name not found in $_\n"; 
	    }		# 
	}
	
	if ( $_ !~ /^\d+\s+/ ) { 
	    next;
	}			 
	@tmp = split /\s+/;
	$pos = $tmp[0];
	$strut = lc($tmp[$colPhdNo]);
	$acc = $tmp[$colAccNo];
	$sec[$pos] = $strut;
	if ( $acc > $minAcc ) {
	    $acc[$pos] = 1;
	} else {
	    $acc[$pos] = 0;
	}
    }			       
    close $fhPhd;
    return ([@sec],[@acc]);
}



sub hasNsrAcc {
    my ($accLen,$ctPhdNsr,$acc,$phdNsrBeg,$phdNsrEnd) = @_;
    my ($ctNsrAcc,$i,$nsrBeg,$nsrEnd,$isBuried,$lenExp,$maxLenExp);
    my ($j,$accNsrBeg,$accNsrEnd);

    $ctNsrAcc=0;

    for $i ( 1..$ctPhdNsr ) {
	$nsrBeg = $phdNsrBeg->[$i];
	$nsrEnd = $phdNsrEnd->[$i];
	$isBuried = 1;
	$lenExp = 0;
	$maxLenExp=0;
	
	for $j ( $nsrBeg..$nsrEnd ) {
	    if ( ! $acc->[$j] ) {
		if ( ! $isBuried ) {
		    $maxLenExp = $lenExp if ( $lenExp > $maxLenExp );
		}
		$lenExp = 0;
		$isBuried = 1;
	    } else {
		$isBuried = 0;
		$lenExp++;
		$maxLenExp = $lenExp if ( $lenExp > $maxLenExp );
	    }
	}
	
	if ( $maxLenExp >= $accLen ) {
	    $ctNsrAcc++;
	    $accNsrBeg->[$ctNsrAcc] = $phdNsrBeg->[$i];
	    $accNsrEnd->[$ctNsrAcc] = $phdNsrEnd->[$i];
	}
    }
    if ( $ctNsrAcc ) {
	return ($ctNsrAcc,$accNsrBeg,$accNsrEnd);
    } else {
	return 0;
    }
}


	

sub hasNsrPhd {
    my $sbr = "isNsrPhd";
    my ($window,$secCut,$contentPhd,$beg,$end) = @_;
    my ($isNsrPhd,$ctPhdNsr,$i,@phdNsrEnd,@phdNsrBeg);

    undef @phdNsrBeg;
    undef @phdNsrEnd;

    $isNsrPhd = 0;
    $ctPhdNsr = 0;
    for $i ( $beg..$end) {
	if ( $contentPhd->[$i] <= $secCut/100 ) {
	    if ( ! $isNsrPhd ) {
		$isNsrPhd = 1;
		if ( $ctPhdNsr > 0 and  $phdNsrEnd[$ctPhdNsr] < ($i - $window/2)) {
		    $ctPhdNsr++;
		    $phdNsrBeg[$ctPhdNsr] = $i - $window/2 + 1;
		}
		if ( $ctPhdNsr == 0 ) {
		    $ctPhdNsr++;
		    $phdNsrBeg[$ctPhdNsr] = $i - $window/2 + 1;
		}
	    } 
	    $phdNsrEnd[$ctPhdNsr] = $i + $window/2;
	} else {		# 
	    $isNsrPhd = 0;
	}
    }
    if ( $ctPhdNsr ) {
	return ($ctPhdNsr,[@phdNsrBeg],[@phdNsrEnd]);
    } else {
	return 0;
    }

    
}


sub isCollagen {
    my ($fileHssp,$collagenCutoff) = @_;
    my $sbr = "isCollage";
    my ($msgCollagen,$posIde,$posSim,$ide,$sim );
    my ($hsspHeader);
    
 
    if ( ! -s $fileHssp ) {
	warn "$fileHssp not found.\n";
	return (0,"");
    }
    
    $fhHssp = "HSSP_$sbr";
    open ($fhHssp, $fileHssp) or die "cannot open $fileHssp:$!";
    while ($tmpLine=<$fhHssp>) {
	if ( $tmpLine =~ /^\#\# PROTEINS/ ) {
	    $hsspHeader = <$fhHssp>;
	    $posIde = index($hsspHeader,'%IDE');
	    if ( $hsspHeader =~ /\%WSIM/ ) { 
		$posSim = index($hsspHeader,'%WSIM');
	    } else {
		$posSim = index($hsspHeader,'%SIM');
	    }
	    last;
	}
    }
    while ($tmpLine=<$fhHssp>) {
	if ( $tmpLine =~ /^\#\# ALIGNMENTS/ ) {
	     last;
	 }
	if ( $tmpLine !~ /^\s*\d+\s*:/ ) {
	    next;
	}
	
	$ide = substr($tmpLine,$posIde,5);
	$sim = substr($tmpLine,$posSim,5);
	$ide =~ s/\s+//g;
	$sim =~ s/\s+//g;
	
#	print STDERR "xx ide=$ide, sim=$sim\n";

	if ( $ide !~ /\d/ or $sim !~ /\d/ ) {
	    print STDERR 
		"ide=$ide,sim=$sim\n",
		"$fileHssp: wrong parsing hssp?\n$_\n$tmpLine\n";
	    die;
	}
	
	if ( $ide > 1 or $sim > 1 ) {
	    die "$fileHssp: wrong parsing hssp?\n$_\nide=$ide,sim=$sim\n";
	}
	
	if ( $ide < $collagenCutoff and $sim < $collagenCutoff ) {
	    last;
	}
	
	if ( $tmpLine =~ /collagen/i and $tmpLine !~ /collagenase/i ) {
	    $msgCollagen .= "$fileHssp -- from hssp:\n$tmpLine";
	    last;
	}
    }
    close $fhHssp;
    if ( $msgCollagen ) {
	return (1,$msgCollagen);
    } else {
	return (0,"");
    }
}


sub readSeq {
    my ( $fileIn ) = @_;
    my $sbr = "readSeq";
    my $fhIn = "SEQ_$sbr";
    open ( $fhIn,$fileIn ) or die "cannot open $fileIn:$!";
    my $seq = "";
    while ( <$fhIn> ) {
	next if ( /^\s*\>/ );
	chomp;
	$seq .= $_;
    }
    close $fhIn;

    $seq =~ s/\W+//g;
    $seq =~ s/\d+//g;
    
    return $seq;
}

1;

