=pod

=head1 NAME

RG::Liu::LibPDB - Perl modules by J. Liu

=head1 SYNOPSIS

use RG::Liu::LibPDB;

=head1 FUNCTIONS

See module source for description.

=over

=item cmp_pdb_date

=item get_pdb_date

=item date_pdb2iso

=back

=head1 VARIABLES

=over

=item %letter2month

=back

=head1 AUTHOR

J. Liu

=head1 SEE ALSO

=over

=item Main website

L<https://rostlab.informatik.tu-muenchen.de/wiki/index.php/Slashdata:cubicmanpages>

=back

=cut

package      RG::Liu::LibPDB;
require      Exporter;
@ISA       = qw(Exporter);
@EXPORT    = qw(%letter2month get_pdb_date date_pdb2iso 
		cmp_pdb_date );

%letter2month = 
    ( 'JAN' => '01',
      'FEB' => '02',
      'MAR' => '03',
      'APR' => '04',
      'MAY' => '05',
      'JUN' => '06',
      'JUL' => '07',
      'AUG' => '08',
      'SEP' => '09',
      'OCT' => '10',
      'NOV' => '11',
      'DEC' => '12',
      );

		 

sub get_pdb_date {
    my ( $id, $dir ) = @_;
    my $sbr = "get_pdb_date";
    my $fh = "PDB_$sbr";
    
    my ($line,$date);

    $dir = '/data/pdb/' if ( ! $dir );
    $dir_old = '/data/pdb_obsolete/';
#    $file_date = '/home/liu/project/pdb/data/pdb_all.date';

    $file = $dir.$id.'.pdb';
    if ( ! -s $file or ! -r $file ) {
	$file = $dir_old.$id.'.pdb';
	return undef if ( ! -s $file or ! -r $file );	
	print STDERR "*** WARN: $id from obsolete PDB entry\n";
    }

    open ($fh,$file) or die "cannot open $file:$!";
    while ($line=<$fh>) {
	if ($line =~ /^HEADER/ ) {
	    $date = substr($line,50,10);
	    last;
	}
    }
    close $fh;
    $date =~ s/\s+//g;
    return $date;
}

sub date_pdb2iso {
    my ( $pdb_date ) = @_;
    my ( $date,$month,$year,$iso_date );

    return undef if ( ! $pdb_date );
    ($date,$month,$year) = split /-/,$pdb_date;
    if ( $year < 40 ) {
	$year += 2000;
    } else {
	$year += 1900;
    }
    $month = $letter2month{uc(substr($month,0,3))};
    $iso_date = "$year-$month-$date";
    return $iso_date;
}    



sub cmp_pdb_date {
    my ($a,$b) = @_;
    my ( %date,%month,%year );
    
    $iso_a = &date_pdb2iso($a);
    $iso_b = &date_pdb2iso($b);
    return ( $iso_a cmp $iso_b );
}   

1;
