=pod

=head1 NAME

RG::Liu::LibSeq - Perl modules by J. Liu

=head1 SYNOPSIS

use RG::Liu::LibSeq;

=head1 FUNCTIONS

See module source for description.

=over

=item get_seq_info

=back

=head1 VARIABLES

=over

=item %aa2hydro

=item %aa2hydro_hopp

=item %aa2mw

=item %aa3to1

=item %aascale

=back

=head1 AUTHOR

J. Liu

=head1 SEE ALSO

=over

=item Main website

L<https://rostlab.informatik.tu-muenchen.de/wiki/index.php/Slashdata:cubicmanpages>

=back

=cut

package      RG::Liu::LibSeq;
require      Exporter;
@ISA       = qw(Exporter);
@EXPORT    = qw(get_seq_info);
@EXPORT_OK = qw(%aa3to1 %aa2mw %aa2hydro %aascale);

#========================================================
sub get_seq_info {
    my ($fileFasta) = @_;
    my ( $id,$seq,$seqLen );
    my ( $nameSub, $fhSeq_sub );
#--------------------------------------------------------

    $nameSub = 'get_seq_info';
    $fhSeq_sub = $nameSub."_SEQ";

    $seq = "";
    open ($fhSeq_sub,$fileFasta) or die "cannot open $fileFasta:$!";
    while (<$fhSeq_sub>) {
	chomp;
	if ( /^\s*\>/ ) {
	    $id = $_;
	    $id =~ s/^\s*\>\s*//g;
	    $id =~ s/\s+.*//g;
	    if ( $id =~ /\bgi\|(\d+)\|/i ) { # if we have a GI number
                $id = $1;
	    } elsif ( $id =~ /\|(\w+)$/ ) {
		$id =~ s/.*\|//g;
	    } else {		# we just take the file name
		$id = $fileFasta;
		$id =~ s/.*\///g;
		$id =~ s/\..*//g;
	    }
	    next;
	} 
	$seq .= $_;
    }
    close $fhSeq_sub;
    $seq =~ s/[^A-Za-z]//g;
    $seqLen = length $seq;
    return ($id,$seqLen,$seq);
}				# END of SUB get_seq_info


%aa3to1 = 
    ( 'Ala' => 'A',
      'Arg' => 'R',
      'Asn' => 'N',
      'Asp' => 'D',
      'Cys' => 'C',
      'Gln' => 'Q',
      'Glu' => 'E',
      'Gly' => 'G',
      'His' => 'H',
      'Ile' => 'I',
      'Leu' => 'L',
      'Lys' => 'K',
      'Met' => 'M',
      'Phe' => 'F',
      'Pro' => 'P',
      'Ser' => 'S',
      'Thr' => 'T',
      'Trp' => 'W',
      'Tyr' => 'Y',
      'Val' => 'V',
      );


%aa2mw = 
    ( 'A' => 89.09,
      'C' => 121.15,
      'D' => 133.10,
      'E' => 147.13,
      'F' => 165.19,
      'G' => 75.07,
      'H' => 155.16,
      'I' => 131.17,
      'K' => 146.19,
      'L' => 131.17,
      'M' => 149.21,
      'N' => 132.12,
      'P' => 115.13,
      'Q' => 146.15,
      'R' => 174.20,
      'S' => 105.09,
      'T' => 119.12,
      'V' => 117.15,
      'W' => 204.23,
      'Y' => 181.19
      );

				# Hopp-woods
%aa2hydro_hopp =
    ("A" => -0.5 ,
     "C" => -1.0 ,
     "D" => 2.5 ,
     "E" => 2.5 ,
     "F" => -2.5 ,
     "G" => 0 ,
     "H" => -0.5 ,
     "I" => -1.8 ,
     "K" => 3.0 ,
     "L" => -1.8 ,
     "M" => -1.3 ,
     "N" => 0.2 ,
     "P" => -1.4 ,
     "Q" => 0.2 ,
     "R" => 3.0 ,
     "S" => 0.3 ,
     "T" => -0.4 ,
     "V" => -1.5 ,
     "W" => -3.4 ,
     "Y" => -2.3 ,
     "X" => 0,			# unknown aa
     );

				# Kyte-doolittle
%aa2hydro = 
    ( "A" => 1.8,
      "C" => 2.5,
      "D" => -3.5,
      "E" => -3.5,
      "F" => 2.8,
      "G" => -0.4,
      "H" => -3.2,
      "I" => 4.5,
      "K" => -3.9,
      "L" => 3.8,
      "M" => 1.9,
      "N" => -3.5,
      "P" => -1.6,
      "Q" => -3.5,
      "R" => -4.5,
      "S" => -0.8,
      "T" => -0.7,
      "V" => 4.2,
      "W" => -0.9,
      "Y" => -1.3,
      "X" => 0,			# unknown
      );

# http://www.mat.univie.ac.at/~neum/software/protein/aminoacids.html
%aascale = 
    ( "A" => [ 0.06, -0.25, 0.25 ],
      "C" => [ -0.56, -0.40, -0.14 ] ,
      "D" => [ 0.97, -0.08, 0.08 ],
      "E" => [ 0.85, -0.10, -0.05 ],
      "F" => [ -0.99, 0.18, 0.15 ],
      "G" => [ 0.32, -0.32, 0.28 ],
      "H" => [0.15, -0.03, -0.10 ],
      "I" => [ -1.00, -0.03, 0.10 ],
      "K" => [1.00, 0.32, 0.11],
      "L" => [-0.83, 0.05, 0.01],
      "M" => [-0.68, -0.01, 0.04],
      "N" => [0.70, -0.06, 0.17],
      "P" => [0.45, 0.23, 0.41],
      "Q" => [0.71,-0.02,0.12],
      "R" => [0.80,0.19,-0.41],
      "S" => [0.48,-0.15,0.23],
      "T" => [0.38,-0.10,0.29],
      "V" => [-0.75,-0.19,0.03],
      "W" => [-0.57,0.31,0.34],
      "Y" => [-0.35,0.40,-0.02],
      "X" => [0,0,0],			# unknown
      );


1;

