=pod

=head1 NAME

RG::Liu::Lib-genome - Perl modules by J. Liu

=head1 SYNOPSIS

use RG::Liu::Lib-genome;

=head1 FUNCTIONS

See module source for description.

=over

=item aaCompFromList

=item calcMW

=item getIdList

=item getSeq

=back

=head1 VARIABLES

=over

=item %aa2mw

=item %aa3to1

=item @commClass

=item @energyClass

=item @euclidClasses14

=item @euclidClasses3

=item @fullOrgList

=item @infoClass

=item %name_latin

=item %name_latin_short

=item %org2kingdom

=back

=head1 AUTHOR

J. Liu

=head1 SEE ALSO

=over

=item Main website

L<https://rostlab.informatik.tu-muenchen.de/wiki/index.php/Slashdata:cubicmanpages>

=back

=cut

package RG::Liu::Lib-genome;
require      Exporter;
@ISA       = qw(Exporter);
@EXPORT    = qw( fullOrgList name_latin_short name_latin_short name_latin org2kingdom euclidClasses14 euclidClasses3 energyClass infoClass commClass aa3to1 aa2mw aaCompFromList calcMW getIdList getSeq );

@fullOrgList=(
	      'aerpe','arcfu','metja','mettm','pyrab','pyrho',
	      'aquae','bacsu','borbu','camje','chlpn','chltr','deira',
	      'ecoli','haein','helpy','mycge','mycpn','myctu','neime',
	      'ricpr','syny3','thema','trepa','ureur',
	      'arath','caeel','drome','enccu','yeast','mouse','human');


%name_latin_short=(
		   'arcfu',  "A fulgidus",
		   'helpy',  "H pylori",
		   'borbu',  "B burgdorferi",
		   'bacsu',  "B subtilis",
		   'caeel',  "C elegans",
		   'syny1',  "S sp. (cyanobacterium)",
		   'ecoli',  "E coli",
		   'haein',  "H influenzae",
		   'helpy',  "H pylori",
		   'human',  "H sapiens",
		   'mycge',  "M genitalium",
		   'metja',  "M jannaschii",
		   'mycpn',  "M pneumoniae",
		   'mettm',  "M thermoautotrophicum ",
		   'yeast',  "S cerevisiae",
		   'aerpe',  "A pernix",
		   'aquae',  "A aeolicus",
		   'chlpn',  "C pneumoniae",
		   'chltr',  "C trachomatis",
		   'myctu',  "M tuberculosis",
		   'pyrab',  "P abyssi",
		   'pyrho',  "P horikoshii",
		   'ricpr',  "R prowazekii",
		   'syny3',  "S PCC6803",
		   'thema',  "T maritima",
		   'trepa',  "T pallidum",
		   'deira',  "D radiodurans",
		   'camje',  "C jejuni",
		   'drome',  "D melanogaster",
		   'neime',  "N meningitidis",
		   'ureur',  "U urealyticum",
		   'enccu',  "E cuniculi",
		   'hs22',   "H sapiens(chr 22)",
		   'arath', "A thaliana",
		   '', "",
		   );


%name_latin = ( 'aerpe' => "Aeropyrum pernix K1",
		'arcfu' => "Achaeoglobus fulgidus",
		'metja' => "Methanococcus jannaschii",
		'mettm' => "Methanobacterium thermoautotrophicum",
		'pyrab' => "Pyrococcus abyssi",
		'pyrho' => "Pyrococcus horikoshii",
		'aquae' => "Aquifex aeolicus",
		'bacsu' => "Bacillus subtilis",
		'borbu' => "Borrelia burgdorferi",
		'camje' => "Campylobacter jejuni",
		'chlpn' => "Chlamydia pneumoniae",
		'chltr'	=> "Chlamydia trachomatis",
		'deira' => "Deinococcus radiodurans",
		'ecoli' => "Escherichia coli",
		'haein' => "Haemophilus influenzae",
		'helpy' => "Helicobacter pylori",
		'mycge' => "Mycoplasma genitalium",
		'mycpn' => "Mycoplasma pneumoniae",
		'myctu' => "Mycobacterium tuberculosis",
		'neime' => "Neisseria meningitidis",
		'ricpr' => "Rickettsia prowazekii",
		'syny3' => "Synechocystis PCC6803",
		'thema' => "Thermotoga maritima",
		'trepa' => "Treponema pallidum",
		'ureur' => "Ureaplasma urealyticum",
		'arath' => "Arabidopsis thaliana",
		'caeel' => "Caenorhabditis elegans",
		'drome' => "Drosophila melanogaster",
		'enccu' => "Encephalitozoon cuniculi",
		'human' => "Homo sapiens",
		'yeast' => "Saccharomyces cerevisiae",
		);

%org2kingdom = 
    ('aerpe' => "Archean",
     'arcfu' => "Archean",
     'metja' => "Archean",
     'mettm' => "Archean",
     'pyrab' => "Archean",
     'pyrho' => "Archean",
     'aquae' => "Prokaryote",
     'bacsu' => "Prokaryote",
     'borbu' => "Prokaryote",
     'camje' => "Prokaryote",
     'chlpn' => "Prokaryote",
     'chltr' => "Prokaryote",
     'deira' => "Prokaryote",
     'ecoli' => "Prokaryote",
     'haein' => "Prokaryote",
     'helpy' => "Prokaryote",
     'mycge' => "Prokaryote",
     'mycpn' => "Prokaryote",
     'myctu' => "Prokaryote",
     'neime' => "Prokaryote",
     'ricpr' => "Prokaryote",
     'syny3' => "Prokaryote",
     'thema' => "Prokaryote",
     'trepa' => "Prokaryote",
     'ureur' => "Prokaryote",	
     'arath' => "Eukaryote",
     'caeel' => "Eukaryote",
     'drome' => "Eukaryote",
     'enccu' => "Eukaryote",
     'yeast' => "Eukaryote",
     'human' => "Eukaryote");

@euclidClasses14 = (
		    'Amino acid biosynthesis',
		    'Biosynthesis of cofactors, prosthetic groups, and carriers',
		    'Cell envelope','Cellular processes',
		    'Central intermediary metabolism','Energy metabolism',
		    'Fatty acid and phospholipid metabolism','Other categories',
		    'Purines, pyrimidines, nucleosides, and nucleotides','Regulatory functions',
		    'Replication','Transcription','Translation',
		    'Transport and binding proteins',
		    'Unclassified');

@euclidClasses3 = ( 'Energy', 'Communication','Information',
		'Other categories','Unclassified');

@energyClass = ( 'Amino acid biosynthesis',
		 'Biosynthesis of cofactors, prosthetic groups, and carriers',
		 'Central intermediary metabolism','Energy metabolism',
		 'Energy metabolism',
		 'Fatty acid and phospholipid metabolism',
		 'Purines, pyrimidines, nucleosides, and nucleotides',
		 'Transport and binding proteins');
@infoClass = ( 'Replication','Transcription','Translation');
@commClass = ( 'Cell envelope','Cellular processes','Regulatory functions');



%aa3to1 = 
    ( 'Ala' => 'A',
      'Arg' => 'R',
      'Asn' => 'N',
      'Asp' => 'D',
      'Cys' => 'C',
      'Gln' => 'Q',
      'Glu' => 'E',
      'Gly' => 'G',
      'His' => 'H',
      'Ile' => 'I',
      'Leu' => 'L',
      'Lys' => 'K',
      'Met' => 'M',
      'Phe' => 'F',
      'Pro' => 'P',
      'Ser' => 'S',
      'Thr' => 'T',
      'Trp' => 'W',
      'Tyr' => 'Y',
      'Val' => 'V',
      );


%aa2mw = 
    ( 'A' => 89.09,
      'C' => 121.15,
      'D' => 133.10,
      'E' => 147.13,
      'F' => 165.19,
      'G' => 75.07,
      'H' => 155.16,
      'I' => 131.17,
      'K' => 146.19,
      'L' => 131.17,
      'M' => 149.21,
      'N' => 132.12,
      'P' => 115.13,
      'Q' => 146.15,
      'R' => 174.20,
      'S' => 105.09,
      'T' => 119.12,
      'V' => 117.15,
      'W' => 204.23,
      'Y' => 181.19
      );



sub aaCompFromList {
#======================================================
# take a fasta list file as input and spit out the aa compostion
# for all the sequences in the list
#=======================================================
    my ( $fileList ) = @_;
    my %aa = ();
    my $errMsg = "";


    my ( @letters, $aa, %isAA, @tmp, $ctTotal );
    if ( ! -e $fileList ) {
	$errMsg .=  "file list $fileList not found, exiting..\n";
	return ({%aa}, 0, $errMsg);
    }

    @letters = qw( A C D E F G H I K L M N P Q R S T V W Y );
    foreach $aa ( @letters ) {
	$isAA{$aa} = 1;
    }


    $ctTotal = 0;
    open (LIST, $fileList) or die "cannot open $fileList:$!";
    while (<LIST>) {
	next if ( /^\s*\>/ );
	s/\s+//g;
	@tmp = split //;
	foreach $aa ( @tmp ) {
	    next if ( ! $isAA{$aa} );
	    $aa{$aa}{'ct'}++;
	    $ctTotal++;
	}
    }
    close LIST;
    
    

    foreach $aa ( @letters ) {
	$aa{$aa}{'freq'} = $aa{$aa}{'ct'}/$ctTotal*100;
    }


    return ( {%aa}, 1, "ok" );
}


sub calcMW {
    my ( $seqRef ) = @_;
    my ( @seq, $seqLen, $mw, $aa );
    
    @seq = split //, uc($$seqRef);
    $seqLen = 0;
    $mw = 0;
    foreach $aa ( @seq ) {
	if ( ! defined $aa2mw{$aa} ) {
	    print STDERR "MW for aa $aa not found, skip..\n";
	    next;
	}
	$seqLen++;
	$mw += $aa2mw{$aa};
    }
				# substract the peptide bond water
    $mw = $mw - 18.015 * ( $seqLen - 1 );
    #$mw = $mw/1000;		# use kDa as unit
    return $mw;
}
	
sub getIdList {
    my $sbr = "getIdList";
    my ( $fileList ) = @_;
    my ( $fhList,$id,@idList );

    return () if ( ! -f $fileList );
    @idList = ();
    $fhList = "LIST_$sbr";
    open ( $fhList, $fileList) or die "cannot open $fileList:$!";
    while (<$fhList>) {
	next if ( $_ !~ /\w+/ );
	chomp($id=$_);
	$id =~ s/\s+//g;
	$id =~ s/\..*//g;
	push @idList, $id if ( $id );
    }
    close $fhList;
    return [@idList];
}

sub getSeq {
    my $sbr = "getSeq";
    my ( $fileSeq ) = @_;
    my ($seq,$fhSeq);
   
    return "" if ( ! -f $fileSeq );
    $seq = "";
    $fhSeq = "SEQ_$sbr";
    open ($fhSeq,$fileSeq) or die "cannot open $fileSeq:$!";
    while (<$fhSeq>) {
	next if ( /^\s*\>/ );
	s/\W+//g;
	$seq .= $_;
    }
    close $fhSeq;
    return $seq;
}
    

1;









