=pod

=head1 NAME

RG::Liu::LibSwiss - Perl modules by J. Liu

=head1 SYNOPSIS

use RG::Liu::LibSwiss;

=head1 FUNCTIONS

See module source for description.

=over

=item readSwiss

=back

=head1 VARIABLES

=over

=item %org2kingdom

=back

=head1 AUTHOR

J. Liu

=head1 SEE ALSO

=over

=item Main website

L<https://rostlab.informatik.tu-muenchen.de/wiki/index.php/Slashdata:cubicmanpages>

=back

=cut

package      RG::Liu::LibSwiss;
require      Exporter;
@ISA       = qw(Exporter);
@EXPORT    = qw(readSwiss);
@EXPORT_OK = qw(%org2kingdom %org2taxon);


sub readSwiss {
    my $dirSwiss = '/data/swissprot/';
    my $dirSplit = $dirSwiss.'current/';
    my ( $swissId ) = @_;
    my ( $id,$org,$subDir,$dirEntry,$swiss,$fileSwiss,$field);
    my ( $drLine,$database,$entry,$seqLine );

    $swissId = lc($swissId);

    ($id,$org) = split /_/,$swissId;
    $subDir = substr($org,0,1);
    $dirEntry = $dirSplit.$subDir.'/';

    $swiss= { };
    $fileSwiss = $dirEntry.$swissId;
    if ( ! -f $fileSwiss ) {
	return ( 0,undef,"swiss ID not found in current database");
    }

    open (SWISS, $fileSwiss) or die "cannot open $fileSwiss:$!";
    while (<SWISS>) {
	chomp;
	if ( /^ID\s+(\S+).*(\d+)\s+AA/ ) {
	    $swiss->{ID} = $1;
	    $swiss->{SEQLEN} = $2;
	} elsif ( /^AC\s+(.*)/ ) {
	    $swiss->{AC} = $1;
	} elsif ( /^(DE|OS|OC|KW)\s+(.*)/ ) {
	    $field = $1;
	    $swiss->{$field} .= ' '.$2;
	    $swiss->{$field} =~ s/^\s+|\s+$//g;
	} elsif ( /^DR\s+(.*)/ ) {
	    $drLine = $1;
	    ($database,$entry) = split /;/, $drLine,2;
	    #print "$database\t$entry";
	    push @{$swiss->{DR}{$database}}, $entry;
	} elsif ( /^SQ/ ) {
	    while ( $seqLine = <SWISS> ) {
		$seqLine =~ s/\s+//g;
		$swiss->{SQ} .= $seqLine;
	    }
	    $swiss->{SQ} =~ s/\W+//g;
	}
    }
    close SWISS;
    return (1,$swiss,"0k");
}


%org2kingdom = 
    (
	'AAV2' => 'V',
	'ABAPA' => 'E',
	'ABDS2' => 'B',
	'ABECH' => 'E',
	'ABEFI' => 'E',
	'ABEGR' => 'E',
	'ABEMA' => 'E',
	'ABIAL' => 'E',
	'ABIBA' => 'E',
	'ABIBE' => 'E',
	'ABIBR' => 'E',
	'ABIDE' => 'B',
	'ABIFI' => 'E',
	'ABIGR' => 'E',
	'ABIHL' => 'E',
	'ABIHO' => 'E',
	'ABIKO' => 'E',
	'ABILA' => 'E',
	'ABIMA' => 'E',
	'ABIMR' => 'E',
	'ABINE' => 'E',
	'ABISA' => 'E',
	'ABIVE' => 'E',
	'ABMVW' => 'V',
	'ABRAN' => 'E',
	'ABRBE' => 'E',
	'ABROR' => 'E',
	'ABRPR' => 'E',
	'ABSGL' => 'E',
	'ABUPI' => 'E',
	'ABUSA' => 'E',
	'ABUTH' => 'E',
	'ABYKO' => 'E',
	'ACAAN' => 'E',
	'ACAAU' => 'E',
	'ACABA' => 'E',
	'ACABE' => 'E',
	'ACABI' => 'E',
	'ACABU' => 'E',
	'ACACA' => 'E',
	'ACACE' => 'E',
	'ACACH' => 'E',
	'ACACL' => 'E',
	'ACACO' => 'E',
	'ACACP' => 'E',
	'ACAER' => 'E',
	'ACAFA' => 'E',
	'ACAGO' => 'E',
	'ACAKA' => 'E',
	'ACALA' => 'E',
	'ACALU' => 'E',
	'ACAMA' => 'E',
	'ACAMR' => 'B',
	'ACAMY' => 'E',
	'ACAOB' => 'E',
	'ACAPE' => 'E',
	'ACAPI' => 'E',
	'ACAPL' => 'E',
	'ACAPO' => 'E',
	'ACARH' => 'E',
	'ACASA' => 'E',
	'ACASC' => 'E',
	'ACASI' => 'E',
	'ACAVI' => 'E',
	'ACAVT' => 'E',
	'ACCGE' => 'E',
	'ACCST' => 'E',
	'ACEAC' => 'B',
	'ACEAT' => 'E',
	'ACEBU' => 'E',
	'ACECA' => 'E',
	'ACECL' => 'E',
	'ACEDI' => 'B',
	'ACEEU' => 'B',
	'ACEHA' => 'B',
	'ACEKI' => 'B',
	'ACELI' => 'B',
	'ACEME' => 'E',
	'ACEMO' => 'E',
	'ACEMT' => 'B',
	'ACENE' => 'E',
	'ACEOP' => 'E',
	'ACEPA' => 'B',
	'ACEPL' => 'E',
	'ACEPM' => 'E',
	'ACEPO' => 'B',
	'ACEPS' => 'E',
	'ACESA' => 'E',
	'ACESP' => 'E',
	'ACEWO' => 'B',
	'ACEXY' => 'B',
	'ACHAM' => 'E',
	'ACHAR' => 'E',
	'ACHAX' => 'B',
	'ACHBI' => 'E',
	'ACHCY' => 'B',
	'ACHDO' => 'E',
	'ACHFU' => 'E',
	'ACHKL' => 'E',
	'ACHLA' => 'B',
	'ACHLY' => 'B',
	'ACHMI' => 'E',
	'ACHSL' => 'B',
	'ACHSP' => 'B',
	'ACHTA' => 'E',
	'ACHTE' => 'E',
	'ACHTR' => 'E',
	'ACIAD' => 'B',
	'ACIAL' => 'E',
	'ACIAM' => 'A',
	'ACIAN' => 'B',
	'ACIAU' => 'E',
	'ACIBA' => 'B',
	'ACIBE' => 'E',
	'ACIBL' => 'B',
	'ACIBR' => 'E',
	'ACICA' => 'B',
	'ACICE' => 'B',
	'ACICH' => 'E',
	'ACICR' => 'E',
	'ACICY' => 'B',
	'ACIDA' => 'E',
	'ACIDE' => 'B',
	'ACIFA' => 'B',
	'ACIFE' => 'B',
	'ACIFU' => 'E',
	'ACIG3' => 'B',
	'ACIG6' => 'B',
	'ACIG9' => 'B',
	'ACIGA' => 'B',
	'ACIGB' => 'B',
	'ACIGL' => 'B',
	'ACIGU' => 'E',
	'ACIHA' => 'B',
	'ACIIN' => 'A',
	'ACIJB' => 'E',
	'ACIJO' => 'B',
	'ACIJU' => 'B',
	'ACILW' => 'B',
	'ACIME' => 'E',
	'ACIMI' => 'E',
	'ACIMU' => 'B',
	'ACINA' => 'E',
	'ACINU' => 'E',
	'ACIOR' => 'B',
	'ACIPE' => 'E',
	'ACIRA' => 'B',
	'ACIRT' => 'E',
	'ACIRU' => 'B',
	'ACIS6' => 'B',
	'ACIS7' => 'B',
	'ACIS8' => 'B',
	'ACIS9' => 'B',
	'ACISA' => 'B',
	'ACISC' => 'E',
	'ACISE' => 'B',
	'ACISI' => 'E',
	'ACISL' => 'E',
	'ACISN' => 'B',
	'ACISP' => 'B',
	'ACISR' => 'B',
	'ACIST' => 'E',
	'ACISU' => 'E',
	'ACITR' => 'E',
	'ACIUN' => 'E',
	'ACLSA' => 'V',
	'ACLSP' => 'V',
	'ACMMI' => 'E',
	'ACMRA' => 'E',
	'ACMSM' => 'E',
	'ACOCA' => 'E',
	'ACOCE' => 'E',
	'ACOCL' => 'E',
	'ACOGR' => 'E',
	'ACOIG' => 'E',
	'ACOWI' => 'E',
	'ACRAC' => 'E',
	'ACRAL' => 'E',
	'ACRAS' => 'E',
	'ACRAU' => 'E',
	'ACRBR' => 'E',
	'ACRCA' => 'E',
	'ACRCE' => 'E',
	'ACRCO' => 'E',
	'ACRDO' => 'E',
	'ACRDU' => 'E',
	'ACRFO' => 'E',
	'ACRGR' => 'E',
	'ACRHI' => 'E',
	'ACRLO' => 'E',
	'ACRMA' => 'E',
	'ACRMI' => 'E',
	'ACROR' => 'E',
	'ACRPA' => 'E',
	'ACRPL' => 'E',
	'ACRPR' => 'E',
	'ACRPY' => 'E',
	'ACRSP' => 'E',
	'ACRST' => 'E',
	'ACRTA' => 'E',
	'ACRTE' => 'E',
	'ACRVU' => 'E',
	'ACTAC' => 'B',
	'ACTAF' => 'E',
	'ACTCA' => 'B',
	'ACTCH' => 'E',
	'ACTCU' => 'E',
	'ACTDE' => 'E',
	'ACTEQ' => 'E',
	'ACTEU' => 'B',
	'ACTHE' => 'E',
	'ACTLG' => 'B',
	'ACTLI' => 'B',
	'ACTLU' => 'E',
	'ACTMI' => 'B',
	'ACTNA' => 'B',
	'ACTPA' => 'B',
	'ACTPL' => 'B',
	'ACTS5' => 'B',
	'ACTSC' => 'B',
	'ACTSK' => 'B',
	'ACTSL' => 'B',
	'ACTSP' => 'B',
	'ACTSU' => 'B',
	'ACTTE' => 'E',
	'ACTTI' => 'B',
	'ACTUT' => 'B',
	'ACTVI' => 'B',
	'ACTVL' => 'E',
	'ACYKO' => 'E',
	'ACYMA' => 'E',
	'ACYPI' => 'E',
	'ADAAL' => 'E',
	'ADAAU' => 'E',
	'ADABI' => 'E',
	'ADACA' => 'E',
	'ADADE' => 'E',
	'ADADI' => 'E',
	'ADAGI' => 'E',
	'ADAGR' => 'E',
	'ADARU' => 'E',
	'ADAZA' => 'E',
	'ADDNA' => 'E',
	'ADE01' => 'V',
	'ADE02' => 'V',
	'ADE03' => 'V',
	'ADE04' => 'V',
	'ADE05' => 'V',
	'ADE06' => 'V',
	'ADE07' => 'V',
	'ADE08' => 'V',
	'ADE09' => 'V',
	'ADE12' => 'V',
	'ADE15' => 'V',
	'ADE16' => 'V',
	'ADE17' => 'V',
	'ADE18' => 'V',
	'ADE1A' => 'V',
	'ADE1H' => 'V',
	'ADE1P' => 'V',
	'ADE31' => 'V',
	'ADE35' => 'V',
	'ADE40' => 'V',
	'ADE41' => 'V',
	'ADEB2' => 'V',
	'ADEB3' => 'V',
	'ADEB4' => 'V',
	'ADEB7' => 'V',
	'ADEBA' => 'V',
	'ADEC2' => 'V',
	'ADECC' => 'V',
	'ADECG' => 'V',
	'ADECR' => 'V',
	'ADECT' => 'V',
	'ADECU' => 'V',
	'ADEE1' => 'V',
	'ADEE2' => 'V',
	'ADEF1' => 'V',
	'ADEFA' => 'E',
	'ADEG1' => 'V',
	'ADEG8' => 'V',
	'ADEGU' => 'E',
	'ADEGX' => 'V',
	'ADEHI' => 'E',
	'ADEHY' => 'E',
	'ADELA' => 'E',
	'ADELI' => 'E',
	'ADEM1' => 'V',
	'ADEO7' => 'V',
	'ADEOB' => 'E',
	'ADEOO' => 'E',
	'ADEP3' => 'V',
	'ADEP4' => 'V',
	'ADEPA' => 'E',
	'ADEPE' => 'E',
	'ADEPI' => 'E',
	'ADES1' => 'V',
	'ADES7' => 'V',
	'ADET1' => 'V',
	'ADETR' => 'E',
	'ADEUN' => 'E',
	'ADEVO' => 'E',
	'ADIBE' => 'E',
	'ADICA' => 'E',
	'ADIPE' => 'E',
	'ADIRA' => 'E',
	'ADOCA' => 'E',
	'ADOMO' => 'E',
	'ADOVE' => 'E',
	'ADVG' => 'V',
	'AEDAE' => 'E',
	'AEDAL' => 'E',
	'AEDEB' => 'V',
	'AEDEV' => 'V',
	'AEDTO' => 'E',
	'AEDTR' => 'E',
	'AEGAC' => 'E',
	'AEGAR' => 'E',
	'AEGBI' => 'E',
	'AEGCA' => 'E',
	'AEGCM' => 'E',
	'AEGCO' => 'E',
	'AEGCR' => 'E',
	'AEGCY' => 'E',
	'AEGFU' => 'E',
	'AEGHA' => 'E',
	'AEGLO' => 'E',
	'AEGMA' => 'E',
	'AEGMO' => 'E',
	'AEGPO' => 'E',
	'AEGSA' => 'E',
	'AEGSE' => 'E',
	'AEGSP' => 'E',
	'AEGTA' => 'E',
	'AEGTI' => 'E',
	'AEGTS' => 'E',
	'AEGUM' => 'E',
	'AEGUN' => 'E',
	'AEGVE' => 'E',
	'AENAR' => 'E',
	'AEOAL' => 'E',
	'AEOTU' => 'E',
	'AEPAR' => 'E',
	'AEPME' => 'E',
	'AEPRU' => 'E',
	'AEQIR' => 'E',
	'AEQOP' => 'E',
	'AEQTE' => 'E',
	'AEQVI' => 'E',
	'AERHY' => 'B',
	'AERJA' => 'B',
	'AERJP' => 'E',
	'AERME' => 'B',
	'AERPE' => 'A',
	'AERPU' => 'B',
	'AERRA' => 'E',
	'AERSA' => 'B',
	'AERSO' => 'B',
	'AERTR' => 'B',
	'AERVU' => 'E',
	'AESCY' => 'E',
	'AESHI' => 'E',
	'AESPA' => 'E',
	'AETAL' => 'E',
	'AETCR' => 'E',
	'AETCY' => 'E',
	'AETGR' => 'E',
	'AETNA' => 'E',
	'AETPU' => 'E',
	'AETPY' => 'E',
	'AETSA' => 'E',
	'AFIFE' => 'B',
	'AFRCO' => 'E',
	'AGAAC' => 'E',
	'AGAAF' => 'E',
	'AGAAG' => 'E',
	'AGAAM' => 'E',
	'AGAAN' => 'E',
	'AGAAT' => 'E',
	'AGAAU' => 'E',
	'AGABE' => 'E',
	'AGABI' => 'E',
	'AGABP' => 'E',
	'AGABR' => 'E',
	'AGABT' => 'E',
	'AGACA' => 'E',
	'AGACE' => 'E',
	'AGACL' => 'E',
	'AGACM' => 'E',
	'AGACN' => 'E',
	'AGACP' => 'E',
	'AGADA' => 'E',
	'AGAFI' => 'E',
	'AGAFO' => 'E',
	'AGAGH' => 'E',
	'AGAIM' => 'E',
	'AGALI' => 'E',
	'AGALL' => 'E',
	'AGAME' => 'E',
	'AGAMO' => 'E',
	'AGAMR' => 'E',
	'AGANI' => 'E',
	'AGAOD' => 'E',
	'AGAPA' => 'E',
	'AGAPE' => 'E',
	'AGAPL' => 'E',
	'AGAPR' => 'E',
	'AGAPU' => 'E',
	'AGARO' => 'E',
	'AGARS' => 'E',
	'AGARU' => 'E',
	'AGASU' => 'E',
	'AGATA' => 'E',
	'AGAXA' => 'E',
	'AGEAL' => 'E',
	'AGEAP' => 'E',
	'AGEBA' => 'E',
	'AGECY' => 'E',
	'AGEFL' => 'E',
	'AGEHU' => 'E',
	'AGEOP' => 'E',
	'AGEOR' => 'E',
	'AGEPH' => 'E',
	'AGEPP' => 'E',
	'AGETH' => 'E',
	'AGETR' => 'E',
	'AGEXA' => 'E',
	'AGKAC' => 'E',
	'AGKBI' => 'E',
	'AGKBL' => 'E',
	'AGKCA' => 'E',
	'AGKCL' => 'E',
	'AGKCO' => 'E',
	'AGKHA' => 'E',
	'AGKHB' => 'E',
	'AGKHP' => 'E',
	'AGKIN' => 'E',
	'AGKPI' => 'E',
	'AGKRH' => 'E',
	'AGLCU' => 'E',
	'AGLMI' => 'E',
	'AGLNE' => 'E',
	'AGLTR' => 'E',
	'AGLUR' => 'E',
	'AGOFL' => 'E',
	'AGOPA' => 'E',
	'AGOTA' => 'E',
	'AGRAE' => 'E',
	'AGRAL' => 'E',
	'AGRCA' => 'E',
	'AGRCI' => 'E',
	'AGRCO' => 'E',
	'AGRCR' => 'E',
	'AGRCY' => 'E',
	'AGRDO' => 'E',
	'AGRGI' => 'E',
	'AGRIP' => 'E',
	'AGRLI' => 'E',
	'AGRME' => 'B',
	'AGROC' => 'E',
	'AGRPA' => 'E',
	'AGRPL' => 'E',
	'AGRRD' => 'B',
	'AGRRH' => 'B',
	'AGRSA' => 'B',
	'AGRSC' => 'B',
	'AGRSK' => 'B',
	'AGRSP' => 'B',
	'AGRT4' => 'B',
	'AGRT5' => 'B',
	'AGRT7' => 'B',
	'AGRT9' => 'B',
	'AGRTA' => 'B',
	'AGRTB' => 'B',
	'AGRTC' => 'B',
	'AGRTR' => 'B',
	'AGRTU' => 'B',
	'AGRVA' => 'E',
	'AGRVI' => 'B',
	'AHNNV' => 'V',
	'AHSV1' => 'V',
	'AHSV2' => 'V',
	'AHSV3' => 'V',
	'AHSV4' => 'V',
	'AHSV5' => 'V',
	'AHSV6' => 'V',
	'AHSV7' => 'V',
	'AHSV8' => 'V',
	'AHSV9' => 'V',
	'AILAL' => 'E',
	'AILDE' => 'E',
	'AILFU' => 'E',
	'AILME' => 'E',
	'AILUR' => 'E',
	'AIMCA' => 'E',
	'AINOV' => 'V',
	'AIPLA' => 'E',
	'AIPPA' => 'E',
	'AIPPU' => 'E',
	'AIXGA' => 'E',
	'AIXSP' => 'E',
	'AJECA' => 'E',
	'AJEDE' => 'E',
	'AJUCH' => 'E',
	'AJURE' => 'E',
	'AKABI' => 'E',
	'AKEQU' => 'E',
	'AKKLU' => 'E',
	'AKOAE' => 'E',
	'AKOAF' => 'E',
	'AKOAL' => 'E',
	'AKOAN' => 'E',
	'AKOAZ' => 'E',
	'AKOBO' => 'E',
	'AKOBU' => 'E',
	'AKOCU' => 'E',
	'AKODA' => 'E',
	'AKODO' => 'E',
	'AKOFU' => 'E',
	'AKOIN' => 'E',
	'AKOJE' => 'E',
	'AKOJU' => 'E',
	'AKOKO' => 'E',
	'AKOLI' => 'E',
	'AKOLO' => 'E',
	'AKOMI' => 'E',
	'AKOML' => 'E',
	'AKOMN' => 'E',
	'AKOMO' => 'E',
	'AKOMY' => 'E',
	'AKONI' => 'E',
	'AKOOL' => 'E',
	'AKOOR' => 'E',
	'AKOPA' => 'E',
	'AKOPH' => 'E',
	'AKOPU' => 'E',
	'AKORE' => 'E',
	'AKOSE' => 'E',
	'AKOSI' => 'E',
	'AKOSP' => 'E',
	'AKOSU' => 'E',
	'AKOTB' => 'E',
	'AKOTO' => 'E',
	'ALAAR' => 'E',
	'ALACH' => 'E',
	'ALAES' => 'E',
	'ALAHE' => 'E',
	'ALAMA' => 'E',
	'ALBCO' => 'E',
	'ALBJU' => 'E',
	'ALBSE' => 'E',
	'ALBTU' => 'E',
	'ALCAA' => 'E',
	'ALCAC' => 'E',
	'ALCAT' => 'E',
	'ALCBS' => 'B',
	'ALCBU' => 'E',
	'ALCCR' => 'E',
	'ALCDE' => 'B',
	'ALCDF' => 'B',
	'ALCFA' => 'B',
	'ALCHY' => 'B',
	'ALCLI' => 'E',
	'ALCSC' => 'B',
	'ALCSD' => 'B',
	'ALCSP' => 'B',
	'ALCTO' => 'E',
	'ALCXX' => 'B',
	'ALDEL' => 'E',
	'ALDYE' => 'B',
	'ALEAL' => 'E',
	'ALEAN' => 'E',
	'ALEAU' => 'E',
	'ALECA' => 'E',
	'ALECH' => 'E',
	'ALECI' => 'E',
	'ALECO' => 'E',
	'ALEFA' => 'E',
	'ALEFU' => 'E',
	'ALEGR' => 'E',
	'ALELA' => 'E',
	'ALERU' => 'E',
	'ALETA' => 'E',
	'ALHEH' => 'B',
	'ALIAC' => 'B',
	'ALICA' => 'E',
	'ALIPL' => 'E',
	'ALLAL' => 'E',
	'ALLAR' => 'E',
	'ALLAS' => 'E',
	'ALLCA' => 'E',
	'ALLCE' => 'E',
	'ALLDI' => 'E',
	'ALLEL' => 'E',
	'ALLFI' => 'E',
	'ALLHA' => 'E',
	'ALLIN' => 'E',
	'ALLMA' => 'E',
	'ALLMI' => 'E',
	'ALLNG' => 'E',
	'ALLNI' => 'E',
	'ALLOC' => 'E',
	'ALLPE' => 'E',
	'ALLPO' => 'E',
	'ALLPR' => 'E',
	'ALLSA' => 'E',
	'ALLSB' => 'E',
	'ALLSC' => 'E',
	'ALLSI' => 'E',
	'ALLTE' => 'E',
	'ALLTR' => 'E',
	'ALLTU' => 'E',
	'ALLUR' => 'E',
	'ALLWI' => 'E',
	'ALNCR' => 'E',
	'ALNGL' => 'E',
	'ALNIN' => 'E',
	'ALNMA' => 'E',
	'ALNVI' => 'E',
	'ALOAE' => 'E',
	'ALOAR' => 'E',
	'ALOBE' => 'E',
	'ALOCA' => 'E',
	'ALOGU' => 'E',
	'ALOLA' => 'E',
	'ALOMA' => 'E',
	'ALOMY' => 'E',
	'ALOPA' => 'E',
	'ALOPI' => 'E',
	'ALOPR' => 'E',
	'ALOSA' => 'E',
	'ALOSE' => 'E',
	'ALOVE' => 'E',
	'ALOVR' => 'E',
	'ALOVU' => 'E',
	'ALPCA' => 'E',
	'ALPPA' => 'E',
	'ALPZE' => 'E',
	'ALSAU' => 'E',
	'ALSIN' => 'E',
	'ALSLI' => 'E',
	'ALSPE' => 'E',
	'ALSPS' => 'E',
	'ALTAL' => 'E',
	'ALTAT' => 'B',
	'ALTBR' => 'E',
	'ALTCA' => 'B',
	'ALTCL' => 'E',
	'ALTMA' => 'B',
	'ALTMC' => 'E',
	'ALTS2' => 'B',
	'ALTSM' => 'B',
	'ALTSO' => 'B',
	'ALTSP' => 'B',
	'ALV' => 'V',
	'ALVAM' => 'E',
	'ALVHS' => 'B',
	'ALYCI' => 'E',
	'ALYLE' => 'E',
	'ALYMO' => 'E',
	'ALYMU' => 'E',
	'ALYOB' => 'E',
	'ALYSP' => 'E',
	'AMAAE' => 'E',
	'AMAAP' => 'E',
	'AMABE' => 'E',
	'AMABL' => 'E',
	'AMABR' => 'E',
	'AMACA' => 'E',
	'AMACO' => 'E',
	'AMACR' => 'E',
	'AMAFA' => 'E',
	'AMAGR' => 'E',
	'AMAHP' => 'E',
	'AMAHY' => 'E',
	'AMAMU' => 'E',
	'AMAPA' => 'E',
	'AMAPH' => 'E',
	'AMAPO' => 'E',
	'AMARE' => 'E',
	'AMARU' => 'E',
	'AMASU' => 'E',
	'AMATR' => 'E',
	'AMATZ' => 'E',
	'AMAVE' => 'E',
	'AMAVI' => 'E',
	'AMBAC' => 'E',
	'AMBAR' => 'E',
	'AMBCA' => 'E',
	'AMBCE' => 'E',
	'AMBCH' => 'E',
	'AMBCI' => 'E',
	'AMBCR' => 'E',
	'AMBEL' => 'E',
	'AMBGR' => 'E',
	'AMBHL' => 'E',
	'AMBHO' => 'E',
	'AMBHS' => 'E',
	'AMBJE' => 'E',
	'AMBLA' => 'E',
	'AMBMA' => 'E',
	'AMBMC' => 'E',
	'AMBME' => 'E',
	'AMBOP' => 'E',
	'AMBPH' => 'E',
	'AMBPS' => 'E',
	'AMBPU' => 'E',
	'AMBRU' => 'E',
	'AMBTC' => 'E',
	'AMBTE' => 'E',
	'AMBTI' => 'E',
	'AMBTR' => 'E',
	'AMBTS' => 'E',
	'AMBWH' => 'E',
	'AMCV' => 'V',
	'AMEAM' => 'E',
	'AMEAR' => 'E',
	'AMECE' => 'E',
	'AMEPV' => 'V',
	'AMIAM' => 'B',
	'AMICA' => 'E',
	'AMMAR' => 'E',
	'AMMHA' => 'E',
	'AMMIN' => 'E',
	'AMMIT' => 'E',
	'AMMLE' => 'E',
	'AMMLU' => 'E',
	'AMMSA' => 'E',
	'AMOAL' => 'E',
	'AMOBY' => 'E',
	'AMOPA' => 'E',
	'AMOPE' => 'B',
	'AMOPO' => 'E',
	'AMOPR' => 'E',
	'AMOPS' => 'B',
	'AMOTI' => 'E',
	'AMOWR' => 'E',
	'AMPBE' => 'E',
	'AMPBR' => 'E',
	'AMPCA' => 'E',
	'AMPCL' => 'E',
	'AMPCO' => 'E',
	'AMPFR' => 'E',
	'AMPHE' => 'E',
	'AMPLO' => 'E',
	'AMPME' => 'E',
	'AMPMU' => 'E',
	'AMPOC' => 'E',
	'AMPOP' => 'E',
	'AMPPO' => 'E',
	'AMPQU' => 'E',
	'AMPSA' => 'E',
	'AMPSP' => 'B',
	'AMPST' => 'E',
	'AMSAL' => 'E',
	'AMSMO' => 'E',
	'AMVLE' => 'V',
	'AMVMA' => 'V',
	'AMVST' => 'V',
	'AMVYS' => 'V',
	'AMYMD' => 'B',
	'AMYME' => 'B',
	'AMYOR' => 'B',
	'ANAAB' => 'B',
	'ANAAC' => 'E',
	'ANAAL' => 'E',
	'ANAAM' => 'E',
	'ANAAR' => 'E',
	'ANAAU' => 'E',
	'ANAAZ' => 'B',
	'ANABA' => 'E',
	'ANABE' => 'E',
	'ANABR' => 'E',
	'ANACA' => 'E',
	'ANACE' => 'B',
	'ANACH' => 'E',
	'ANACL' => 'E',
	'ANACN' => 'E',
	'ANACO' => 'E',
	'ANACR' => 'E',
	'ANACS' => 'E',
	'ANACY' => 'B',
	'ANADE' => 'B',
	'ANADI' => 'E',
	'ANAER' => 'E',
	'ANAFA' => 'E',
	'ANAFL' => 'B',
	'ANAFO' => 'E',
	'ANAFU' => 'E',
	'ANAFV' => 'E',
	'ANAGE' => 'E',
	'ANAGI' => 'E',
	'ANAGR' => 'E',
	'ANAHO' => 'E',
	'ANAJA' => 'E',
	'ANALA' => 'E',
	'ANALU' => 'E',
	'ANALZ' => 'E',
	'ANAMA' => 'B',
	'ANAME' => 'E',
	'ANAMF' => 'B',
	'ANAMI' => 'E',
	'ANAML' => 'B',
	'ANAMM' => 'B',
	'ANAMV' => 'B',
	'ANANE' => 'E',
	'ANAOC' => 'E',
	'ANAOV' => 'E',
	'ANAPA' => 'E',
	'ANAPE' => 'E',
	'ANAPH' => 'B',
	'ANAPL' => 'E',
	'ANAPN' => 'E',
	'ANAPO' => 'E',
	'ANAPP' => 'E',
	'ANAPU' => 'B',
	'ANAPZ' => 'B',
	'ANAQU' => 'E',
	'ANARH' => 'E',
	'ANARU' => 'E',
	'ANASA' => 'E',
	'ANASC' => 'B',
	'ANASE' => 'E',
	'ANASI' => 'E',
	'ANASL' => 'B',
	'ANASM' => 'E',
	'ANASO' => 'B',
	'ANASP' => 'B',
	'ANAST' => 'E',
	'ANASU' => 'B',
	'ANATE' => 'E',
	'ANATH' => 'B',
	'ANATR' => 'E',
	'ANAUN' => 'E',
	'ANAVA' => 'B',
	'ANAVE' => 'E',
	'ANAVT' => 'B',
	'ANCAQ' => 'B',
	'ANCCA' => 'E',
	'ANCDI' => 'E',
	'ANCKO' => 'E',
	'ANCOF' => 'E',
	'ANCSP' => 'E',
	'ANDAM' => 'E',
	'ANDAU' => 'E',
	'ANDDA' => 'E',
	'ANDDE' => 'E',
	'ANDIN' => 'E',
	'ANDIS' => 'E',
	'ANDKO' => 'E',
	'ANDMA' => 'E',
	'ANDOL' => 'E',
	'ANDPE' => 'E',
	'ANDPO' => 'E',
	'ANDRO' => 'E',
	'ANDSE' => 'E',
	'ANEAD' => 'E',
	'ANEAN' => 'E',
	'ANEAS' => 'E',
	'ANEBL' => 'E',
	'ANEER' => 'E',
	'ANEMA' => 'E',
	'ANEME' => 'E',
	'ANEMI' => 'B',
	'ANEMU' => 'E',
	'ANENE' => 'E',
	'ANEPH' => 'E',
	'ANESU' => 'E',
	'ANETH' => 'B',
	'ANGAN' => 'E',
	'ANGAR' => 'E',
	'ANGAU' => 'E',
	'ANGCO' => 'E',
	'ANGCU' => 'E',
	'ANGDI' => 'E',
	'ANGEB' => 'E',
	'ANGEI' => 'E',
	'ANGEV' => 'E',
	'ANGFR' => 'E',
	'ANGHO' => 'E',
	'ANGIN' => 'E',
	'ANGJA' => 'E',
	'ANGLY' => 'E',
	'ANGMA' => 'E',
	'ANGMO' => 'E',
	'ANGPA' => 'E',
	'ANGPH' => 'E',
	'ANGRE' => 'E',
	'ANGRO' => 'E',
	'ANGSE' => 'E',
	'ANHNO' => 'E',
	'ANIBU' => 'E',
	'ANIFL' => 'E',
	'ANIIF' => 'E',
	'ANIIM' => 'E',
	'ANIIN' => 'E',
	'ANISC' => 'E',
	'ANISI' => 'E',
	'ANNCH' => 'E',
	'ANNGL' => 'E',
	'ANNMU' => 'E',
	'ANNPU' => 'E',
	'ANNSE' => 'E',
	'ANOAB' => 'E',
	'ANOAL' => 'E',
	'ANOAN' => 'E',
	'ANOAQ' => 'E',
	'ANOAR' => 'E',
	'ANOCA' => 'E',
	'ANOCO' => 'E',
	'ANOCP' => 'E',
	'ANOCU' => 'E',
	'ANODA' => 'E',
	'ANODD' => 'E',
	'ANODI' => 'E',
	'ANOEQ' => 'E',
	'ANOFR' => 'E',
	'ANOFU' => 'E',
	'ANOGA' => 'E',
	'ANOGE' => 'E',
	'ANOHY' => 'E',
	'ANOMA' => 'E',
	'ANOME' => 'E',
	'ANOOC' => 'E',
	'ANOOR' => 'E',
	'ANOOS' => 'E',
	'ANOPN' => 'E',
	'ANOPU' => 'E',
	'ANOQN' => 'E',
	'ANOQU' => 'E',
	'ANOSA' => 'E',
	'ANOSM' => 'E',
	'ANOSP' => 'E',
	'ANOSQ' => 'E',
	'ANOST' => 'E',
	'ANOTI' => 'E',
	'ANOTR' => 'E',
	'ANOYA' => 'E',
	'ANRCO' => 'E',
	'ANSAL' => 'E',
	'ANSAN' => 'E',
	'ANSCA' => 'E',
	'ANSCE' => 'E',
	'ANSCY' => 'E',
	'ANSGI' => 'E',
	'ANSIN' => 'E',
	'ANSRO' => 'E',
	'ANSSE' => 'E',
	'ANTAD' => 'E',
	'ANTAF' => 'E',
	'ANTAM' => 'E',
	'ANTAN' => 'E',
	'ANTBE' => 'E',
	'ANTBU' => 'E',
	'ANTCE' => 'E',
	'ANTCR' => 'E',
	'ANTEL' => 'E',
	'ANTFL' => 'E',
	'ANTFM' => 'E',
	'ANTFO' => 'E',
	'ANTFU' => 'E',
	'ANTGA' => 'E',
	'ANTGL' => 'E',
	'ANTGO' => 'E',
	'ANTGR' => 'E',
	'ANTHA' => 'E',
	'ANTHE' => 'E',
	'ANTHI' => 'E',
	'ANTJA' => 'E',
	'ANTLA' => 'E',
	'ANTLE' => 'E',
	'ANTLI' => 'E',
	'ANTLO' => 'E',
	'ANTLP' => 'E',
	'ANTLU' => 'E',
	'ANTMA' => 'E',
	'ANTMC' => 'E',
	'ANTMD' => 'E',
	'ANTME' => 'E',
	'ANTMI' => 'E',
	'ANTMN' => 'E',
	'ANTMR' => 'E',
	'ANTMU' => 'E',
	'ANTMY' => 'E',
	'ANTNA' => 'E',
	'ANTOB' => 'E',
	'ANTOD' => 'E',
	'ANTPA' => 'E',
	'ANTPE' => 'E',
	'ANTPL' => 'E',
	'ANTPO' => 'E',
	'ANTPU' => 'E',
	'ANTRE' => 'E',
	'ANTSC' => 'E',
	'ANTSI' => 'E',
	'ANTSP' => 'E',
	'ANTST' => 'E',
	'ANTSW' => 'E',
	'ANTTI' => 'E',
	'ANTVI' => 'E',
	'ANTVR' => 'E',
	'ANTVS' => 'E',
	'ANTXA' => 'E',
	'ANTYA' => 'E',
	'ANUPH' => 'E',
	'AONCA' => 'E',
	'AOTAZ' => 'E',
	'AOTIN' => 'E',
	'AOTLE' => 'E',
	'AOTNA' => 'E',
	'AOTNI' => 'E',
	'AOTTR' => 'E',
	'AOTVO' => 'E',
	'APAAM' => 'E',
	'APACH' => 'E',
	'APAFE' => 'E',
	'APAIR' => 'E',
	'APAKA' => 'E',
	'APANA' => 'E',
	'APASP' => 'E',
	'APATO' => 'E',
	'APAVI' => 'E',
	'APHAL' => 'E',
	'APHAP' => 'E',
	'APHAU' => 'E',
	'APHAV' => 'E',
	'APHBL' => 'B',
	'APHCA' => 'E',
	'APHCE' => 'E',
	'APHCH' => 'E',
	'APHCO' => 'E',
	'APHCR' => 'E',
	'APHDE' => 'E',
	'APHEC' => 'E',
	'APHER' => 'E',
	'APHEX' => 'E',
	'APHFA' => 'E',
	'APHFL' => 'B',
	'APHGL' => 'E',
	'APHGO' => 'E',
	'APHHA' => 'B',
	'APHHY' => 'E',
	'APHJA' => 'E',
	'APHMA' => 'E',
	'APHRU' => 'E',
	'APHSA' => 'B',
	'APHSI' => 'E',
	'APICA' => 'E',
	'APICC' => 'E',
	'APICE' => 'E',
	'APIDO' => 'E',
	'APIER' => 'E',
	'APIFL' => 'E',
	'APIGR' => 'E',
	'APIKO' => 'E',
	'APILI' => 'E',
	'APIME' => 'E',
	'APIMS' => 'E',
	'APLBR' => 'E',
	'APLCA' => 'E',
	'APLDE' => 'E',
	'APLFA' => 'E',
	'APLJU' => 'E',
	'APLKU' => 'E',
	'APLLI' => 'E',
	'APLPA' => 'E',
	'APLPU' => 'E',
	'APLRU' => 'E',
	'APLSP' => 'E',
	'APLVA' => 'E',
	'APMV' => 'V',
	'APOAG' => 'E',
	'APOAL' => 'E',
	'APOAN' => 'E',
	'APOAR' => 'E',
	'APOCA' => 'E',
	'APOCR' => 'E',
	'APOCT' => 'E',
	'APODA' => 'E',
	'APOFL' => 'E',
	'APOGR' => 'E',
	'APOHY' => 'E',
	'APOIN' => 'E',
	'APOMI' => 'E',
	'APOMO' => 'E',
	'APOMU' => 'E',
	'APOMY' => 'E',
	'APOSE' => 'E',
	'APOSM' => 'E',
	'APOSY' => 'E',
	'APOTR' => 'E',
	'APPPP' => 'B',
	'APRBU' => 'E',
	'APTAP' => 'E',
	'APTAU' => 'E',
	'APTCO' => 'E',
	'APTFO' => 'E',
	'APTFU' => 'E',
	'APTHA' => 'E',
	'APTOW' => 'E',
	'APTPA' => 'E',
	'APTSC' => 'E',
	'APUAP' => 'E',
	'AQUAD' => 'E',
	'AQUAE' => 'B',
	'AQUAL' => 'E',
	'AQUAR' => 'B',
	'AQUAU' => 'E',
	'AQUCA' => 'E',
	'AQUCH' => 'E',
	'AQUCL' => 'E',
	'AQUFO' => 'E',
	'AQUHE' => 'E',
	'AQUIT' => 'B',
	'AQUNA' => 'E',
	'AQUPY' => 'B',
	'AQUSE' => 'B',
	'ARAAA' => 'E',
	'ARAAC' => 'E',
	'ARAAI' => 'E',
	'ARAAL' => 'E',
	'ARAAR' => 'E',
	'ARAAU' => 'E',
	'ARABI' => 'E',
	'ARABL' => 'E',
	'ARABR' => 'E',
	'ARACH' => 'E',
	'ARACO' => 'E',
	'ARACU' => 'E',
	'ARADE' => 'E',
	'ARADI' => 'E',
	'ARAEL' => 'E',
	'ARAFE' => 'E',
	'ARAFL' => 'E',
	'ARAGE' => 'E',
	'ARAGI' => 'E',
	'ARAGL' => 'E',
	'ARAGU' => 'E',
	'ARAHA' => 'E',
	'ARAHE' => 'E',
	'ARAHI' => 'E',
	'ARAHO' => 'E',
	'ARAHY' => 'E',
	'ARAIR' => 'E',
	'ARAKO' => 'E',
	'ARALE' => 'E',
	'ARALI' => 'E',
	'ARALP' => 'E',
	'ARALY' => 'E',
	'ARAMC' => 'E',
	'ARAMI' => 'E',
	'ARAMT' => 'E',
	'ARAPR' => 'E',
	'ARAPU' => 'E',
	'ARASO' => 'E',
	'ARASU' => 'E',
	'ARATH' => 'E',
	'ARATU' => 'E',
	'ARAWE' => 'E',
	'ARBCA' => 'E',
	'ARBLI' => 'E',
	'ARBME' => 'E',
	'ARBPU' => 'E',
	'ARBTO' => 'E',
	'ARBUN' => 'E',
	'ARCAD' => 'E',
	'ARCAL' => 'E',
	'ARCAR' => 'E',
	'ARCAU' => 'E',
	'ARCBI' => 'E',
	'ARCCA' => 'E',
	'ARCCE' => 'E',
	'ARCCL' => 'E',
	'ARCCO' => 'E',
	'ARCDE' => 'E',
	'ARCEC' => 'E',
	'ARCEL' => 'E',
	'ARCFE' => 'E',
	'ARCFO' => 'E',
	'ARCFU' => 'A',
	'ARCGA' => 'E',
	'ARCGL' => 'E',
	'ARCGZ' => 'E',
	'ARCHA' => 'B',
	'ARCIS' => 'E',
	'ARCLA' => 'E',
	'ARCLI' => 'A',
	'ARCLU' => 'E',
	'ARCMA' => 'E',
	'ARCMI' => 'E',
	'ARCPD' => 'E',
	'ARCPH' => 'E',
	'ARCPR' => 'A',
	'ARCPS' => 'E',
	'ARCRO' => 'E',
	'ARCSE' => 'E',
	'ARCSM' => 'E',
	'ARCTE' => 'E',
	'ARCTO' => 'E',
	'ARCTR' => 'E',
	'ARCUU' => 'E',
	'ARCVE' => 'A',
	'ARCZE' => 'E',
	'ARDAL' => 'E',
	'ARDCI' => 'E',
	'ARDCR' => 'E',
	'ARDHE' => 'E',
	'ARDNC' => 'E',
	'ARDNI' => 'E',
	'AREBU' => 'E',
	'AREDR' => 'E',
	'AREIN' => 'E',
	'AREMA' => 'E',
	'ARGAR' => 'E',
	'ARGAU' => 'E',
	'ARGME' => 'E',
	'ARGPA' => 'E',
	'ARGPU' => 'E',
	'ARGRE' => 'E',
	'ARGSP' => 'E',
	'ARGTR' => 'E',
	'ARGVI' => 'E',
	'ARIAB' => 'E',
	'ARIAG' => 'E',
	'ARIAR' => 'E',
	'ARIBA' => 'E',
	'ARICA' => 'E',
	'ARICI' => 'E',
	'ARICL' => 'E',
	'ARICO' => 'E',
	'ARICY' => 'E',
	'ARIDE' => 'E',
	'ARIEE' => 'E',
	'ARIEL' => 'E',
	'ARIER' => 'E',
	'ARIFA' => 'E',
	'ARIFI' => 'E',
	'ARIFL' => 'E',
	'ARIGG' => 'E',
	'ARIGI' => 'E',
	'ARIGL' => 'E',
	'ARIGR' => 'E',
	'ARIKA' => 'E',
	'ARILI' => 'E',
	'ARIMA' => 'E',
	'ARIMN' => 'E',
	'ARIMX' => 'E',
	'ARINC' => 'E',
	'ARIOD' => 'E',
	'ARION' => 'E',
	'ARIOV' => 'E',
	'ARIPE' => 'E',
	'ARIPI' => 'E',
	'ARIPL' => 'E',
	'ARIRI' => 'E',
	'ARITA' => 'E',
	'ARITI' => 'E',
	'ARITM' => 'E',
	'ARITO' => 'E',
	'ARITR' => 'E',
	'ARIWE' => 'E',
	'ARMMA' => 'E',
	'ARMME' => 'E',
	'ARMRU' => 'E',
	'ARMV' => 'V',
	'ARMVN' => 'V',
	'ARMVS' => 'V',
	'ARMVU' => 'E',
	'ARNDE' => 'E',
	'ARNIM' => 'E',
	'ARNMI' => 'E',
	'ARNMO' => 'E',
	'ARNTH' => 'E',
	'ARPCO' => 'E',
	'ARPGI' => 'E',
	'ARPPS' => 'E',
	'ARREL' => 'E',
	'ARRRU' => 'E',
	'ARTAD' => 'E',
	'ARTAM' => 'E',
	'ARTAN' => 'E',
	'ARTAU' => 'B',
	'ARTAZ' => 'E',
	'ARTBA' => 'E',
	'ARTBE' => 'E',
	'ARTCI' => 'E',
	'ARTCO' => 'E',
	'ARTCR' => 'E',
	'ARTDA' => 'E',
	'ARTFI' => 'E',
	'ARTFM' => 'E',
	'ARTFR' => 'E',
	'ARTFS' => 'E',
	'ARTFU' => 'E',
	'ARTGA' => 'E',
	'ARTGG' => 'E',
	'ARTGL' => 'B',
	'ARTGO' => 'B',
	'ARTGW' => 'E',
	'ARTHA' => 'E',
	'ARTHE' => 'E',
	'ARTHI' => 'E',
	'ARTHX' => 'E',
	'ARTIN' => 'E',
	'ARTIO' => 'E',
	'ARTIT' => 'E',
	'ARTJA' => 'E',
	'ARTLE' => 'E',
	'ARTLI' => 'E',
	'ARTNI' => 'B',
	'ARTOB' => 'E',
	'ARTOL' => 'E',
	'ARTOX' => 'B',
	'ARTPA' => 'E',
	'ARTPH' => 'E',
	'ARTPL' => 'E',
	'ARTRA' => 'E',
	'ARTRM' => 'B',
	'ARTS1' => 'B',
	'ARTS3' => 'B',
	'ARTS7' => 'B',
	'ARTS8' => 'B',
	'ARTSA' => 'E',
	'ARTSB' => 'B',
	'ARTSC' => 'B',
	'ARTSD' => 'B',
	'ARTSF' => 'E',
	'ARTSK' => 'B',
	'ARTSP' => 'B',
	'ARTSQ' => 'B',
	'ARTST' => 'B',
	'ARTSU' => 'E',
	'ARTSW' => 'B',
	'ARTSX' => 'E',
	'ARTSY' => 'B',
	'ARTTL' => 'E',
	'ARTTO' => 'E',
	'ARTTR' => 'E',
	'ARTVI' => 'B',
	'ARTVU' => 'E',
	'ARUDI' => 'E',
	'ARUDO' => 'E',
	'ARUJA' => 'E',
	'ARUMA' => 'E',
	'ARUMO' => 'E',
	'ARVS1' => 'V',
	'ARVSO' => 'E',
	'ARVTE' => 'E',
	'ARXAD' => 'E',
	'ARXTE' => 'E',
	'ARYSP' => 'E',
	'ASACA' => 'E',
	'ASACU' => 'E',
	'ASADI' => 'E',
	'ASAEU' => 'E',
	'ASCCU' => 'E',
	'ASCEX' => 'E',
	'ASCIM' => 'E',
	'ASCIN' => 'E',
	'ASCNO' => 'E',
	'ASCRA' => 'E',
	'ASCSS' => 'E',
	'ASCSU' => 'E',
	'ASCSY' => 'E',
	'ASCTA' => 'E',
	'ASCTR' => 'E',
	'ASCTU' => 'E',
	'ASEAQ' => 'E',
	'ASF' => 'V',
	'ASFB7' => 'V',
	'ASFC1' => 'V',
	'ASFC3' => 'V',
	'ASFCH' => 'V',
	'ASFE1' => 'V',
	'ASFE4' => 'V',
	'ASFE7' => 'V',
	'ASFH8' => 'V',
	'ASFL5' => 'V',
	'ASFL6' => 'V',
	'ASFM1' => 'V',
	'ASFM2' => 'V',
	'ASFP5' => 'V',
	'ASGVK' => 'V',
	'ASGVP' => 'V',
	'ASHGO' => 'E',
	'ASHYP' => 'B',
	'ASIFL' => 'E',
	'ASIOT' => 'E',
	'ASIPA' => 'E',
	'ASITR' => 'E',
	'ASOTA' => 'E',
	'ASPAC' => 'E',
	'ASPAM' => 'E',
	'ASPAN' => 'E',
	'ASPAU' => 'E',
	'ASPAW' => 'E',
	'ASPCL' => 'E',
	'ASPCY' => 'E',
	'ASPEL' => 'E',
	'ASPFI' => 'E',
	'ASPFL' => 'E',
	'ASPFU' => 'E',
	'ASPGI' => 'E',
	'ASPJA' => 'E',
	'ASPKA' => 'E',
	'ASPLA' => 'E',
	'ASPLU' => 'E',
	'ASPME' => 'E',
	'ASPMU' => 'E',
	'ASPND' => 'E',
	'ASPNG' => 'E',
	'ASPNO' => 'E',
	'ASPOF' => 'E',
	'ASPOR' => 'E',
	'ASPPA' => 'E',
	'ASPPL' => 'E',
	'ASPPS' => 'E',
	'ASPRE' => 'E',
	'ASPSA' => 'E',
	'ASPSB' => 'E',
	'ASPSC' => 'E',
	'ASPSE' => 'E',
	'ASPSH' => 'E',
	'ASPSO' => 'E',
	'ASPTE' => 'E',
	'ASPTR' => 'E',
	'ASPTU' => 'E',
	'ASPVI' => 'E',
	'ASPWE' => 'E',
	'ASTAL' => 'E',
	'ASTAM' => 'E',
	'ASTBI' => 'E',
	'ASTCL' => 'E',
	'ASTCO' => 'E',
	'ASTDO' => 'E',
	'ASTFA' => 'E',
	'ASTFC' => 'E',
	'ASTFL' => 'E',
	'ASTFO' => 'E',
	'ASTGL' => 'E',
	'ASTGR' => 'E',
	'ASTLA' => 'E',
	'ASTLJ' => 'E',
	'ASTLO' => 'E',
	'ASTME' => 'E',
	'ASTMI' => 'E',
	'ASTMO' => 'E',
	'ASTMY' => 'E',
	'ASTOC' => 'E',
	'ASTPE' => 'E',
	'ASTRA' => 'E',
	'ASTRI' => 'B',
	'ASTRU' => 'E',
	'ASTSE' => 'E',
	'ASTSI' => 'E',
	'ASTSM' => 'E',
	'ASTST' => 'E',
	'ASTTR' => 'E',
	'ASTVU' => 'E',
	'ASTYP' => 'B',
	'ATEAB' => 'E',
	'ATEAL' => 'E',
	'ATEBE' => 'E',
	'ATEFR' => 'E',
	'ATEFU' => 'E',
	'ATEGE' => 'E',
	'ATEMI' => 'E',
	'ATEPA' => 'E',
	'ATESP' => 'E',
	'ATHBO' => 'E',
	'ATHBR' => 'E',
	'ATHCE' => 'E',
	'ATHCH' => 'E',
	'ATHCU' => 'E',
	'ATHDE' => 'E',
	'ATHFF' => 'E',
	'ATHGP' => 'E',
	'ATHGR' => 'E',
	'ATHLA' => 'E',
	'ATHMA' => 'E',
	'ATHNI' => 'E',
	'ATHNO' => 'E',
	'ATHSE' => 'E',
	'ATHSQ' => 'E',
	'ATHV3' => 'V',
	'ATLFU' => 'E',
	'ATLME' => 'E',
	'ATRBE' => 'E',
	'ATRBI' => 'E',
	'ATRCA' => 'E',
	'ATREN' => 'E',
	'ATRFR' => 'E',
	'ATRHA' => 'E',
	'ATRHO' => 'E',
	'ATRIL' => 'E',
	'ATRJA' => 'E',
	'ATRLE' => 'E',
	'ATRMI' => 'E',
	'ATRMM' => 'E',
	'ATRNM' => 'E',
	'ATRNU' => 'E',
	'ATRPA' => 'E',
	'ATRPI' => 'E',
	'ATRPR' => 'E',
	'ATRRI' => 'E',
	'ATRRO' => 'E',
	'ATRRS' => 'E',
	'ATTAT' => 'E',
	'ATTPU' => 'E',
	'AUCJA' => 'E',
	'AULBO' => 'E',
	'AULCH' => 'E',
	'AULHA' => 'E',
	'AULMI' => 'E',
	'AULPI' => 'E',
	'AULVE' => 'E',
	'AURAU' => 'E',
	'AURAV' => 'V',
	'AURPU' => 'E',
	'AUSBL' => 'E',
	'AUSDE' => 'E',
	'AUSSU' => 'E',
	'AUSVE' => 'E',
	'AUSVS' => 'E',
	'AUTGA' => 'E',
	'AUTIO' => 'E',
	'AUXRO' => 'E',
	'AUXZU' => 'E',
	'AVALA' => 'E',
	'AVAOC' => 'E',
	'AVECA' => 'E',
	'AVEFA' => 'E',
	'AVENU' => 'E',
	'AVESA' => 'E',
	'AVEV1' => 'V',
	'AVEV2' => 'V',
	'AVEVR' => 'V',
	'AVIER' => 'V',
	'AVIES' => 'V',
	'AVIET' => 'V',
	'AVIEU' => 'V',
	'AVIGE' => 'E',
	'AVII1' => 'V',
	'AVILE' => 'V',
	'AVIM2' => 'V',
	'AVIMA' => 'V',
	'AVIMB' => 'V',
	'AVIMC' => 'V',
	'AVIMD' => 'V',
	'AVIME' => 'V',
	'AVIMH' => 'V',
	'AVIMR' => 'E',
	'AVINK' => 'V',
	'AVIOK' => 'V',
	'AVIR3' => 'V',
	'AVIRE' => 'V',
	'AVIS1' => 'V',
	'AVIS2' => 'V',
	'AVIS3' => 'V',
	'AVIS4' => 'V',
	'AVISC' => 'V',
	'AVISN' => 'V',
	'AVISP' => 'V',
	'AVISR' => 'V',
	'AVISS' => 'V',
	'AVIST' => 'V',
	'AVISU' => 'V',
	'AVISY' => 'V',
	'AXIAX' => 'E',
	'AXICO' => 'E',
	'AXIDA' => 'E',
	'AXIDI' => 'E',
	'AXIPR' => 'E',
	'AXIVE' => 'E',
	'AYTAM' => 'E',
	'AYTFU' => 'E',
	'AYTVA' => 'E',
	'AYWBP' => 'B',
	'AZAIN' => 'E',
	'AZEFE' => 'E',
	'AZOBR' => 'B',
	'AZOCA' => 'B',
	'AZOCH' => 'B',
	'AZOFI' => 'E',
	'AZOIR' => 'B',
	'AZOLI' => 'B',
	'AZOMA' => 'B',
	'AZOPA' => 'B',
	'AZOSA' => 'B',
	'AZOSE' => 'B',
	'AZOVI' => 'B',
	'BABBA' => 'E',
	'BABBI' => 'E',
	'BABBO' => 'E',
	'BABCA' => 'E',
	'BABCB' => 'E',
	'BABCE' => 'E',
	'BABDI' => 'E',
	'BABEQ' => 'E',
	'BABGI' => 'E',
	'BABHY' => 'E',
	'BABMI' => 'E',
	'BABOD' => 'E',
	'BABOV' => 'E',
	'BABPO' => 'E',
	'BABRO' => 'E',
	'BABRS' => 'E',
	'BABST' => 'E',
	'BAC11' => 'B',
	'BAC17' => 'B',
	'BAC25' => 'B',
	'BACAD' => 'B',
	'BACAE' => 'E',
	'BACAG' => 'B',
	'BACAL' => 'E',
	'BACAM' => 'B',
	'BACAN' => 'B',
	'BACAO' => 'B',
	'BACAQ' => 'E',
	'BACAR' => 'B',
	'BACAT' => 'B',
	'BACAU' => 'E',
	'BACAZ' => 'B',
	'BACB0' => 'B',
	'BACB2' => 'B',
	'BACBA' => 'B',
	'BACBN' => 'E',
	'BACC1' => 'B',
	'BACCA' => 'B',
	'BACCB' => 'E',
	'BACCC' => 'E',
	'BACCD' => 'B',
	'BACCE' => 'B',
	'BACCF' => 'E',
	'BACCG' => 'E',
	'BACCH' => 'E',
	'BACCI' => 'B',
	'BACCL' => 'B',
	'BACCM' => 'E',
	'BACCO' => 'B',
	'BACCR' => 'B',
	'BACCS' => 'B',
	'BACCT' => 'E',
	'BACCU' => 'E',
	'BACCV' => 'E',
	'BACCY' => 'E',
	'BACCZ' => 'B',
	'BACDE' => 'E',
	'BACDI' => 'E',
	'BACDO' => 'E',
	'BACEN' => 'E',
	'BACEX' => 'E',
	'BACF5' => 'B',
	'BACFA' => 'E',
	'BACFI' => 'B',
	'BACFN' => 'B',
	'BACFO' => 'B',
	'BACFR' => 'B',
	'BACGL' => 'B',
	'BACGO' => 'B',
	'BACHA' => 'B',
	'BACHD' => 'B',
	'BACHK' => 'B',
	'BACHL' => 'E',
	'BACIN' => 'B',
	'BACIS' => 'B',
	'BACJA' => 'E',
	'BACKI' => 'E',
	'BACLA' => 'E',
	'BACLD' => 'B',
	'BACLE' => 'B',
	'BACLI' => 'B',
	'BACMC' => 'B',
	'BACME' => 'B',
	'BACML' => 'E',
	'BACMO' => 'B',
	'BACMR' => 'E',
	'BACMT' => 'B',
	'BACMU' => 'E',
	'BACMY' => 'B',
	'BACNA' => 'B',
	'BACNE' => 'E',
	'BACNG' => 'E',
	'BACNO' => 'B',
	'BACOH' => 'B',
	'BACOL' => 'E',
	'BACOV' => 'B',
	'BACOY' => 'B',
	'BACP3' => 'B',
	'BACPA' => 'B',
	'BACPD' => 'E',
	'BACPF' => 'B',
	'BACPI' => 'E',
	'BACPJ' => 'B',
	'BACPP' => 'E',
	'BACPS' => 'B',
	'BACPU' => 'B',
	'BACPY' => 'B',
	'BACRI' => 'E',
	'BACRY' => 'E',
	'BACS0' => 'B',
	'BACS1' => 'B',
	'BACS2' => 'B',
	'BACS3' => 'B',
	'BACS4' => 'B',
	'BACS5' => 'B',
	'BACS6' => 'B',
	'BACS7' => 'B',
	'BACS8' => 'B',
	'BACS9' => 'B',
	'BACSA' => 'B',
	'BACSB' => 'B',
	'BACSC' => 'B',
	'BACSD' => 'B',
	'BACSE' => 'B',
	'BACSF' => 'B',
	'BACSG' => 'B',
	'BACSH' => 'B',
	'BACSI' => 'B',
	'BACSJ' => 'B',
	'BACSK' => 'B',
	'BACSL' => 'B',
	'BACSM' => 'B',
	'BACSN' => 'B',
	'BACSO' => 'B',
	'BACSP' => 'B',
	'BACSQ' => 'B',
	'BACSR' => 'B',
	'BACSS' => 'B',
	'BACST' => 'B',
	'BACSU' => 'B',
	'BACSV' => 'B',
	'BACSW' => 'B',
	'BACSX' => 'B',
	'BACSY' => 'B',
	'BACSZ' => 'B',
	'BACTA' => 'B',
	'BACTB' => 'B',
	'BACTC' => 'B',
	'BACTD' => 'B',
	'BACTE' => 'B',
	'BACTF' => 'B',
	'BACTG' => 'B',
	'BACTH' => 'B',
	'BACTI' => 'B',
	'BACTJ' => 'B',
	'BACTK' => 'B',
	'BACTL' => 'B',
	'BACTM' => 'B',
	'BACTN' => 'B',
	'BACTO' => 'B',
	'BACTP' => 'B',
	'BACTQ' => 'B',
	'BACTR' => 'B',
	'BACTS' => 'B',
	'BACTT' => 'B',
	'BACTU' => 'B',
	'BACTV' => 'B',
	'BACTW' => 'B',
	'BACTX' => 'B',
	'BACTY' => 'B',
	'BACTZ' => 'B',
	'BACUA' => 'B',
	'BACUB' => 'E',
	'BACUD' => 'B',
	'BACUE' => 'E',
	'BACUF' => 'B',
	'BACUH' => 'B',
	'BACUK' => 'B',
	'BACUM' => 'E',
	'BACUN' => 'B',
	'BACUT' => 'B',
	'BACVA' => 'B',
	'BACVU' => 'B',
	'BACXA' => 'E',
	'BACY2' => 'B',
	'BACYA' => 'B',
	'BACYM' => 'B',
	'BACYN' => 'B',
	'BAEBI' => 'E',
	'BAEIN' => 'E',
	'BAEVM' => 'V',
	'BAEWO' => 'E',
	'BAHAB' => 'E',
	'BAHTO' => 'E',
	'BAITA' => 'E',
	'BALAC' => 'E',
	'BALAM' => 'E',
	'BALBN' => 'E',
	'BALBO' => 'E',
	'BALBR' => 'E',
	'BALCA' => 'E',
	'BALED' => 'E',
	'BALGL' => 'E',
	'BALMA' => 'E',
	'BALMU' => 'E',
	'BALMY' => 'E',
	'BALNU' => 'E',
	'BALOB' => 'E',
	'BALOM' => 'E',
	'BALPA' => 'E',
	'BALPH' => 'E',
	'BALPL' => 'E',
	'BALRA' => 'E',
	'BALRE' => 'E',
	'BALSE' => 'E',
	'BALVI' => 'E',
	'BAMGL' => 'E',
	'BAMMA' => 'V',
	'BAMMN' => 'V',
	'BAMMU' => 'V',
	'BAMOL' => 'E',
	'BAMTH' => 'E',
	'BAMVU' => 'E',
	'BANAT' => 'E',
	'BANCA' => 'E',
	'BANCU' => 'E',
	'BANGO' => 'E',
	'BANRO' => 'E',
	'BAPTI' => 'E',
	'BARAL' => 'E',
	'BARAS' => 'E',
	'BARBA' => 'B',
	'BARBO' => 'E',
	'BARBR' => 'E',
	'BARBU' => 'E',
	'BARCA' => 'E',
	'BARCL' => 'B',
	'BARDO' => 'B',
	'BAREL' => 'B',
	'BARGR' => 'B',
	'BARHE' => 'B',
	'BARIN' => 'E',
	'BARLO' => 'E',
	'BARMA' => 'E',
	'BARPR' => 'E',
	'BARPS' => 'E',
	'BARQU' => 'B',
	'BARRE' => 'E',
	'BARRU' => 'E',
	'BARSC' => 'E',
	'BARTA' => 'B',
	'BARVB' => 'B',
	'BARVI' => 'B',
	'BARVU' => 'E',
	'BASAL' => 'E',
	'BASAS' => 'E',
	'BASCU' => 'E',
	'BASHY' => 'E',
	'BASPL' => 'E',
	'BATEA' => 'E',
	'BATGI' => 'E',
	'BATGR' => 'E',
	'BATJA' => 'E',
	'BATMA' => 'E',
	'BATMC' => 'E',
	'BATMU' => 'E',
	'BATNI' => 'E',
	'BATOE' => 'E',
	'BATPH' => 'E',
	'BATSP' => 'E',
	'BATSU' => 'E',
	'BAUBA' => 'E',
	'BAUCH' => 'B',
	'BAUPU' => 'E',
	'BAURF' => 'E',
	'BAURU' => 'E',
	'BAUSP' => 'E',
	'BAUUN' => 'E',
	'BAUVA' => 'E',
	'BAYMG' => 'V',
	'BAYMJ' => 'V',
	'BAYPR' => 'E',
	'BAZTR' => 'E',
	'BBMV' => 'V',
	'BBV' => 'V',
	'BCMVN' => 'V',
	'BCTV' => 'V',
	'BDEBA' => 'B',
	'BDECA' => 'E',
	'BDV' => 'V',
	'BEABA' => 'E',
	'BEAGR' => 'E',
	'BEAHI' => 'E',
	'BEAHU' => 'E',
	'BEARE' => 'E',
	'BEBJU' => 'E',
	'BEFRA' => 'E',
	'BEFRE' => 'E',
	'BEFV' => 'V',
	'BEGMS' => 'E',
	'BEHRE' => 'E',
	'BELCH' => 'E',
	'BELMO' => 'E',
	'BELPA' => 'E',
	'BELPE' => 'E',
	'BEMTA' => 'E',
	'BENHI' => 'E',
	'BERAR' => 'E',
	'BERBI' => 'E',
	'BERBO' => 'E',
	'BERBR' => 'E',
	'BERCI' => 'E',
	'BERCO' => 'E',
	'BEREX' => 'E',
	'BERLA' => 'E',
	'BEROV' => 'E',
	'BERSI' => 'E',
	'BERST' => 'E',
	'BERTH' => 'E',
	'BERVA' => 'E',
	'BESDA' => 'E',
	'BESOR' => 'E',
	'BETCO' => 'E',
	'BETLO' => 'E',
	'BETMA' => 'E',
	'BETMR' => 'E',
	'BETNA' => 'E',
	'BETNI' => 'E',
	'BETPA' => 'E',
	'BETPE' => 'E',
	'BETPR' => 'E',
	'BETTR' => 'E',
	'BETVE' => 'E',
	'BETVU' => 'E',
	'BETWE' => 'E',
	'BEV' => 'V',
	'BFDV' => 'V',
	'BFDVM' => 'V',
	'BFV' => 'V',
	'BGMV' => 'V',
	'BHV16' => 'V',
	'BHV1C' => 'V',
	'BHV1J' => 'V',
	'BHV1K' => 'V',
	'BHV1P' => 'V',
	'BHV1Q' => 'V',
	'BHV1S' => 'V',
	'BHV2B' => 'V',
	'BHV2H' => 'V',
	'BHV4' => 'V',
	'BHV46' => 'V',
	'BHV4D' => 'V',
	'BHV5' => 'V',
	'BIBMA' => 'E',
	'BIDPI' => 'E',
	'BIFAD' => 'B',
	'BIFAN' => 'B',
	'BIFBR' => 'B',
	'BIFLO' => 'B',
	'BILWA' => 'B',
	'BIOAL' => 'E',
	'BIOGL' => 'E',
	'BIOOB' => 'E',
	'BIOOC' => 'E',
	'BIOPF' => 'E',
	'BIOTE' => 'E',
	'BIPBI' => 'E',
	'BIPLU' => 'E',
	'BISBI' => 'E',
	'BISBO' => 'E',
	'BISPR' => 'E',
	'BITAR' => 'E',
	'BITAT' => 'E',
	'BITCA' => 'E',
	'BITGA' => 'E',
	'BITNA' => 'E',
	'BITPI' => 'E',
	'BITST' => 'E',
	'BITTE' => 'E',
	'BITWO' => 'E',
	'BIV06' => 'V',
	'BIV27' => 'V',
	'BIXOR' => 'E',
	'BIZLO' => 'E',
	'BLABE' => 'E',
	'BLABR' => 'E',
	'BLACA' => 'E',
	'BLACI' => 'E',
	'BLACR' => 'E',
	'BLADC' => 'E',
	'BLADI' => 'E',
	'BLADU' => 'E',
	'BLAEM' => 'E',
	'BLAGE' => 'E',
	'BLAGI' => 'E',
	'BLAGR' => 'E',
	'BLAHO' => 'E',
	'BLAHY' => 'E',
	'BLAMU' => 'E',
	'BLAOC' => 'E',
	'BLAOR' => 'E',
	'BLEAM' => 'E',
	'BLEDE' => 'E',
	'BLEJA' => 'E',
	'BLEMU' => 'E',
	'BLENA' => 'E',
	'BLEOC' => 'E',
	'BLEOR' => 'E',
	'BLESP' => 'E',
	'BLEZA' => 'E',
	'BLOCR' => 'E',
	'BLOFL' => 'B',
	'BLOPB' => 'B',
	'BLOTA' => 'E',
	'BLRV' => 'V',
	'BLUGR' => 'E',
	'BLV' => 'V',
	'BLVAF' => 'V',
	'BLVAU' => 'V',
	'BLVAV' => 'V',
	'BLVB2' => 'V',
	'BLVB5' => 'V',
	'BLVJ' => 'V',
	'BMDNV' => 'V',
	'BMDV' => 'V',
	'BMV' => 'V',
	'BNYVF' => 'V',
	'BNYVG' => 'V',
	'BOACO' => 'E',
	'BOBGL' => 'E',
	'BOEDR' => 'E',
	'BOENI' => 'E',
	'BOEPA' => 'E',
	'BOIDE' => 'E',
	'BOLAD' => 'E',
	'BOLAL' => 'E',
	'BOLAM' => 'E',
	'BOLAV' => 'E',
	'BOLBE' => 'E',
	'BOLCO' => 'E',
	'BOLDO' => 'E',
	'BOLED' => 'E',
	'BOLEP' => 'E',
	'BOLFL' => 'E',
	'BOLLA' => 'E',
	'BOLLS' => 'E',
	'BOLMU' => 'E',
	'BOLTE' => 'E',
	'BOLUR' => 'E',
	'BOMBO' => 'E',
	'BOMBU' => 'E',
	'BOMCE' => 'E',
	'BOMCI' => 'E',
	'BOMFR' => 'E',
	'BOMGA' => 'E',
	'BOMHO' => 'E',
	'BOMHU' => 'E',
	'BOMHY' => 'E',
	'BOMIM' => 'E',
	'BOMJA' => 'E',
	'BOMLA' => 'E',
	'BOMLU' => 'E',
	'BOMMA' => 'E',
	'BOMMO' => 'E',
	'BOMMX' => 'E',
	'BOMOR' => 'E',
	'BOMPA' => 'E',
	'BOMPR' => 'E',
	'BOMRU' => 'E',
	'BOMSP' => 'E',
	'BOMSU' => 'E',
	'BOMSY' => 'E',
	'BOMTE' => 'E',
	'BOMVA' => 'E',
	'BONBI' => 'E',
	'BONUM' => 'E',
	'BOOGL' => 'E',
	'BOOLV' => 'V',
	'BOOMI' => 'E',
	'BORA1' => 'B',
	'BORAD' => 'B',
	'BORAF' => 'B',
	'BORAN' => 'B',
	'BORAP' => 'B',
	'BORAR' => 'E',
	'BORAV' => 'B',
	'BORBI' => 'B',
	'BORBR' => 'B',
	'BORBU' => 'B',
	'BORFR' => 'E',
	'BORGA' => 'B',
	'BORHE' => 'B',
	'BORJA' => 'B',
	'BOROF' => 'E',
	'BORPA' => 'B',
	'BORPE' => 'B',
	'BORPR' => 'B',
	'BORSA' => 'E',
	'BORTU' => 'B',
	'BORVA' => 'B',
	'BOSCA' => 'E',
	'BOSCL' => 'E',
	'BOSGA' => 'E',
	'BOSGF' => 'E',
	'BOSIN' => 'E',
	'BOSJA' => 'E',
	'BOSMO' => 'E',
	'BOSMU' => 'E',
	'BOSPR' => 'E',
	'BOSRA' => 'E',
	'BOSSA' => 'E',
	'BOSTR' => 'E',
	'BOTAC' => 'E',
	'BOTAS' => 'E',
	'BOTAT' => 'E',
	'BOTBI' => 'E',
	'BOTBR' => 'E',
	'BOTCI' => 'E',
	'BOTCO' => 'E',
	'BOTDI' => 'E',
	'BOTER' => 'E',
	'BOTIN' => 'E',
	'BOTJA' => 'E',
	'BOTJR' => 'E',
	'BOTLA' => 'E',
	'BOTLC' => 'E',
	'BOTLE' => 'E',
	'BOTLU' => 'E',
	'BOTMO' => 'E',
	'BOTMU' => 'E',
	'BOTNE' => 'E',
	'BOTPC' => 'E',
	'BOTPI' => 'E',
	'BOTPO' => 'E',
	'BOTSC' => 'E',
	'BOTSH' => 'E',
	'BOTST' => 'E',
	'BOTSU' => 'E',
	'BOUAN' => 'E',
	'BOUCH' => 'E',
	'BOUGL' => 'E',
	'BOUMI' => 'E',
	'BOUTA' => 'E',
	'BOVEV' => 'V',
	'BOVIN' => 'E',
	'BOVVA' => 'E',
	'BOWMI' => 'E',
	'BOWSE' => 'E',
	'BOWVO' => 'E',
	'BP163' => 'V',
	'BP186' => 'V',
	'BP434' => 'V',
	'BP82' => 'V',
	'BP933' => 'V',
	'BPA18' => 'V',
	'BPA50' => 'V',
	'BPA51' => 'V',
	'BPAL3' => 'V',
	'BPAPS' => 'V',
	'BPAR1' => 'V',
	'BPB03' => 'V',
	'BPBF2' => 'V',
	'BPBO1' => 'V',
	'BPBZ1' => 'V',
	'BPCHP' => 'V',
	'BPCP1' => 'V',
	'BPCP7' => 'V',
	'BPCP9' => 'V',
	'BPCPT' => 'V',
	'BPD10' => 'V',
	'BPD3' => 'V',
	'BPD31' => 'V',
	'BPDP1' => 'V',
	'BPF1' => 'V',
	'BPF2' => 'V',
	'BPF41' => 'V',
	'BPFD' => 'V',
	'BPFR' => 'V',
	'BPFSA' => 'V',
	'BPG4' => 'V',
	'BPGA' => 'V',
	'BPGA1' => 'V',
	'BPH19' => 'V',
	'BPH30' => 'V',
	'BPH44' => 'V',
	'BPH45' => 'V',
	'BPH75' => 'V',
	'BPHB3' => 'V',
	'BPHK0' => 'V',
	'BPHK6' => 'V',
	'BPHK7' => 'V',
	'BPHP1' => 'V',
	'BPI22' => 'V',
	'BPIF1' => 'V',
	'BPIKE' => 'V',
	'BPJP3' => 'V',
	'BPJP5' => 'V',
	'BPK11' => 'V',
	'BPK1E' => 'V',
	'BPK1F' => 'V',
	'BPK3' => 'V',
	'BPKU1' => 'V',
	'BPKV4' => 'V',
	'BPL2' => 'V',
	'BPL54' => 'V',
	'BPL79' => 'V',
	'BPLC2' => 'V',
	'BPLLH' => 'V',
	'BPLP7' => 'V',
	'BPLZ1' => 'V',
	'BPLZ3' => 'V',
	'BPLZ4' => 'V',
	'BPLZ5' => 'V',
	'BPM1' => 'V',
	'BPM13' => 'V',
	'BPM2' => 'V',
	'BPMB1' => 'V',
	'BPMB2' => 'V',
	'BPMD2' => 'V',
	'BPMFR' => 'V',
	'BPML5' => 'V',
	'BPMS2' => 'V',
	'BPMT4' => 'V',
	'BPMU' => 'V',
	'BPMV' => 'V',
	'BPMV1' => 'V',
	'BPMV4' => 'V',
	'BPN15' => 'V',
	'BPN4' => 'V',
	'BPNF' => 'V',
	'BPOX2' => 'V',
	'BPP1' => 'V',
	'BPP2' => 'V',
	'BPP21' => 'V',
	'BPP22' => 'V',
	'BPP4' => 'V',
	'BPP42' => 'V',
	'BPP7' => 'V',
	'BPPA2' => 'V',
	'BPPB1' => 'V',
	'BPPB2' => 'V',
	'BPPF1' => 'V',
	'BPPF3' => 'V',
	'BPPH1' => 'V',
	'BPPH2' => 'V',
	'BPPH3' => 'V',
	'BPPH5' => 'V',
	'BPPH6' => 'V',
	'BPPH8' => 'V',
	'BPPHA' => 'V',
	'BPPHC' => 'V',
	'BPPHD' => 'V',
	'BPPHH' => 'V',
	'BPPHK' => 'V',
	'BPPHL' => 'V',
	'BPPHT' => 'V',
	'BPPHV' => 'V',
	'BPPHX' => 'V',
	'BPPM2' => 'V',
	'BPPP7' => 'V',
	'BPPRD' => 'V',
	'BPPRR' => 'V',
	'BPPS1' => 'V',
	'BPPS3' => 'V',
	'BPPST' => 'V',
	'BPPZA' => 'V',
	'BPQBE' => 'V',
	'BPR03' => 'V',
	'BPR06' => 'V',
	'BPR08' => 'V',
	'BPR09' => 'V',
	'BPR10' => 'V',
	'BPR15' => 'V',
	'BPR17' => 'V',
	'BPR18' => 'V',
	'BPR1T' => 'V',
	'BPR27' => 'V',
	'BPR32' => 'V',
	'BPR51' => 'V',
	'BPR69' => 'V',
	'BPR70' => 'V',
	'BPRH1' => 'V',
	'BPRH5' => 'V',
	'BPS13' => 'V',
	'BPS14' => 'V',
	'BPS2' => 'V',
	'BPS76' => 'V',
	'BPSF2' => 'V',
	'BPSF5' => 'V',
	'BPSF6' => 'V',
	'BPSFV' => 'V',
	'BPSFX' => 'V',
	'BPSP' => 'V',
	'BPSP1' => 'V',
	'BPSP2' => 'V',
	'BPSP6' => 'V',
	'BPSPB' => 'V',
	'BPSPC' => 'V',
	'BPSPP' => 'V',
	'BPSPR' => 'V',
	'BPST1' => 'V',
	'BPST6' => 'V',
	'BPT12' => 'V',
	'BPT2' => 'V',
	'BPT3' => 'V',
	'BPT4' => 'V',
	'BPT5' => 'V',
	'BPT6' => 'V',
	'BPT7' => 'V',
	'BPTH1' => 'V',
	'BPTU2' => 'V',
	'BPV1' => 'V',
	'BPV2' => 'V',
	'BPV3' => 'V',
	'BPV4' => 'V',
	'BPV5' => 'V',
	'BPV6' => 'V',
	'BPVK' => 'V',
	'BPVT2' => 'V',
	'BPXF' => 'V',
	'BPZJ2' => 'V',
	'BPZR' => 'V',
	'BRAAC' => 'E',
	'BRAAD' => 'E',
	'BRAAL' => 'E',
	'BRAAR' => 'E',
	'BRABE' => 'E',
	'BRABN' => 'E',
	'BRABR' => 'E',
	'BRABT' => 'E',
	'BRACA' => 'E',
	'BRACE' => 'E',
	'BRACI' => 'E',
	'BRACL' => 'E',
	'BRACM' => 'E',
	'BRACR' => 'E',
	'BRACV' => 'E',
	'BRADE' => 'E',
	'BRAEL' => 'B',
	'BRAFA' => 'E',
	'BRAFL' => 'E',
	'BRAHY' => 'E',
	'BRAID' => 'E',
	'BRAJA' => 'B',
	'BRAJU' => 'E',
	'BRALA' => 'E',
	'BRAMA' => 'E',
	'BRANA' => 'E',
	'BRANI' => 'E',
	'BRANN' => 'E',
	'BRANO' => 'E',
	'BRAOA' => 'E',
	'BRAOB' => 'E',
	'BRAOC' => 'E',
	'BRAOE' => 'E',
	'BRAOG' => 'E',
	'BRAOI' => 'E',
	'BRAOL' => 'E',
	'BRAOT' => 'E',
	'BRAOX' => 'E',
	'BRAPH' => 'E',
	'BRAPI' => 'E',
	'BRAPL' => 'B',
	'BRAPM' => 'E',
	'BRAPO' => 'E',
	'BRAPU' => 'E',
	'BRARA' => 'E',
	'BRARC' => 'E',
	'BRARE' => 'E',
	'BRARM' => 'E',
	'BRARO' => 'E',
	'BRARP' => 'E',
	'BRARU' => 'E',
	'BRASA' => 'E',
	'BRASC' => 'E',
	'BRASM' => 'E',
	'BRASN' => 'B',
	'BRASP' => 'B',
	'BRASR' => 'B',
	'BRASS' => 'B',
	'BRASW' => 'B',
	'BRASX' => 'E',
	'BRASY' => 'E',
	'BRATA' => 'E',
	'BRATN' => 'E',
	'BRATO' => 'E',
	'BRATR' => 'E',
	'BRAV' => 'V',
	'BRAVA' => 'E',
	'BRAVE' => 'E',
	'BRAVI' => 'E',
	'BRD' => 'V',
	'BREAN' => 'E',
	'BREBE' => 'B',
	'BREBR' => 'E',
	'BRECH' => 'B',
	'BRECS' => 'E',
	'BREDI' => 'B',
	'BREEP' => 'B',
	'BREHE' => 'B',
	'BRELC' => 'E',
	'BRELI' => 'B',
	'BRELN' => 'B',
	'BREMA' => 'E',
	'BRENA' => 'E',
	'BRENE' => 'E',
	'BREPA' => 'B',
	'BREST' => 'B',
	'BREVE' => 'B',
	'BRIAM' => 'E',
	'BRIIN' => 'E',
	'BRIMA' => 'E',
	'BRIPO' => 'E',
	'BROAM' => 'E',
	'BROAN' => 'E',
	'BROAR' => 'E',
	'BROAV' => 'E',
	'BROBR' => 'E',
	'BROCA' => 'E',
	'BROCM' => 'E',
	'BROCN' => 'E',
	'BROCO' => 'E',
	'BROCR' => 'E',
	'BROER' => 'E',
	'BROFI' => 'E',
	'BROFL' => 'E',
	'BROHE' => 'E',
	'BROHO' => 'E',
	'BROIN' => 'E',
	'BROMI' => 'E',
	'BRONA' => 'E',
	'BROOR' => 'E',
	'BROPA' => 'E',
	'BROPE' => 'E',
	'BROPL' => 'E',
	'BROPY' => 'E',
	'BROSE' => 'E',
	'BROST' => 'E',
	'BROSU' => 'E',
	'BROTE' => 'E',
	'BROTH' => 'B',
	'BROTR' => 'E',
	'BROTU' => 'E',
	'BRSV' => 'V',
	'BRSV1' => 'V',
	'BRSV2' => 'V',
	'BRSV3' => 'V',
	'BRSV4' => 'V',
	'BRSV7' => 'V',
	'BRSV9' => 'V',
	'BRSVA' => 'V',
	'BRSVC' => 'V',
	'BRSVL' => 'V',
	'BRSVR' => 'V',
	'BRSVS' => 'V',
	'BRSVW' => 'V',
	'BRUA2' => 'B',
	'BRUAB' => 'B',
	'BRUCA' => 'B',
	'BRUMA' => 'E',
	'BRUME' => 'B',
	'BRUNE' => 'B',
	'BRUOV' => 'B',
	'BRUPA' => 'E',
	'BRUSP' => 'E',
	'BRUSU' => 'B',
	'BRV1' => 'V',
	'BRV2' => 'V',
	'BRYCA' => 'E',
	'BRYDI' => 'E',
	'BRYGM' => 'E',
	'BRYMA' => 'E',
	'BRYPL' => 'E',
	'BSCR3' => 'V',
	'BSMV' => 'V',
	'BSNV' => 'V',
	'BSTV1' => 'V',
	'BSTVG' => 'V',
	'BTMV' => 'V',
	'BTV10' => 'V',
	'BTV11' => 'V',
	'BTV13' => 'V',
	'BTV17' => 'V',
	'BTV1A' => 'V',
	'BTV1S' => 'V',
	'BTV1V' => 'V',
	'BTV1X' => 'V',
	'BTV20' => 'V',
	'BTV2A' => 'V',
	'BTV3V' => 'V',
	'BTVBZ' => 'V',
	'BUBAF' => 'E',
	'BUBAS' => 'E',
	'BUBBB' => 'E',
	'BUBBE' => 'E',
	'BUBBU' => 'E',
	'BUBCA' => 'E',
	'BUBDE' => 'E',
	'BUBID' => 'E',
	'BUBLA' => 'E',
	'BUBMA' => 'E',
	'BUBMI' => 'E',
	'BUBNI' => 'E',
	'BUBQU' => 'E',
	'BUBVI' => 'E',
	'BUCAI' => 'B',
	'BUCAK' => 'B',
	'BUCAP' => 'B',
	'BUCAS' => 'B',
	'BUCBP' => 'B',
	'BUCCL' => 'E',
	'BUCCM' => 'B',
	'BUCDN' => 'B',
	'BUCGU' => 'B',
	'BUCMD' => 'B',
	'BUCMH' => 'B',
	'BUCMK' => 'B',
	'BUCML' => 'B',
	'BUCMP' => 'B',
	'BUCMR' => 'B',
	'BUCOB' => 'E',
	'BUCPB' => 'B',
	'BUCPP' => 'B',
	'BUCPS' => 'B',
	'BUCRC' => 'B',
	'BUCRI' => 'B',
	'BUCRM' => 'B',
	'BUCRO' => 'E',
	'BUCRP' => 'B',
	'BUCSC' => 'B',
	'BUCTC' => 'B',
	'BUCTS' => 'B',
	'BUCTT' => 'B',
	'BUCUA' => 'B',
	'BUCUC' => 'B',
	'BUCUD' => 'B',
	'BUCUE' => 'B',
	'BUCUH' => 'B',
	'BUCUJ' => 'B',
	'BUCUL' => 'B',
	'BUCUM' => 'B',
	'BUCUN' => 'B',
	'BUCUO' => 'B',
	'BUCUR' => 'B',
	'BUCUS' => 'B',
	'BUCUT' => 'B',
	'BUCUU' => 'E',
	'BUDDA' => 'E',
	'BUDTA' => 'E',
	'BUFAL' => 'E',
	'BUFAM' => 'E',
	'BUFAR' => 'E',
	'BUFBA' => 'E',
	'BUFBG' => 'E',
	'BUFBO' => 'E',
	'BUFBU' => 'E',
	'BUFCA' => 'E',
	'BUFCM' => 'E',
	'BUFCN' => 'E',
	'BUFCO' => 'E',
	'BUFCP' => 'E',
	'BUFGR' => 'E',
	'BUFJA' => 'E',
	'BUFMA' => 'E',
	'BUFRE' => 'E',
	'BUFRT' => 'E',
	'BUFVA' => 'E',
	'BUFVI' => 'E',
	'BUGCU' => 'E',
	'BUGDE' => 'E',
	'BUGFL' => 'E',
	'BUGNE' => 'E',
	'BUGPA' => 'E',
	'BUGTU' => 'E',
	'BULAR' => 'E',
	'BULBI' => 'E',
	'BULGO' => 'E',
	'BULLO' => 'E',
	'BULMA' => 'E',
	'BUMFI' => 'E',
	'BUNCA' => 'E',
	'BUNCE' => 'E',
	'BUNCI' => 'E',
	'BUNCN' => 'E',
	'BUNCV' => 'E',
	'BUNFA' => 'E',
	'BUNFL' => 'E',
	'BUNGE' => 'V',
	'BUNGR' => 'E',
	'BUNHO' => 'E',
	'BUNL7' => 'V',
	'BUNLC' => 'V',
	'BUNMM' => 'E',
	'BUNMO' => 'E',
	'BUNMU' => 'E',
	'BUNSH' => 'V',
	'BUNYW' => 'V',
	'BUPAM' => 'E',
	'BUPAN' => 'E',
	'BUPFA' => 'E',
	'BUPFR' => 'E',
	'BUPRO' => 'E',
	'BURCA' => 'B',
	'BURCE' => 'B',
	'BURGL' => 'B',
	'BURIN' => 'E',
	'BURLE' => 'E',
	'BURMA' => 'B',
	'BURMG' => 'E',
	'BURMU' => 'E',
	'BUROE' => 'E',
	'BURP1' => 'B',
	'BURPA' => 'E',
	'BURPI' => 'B',
	'BURPS' => 'B',
	'BURS3' => 'B',
	'BURSE' => 'E',
	'BURSP' => 'B',
	'BURSR' => 'B',
	'BURST' => 'B',
	'BURTA' => 'B',
	'BURTH' => 'B',
	'BURUM' => 'E',
	'BURVI' => 'B',
	'BURXL' => 'B',
	'BURXY' => 'E',
	'BUSCA' => 'E',
	'BUSCR' => 'E',
	'BUSPE' => 'E',
	'BUSSI' => 'E',
	'BUTAL' => 'E',
	'BUTAR' => 'E',
	'BUTBU' => 'E',
	'BUTEU' => 'E',
	'BUTFI' => 'B',
	'BUTGA' => 'E',
	'BUTJA' => 'E',
	'BUTJU' => 'E',
	'BUTLA' => 'E',
	'BUTME' => 'B',
	'BUTMO' => 'E',
	'BUTOC' => 'E',
	'BUTOI' => 'E',
	'BUTOM' => 'E',
	'BUTRI' => 'E',
	'BUTSI' => 'E',
	'BUTSP' => 'B',
	'BUTUM' => 'E',
	'BUTVI' => 'E',
	'BUXSE' => 'E',
	'BVDV' => 'V',
	'BVDVC' => 'V',
	'BVDVN' => 'V',
	'BVDVS' => 'V',
	'BWYVG' => 'V',
	'BYBLI' => 'E',
	'BYDV1' => 'V',
	'BYDVM' => 'V',
	'BYDVN' => 'V',
	'BYDVP' => 'V',
	'BYDVR' => 'V',
	'BYMV' => 'V',
	'BYRCR' => 'E',
	'BYV' => 'V',
	'CABCA' => 'E',
	'CABUN' => 'E',
	'CACAL' => 'E',
	'CACCA' => 'E',
	'CACCE' => 'E',
	'CACDU' => 'E',
	'CACGA' => 'E',
	'CACGO' => 'E',
	'CACHA' => 'E',
	'CACME' => 'E',
	'CACMO' => 'E',
	'CACMR' => 'E',
	'CACOP' => 'E',
	'CACSO' => 'E',
	'CACSU' => 'E',
	'CACUR' => 'E',
	'CACV4' => 'V',
	'CADLA' => 'E',
	'CADTA' => 'E',
	'CAEBR' => 'E',
	'CAECA' => 'E',
	'CAECU' => 'E',
	'CAEEC' => 'E',
	'CAEEL' => 'E',
	'CAEEX' => 'E',
	'CAEFU' => 'E',
	'CAEJA' => 'E',
	'CAEPU' => 'E',
	'CAERE' => 'E',
	'CAETA' => 'B',
	'CAEV' => 'V',
	'CAEVC' => 'V',
	'CAEVG' => 'V',
	'CAEVU' => 'E',
	'CAFRO' => 'E',
	'CAIAM' => 'E',
	'CAICA' => 'E',
	'CAICR' => 'E',
	'CAIMO' => 'E',
	'CAJCA' => 'E',
	'CAKMA' => 'E',
	'CALAB' => 'E',
	'CALAE' => 'E',
	'CALAI' => 'E',
	'CALAL' => 'E',
	'CALAN' => 'E',
	'CALAP' => 'E',
	'CALAR' => 'E',
	'CALAU' => 'E',
	'CALBN' => 'E',
	'CALBO' => 'E',
	'CALBR' => 'E',
	'CALBU' => 'E',
	'CALCA' => 'E',
	'CALCE' => 'E',
	'CALCH' => 'E',
	'CALCI' => 'E',
	'CALCL' => 'E',
	'CALCN' => 'E',
	'CALCP' => 'E',
	'CALCR' => 'E',
	'CALCS' => 'E',
	'CALCU' => 'E',
	'CALDC' => 'E',
	'CALDE' => 'E',
	'CALDI' => 'E',
	'CALDO' => 'E',
	'CALDR' => 'E',
	'CALEM' => 'E',
	'CALEP' => 'E',
	'CALER' => 'E',
	'CALET' => 'E',
	'CALFC' => 'E',
	'CALFE' => 'E',
	'CALFI' => 'E',
	'CALFL' => 'E',
	'CALFO' => 'E',
	'CALFR' => 'E',
	'CALFS' => 'E',
	'CALFU' => 'E',
	'CALGA' => 'E',
	'CALGD' => 'E',
	'CALGE' => 'E',
	'CALGI' => 'E',
	'CALGO' => 'E',
	'CALHE' => 'E',
	'CALHI' => 'E',
	'CALHM' => 'E',
	'CALHO' => 'E',
	'CALHU' => 'E',
	'CALIN' => 'E',
	'CALIR' => 'E',
	'CALJA' => 'E',
	'CALJP' => 'E',
	'CALKE' => 'E',
	'CALKU' => 'E',
	'CALKY' => 'E',
	'CALLA' => 'E',
	'CALLC' => 'E',
	'CALLE' => 'E',
	'CALLN' => 'E',
	'CALLP' => 'E',
	'CALLT' => 'E',
	'CALLU' => 'E',
	'CALMA' => 'E',
	'CALMC' => 'E',
	'CALME' => 'E',
	'CALMI' => 'E',
	'CALML' => 'E',
	'CALMO' => 'E',
	'CALMS' => 'E',
	'CALMT' => 'E',
	'CALMU' => 'E',
	'CALNA' => 'E',
	'CALNI' => 'E',
	'CALNO' => 'A',
	'CALOC' => 'E',
	'CALOF' => 'E',
	'CALOL' => 'E',
	'CALOS' => 'E',
	'CALPA' => 'E',
	'CALPD' => 'E',
	'CALPE' => 'E',
	'CALPH' => 'E',
	'CALPI' => 'E',
	'CALPL' => 'E',
	'CALPN' => 'E',
	'CALPO' => 'E',
	'CALPP' => 'E',
	'CALPR' => 'E',
	'CALPV' => 'E',
	'CALQU' => 'E',
	'CALRE' => 'E',
	'CALS5' => 'E',
	'CALSA' => 'B',
	'CALSC' => 'E',
	'CALSE' => 'E',
	'CALSF' => 'E',
	'CALSH' => 'E',
	'CALSI' => 'E',
	'CALSL' => 'E',
	'CALSN' => 'E',
	'CALSO' => 'E',
	'CALSP' => 'E',
	'CALSQ' => 'E',
	'CALSR' => 'B',
	'CALSS' => 'E',
	'CALST' => 'E',
	'CALSU' => 'E',
	'CALTE' => 'E',
	'CALTO' => 'E',
	'CALTR' => 'E',
	'CALTU' => 'E',
	'CALUR' => 'E',
	'CALUS' => 'E',
	'CALVA' => 'E',
	'CALVE' => 'E',
	'CALVI' => 'E',
	'CALVL' => 'E',
	'CALVN' => 'E',
	'CALVO' => 'E',
	'CALVR' => 'E',
	'CALVU' => 'E',
	'CALWE' => 'E',
	'CAMAB' => 'E',
	'CAMAC' => 'E',
	'CAMAR' => 'E',
	'CAMBA' => 'E',
	'CAMBO' => 'E',
	'CAMCO' => 'B',
	'CAMDR' => 'E',
	'CAMFA' => 'E',
	'CAMFE' => 'B',
	'CAMFI' => 'E',
	'CAMFL' => 'E',
	'CAMGR' => 'E',
	'CAMHU' => 'E',
	'CAMHY' => 'B',
	'CAMJE' => 'B',
	'CAMJR' => 'B',
	'CAMLA' => 'B',
	'CAMLE' => 'E',
	'CAMLU' => 'E',
	'CAMMA' => 'E',
	'CAMMC' => 'E',
	'CAMME' => 'E',
	'CAMMI' => 'E',
	'CAMPA' => 'E',
	'CAMPC' => 'V',
	'CAMPE' => 'E',
	'CAMPM' => 'V',
	'CAMPR' => 'E',
	'CAMPS' => 'V',
	'CAMRA' => 'E',
	'CAMSA' => 'E',
	'CAMSC' => 'E',
	'CAMSI' => 'E',
	'CAMSS' => 'E',
	'CAMSX' => 'E',
	'CAMUP' => 'B',
	'CAMV4' => 'V',
	'CAMVB' => 'V',
	'CAMVC' => 'V',
	'CAMVD' => 'V',
	'CAMVE' => 'V',
	'CAMVJ' => 'V',
	'CAMVN' => 'V',
	'CAMVP' => 'V',
	'CAMVS' => 'V',
	'CAMVW' => 'V',
	'CANAD' => 'E',
	'CANAL' => 'E',
	'CANAP' => 'E',
	'CANAR' => 'E',
	'CANAS' => 'E',
	'CANAU' => 'E',
	'CANBN' => 'E',
	'CANBO' => 'E',
	'CANBR' => 'E',
	'CANBU' => 'E',
	'CANCA' => 'E',
	'CANDU' => 'E',
	'CANEN' => 'E',
	'CANFA' => 'E',
	'CANGA' => 'E',
	'CANGL' => 'E',
	'CANGY' => 'E',
	'CANLA' => 'E',
	'CANLI' => 'E',
	'CANLU' => 'E',
	'CANMA' => 'E',
	'CANME' => 'E',
	'CANMG' => 'E',
	'CANMI' => 'E',
	'CANMR' => 'E',
	'CANNO' => 'E',
	'CANOD' => 'E',
	'CANOL' => 'E',
	'CANPA' => 'E',
	'CANPG' => 'E',
	'CANRF' => 'E',
	'CANRU' => 'E',
	'CANS1' => 'E',
	'CANSA' => 'E',
	'CANSH' => 'E',
	'CANSI' => 'E',
	'CANST' => 'E',
	'CANTA' => 'E',
	'CANTE' => 'E',
	'CANTR' => 'E',
	'CANTS' => 'E',
	'CANVI' => 'E',
	'CANWI' => 'E',
	'CAPAA' => 'E',
	'CAPAE' => 'E',
	'CAPAN' => 'E',
	'CAPBA' => 'E',
	'CAPBU' => 'E',
	'CAPCA' => 'E',
	'CAPCH' => 'E',
	'CAPCR' => 'E',
	'CAPCU' => 'E',
	'CAPCY' => 'E',
	'CAPFA' => 'E',
	'CAPFL' => 'E',
	'CAPFR' => 'E',
	'CAPGI' => 'B',
	'CAPGR' => 'E',
	'CAPHA' => 'E',
	'CAPHI' => 'E',
	'CAPIB' => 'E',
	'CAPII' => 'E',
	'CAPMA' => 'E',
	'CAPMR' => 'E',
	'CAPNU' => 'E',
	'CAPOC' => 'B',
	'CAPPI' => 'E',
	'CAPPY' => 'E',
	'CAPSI' => 'E',
	'CAPSN' => 'E',
	'CAPSP' => 'B',
	'CAPSU' => 'E',
	'CAPSW' => 'E',
	'CAPVO' => 'E',
	'CARAB' => 'E',
	'CARAC' => 'E',
	'CARAE' => 'E',
	'CARAG' => 'E',
	'CARAL' => 'E',
	'CARAN' => 'E',
	'CARAO' => 'E',
	'CARAR' => 'E',
	'CARAS' => 'E',
	'CARAU' => 'E',
	'CARBA' => 'E',
	'CARBE' => 'E',
	'CARBL' => 'E',
	'CARBN' => 'E',
	'CARBR' => 'E',
	'CARBU' => 'E',
	'CARBV' => 'E',
	'CARBW' => 'E',
	'CARCA' => 'E',
	'CARCB' => 'E',
	'CARCC' => 'E',
	'CARCD' => 'E',
	'CARCE' => 'E',
	'CARCF' => 'E',
	'CARCG' => 'E',
	'CARCH' => 'E',
	'CARCI' => 'E',
	'CARCJ' => 'E',
	'CARCK' => 'E',
	'CARCL' => 'E',
	'CARCM' => 'E',
	'CARCN' => 'E',
	'CARCO' => 'E',
	'CARCP' => 'E',
	'CARCQ' => 'E',
	'CARCR' => 'E',
	'CARCS' => 'E',
	'CARCT' => 'E',
	'CARCU' => 'E',
	'CARCV' => 'E',
	'CARCW' => 'E',
	'CARCX' => 'E',
	'CARCY' => 'E',
	'CARCZ' => 'E',
	'CARDE' => 'E',
	'CARDI' => 'E',
	'CARDM' => 'E',
	'CARDO' => 'E',
	'CARDV' => 'B',
	'CARER' => 'E',
	'CARFL' => 'E',
	'CARGE' => 'E',
	'CARGL' => 'E',
	'CARGO' => 'E',
	'CARGR' => 'E',
	'CARHI' => 'E',
	'CARHO' => 'E',
	'CARHU' => 'E',
	'CARHY' => 'B',
	'CARHZ' => 'B',
	'CARIL' => 'E',
	'CARIN' => 'E',
	'CARKI' => 'E',
	'CARLA' => 'E',
	'CARLO' => 'E',
	'CARMA' => 'E',
	'CARMC' => 'E',
	'CARME' => 'E',
	'CARMI' => 'E',
	'CARMO' => 'E',
	'CARMT' => 'E',
	'CARMV' => 'V',
	'CARMX' => 'E',
	'CARNE' => 'E',
	'CARNG' => 'E',
	'CARNI' => 'E',
	'CARNO' => 'E',
	'CARNP' => 'E',
	'CARNU' => 'E',
	'CAROB' => 'E',
	'CAROL' => 'E',
	'CAROP' => 'E',
	'CAROR' => 'E',
	'CAROT' => 'E',
	'CAROX' => 'E',
	'CARPA' => 'E',
	'CARPB' => 'E',
	'CARPE' => 'E',
	'CARPH' => 'E',
	'CARPI' => 'B',
	'CARPL' => 'E',
	'CARPN' => 'E',
	'CARPO' => 'E',
	'CARPP' => 'E',
	'CARPR' => 'E',
	'CARPS' => 'E',
	'CARPT' => 'E',
	'CARPU' => 'E',
	'CARPV' => 'E',
	'CARPY' => 'E',
	'CARRA' => 'E',
	'CARRB' => 'E',
	'CARRE' => 'E',
	'CARRH' => 'E',
	'CARRI' => 'E',
	'CARRO' => 'E',
	'CARRS' => 'E',
	'CARRU' => 'B',
	'CARSA' => 'E',
	'CARSC' => 'E',
	'CARSE' => 'E',
	'CARSH' => 'E',
	'CARSI' => 'E',
	'CARSP' => 'E',
	'CARSR' => 'E',
	'CARST' => 'B',
	'CARSU' => 'E',
	'CARSY' => 'E',
	'CARTI' => 'E',
	'CARUI' => 'B',
	'CARUM' => 'E',
	'CARVI' => 'E',
	'CARVL' => 'E',
	'CARVO' => 'E',
	'CARVU' => 'E',
	'CARWA' => 'E',
	'CARXE' => 'E',
	'CARZE' => 'E',
	'CASBE' => 'E',
	'CASCA' => 'E',
	'CASCH' => 'E',
	'CASCN' => 'E',
	'CASCR' => 'E',
	'CASDI' => 'E',
	'CASDU' => 'E',
	'CASED' => 'E',
	'CASEQ' => 'E',
	'CASFI' => 'E',
	'CASFR' => 'E',
	'CASFS' => 'E',
	'CASGL' => 'E',
	'CASLI' => 'E',
	'CASLN' => 'E',
	'CASLY' => 'E',
	'CASME' => 'E',
	'CASSA' => 'E',
	'CASXA' => 'E',
	'CATAN' => 'E',
	'CATAU' => 'E',
	'CATBC' => 'E',
	'CATBI' => 'E',
	'CATBO' => 'E',
	'CATBS' => 'E',
	'CATCI' => 'E',
	'CATCL' => 'E',
	'CATCO' => 'E',
	'CATDO' => 'E',
	'CATEX' => 'E',
	'CATFR' => 'E',
	'CATGT' => 'E',
	'CATGU' => 'E',
	'CATMA' => 'E',
	'CATRO' => 'E',
	'CATRU' => 'E',
	'CATSE' => 'E',
	'CATSP' => 'E',
	'CATWA' => 'E',
	'CAUAR' => 'E',
	'CAUCR' => 'B',
	'CAURH' => 'E',
	'CAUSP' => 'B',
	'CAUTH' => 'E',
	'CAV26' => 'V',
	'CAV82' => 'V',
	'CAVAP' => 'E',
	'CAVAU' => 'V',
	'CAVC1' => 'V',
	'CAVCI' => 'V',
	'CAVCU' => 'E',
	'CAVPO' => 'E',
	'CAYMV' => 'V',
	'CBCP' => 'V',
	'CBDP' => 'V',
	'CBEPV' => 'V',
	'CCHFV' => 'V',
	'CCMV' => 'V',
	'CCPV1' => 'V',
	'CDVA4' => 'V',
	'CDVA6' => 'V',
	'CDVC' => 'V',
	'CDVO' => 'V',
	'CEACR' => 'E',
	'CEATH' => 'E',
	'CEATO' => 'E',
	'CEAVE' => 'E',
	'CEBAL' => 'E',
	'CEBAP' => 'E',
	'CEBCA' => 'E',
	'CEBKA' => 'E',
	'CEBOL' => 'E',
	'CEBPY' => 'E',
	'CEDAT' => 'E',
	'CEDDE' => 'E',
	'CEIAC' => 'E',
	'CELAR' => 'E',
	'CELBM' => 'E',
	'CELCE' => 'B',
	'CELFI' => 'B',
	'CELLA' => 'E',
	'CELOR' => 'E',
	'CELSC' => 'E',
	'CELSP' => 'B',
	'CELUD' => 'B',
	'CENAM' => 'E',
	'CENAR' => 'E',
	'CENAS' => 'B',
	'CENAU' => 'E',
	'CENBI' => 'E',
	'CENBS' => 'E',
	'CENCA' => 'E',
	'CENCI' => 'E',
	'CENCU' => 'E',
	'CENEI' => 'E',
	'CENEL' => 'E',
	'CENEN' => 'E',
	'CENEX' => 'E',
	'CENFA' => 'E',
	'CENFE' => 'E',
	'CENFL' => 'E',
	'CENGR' => 'E',
	'CENII' => 'E',
	'CENLI' => 'E',
	'CENLL' => 'E',
	'CENLM' => 'E',
	'CENLO' => 'E',
	'CENMA' => 'E',
	'CENME' => 'E',
	'CENMR' => 'E',
	'CENMU' => 'E',
	'CENNO' => 'E',
	'CENNX' => 'E',
	'CENPO' => 'E',
	'CENRU' => 'E',
	'CENSC' => 'E',
	'CENSE' => 'E',
	'CENSI' => 'E',
	'CENSU' => 'E',
	'CENTI' => 'E',
	'CENUR' => 'E',
	'CENVI' => 'E',
	'CENVR' => 'E',
	'CEPAC' => 'E',
	'CEPAD' => 'E',
	'CEPBO' => 'E',
	'CEPCA' => 'E',
	'CEPCM' => 'E',
	'CEPCO' => 'E',
	'CEPCR' => 'E',
	'CEPDO' => 'E',
	'CEPEU' => 'E',
	'CEPFO' => 'E',
	'CEPFR' => 'E',
	'CEPGR' => 'E',
	'CEPHA' => 'E',
	'CEPHE' => 'E',
	'CEPHR' => 'E',
	'CEPJE' => 'E',
	'CEPLE' => 'E',
	'CEPMA' => 'E',
	'CEPMO' => 'E',
	'CEPNA' => 'E',
	'CEPNE' => 'E',
	'CEPNG' => 'E',
	'CEPNI' => 'E',
	'CEPOC' => 'E',
	'CEPOG' => 'E',
	'CEPRF' => 'E',
	'CEPRU' => 'E',
	'CEPSI' => 'E',
	'CEPSP' => 'E',
	'CEPWE' => 'E',
	'CEPZE' => 'E',
	'CERAE' => 'E',
	'CERAG' => 'E',
	'CERAL' => 'E',
	'CERAR' => 'E',
	'CERAS' => 'E',
	'CERAT' => 'E',
	'CERBA' => 'E',
	'CERBE' => 'E',
	'CERBT' => 'E',
	'CERCA' => 'E',
	'CERCC' => 'E',
	'CERCE' => 'E',
	'CERCL' => 'E',
	'CERCN' => 'E',
	'CERCO' => 'E',
	'CERCP' => 'E',
	'CERCR' => 'E',
	'CERCS' => 'E',
	'CERCT' => 'E',
	'CERCU' => 'E',
	'CERDE' => 'E',
	'CERDI' => 'E',
	'CERDU' => 'E',
	'CERED' => 'E',
	'CEREH' => 'E',
	'CEREI' => 'E',
	'CEREL' => 'E',
	'CEREN' => 'E',
	'CERER' => 'E',
	'CERFA' => 'E',
	'CERFI' => 'E',
	'CERGA' => 'E',
	'CERGC' => 'E',
	'CERGL' => 'E',
	'CERGO' => 'E',
	'CERGU' => 'E',
	'CERHA' => 'E',
	'CERHI' => 'E',
	'CERHO' => 'E',
	'CERJA' => 'E',
	'CERLA' => 'E',
	'CERLD' => 'E',
	'CERLE' => 'E',
	'CERLH' => 'E',
	'CERLP' => 'E',
	'CERME' => 'E',
	'CERMI' => 'E',
	'CERMM' => 'E',
	'CERMN' => 'E',
	'CERMO' => 'E',
	'CERNA' => 'E',
	'CERNC' => 'E',
	'CERNE' => 'E',
	'CERNH' => 'E',
	'CERNI' => 'E',
	'CERNN' => 'E',
	'CERNO' => 'E',
	'CERNP' => 'E',
	'CERNS' => 'E',
	'CERNT' => 'E',
	'CERNU' => 'E',
	'CERNY' => 'E',
	'CERON' => 'E',
	'CERPE' => 'E',
	'CERPI' => 'E',
	'CERPR' => 'E',
	'CERPU' => 'E',
	'CERPY' => 'E',
	'CERRH' => 'E',
	'CERRI' => 'E',
	'CERRO' => 'E',
	'CERSA' => 'E',
	'CERSB' => 'E',
	'CERSC' => 'E',
	'CERSH' => 'E',
	'CERSI' => 'E',
	'CERSL' => 'E',
	'CERSO' => 'E',
	'CERSU' => 'E',
	'CERSY' => 'A',
	'CERTA' => 'E',
	'CERTL' => 'E',
	'CERTO' => 'E',
	'CERUN' => 'E',
	'CERV' => 'V',
	'CERVI' => 'E',
	'CERVU' => 'E',
	'CESEL' => 'E',
	'CETBI' => 'E',
	'CETOF' => 'E',
	'CFEPV' => 'V',
	'CGMVS' => 'V',
	'CGMVW' => 'V',
	'CHAAA' => 'E',
	'CHAAB' => 'E',
	'CHAAC' => 'E',
	'CHAAD' => 'E',
	'CHAAE' => 'E',
	'CHAAF' => 'E',
	'CHAAI' => 'E',
	'CHAAL' => 'E',
	'CHAAN' => 'E',
	'CHAAP' => 'E',
	'CHAAR' => 'E',
	'CHAAS' => 'E',
	'CHAAT' => 'E',
	'CHAAU' => 'E',
	'CHABA' => 'E',
	'CHABE' => 'E',
	'CHABI' => 'E',
	'CHABR' => 'E',
	'CHACA' => 'E',
	'CHACB' => 'E',
	'CHACC' => 'E',
	'CHACE' => 'E',
	'CHACH' => 'E',
	'CHACI' => 'E',
	'CHACL' => 'E',
	'CHACM' => 'E',
	'CHACN' => 'E',
	'CHACO' => 'E',
	'CHACP' => 'E',
	'CHACR' => 'E',
	'CHACS' => 'E',
	'CHACT' => 'E',
	'CHACU' => 'E',
	'CHACY' => 'E',
	'CHADB' => 'E',
	'CHADE' => 'E',
	'CHADR' => 'E',
	'CHADU' => 'E',
	'CHAEL' => 'E',
	'CHAEP' => 'E',
	'CHAER' => 'E',
	'CHAFA' => 'E',
	'CHAFB' => 'E',
	'CHAFE' => 'E',
	'CHAFI' => 'E',
	'CHAFL' => 'E',
	'CHAFO' => 'E',
	'CHAFR' => 'E',
	'CHAFS' => 'E',
	'CHAFU' => 'E',
	'CHAFV' => 'E',
	'CHAGB' => 'E',
	'CHAGD' => 'E',
	'CHAGL' => 'E',
	'CHAGO' => 'E',
	'CHAGR' => 'E',
	'CHAGT' => 'E',
	'CHAGU' => 'E',
	'CHAHE' => 'E',
	'CHAHI' => 'E',
	'CHAHU' => 'E',
	'CHAIN' => 'E',
	'CHAJA' => 'E',
	'CHAJB' => 'E',
	'CHAJO' => 'E',
	'CHAKL' => 'E',
	'CHALA' => 'E',
	'CHALI' => 'E',
	'CHALR' => 'E',
	'CHALU' => 'E',
	'CHAMA' => 'E',
	'CHAMB' => 'E',
	'CHAMD' => 'E',
	'CHAME' => 'E',
	'CHAMG' => 'E',
	'CHAMI' => 'E',
	'CHAML' => 'E',
	'CHAMN' => 'E',
	'CHAMO' => 'E',
	'CHAMP' => 'E',
	'CHAMR' => 'E',
	'CHAMS' => 'E',
	'CHAMT' => 'E',
	'CHAMU' => 'E',
	'CHAMY' => 'E',
	'CHANA' => 'E',
	'CHANE' => 'E',
	'CHANI' => 'E',
	'CHANO' => 'E',
	'CHAOB' => 'E',
	'CHAOC' => 'E',
	'CHAOR' => 'E',
	'CHAOT' => 'E',
	'CHAOX' => 'E',
	'CHAPA' => 'E',
	'CHAPC' => 'E',
	'CHAPD' => 'E',
	'CHAPE' => 'E',
	'CHAPF' => 'E',
	'CHAPL' => 'E',
	'CHAPM' => 'E',
	'CHAPN' => 'E',
	'CHAPR' => 'E',
	'CHAPT' => 'E',
	'CHAPU' => 'E',
	'CHAPW' => 'E',
	'CHAQA' => 'E',
	'CHAQI' => 'E',
	'CHAQU' => 'E',
	'CHARA' => 'E',
	'CHARC' => 'E',
	'CHARD' => 'E',
	'CHARF' => 'E',
	'CHARH' => 'E',
	'CHARI' => 'E',
	'CHARU' => 'E',
	'CHASA' => 'E',
	'CHASC' => 'E',
	'CHASE' => 'E',
	'CHASI' => 'E',
	'CHASL' => 'E',
	'CHASM' => 'E',
	'CHASN' => 'E',
	'CHASO' => 'E',
	'CHASP' => 'E',
	'CHAST' => 'E',
	'CHASU' => 'E',
	'CHATF' => 'E',
	'CHATI' => 'E',
	'CHATO' => 'E',
	'CHATR' => 'E',
	'CHATU' => 'E',
	'CHATV' => 'E',
	'CHAUL' => 'E',
	'CHAV' => 'V',
	'CHAVA' => 'E',
	'CHAVE' => 'E',
	'CHAVI' => 'E',
	'CHAVO' => 'E',
	'CHAVR' => 'E',
	'CHAVU' => 'E',
	'CHAWI' => 'E',
	'CHAXA' => 'E',
	'CHAYP' => 'B',
	'CHEAL' => 'E',
	'CHEBH' => 'E',
	'CHEBI' => 'E',
	'CHEBR' => 'E',
	'CHECA' => 'E',
	'CHECR' => 'E',
	'CHEDE' => 'E',
	'CHEFI' => 'E',
	'CHEHE' => 'B',
	'CHEIL' => 'E',
	'CHEJU' => 'E',
	'CHEKU' => 'E',
	'CHELA' => 'E',
	'CHELB' => 'E',
	'CHELO' => 'E',
	'CHEMA' => 'E',
	'CHEME' => 'E',
	'CHEMJ' => 'E',
	'CHEMU' => 'E',
	'CHEMY' => 'E',
	'CHEPA' => 'E',
	'CHEPR' => 'E',
	'CHEQI' => 'E',
	'CHEQU' => 'E',
	'CHERO' => 'E',
	'CHERU' => 'E',
	'CHESE' => 'E',
	'CHETE' => 'E',
	'CHIAB' => 'E',
	'CHIAL' => 'E',
	'CHIBR' => 'E',
	'CHICK' => 'E',
	'CHICO' => 'E',
	'CHIDO' => 'E',
	'CHIFL' => 'E',
	'CHIHA' => 'E',
	'CHIHI' => 'E',
	'CHIIM' => 'E',
	'CHIIN' => 'E',
	'CHIJI' => 'E',
	'CHIK3' => 'V',
	'CHIKI' => 'E',
	'CHIKN' => 'V',
	'CHIKS' => 'V',
	'CHIKV' => 'V',
	'CHILA' => 'E',
	'CHIME' => 'E',
	'CHIMI' => 'E',
	'CHIMN' => 'E',
	'CHIMO' => 'E',
	'CHIMX' => 'E',
	'CHIOP' => 'E',
	'CHIPA' => 'E',
	'CHIPL' => 'E',
	'CHIPT' => 'E',
	'CHIPU' => 'E',
	'CHIQU' => 'E',
	'CHIRA' => 'E',
	'CHIRE' => 'E',
	'CHIRO' => 'E',
	'CHISA' => 'E',
	'CHISL' => 'E',
	'CHITE' => 'E',
	'CHITH' => 'E',
	'CHITP' => 'E',
	'CHITR' => 'E',
	'CHIUM' => 'E',
	'CHIVI' => 'E',
	'CHIVL' => 'E',
	'CHLAB' => 'B',
	'CHLAC' => 'E',
	'CHLAG' => 'E',
	'CHLAR' => 'E',
	'CHLAS' => 'E',
	'CHLAT' => 'E',
	'CHLAU' => 'B',
	'CHLCA' => 'E',
	'CHLCH' => 'B',
	'CHLCO' => 'E',
	'CHLCV' => 'B',
	'CHLEC' => 'E',
	'CHLEL' => 'E',
	'CHLEU' => 'E',
	'CHLFA' => 'E',
	'CHLFF' => 'B',
	'CHLFR' => 'B',
	'CHLFU' => 'E',
	'CHLGO' => 'E',
	'CHLHA' => 'E',
	'CHLHU' => 'E',
	'CHLIN' => 'E',
	'CHLIS' => 'E',
	'CHLKE' => 'E',
	'CHLKI' => 'E',
	'CHLLI' => 'B',
	'CHLLO' => 'E',
	'CHLLT' => 'B',
	'CHLMA' => 'E',
	'CHLME' => 'E',
	'CHLML' => 'E',
	'CHLMO' => 'E',
	'CHLMU' => 'B',
	'CHLNI' => 'E',
	'CHLNU' => 'E',
	'CHLNY' => 'E',
	'CHLPA' => 'E',
	'CHLPH' => 'B',
	'CHLPI' => 'E',
	'CHLPL' => 'E',
	'CHLPN' => 'B',
	'CHLPO' => 'E',
	'CHLPR' => 'E',
	'CHLPS' => 'B',
	'CHLPT' => 'E',
	'CHLPY' => 'E',
	'CHLRE' => 'E',
	'CHLRI' => 'E',
	'CHLS6' => 'E',
	'CHLSA' => 'E',
	'CHLSE' => 'E',
	'CHLSI' => 'E',
	'CHLSM' => 'E',
	'CHLSO' => 'E',
	'CHLSP' => 'E',
	'CHLSQ' => 'B',
	'CHLSU' => 'E',
	'CHLSW' => 'E',
	'CHLTA' => 'B',
	'CHLTE' => 'B',
	'CHLTR' => 'B',
	'CHLVI' => 'B',
	'CHLVR' => 'E',
	'CHLVU' => 'E',
	'CHOAL' => 'E',
	'CHOBG' => 'E',
	'CHOBI' => 'E',
	'CHOBU' => 'E',
	'CHOCA' => 'E',
	'CHOCR' => 'E',
	'CHODI' => 'E',
	'CHODM' => 'E',
	'CHOEL' => 'E',
	'CHOFA' => 'E',
	'CHOFL' => 'E',
	'CHOFU' => 'E',
	'CHOGI' => 'E',
	'CHOGO' => 'E',
	'CHOHA' => 'E',
	'CHOHO' => 'E',
	'CHOJU' => 'E',
	'CHOME' => 'E',
	'CHOMI' => 'E',
	'CHONI' => 'E',
	'CHONU' => 'E',
	'CHOOC' => 'E',
	'CHOPA' => 'E',
	'CHOPC' => 'E',
	'CHOPI' => 'E',
	'CHOPR' => 'E',
	'CHOQU' => 'E',
	'CHORE' => 'E',
	'CHORO' => 'E',
	'CHOSU' => 'E',
	'CHOVE' => 'E',
	'CHOVI' => 'E',
	'CHPVE' => 'V',
	'CHPVU' => 'V',
	'CHRAA' => 'E',
	'CHRAE' => 'E',
	'CHRAL' => 'E',
	'CHRAM' => 'E',
	'CHRAN' => 'E',
	'CHRAR' => 'E',
	'CHRAS' => 'E',
	'CHRAU' => 'E',
	'CHRBA' => 'E',
	'CHRBE' => 'E',
	'CHRBR' => 'E',
	'CHRCA' => 'E',
	'CHRCE' => 'E',
	'CHRCH' => 'E',
	'CHRCL' => 'E',
	'CHRCO' => 'E',
	'CHRCR' => 'E',
	'CHRCY' => 'E',
	'CHRDI' => 'E',
	'CHRDO' => 'E',
	'CHRFA' => 'E',
	'CHRFL' => 'E',
	'CHRFU' => 'E',
	'CHRGA' => 'E',
	'CHRGO' => 'E',
	'CHRGR' => 'B',
	'CHRHA' => 'E',
	'CHRHE' => 'E',
	'CHRHI' => 'E',
	'CHRHY' => 'E',
	'CHRIC' => 'E',
	'CHRKE' => 'E',
	'CHRKN' => 'E',
	'CHRKR' => 'E',
	'CHRKU' => 'E',
	'CHRLA' => 'E',
	'CHRLU' => 'E',
	'CHRLV' => 'E',
	'CHRMA' => 'E',
	'CHRME' => 'E',
	'CHROW' => 'E',
	'CHRPC' => 'E',
	'CHRPE' => 'E',
	'CHRPI' => 'E',
	'CHRPL' => 'E',
	'CHRPO' => 'E',
	'CHRPP' => 'E',
	'CHRPU' => 'E',
	'CHRQA' => 'E',
	'CHRQI' => 'E',
	'CHRQU' => 'E',
	'CHRRF' => 'E',
	'CHRRU' => 'E',
	'CHRSA' => 'B',
	'CHRSB' => 'E',
	'CHRSC' => 'E',
	'CHRSD' => 'B',
	'CHRSI' => 'E',
	'CHRSL' => 'B',
	'CHRSO' => 'E',
	'CHRSP' => 'E',
	'CHRST' => 'E',
	'CHRVA' => 'E',
	'CHRVG' => 'E',
	'CHRVI' => 'B',
	'CHRVO' => 'B',
	'CHRVR' => 'E',
	'CHRVS' => 'B',
	'CHRVT' => 'E',
	'CHUNA' => 'E',
	'CHV1' => 'V',
	'CHV12' => 'V',
	'CHV16' => 'V',
	'CHV1E' => 'V',
	'CHV9D' => 'V',
	'CHYAM' => 'E',
	'CHYBR' => 'E',
	'CHYMV' => 'V',
	'CIBBA' => 'E',
	'CIBSC' => 'E',
	'CICAR' => 'E',
	'CICBO' => 'E',
	'CICCA' => 'E',
	'CICCE' => 'E',
	'CICCI' => 'E',
	'CICCT' => 'E',
	'CICCY' => 'E',
	'CICDO' => 'E',
	'CICDU' => 'E',
	'CICEN' => 'E',
	'CICFL' => 'E',
	'CICFO' => 'E',
	'CICFU' => 'E',
	'CICHI' => 'E',
	'CICIN' => 'E',
	'CICLA' => 'E',
	'CICLB' => 'E',
	'CICLE' => 'E',
	'CICLH' => 'E',
	'CICLI' => 'E',
	'CICLO' => 'E',
	'CICMA' => 'E',
	'CICNE' => 'E',
	'CICNG' => 'E',
	'CICNI' => 'E',
	'CICOC' => 'E',
	'CICOR' => 'E',
	'CICPA' => 'E',
	'CICPU' => 'E',
	'CICRE' => 'E',
	'CICSE' => 'E',
	'CICSP' => 'E',
	'CICST' => 'E',
	'CICVG' => 'E',
	'CICVI' => 'E',
	'CICVR' => 'E',
	'CIMLE' => 'E',
	'CIMRA' => 'E',
	'CINCA' => 'E',
	'CINCI' => 'E',
	'CINLA' => 'E',
	'CINMA' => 'E',
	'CINVE' => 'E',
	'CIOIN' => 'E',
	'CIOPE' => 'E',
	'CIOSA' => 'E',
	'CIRAE' => 'E',
	'CIRAL' => 'E',
	'CIRAR' => 'E',
	'CIRCY' => 'E',
	'CIRDR' => 'E',
	'CIRPA' => 'E',
	'CIRSU' => 'E',
	'CIRTE' => 'E',
	'CIRV' => 'V',
	'CIRVU' => 'E',
	'CISCH' => 'E',
	'CISDI' => 'E',
	'CISQU' => 'E',
	'CISRH' => 'E',
	'CITAM' => 'B',
	'CITAR' => 'E',
	'CITAU' => 'E',
	'CITBR' => 'B',
	'CITDI' => 'B',
	'CITFR' => 'B',
	'CITHY' => 'E',
	'CITLA' => 'E',
	'CITLI' => 'E',
	'CITLN' => 'E',
	'CITMA' => 'E',
	'CITNA' => 'E',
	'CITPA' => 'E',
	'CITRE' => 'E',
	'CITRO' => 'B',
	'CITSI' => 'E',
	'CITUN' => 'E',
	'CIVCI' => 'E',
	'CLAAB' => 'E',
	'CLAAR' => 'E',
	'CLABR' => 'E',
	'CLACL' => 'E',
	'CLACO' => 'E',
	'CLAEP' => 'E',
	'CLAFC' => 'E',
	'CLAFR' => 'E',
	'CLAFS' => 'E',
	'CLAFU' => 'E',
	'CLAGA' => 'E',
	'CLAGL' => 'E',
	'CLAGO' => 'E',
	'CLAHE' => 'E',
	'CLALE' => 'E',
	'CLALS' => 'E',
	'CLALU' => 'E',
	'CLAMA' => 'E',
	'CLAMI' => 'E',
	'CLAMS' => 'B',
	'CLAPU' => 'E',
	'CLARO' => 'E',
	'CLASP' => 'E',
	'CLAUN' => 'E',
	'CLAVI' => 'E',
	'CLAWI' => 'E',
	'CLAXA' => 'E',
	'CLEAL' => 'E',
	'CLECA' => 'E',
	'CLEDR' => 'E',
	'CLEFL' => 'E',
	'CLEGA' => 'E',
	'CLEGL' => 'E',
	'CLELA' => 'E',
	'CLELI' => 'E',
	'CLEMA' => 'E',
	'CLEMR' => 'E',
	'CLEMU' => 'E',
	'CLERU' => 'E',
	'CLETE' => 'E',
	'CLEVI' => 'E',
	'CLIAL' => 'E',
	'CLIAN' => 'E',
	'CLIBO' => 'E',
	'CLICA' => 'E',
	'CLIGA' => 'E',
	'CLILI' => 'E',
	'CLIMI' => 'E',
	'CLIMR' => 'E',
	'CLINE' => 'E',
	'CLINO' => 'E',
	'CLITE' => 'E',
	'CLIUD' => 'E',
	'CLIUM' => 'E',
	'CLIUN' => 'E',
	'CLOAB' => 'B',
	'CLOAC' => 'B',
	'CLOAL' => 'E',
	'CLOAM' => 'B',
	'CLOBE' => 'B',
	'CLOBI' => 'B',
	'CLOBO' => 'B',
	'CLOBU' => 'B',
	'CLOCB' => 'B',
	'CLOCE' => 'B',
	'CLOCL' => 'B',
	'CLOCO' => 'B',
	'CLOCY' => 'B',
	'CLOD6' => 'B',
	'CLODI' => 'B',
	'CLOHA' => 'B',
	'CLOHI' => 'B',
	'CLOHU' => 'B',
	'CLOIN' => 'B',
	'CLOJO' => 'B',
	'CLOKL' => 'B',
	'CLOLI' => 'B',
	'CLOLM' => 'B',
	'CLOLO' => 'B',
	'CLONO' => 'B',
	'CLOP1' => 'B',
	'CLOPA' => 'B',
	'CLOPE' => 'B',
	'CLOPP' => 'B',
	'CLOPR' => 'B',
	'CLOPS' => 'B',
	'CLOPU' => 'B',
	'CLOS0' => 'B',
	'CLOS4' => 'B',
	'CLOSA' => 'B',
	'CLOSC' => 'B',
	'CLOSE' => 'B',
	'CLOSF' => 'B',
	'CLOSG' => 'B',
	'CLOSI' => 'E',
	'CLOSL' => 'E',
	'CLOSM' => 'B',
	'CLOSO' => 'B',
	'CLOSP' => 'B',
	'CLOSR' => 'B',
	'CLOST' => 'B',
	'CLOSU' => 'B',
	'CLOSY' => 'B',
	'CLOTE' => 'B',
	'CLOTM' => 'B',
	'CLOTS' => 'B',
	'CLOTT' => 'B',
	'CLOTY' => 'B',
	'CLUHA' => 'E',
	'CLUPA' => 'E',
	'CLV' => 'V',
	'CLVK' => 'V',
	'CLVN' => 'V',
	'CLYAR' => 'E',
	'CLYEP' => 'B',
	'CLYGR' => 'E',
	'CLYJA' => 'E',
	'CLYLA' => 'E',
	'CMVAS' => 'V',
	'CMVB' => 'V',
	'CMVBA' => 'V',
	'CMVC' => 'V',
	'CMVC7' => 'V',
	'CMVCS' => 'V',
	'CMVDK' => 'V',
	'CMVE5' => 'V',
	'CMVFC' => 'V',
	'CMVFN' => 'V',
	'CMVFT' => 'V',
	'CMVI1' => 'V',
	'CMVII' => 'V',
	'CMVIX' => 'V',
	'CMVK' => 'V',
	'CMVKI' => 'V',
	'CMVKO' => 'V',
	'CMVM' => 'V',
	'CMVM4' => 'V',
	'CMVMB' => 'V',
	'CMVN' => 'V',
	'CMVNT' => 'V',
	'CMVO' => 'V',
	'CMVP6' => 'V',
	'CMVPE' => 'V',
	'CMVQ' => 'V',
	'CMVS' => 'V',
	'CMVSI' => 'V',
	'CMVTR' => 'V',
	'CMVWL' => 'V',
	'CMVY' => 'V',
	'CNELE' => 'E',
	'CNEMA' => 'E',
	'CNEUN' => 'E',
	'CNIBE' => 'E',
	'CNIJA' => 'E',
	'CNPV' => 'V',
	'CNSV' => 'V',
	'CNV' => 'V',
	'COCCA' => 'E',
	'COCCC' => 'E',
	'COCCO' => 'E',
	'COCCY' => 'E',
	'COCDA' => 'E',
	'COCEL' => 'E',
	'COCER' => 'E',
	'COCHE' => 'E',
	'COCIM' => 'E',
	'COCKU' => 'E',
	'COCMA' => 'E',
	'COCNU' => 'E',
	'COCOF' => 'E',
	'COCPO' => 'E',
	'COCPY' => 'E',
	'COCSA' => 'E',
	'COCSE' => 'E',
	'COCUV' => 'E',
	'COCVI' => 'E',
	'COCVT' => 'E',
	'CODFR' => 'E',
	'COECO' => 'E',
	'COECR' => 'E',
	'COEFR' => 'E',
	'COEIR' => 'E',
	'COEMI' => 'E',
	'COEPA' => 'E',
	'COEPR' => 'E',
	'COERA' => 'E',
	'COERE' => 'E',
	'COETI' => 'E',
	'COETO' => 'E',
	'COETU' => 'E',
	'COFAR' => 'E',
	'COFCA' => 'E',
	'COILA' => 'E',
	'COLAN' => 'E',
	'COLAR' => 'E',
	'COLAS' => 'E',
	'COLAT' => 'E',
	'COLAU' => 'E',
	'COLBA' => 'E',
	'COLCA' => 'E',
	'COLCC' => 'E',
	'COLCE' => 'E',
	'COLCN' => 'E',
	'COLCO' => 'E',
	'COLCR' => 'E',
	'COLES' => 'E',
	'COLEU' => 'E',
	'COLGL' => 'E',
	'COLGR' => 'E',
	'COLGU' => 'E',
	'COLHE' => 'E',
	'COLHO' => 'E',
	'COLHT' => 'E',
	'COLIN' => 'E',
	'COLIR' => 'E',
	'COLLE' => 'E',
	'COLLI' => 'E',
	'COLLN' => 'E',
	'COLMA' => 'B',
	'COLMC' => 'E',
	'COLMI' => 'E',
	'COLMN' => 'E',
	'COLNI' => 'E',
	'COLOB' => 'E',
	'COLP3' => 'B',
	'COLPA' => 'E',
	'COLPH' => 'E',
	'COLPI' => 'E',
	'COLPL' => 'E',
	'COLPO' => 'E',
	'COLPS' => 'B',
	'COLPU' => 'E',
	'COLRU' => 'E',
	'COLSA' => 'E',
	'COLSC' => 'E',
	'COLSN' => 'E',
	'COLSP' => 'E',
	'COLST' => 'E',
	'COLSU' => 'E',
	'COLTR' => 'E',
	'COLVA' => 'E',
	'COLVI' => 'E',
	'COMAC' => 'B',
	'COMAR' => 'E',
	'COMBA' => 'E',
	'COMBE' => 'E',
	'COMCO' => 'E',
	'COMDY' => 'E',
	'COMFR' => 'E',
	'COMHA' => 'E',
	'COMS9' => 'B',
	'COMTE' => 'B',
	'COMTR' => 'B',
	'CONAA' => 'E',
	'CONAB' => 'E',
	'CONAC' => 'E',
	'CONAD' => 'E',
	'CONAE' => 'E',
	'CONAF' => 'E',
	'CONAI' => 'E',
	'CONAL' => 'E',
	'CONAM' => 'E',
	'CONAN' => 'E',
	'CONAO' => 'E',
	'CONAR' => 'E',
	'CONAS' => 'E',
	'CONAT' => 'E',
	'CONAU' => 'E',
	'CONBA' => 'E',
	'CONBE' => 'E',
	'CONBH' => 'E',
	'CONBN' => 'E',
	'CONBR' => 'E',
	'CONBT' => 'E',
	'CONBU' => 'E',
	'CONCA' => 'E',
	'CONCB' => 'E',
	'CONCC' => 'E',
	'CONCD' => 'E',
	'CONCE' => 'E',
	'CONCH' => 'E',
	'CONCI' => 'E',
	'CONCN' => 'E',
	'CONCO' => 'E',
	'CONCP' => 'E',
	'CONCR' => 'E',
	'CONCS' => 'E',
	'CONCT' => 'E',
	'CONCU' => 'E',
	'CONDA' => 'E',
	'CONDD' => 'E',
	'CONDE' => 'E',
	'CONDI' => 'E',
	'CONDL' => 'E',
	'CONEA' => 'E',
	'CONEB' => 'E',
	'CONEP' => 'E',
	'CONER' => 'E',
	'CONFE' => 'E',
	'CONFF' => 'E',
	'CONFL' => 'E',
	'CONGA' => 'E',
	'CONGE' => 'E',
	'CONGI' => 'E',
	'CONGL' => 'E',
	'CONGN' => 'E',
	'CONIM' => 'E',
	'CONKI' => 'E',
	'CONLE' => 'E',
	'CONLI' => 'E',
	'CONLT' => 'E',
	'CONLY' => 'E',
	'CONMA' => 'E',
	'CONMC' => 'E',
	'CONMG' => 'E',
	'CONMI' => 'E',
	'CONMJ' => 'E',
	'CONML' => 'E',
	'CONMO' => 'E',
	'CONMR' => 'E',
	'CONMU' => 'E',
	'CONMY' => 'E',
	'CONNE' => 'E',
	'CONNI' => 'E',
	'CONNU' => 'E',
	'CONOB' => 'E',
	'CONOI' => 'E',
	'CONOM' => 'E',
	'CONOR' => 'E',
	'CONPA' => 'E',
	'CONPE' => 'E',
	'CONPL' => 'E',
	'CONPN' => 'E',
	'CONPR' => 'E',
	'CONPS' => 'E',
	'CONPT' => 'E',
	'CONPU' => 'E',
	'CONQU' => 'E',
	'CONRA' => 'E',
	'CONRE' => 'E',
	'CONSB' => 'E',
	'CONSE' => 'E',
	'CONSO' => 'E',
	'CONSP' => 'E',
	'CONST' => 'E',
	'CONSU' => 'E',
	'CONTA' => 'E',
	'CONTE' => 'E',
	'CONTN' => 'E',
	'CONTO' => 'E',
	'CONTR' => 'E',
	'CONTS' => 'E',
	'CONTU' => 'E',
	'CONVA' => 'E',
	'CONVC' => 'E',
	'CONVE' => 'E',
	'CONVI' => 'E',
	'CONVL' => 'E',
	'CONVR' => 'E',
	'CONVX' => 'E',
	'CONXI' => 'E',
	'COPCI' => 'E',
	'COPCM' => 'E',
	'COPCO' => 'E',
	'COPFO' => 'E',
	'COPJA' => 'E',
	'COPLA' => 'E',
	'COPTE' => 'E',
	'COPV' => 'V',
	'CORAB' => 'E',
	'CORAI' => 'E',
	'CORAL' => 'E',
	'CORAM' => 'B',
	'CORAT' => 'E',
	'CORAU' => 'E',
	'CORAV' => 'E',
	'CORBE' => 'V',
	'CORBR' => 'E',
	'CORCA' => 'E',
	'CORCB' => 'E',
	'CORCC' => 'E',
	'CORCD' => 'E',
	'CORCE' => 'E',
	'CORCH' => 'E',
	'CORCI' => 'E',
	'CORCL' => 'E',
	'CORCN' => 'E',
	'CORCO' => 'E',
	'CORCP' => 'E',
	'CORCR' => 'E',
	'CORCS' => 'E',
	'CORCT' => 'B',
	'CORCU' => 'E',
	'CORCV' => 'E',
	'CORCX' => 'E',
	'CORCY' => 'E',
	'CORDC' => 'E',
	'CORDI' => 'B',
	'COREF' => 'B',
	'COREI' => 'E',
	'COREL' => 'E',
	'COREN' => 'E',
	'COREQ' => 'B',
	'CORFI' => 'E',
	'CORFL' => 'B',
	'CORFO' => 'E',
	'CORFR' => 'E',
	'CORGA' => 'E',
	'CORGL' => 'B',
	'CORGR' => 'E',
	'CORGU' => 'E',
	'CORHA' => 'E',
	'CORHP' => 'E',
	'CORHY' => 'E',
	'CORJE' => 'B',
	'CORJK' => 'B',
	'CORKO' => 'E',
	'CORKU' => 'E',
	'CORLA' => 'E',
	'CORLI' => 'E',
	'CORLN' => 'E',
	'CORLT' => 'E',
	'CORLV' => 'E',
	'CORMA' => 'E',
	'CORMC' => 'E',
	'CORME' => 'E',
	'CORMI' => 'E',
	'CORML' => 'B',
	'CORMO' => 'E',
	'CORMR' => 'E',
	'CORMS' => 'E',
	'CORMY' => 'E',
	'CORNE' => 'B',
	'CORNI' => 'E',
	'COROB' => 'E',
	'COROF' => 'E',
	'COROI' => 'E',
	'COROL' => 'E',
	'COROM' => 'V',
	'CORPC' => 'E',
	'CORPE' => 'E',
	'CORPS' => 'B',
	'CORPT' => 'E',
	'CORPU' => 'E',
	'CORRU' => 'E',
	'CORS1' => 'B',
	'CORS2' => 'B',
	'CORSA' => 'E',
	'CORSC' => 'B',
	'CORSE' => 'E',
	'CORSL' => 'E',
	'CORSP' => 'B',
	'CORSS' => 'B',
	'CORST' => 'B',
	'CORSU' => 'E',
	'CORTI' => 'E',
	'CORUL' => 'B',
	'CORUR' => 'E',
	'CORVA' => 'E',
	'CORVR' => 'E',
	'CORWA' => 'E',
	'COSCO' => 'E',
	'COSCS' => 'E',
	'COSMU' => 'E',
	'COSRU' => 'E',
	'COTBA' => 'E',
	'COTBO' => 'E',
	'COTCG' => 'E',
	'COTCH' => 'E',
	'COTCN' => 'E',
	'COTCO' => 'E',
	'COTDE' => 'E',
	'COTEL' => 'E',
	'COTFL' => 'E',
	'COTGO' => 'E',
	'COTGR' => 'E',
	'COTIN' => 'E',
	'COTJA' => 'E',
	'COTKA' => 'E',
	'COTKE' => 'E',
	'COTMA' => 'E',
	'COTME' => 'E',
	'COTOR' => 'E',
	'COTPA' => 'E',
	'COTPL' => 'E',
	'COTRU' => 'E',
	'COTTO' => 'E',
	'COTWO' => 'E',
	'COUGU' => 'E',
	'COWPX' => 'V',
	'COXBU' => 'B',
	'COYMV' => 'V',
	'CPMV' => 'V',
	'CPSMV' => 'V',
	'CPVBM' => 'V',
	'CPVCS' => 'V',
	'CPVES' => 'V',
	'CPVOP' => 'V',
	'CRAAB' => 'E',
	'CRAAL' => 'E',
	'CRAAN' => 'E',
	'CRAAR' => 'E',
	'CRABL' => 'E',
	'CRABU' => 'E',
	'CRACA' => 'E',
	'CRACO' => 'E',
	'CRAFA' => 'E',
	'CRAFL' => 'E',
	'CRAFU' => 'E',
	'CRAGA' => 'E',
	'CRAGG' => 'E',
	'CRAGI' => 'E',
	'CRAGR' => 'E',
	'CRAGY' => 'E',
	'CRAHE' => 'E',
	'CRAHO' => 'E',
	'CRAIR' => 'E',
	'CRAMA' => 'E',
	'CRAME' => 'E',
	'CRAMN' => 'E',
	'CRAMO' => 'E',
	'CRANE' => 'E',
	'CRAOR' => 'E',
	'CRAPA' => 'E',
	'CRAPE' => 'E',
	'CRAPL' => 'E',
	'CRAPO' => 'E',
	'CRAPR' => 'E',
	'CRARH' => 'E',
	'CRARU' => 'E',
	'CRASI' => 'E',
	'CRATH' => 'E',
	'CRATY' => 'E',
	'CRAVI' => 'E',
	'CRAZI' => 'E',
	'CREAL' => 'E',
	'CREAT' => 'E',
	'CREBE' => 'E',
	'CREBI' => 'E',
	'CREBL' => 'E',
	'CRECO' => 'E',
	'CRECR' => 'E',
	'CREDE' => 'E',
	'CREFO' => 'E',
	'CREIN' => 'E',
	'CRELE' => 'E',
	'CREMA' => 'E',
	'CREOD' => 'E',
	'CREPL' => 'E',
	'CREPO' => 'E',
	'CREPU' => 'E',
	'CRESP' => 'E',
	'CRETR' => 'E',
	'CRIAP' => 'E',
	'CRIAS' => 'E',
	'CRICR' => 'E',
	'CRIDE' => 'E',
	'CRIDU' => 'E',
	'CRIEM' => 'E',
	'CRIFA' => 'E',
	'CRIGA' => 'E',
	'CRIGE' => 'E',
	'CRIGR' => 'E',
	'CRILE' => 'E',
	'CRILO' => 'E',
	'CRIMI' => 'E',
	'CRIMO' => 'E',
	'CRION' => 'E',
	'CRIPE' => 'E',
	'CRISI' => 'E',
	'CRISP' => 'E',
	'CRIYE' => 'E',
	'CROAC' => 'E',
	'CROAD' => 'E',
	'CROAE' => 'E',
	'CROAL' => 'E',
	'CROAT' => 'E',
	'CROAU' => 'E',
	'CROBA' => 'E',
	'CROBC' => 'E',
	'CROBE' => 'E',
	'CROBG' => 'E',
	'CROBI' => 'E',
	'CROBR' => 'E',
	'CROCA' => 'E',
	'CROCC' => 'E',
	'CROCO' => 'E',
	'CROCP' => 'E',
	'CROCR' => 'E',
	'CROCS' => 'E',
	'CRODD' => 'E',
	'CRODR' => 'E',
	'CRODS' => 'E',
	'CRODU' => 'E',
	'CROEL' => 'E',
	'CROEN' => 'E',
	'CROFO' => 'E',
	'CROFU' => 'E',
	'CROGU' => 'E',
	'CROHA' => 'E',
	'CROHI' => 'E',
	'CROHO' => 'E',
	'CROHR' => 'E',
	'CROIN' => 'E',
	'CROJU' => 'E',
	'CROKU' => 'E',
	'CROLA' => 'E',
	'CROLB' => 'E',
	'CROLE' => 'E',
	'CROLP' => 'E',
	'CROLS' => 'E',
	'CROLU' => 'E',
	'CROLV' => 'E',
	'CROMA' => 'E',
	'CROMI' => 'E',
	'CROMM' => 'E',
	'CROMN' => 'E',
	'CROMO' => 'E',
	'CROMU' => 'E',
	'CRONG' => 'E',
	'CRONI' => 'E',
	'CRONO' => 'E',
	'CRONU' => 'E',
	'CROOB' => 'E',
	'CROOR' => 'E',
	'CROPA' => 'E',
	'CROPL' => 'E',
	'CROPO' => 'E',
	'CROPR' => 'E',
	'CROPY' => 'E',
	'CRORA' => 'E',
	'CRORH' => 'E',
	'CRORS' => 'E',
	'CRORU' => 'E',
	'CROSA' => 'E',
	'CROSB' => 'E',
	'CROSH' => 'E',
	'CROSI' => 'E',
	'CROSL' => 'E',
	'CROSP' => 'E',
	'CROSS' => 'E',
	'CROST' => 'E',
	'CROSU' => 'E',
	'CROTI' => 'E',
	'CROUN' => 'E',
	'CROVC' => 'E',
	'CROVE' => 'E',
	'CROVG' => 'E',
	'CROVH' => 'E',
	'CROVL' => 'E',
	'CROVN' => 'E',
	'CROVV' => 'E',
	'CROWA' => 'E',
	'CROWT' => 'B',
	'CROWU' => 'E',
	'CRPV' => 'V',
	'CRPVK' => 'V',
	'CRPVW' => 'V',
	'CRUAN' => 'E',
	'CRUGL' => 'E',
	'CRUHI' => 'E',
	'CRUME' => 'E',
	'CRUSU' => 'E',
	'CRUWA' => 'E',
	'CRV' => 'V',
	'CRYAL' => 'E',
	'CRYAM' => 'E',
	'CRYAN' => 'E',
	'CRYAP' => 'E',
	'CRYCH' => 'E',
	'CRYCO' => 'E',
	'CRYCU' => 'E',
	'CRYDA' => 'E',
	'CRYDR' => 'E',
	'CRYDU' => 'E',
	'CRYFE' => 'E',
	'CRYFL' => 'E',
	'CRYGA' => 'E',
	'CRYGO' => 'E',
	'CRYHO' => 'E',
	'CRYJA' => 'E',
	'CRYMA' => 'E',
	'CRYME' => 'E',
	'CRYMI' => 'E',
	'CRYNE' => 'E',
	'CRYNV' => 'E',
	'CRYPA' => 'E',
	'CRYPR' => 'E',
	'CRYPV' => 'E',
	'CRYSP' => 'E',
	'CRYST' => 'E',
	'CRYTA' => 'E',
	'CRYTR' => 'E',
	'CSFVA' => 'V',
	'CSFVB' => 'V',
	'CSFVC' => 'V',
	'CSMV' => 'V',
	'CSV' => 'V',
	'CTEAR' => 'E',
	'CTEAU' => 'E',
	'CTEBO' => 'E',
	'CTECA' => 'E',
	'CTECL' => 'E',
	'CTECO' => 'E',
	'CTECR' => 'E',
	'CTECY' => 'E',
	'CTEDE' => 'E',
	'CTEEU' => 'E',
	'CTEFA' => 'E',
	'CTEFE' => 'E',
	'CTEFI' => 'E',
	'CTEFL' => 'E',
	'CTEFM' => 'E',
	'CTEFO' => 'E',
	'CTEFR' => 'E',
	'CTEFT' => 'E',
	'CTEGI' => 'E',
	'CTEGO' => 'E',
	'CTEGU' => 'E',
	'CTEHA' => 'E',
	'CTEHE' => 'E',
	'CTEID' => 'E',
	'CTEIS' => 'E',
	'CTELA' => 'E',
	'CTELE' => 'E',
	'CTELI' => 'E',
	'CTELW' => 'E',
	'CTEMA' => 'E',
	'CTEMC' => 'E',
	'CTEME' => 'E',
	'CTEMK' => 'E',
	'CTEML' => 'E',
	'CTEMU' => 'E',
	'CTENU' => 'E',
	'CTEOA' => 'E',
	'CTEOR' => 'E',
	'CTEPA' => 'E',
	'CTEPE' => 'E',
	'CTEPI' => 'E',
	'CTEPO' => 'E',
	'CTEQU' => 'E',
	'CTERE' => 'E',
	'CTERU' => 'E',
	'CTESA' => 'E',
	'CTESC' => 'E',
	'CTESI' => 'E',
	'CTESO' => 'E',
	'CTEST' => 'E',
	'CTETA' => 'E',
	'CTETC' => 'E',
	'CTETU' => 'E',
	'CTEVA' => 'E',
	'CTEVD' => 'E',
	'CTV36' => 'V',
	'CUBDO' => 'E',
	'CUCCO' => 'E',
	'CUCFI' => 'E',
	'CUCMA' => 'E',
	'CUCMC' => 'E',
	'CUCME' => 'E',
	'CUCMI' => 'E',
	'CUCMO' => 'E',
	'CUCMR' => 'E',
	'CUCPE' => 'E',
	'CUCPM' => 'E',
	'CUCSA' => 'E',
	'CULNO' => 'E',
	'CULPI' => 'E',
	'CULPP' => 'E',
	'CULQU' => 'E',
	'CULTA' => 'E',
	'CULTO' => 'E',
	'CUMMO' => 'E',
	'CUNEE' => 'E',
	'CUNEL' => 'E',
	'CUNLA' => 'E',
	'CUOAL' => 'E',
	'CUPAN' => 'E',
	'CUPAR' => 'E',
	'CUPHO' => 'E',
	'CUPLA' => 'E',
	'CUPSA' => 'E',
	'CUPWR' => 'E',
	'CURAC' => 'E',
	'CURCU' => 'E',
	'CURIN' => 'E',
	'CURLA' => 'E',
	'CURLO' => 'E',
	'CURLU' => 'E',
	'CURNU' => 'E',
	'CURTE' => 'E',
	'CUSEU' => 'E',
	'CUSGR' => 'E',
	'CUSJA' => 'E',
	'CUSPE' => 'E',
	'CUSRE' => 'E',
	'CUSSA' => 'E',
	'CVB' => 'V',
	'CVBEN' => 'V',
	'CVBF' => 'V',
	'CVBG9' => 'V',
	'CVBL9' => 'V',
	'CVBLS' => 'V',
	'CVBLU' => 'V',
	'CVBLY' => 'V',
	'CVBM' => 'V',
	'CVBOK' => 'V',
	'CVBON' => 'V',
	'CVBQ' => 'V',
	'CVBV' => 'V',
	'CVCAE' => 'V',
	'CVCAI' => 'V',
	'CVEN9' => 'V',
	'CVFE3' => 'V',
	'CVH22' => 'V',
	'CVHNL' => 'V',
	'CVHOC' => 'V',
	'CVHSA' => 'V',
	'CVM1' => 'V',
	'CVM2' => 'V',
	'CVM3' => 'V',
	'CVM4' => 'V',
	'CVMA5' => 'V',
	'CVMDV' => 'V',
	'CVMJC' => 'V',
	'CVMJD' => 'V',
	'CVMJH' => 'V',
	'CVMS' => 'V',
	'CVP67' => 'V',
	'CVPFS' => 'V',
	'CVPIA' => 'V',
	'CVPMI' => 'V',
	'CVPPU' => 'V',
	'CVPR8' => 'V',
	'CVPRM' => 'V',
	'CVPRT' => 'V',
	'CVPV' => 'V',
	'CVRNJ' => 'V',
	'CVRSD' => 'V',
	'CVTIN' => 'V',
	'CVTKE' => 'V',
	'CVTMI' => 'V',
	'CVTNC' => 'V',
	'CWPXB' => 'V',
	'CWPXG' => 'V',
	'CX16G' => 'V',
	'CX16T' => 'V',
	'CXA21' => 'V',
	'CXA24' => 'V',
	'CXA9' => 'V',
	'CXB1J' => 'V',
	'CXB2O' => 'V',
	'CXB3N' => 'V',
	'CXB3W' => 'V',
	'CXB4E' => 'V',
	'CXB4J' => 'V',
	'CXB5P' => 'V',
	'CXB6S' => 'V',
	'CYAA5' => 'B',
	'CYAAU' => 'E',
	'CYABI' => 'E',
	'CYABO' => 'E',
	'CYABU' => 'E',
	'CYACA' => 'E',
	'CYACE' => 'E',
	'CYACH' => 'E',
	'CYACN' => 'E',
	'CYACP' => 'E',
	'CYACR' => 'E',
	'CYACU' => 'E',
	'CYACY' => 'E',
	'CYAER' => 'E',
	'CYAFO' => 'E',
	'CYAGR' => 'E',
	'CYAMA' => 'E',
	'CYAME' => 'E',
	'CYANO' => 'E',
	'CYAOV' => 'E',
	'CYAPA' => 'E',
	'CYASP' => 'E',
	'CYAST' => 'E',
	'CYATE' => 'E',
	'CYAUN' => 'E',
	'CYAVI' => 'E',
	'CYCAT' => 'E',
	'CYCBI' => 'E',
	'CYCCI' => 'E',
	'CYCCL' => 'E',
	'CYCCO' => 'E',
	'CYCDI' => 'E',
	'CYCLU' => 'E',
	'CYCMD' => 'E',
	'CYCME' => 'E',
	'CYCPA' => 'E',
	'CYCPE' => 'E',
	'CYCPI' => 'E',
	'CYCPS' => 'E',
	'CYCRE' => 'E',
	'CYCRI' => 'E',
	'CYCRL' => 'E',
	'CYCRU' => 'E',
	'CYDAE' => 'E',
	'CYDMO' => 'E',
	'CYDPO' => 'E',
	'CYGAT' => 'E',
	'CYGMA' => 'E',
	'CYGOL' => 'E',
	'CYLFU' => 'E',
	'CYLSN' => 'E',
	'CYLTO' => 'E',
	'CYMAT' => 'E',
	'CYMEC' => 'E',
	'CYMEN' => 'E',
	'CYMV' => 'V',
	'CYMVE' => 'E',
	'CYNBR' => 'E',
	'CYNCA' => 'E',
	'CYNDA' => 'E',
	'CYNGU' => 'E',
	'CYNHO' => 'E',
	'CYNLE' => 'E',
	'CYNLU' => 'E',
	'CYNME' => 'E',
	'CYNNE' => 'E',
	'CYNPA' => 'E',
	'CYNPE' => 'E',
	'CYNPY' => 'E',
	'CYNSC' => 'E',
	'CYNSP' => 'E',
	'CYNVA' => 'E',
	'CYNVO' => 'E',
	'CYPAC' => 'E',
	'CYPAN' => 'E',
	'CYPBE' => 'E',
	'CYPCA' => 'E',
	'CYPCL' => 'E',
	'CYPDO' => 'E',
	'CYPFR' => 'E',
	'CYPGA' => 'E',
	'CYPLU' => 'E',
	'CYPNE' => 'E',
	'CYPPA' => 'E',
	'CYPPP' => 'E',
	'CYPS1' => 'E',
	'CYPSP' => 'E',
	'CYPTI' => 'E',
	'CYPVA' => 'E',
	'CYRAN' => 'E',
	'CYRCI' => 'E',
	'CYRDI' => 'E',
	'CYRFA' => 'E',
	'CYRMA' => 'E',
	'CYRMO' => 'E',
	'CYRPA' => 'E',
	'CYRPO' => 'E',
	'CYRPR' => 'E',
	'CYRPU' => 'E',
	'CYRRA' => 'E',
	'CYRTA' => 'E',
	'CYSCR' => 'E',
	'CYSFR' => 'E',
	'CYTAQ' => 'B',
	'CYTAU' => 'B',
	'CYTH3' => 'B',
	'CYTHU' => 'B',
	'CYTJO' => 'B',
	'CYTLY' => 'B',
	'CYTSC' => 'E',
	'CYTSE' => 'E',
	'CYVV' => 'V',
	'DABCA' => 'E',
	'DABRP' => 'E',
	'DABRR' => 'E',
	'DABRU' => 'E',
	'DACBO' => 'E',
	'DACCA' => 'E',
	'DACCI' => 'E',
	'DACDA' => 'E',
	'DACDE' => 'E',
	'DACDM' => 'E',
	'DACGL' => 'E',
	'DACMI' => 'E',
	'DACNO' => 'E',
	'DACPA' => 'E',
	'DACPE' => 'E',
	'DACRO' => 'E',
	'DACSA' => 'B',
	'DACSI' => 'E',
	'DACTR' => 'E',
	'DACVE' => 'E',
	'DAHCO' => 'E',
	'DALCH' => 'E',
	'DALPU' => 'E',
	'DALWR' => 'E',
	'DAMCA' => 'E',
	'DAMDA' => 'E',
	'DAMDI' => 'E',
	'DAMKO' => 'E',
	'DAMLU' => 'E',
	'DAMME' => 'E',
	'DAMPP' => 'E',
	'DAMPY' => 'E',
	'DANAA' => 'E',
	'DANAE' => 'E',
	'DANAT' => 'E',
	'DANFR' => 'E',
	'DANGE' => 'E',
	'DANKE' => 'E',
	'DANPL' => 'E',
	'DANPU' => 'E',
	'DANSP' => 'E',
	'DAPCA' => 'E',
	'DAPME' => 'E',
	'DAPPU' => 'E',
	'DAPSP' => 'E',
	'DARAR' => 'E',
	'DARCA' => 'E',
	'DARSA' => 'E',
	'DASAB' => 'E',
	'DASAK' => 'E',
	'DASAL' => 'E',
	'DASAM' => 'E',
	'DASAR' => 'E',
	'DASBY' => 'E',
	'DASCA' => 'E',
	'DASCR' => 'E',
	'DASFL' => 'E',
	'DASFU' => 'E',
	'DASGE' => 'E',
	'DASHA' => 'E',
	'DASKA' => 'E',
	'DASLA' => 'E',
	'DASMA' => 'E',
	'DASME' => 'E',
	'DASMR' => 'E',
	'DASNO' => 'E',
	'DASRE' => 'E',
	'DASRO' => 'E',
	'DASSA' => 'E',
	'DASSP' => 'E',
	'DASST' => 'E',
	'DASTR' => 'E',
	'DASVI' => 'E',
	'DATAR' => 'E',
	'DATFA' => 'E',
	'DATFE' => 'E',
	'DATGL' => 'E',
	'DATIN' => 'E',
	'DATME' => 'E',
	'DATPE' => 'E',
	'DATQU' => 'E',
	'DATST' => 'E',
	'DAUCA' => 'E',
	'DAUMA' => 'E',
	'DAUPU' => 'E',
	'DAVIN' => 'E',
	'DEBHA' => 'E',
	'DEBOC' => 'E',
	'DECAR' => 'B',
	'DECKU' => 'E',
	'DECMA' => 'E',
	'DECMC' => 'E',
	'DECMR' => 'E',
	'DECPU' => 'E',
	'DECRU' => 'E',
	'DECTA' => 'E',
	'DECVE' => 'E',
	'DEHE1' => 'B',
	'DEHMU' => 'B',
	'DEHSC' => 'B',
	'DEIGD' => 'B',
	'DEIPR' => 'B',
	'DEIRA' => 'B',
	'DEIRE' => 'E',
	'DEISP' => 'B',
	'DEKBR' => 'E',
	'DELAJ' => 'E',
	'DELBI' => 'E',
	'DELCA' => 'E',
	'DELDE' => 'E',
	'DELKE' => 'E',
	'DELLE' => 'E',
	'DELPU' => 'E',
	'DELRE' => 'E',
	'DELST' => 'E',
	'DELSU' => 'E',
	'DELTR' => 'E',
	'DEN14' => 'V',
	'DEN18' => 'V',
	'DEN19' => 'V',
	'DEN1A' => 'V',
	'DEN1C' => 'V',
	'DEN1S' => 'V',
	'DEN1T' => 'V',
	'DEN1W' => 'V',
	'DEN21' => 'V',
	'DEN22' => 'V',
	'DEN23' => 'V',
	'DEN26' => 'V',
	'DEN27' => 'V',
	'DEN2D' => 'V',
	'DEN2H' => 'V',
	'DEN2J' => 'V',
	'DEN2N' => 'V',
	'DEN2P' => 'V',
	'DEN2T' => 'V',
	'DEN2U' => 'V',
	'DEN3' => 'V',
	'DEN4' => 'V',
	'DENAA' => 'E',
	'DENAC' => 'E',
	'DENAE' => 'E',
	'DENAG' => 'E',
	'DENAN' => 'E',
	'DENAR' => 'E',
	'DENAT' => 'E',
	'DENAU' => 'E',
	'DENBA' => 'E',
	'DENBE' => 'E',
	'DENBI' => 'E',
	'DENCL' => 'E',
	'DENCO' => 'E',
	'DENCR' => 'E',
	'DENCY' => 'E',
	'DENDE' => 'E',
	'DENDM' => 'E',
	'DENDO' => 'E',
	'DENDR' => 'E',
	'DENEY' => 'E',
	'DENFA' => 'E',
	'DENFI' => 'E',
	'DENFU' => 'E',
	'DENGI' => 'E',
	'DENGL' => 'E',
	'DENGO' => 'E',
	'DENIN' => 'E',
	'DENJA' => 'E',
	'DENKI' => 'E',
	'DENKL' => 'E',
	'DENLO' => 'E',
	'DENLU' => 'E',
	'DENMA' => 'E',
	'DENME' => 'E',
	'DENMJ' => 'E',
	'DENMO' => 'E',
	'DENMT' => 'E',
	'DENOC' => 'E',
	'DENOT' => 'E',
	'DENPE' => 'E',
	'DENPI' => 'E',
	'DENPL' => 'E',
	'DENPN' => 'E',
	'DENPO' => 'E',
	'DENPU' => 'E',
	'DENRI' => 'E',
	'DENSA' => 'E',
	'DENSC' => 'E',
	'DENSP' => 'E',
	'DENST' => 'E',
	'DENTA' => 'E',
	'DENTG' => 'E',
	'DENTH' => 'E',
	'DENTI' => 'E',
	'DENTO' => 'E',
	'DENTU' => 'E',
	'DENVD' => 'E',
	'DENVI' => 'E',
	'DENVR' => 'E',
	'DENZE' => 'E',
	'DEPGR' => 'E',
	'DEPPA' => 'E',
	'DERAC' => 'E',
	'DERAN' => 'E',
	'DERBR' => 'E',
	'DERCR' => 'E',
	'DEREJ' => 'E',
	'DERER' => 'E',
	'DERFA' => 'E',
	'DERIM' => 'E',
	'DERKE' => 'E',
	'DERLA' => 'E',
	'DERMA' => 'E',
	'DERMI' => 'E',
	'DERPT' => 'E',
	'DERVA' => 'E',
	'DERVE' => 'E',
	'DESAC' => 'B',
	'DESAE' => 'B',
	'DESAF' => 'B',
	'DESAM' => 'A',
	'DESAN' => 'E',
	'DESAU' => 'E',
	'DESBA' => 'B',
	'DESBR' => 'B',
	'DESCE' => 'E',
	'DESDE' => 'B',
	'DESDG' => 'B',
	'DESFL' => 'E',
	'DESFR' => 'B',
	'DESFU' => 'E',
	'DESGI' => 'B',
	'DESHA' => 'B',
	'DESHD' => 'B',
	'DESHY' => 'B',
	'DESMO' => 'A',
	'DESMS' => 'E',
	'DESMU' => 'B',
	'DESNO' => 'B',
	'DESPA' => 'E',
	'DESPS' => 'B',
	'DESRO' => 'E',
	'DESSA' => 'B',
	'DESSO' => 'E',
	'DESSY' => 'A',
	'DESTE' => 'B',
	'DESTH' => 'B',
	'DESTI' => 'B',
	'DESUN' => 'E',
	'DESVH' => 'B',
	'DESVM' => 'B',
	'DESVO' => 'B',
	'DESVU' => 'B',
	'DETCO' => 'E',
	'DEUGR' => 'E',
	'DEVDE' => 'E',
	'DEVMA' => 'E',
	'DEVPA' => 'E',
	'DHVI1' => 'V',
	'DIAAB' => 'E',
	'DIABA' => 'E',
	'DIABR' => 'E',
	'DIACA' => 'E',
	'DIAEN' => 'E',
	'DIAGR' => 'E',
	'DIALA' => 'E',
	'DIALU' => 'E',
	'DIAMO' => 'E',
	'DIAOB' => 'E',
	'DIAPU' => 'E',
	'DIASA' => 'E',
	'DIASE' => 'E',
	'DIAUN' => 'E',
	'DIAYO' => 'E',
	'DICAB' => 'E',
	'DICAL' => 'E',
	'DICAN' => 'E',
	'DICB4' => 'B',
	'DICBI' => 'E',
	'DICCR' => 'E',
	'DICD3' => 'B',
	'DICDA' => 'B',
	'DICDE' => 'E',
	'DICDH' => 'E',
	'DICDI' => 'E',
	'DICEX' => 'E',
	'DICGR' => 'E',
	'DICLA' => 'E',
	'DICLI' => 'E',
	'DICME' => 'E',
	'DICMU' => 'E',
	'DICSC' => 'E',
	'DICSP' => 'E',
	'DICSU' => 'E',
	'DICTH' => 'B',
	'DICTO' => 'E',
	'DICTR' => 'E',
	'DICTY' => 'E',
	'DICVI' => 'E',
	'DIDAL' => 'E',
	'DIDAU' => 'E',
	'DIDMA' => 'E',
	'DIDMR' => 'E',
	'DIDNA' => 'E',
	'DIDST' => 'E',
	'DIEGR' => 'E',
	'DIERO' => 'E',
	'DIESE' => 'E',
	'DIGCA' => 'E',
	'DIGGR' => 'E',
	'DIGLA' => 'E',
	'DIGPU' => 'E',
	'DILIN' => 'E',
	'DILMA' => 'E',
	'DIMHO' => 'E',
	'DIMVE' => 'E',
	'DINAC' => 'E',
	'DINAU' => 'E',
	'DINNO' => 'E',
	'DINSE' => 'E',
	'DIOAB' => 'E',
	'DIOAM' => 'E',
	'DIOAS' => 'E',
	'DIOBU' => 'E',
	'DIOCA' => 'E',
	'DIOCH' => 'E',
	'DIOCU' => 'E',
	'DIODA' => 'E',
	'DIODI' => 'E',
	'DIOED' => 'E',
	'DIOGA' => 'E',
	'DIOGL' => 'E',
	'DIOGR' => 'E',
	'DIOGU' => 'E',
	'DIOIM' => 'E',
	'DIOJA' => 'E',
	'DIOKA' => 'E',
	'DIOLE' => 'E',
	'DIOMU' => 'E',
	'DIORO' => 'E',
	'DIOSP' => 'E',
	'DIOTE' => 'E',
	'DIOVI' => 'E',
	'DIOVO' => 'E',
	'DIOVR' => 'E',
	'DIOWH' => 'E',
	'DIPAG' => 'E',
	'DIPAN' => 'E',
	'DIPAR' => 'E',
	'DIPBI' => 'E',
	'DIPBL' => 'E',
	'DIPCA' => 'E',
	'DIPCO' => 'E',
	'DIPCT' => 'E',
	'DIPDE' => 'E',
	'DIPDI' => 'E',
	'DIPDO' => 'E',
	'DIPDS' => 'E',
	'DIPEC' => 'E',
	'DIPEL' => 'E',
	'DIPER' => 'E',
	'DIPFO' => 'E',
	'DIPGR' => 'E',
	'DIPHE' => 'E',
	'DIPIN' => 'E',
	'DIPIS' => 'E',
	'DIPLE' => 'E',
	'DIPMA' => 'E',
	'DIPME' => 'E',
	'DIPMI' => 'E',
	'DIPMR' => 'E',
	'DIPNE' => 'E',
	'DIPNI' => 'E',
	'DIPOR' => 'E',
	'DIPPA' => 'E',
	'DIPPU' => 'E',
	'DIPSA' => 'E',
	'DIPSI' => 'E',
	'DIPSM' => 'E',
	'DIPSP' => 'E',
	'DIPST' => 'E',
	'DIPVE' => 'E',
	'DIPVU' => 'E',
	'DIPYU' => 'E',
	'DIPZA' => 'E',
	'DIRIM' => 'E',
	'DISAT' => 'E',
	'DISCA' => 'E',
	'DISEL' => 'E',
	'DISGL' => 'E',
	'DISLO' => 'E',
	'DISMA' => 'E',
	'DISOM' => 'E',
	'DISPE' => 'E',
	'DISRO' => 'E',
	'DISSE' => 'E',
	'DISSP' => 'E',
	'DISST' => 'E',
	'DISTR' => 'E',
	'DIUNO' => 'E',
	'DOBIN' => 'E',
	'DOBMI' => 'E',
	'DOBMO' => 'E',
	'DOBPA' => 'E',
	'DOBPR' => 'E',
	'DOBVI' => 'E',
	'DODME' => 'E',
	'DOLAR' => 'E',
	'DOLAU' => 'E',
	'DOLAX' => 'E',
	'DOLBI' => 'E',
	'DOLDO' => 'E',
	'DOLEC' => 'E',
	'DOLLA' => 'E',
	'DOLMA' => 'E',
	'DOLOR' => 'E',
	'DOLPA' => 'E',
	'DOLTE' => 'E',
	'DONCU' => 'E',
	'DONFA' => 'E',
	'DORBE' => 'E',
	'DORCO' => 'E',
	'DORDA' => 'E',
	'DOREX' => 'E',
	'DORPA' => 'E',
	'DORSP' => 'E',
	'DORVA' => 'E',
	'DORVE' => 'E',
	'DOTCO' => 'E',
	'DRAAL' => 'E',
	'DRACH' => 'E',
	'DRAFL' => 'E',
	'DRAGR' => 'E',
	'DRALA' => 'E',
	'DRALO' => 'E',
	'DRAMO' => 'E',
	'DRANI' => 'E',
	'DRAPA' => 'E',
	'DRAPL' => 'E',
	'DRAPO' => 'E',
	'DRARU' => 'E',
	'DRASI' => 'E',
	'DRASU' => 'E',
	'DRATU' => 'E',
	'DREPE' => 'E',
	'DREPO' => 'E',
	'DRIEL' => 'E',
	'DRIGR' => 'E',
	'DRIMA' => 'E',
	'DRIWI' => 'E',
	'DROAA' => 'E',
	'DROAC' => 'E',
	'DROAD' => 'E',
	'DROAE' => 'E',
	'DROAF' => 'E',
	'DROAI' => 'E',
	'DROAL' => 'E',
	'DROAM' => 'E',
	'DROAN' => 'E',
	'DROAP' => 'E',
	'DROAR' => 'E',
	'DROAS' => 'E',
	'DROAT' => 'E',
	'DROAU' => 'E',
	'DROAV' => 'E',
	'DROAX' => 'E',
	'DROAZ' => 'E',
	'DROBA' => 'E',
	'DROBC' => 'E',
	'DROBF' => 'E',
	'DROBI' => 'E',
	'DROBO' => 'E',
	'DROBP' => 'E',
	'DROBR' => 'E',
	'DROBS' => 'E',
	'DROBU' => 'E',
	'DROCA' => 'E',
	'DROCP' => 'E',
	'DROCR' => 'E',
	'DROCY' => 'E',
	'DRODA' => 'E',
	'DRODC' => 'E',
	'DRODI' => 'E',
	'DRODO' => 'E',
	'DRODS' => 'E',
	'DROEC' => 'E',
	'DROEL' => 'E',
	'DROEM' => 'E',
	'DROEQ' => 'E',
	'DROER' => 'E',
	'DROEU' => 'E',
	'DROEZ' => 'E',
	'DROFC' => 'E',
	'DROFI' => 'E',
	'DROFL' => 'E',
	'DROFM' => 'E',
	'DROFU' => 'E',
	'DROGR' => 'E',
	'DROGU' => 'E',
	'DROHA' => 'E',
	'DROHE' => 'E',
	'DROHY' => 'E',
	'DROIK' => 'E',
	'DROIM' => 'E',
	'DROIN' => 'E',
	'DROJA' => 'E',
	'DROKA' => 'E',
	'DROKI' => 'E',
	'DROKT' => 'E',
	'DROKU' => 'E',
	'DROLA' => 'E',
	'DROLE' => 'E',
	'DROLI' => 'E',
	'DROLM' => 'E',
	'DROLN' => 'E',
	'DROLO' => 'E',
	'DROLR' => 'E',
	'DROLS' => 'E',
	'DROLT' => 'E',
	'DROLU' => 'E',
	'DROMA' => 'E',
	'DROMC' => 'E',
	'DROMD' => 'E',
	'DROME' => 'E',
	'DROMI' => 'E',
	'DROML' => 'E',
	'DROMM' => 'E',
	'DROMN' => 'E',
	'DROMO' => 'E',
	'DROMR' => 'E',
	'DROMS' => 'E',
	'DROMT' => 'E',
	'DROMU' => 'E',
	'DROMX' => 'E',
	'DROMY' => 'E',
	'DRONA' => 'E',
	'DRONC' => 'E',
	'DRONE' => 'E',
	'DRONI' => 'E',
	'DRONO' => 'E',
	'DRONR' => 'E',
	'DRONS' => 'E',
	'DROOB' => 'E',
	'DROOR' => 'E',
	'DROPA' => 'E',
	'DROPB' => 'E',
	'DROPC' => 'E',
	'DROPE' => 'E',
	'DROPI' => 'E',
	'DROPL' => 'E',
	'DROPN' => 'E',
	'DROPO' => 'E',
	'DROPR' => 'E',
	'DROPS' => 'E',
	'DROPT' => 'E',
	'DROPU' => 'E',
	'DROPV' => 'E',
	'DRORE' => 'E',
	'DRORO' => 'E',
	'DRORP' => 'E',
	'DRORT' => 'E',
	'DROSA' => 'E',
	'DROSB' => 'E',
	'DROSC' => 'E',
	'DROSE' => 'E',
	'DROSI' => 'E',
	'DROSL' => 'E',
	'DROSO' => 'E',
	'DROSP' => 'E',
	'DROSR' => 'E',
	'DROSS' => 'E',
	'DROST' => 'E',
	'DROSU' => 'E',
	'DROTA' => 'E',
	'DROTE' => 'E',
	'DROTK' => 'E',
	'DROTO' => 'E',
	'DROTP' => 'E',
	'DROTR' => 'E',
	'DROTS' => 'E',
	'DROVA' => 'E',
	'DROVI' => 'E',
	'DROVL' => 'E',
	'DROWH' => 'E',
	'DROWI' => 'E',
	'DROYA' => 'E',
	'DRYCA' => 'E',
	'DRYCE' => 'E',
	'DRYCO' => 'E',
	'DRYCR' => 'E',
	'DRYFM' => 'E',
	'DRYIU' => 'E',
	'DRYLA' => 'E',
	'DRYNI' => 'E',
	'DRYPI' => 'E',
	'DRYRU' => 'E',
	'DRYSU' => 'E',
	'DSDNV' => 'V',
	'DUCIN' => 'E',
	'DUDVI' => 'E',
	'DUGBV' => 'V',
	'DUGDU' => 'E',
	'DUGJA' => 'E',
	'DUGME' => 'E',
	'DUGTI' => 'E',
	'DUMCA' => 'E',
	'DUMHI' => 'E',
	'DUNAC' => 'E',
	'DUNBA' => 'E',
	'DUNBI' => 'E',
	'DUNSA' => 'E',
	'DUNTE' => 'E',
	'DUSTH' => 'E',
	'DYPLE' => 'E',
	'DYSCR' => 'E',
	'DYSMI' => 'E',
	'DYSPA' => 'E',
	'DYSTE' => 'E',
	'EATNI' => 'E',
	'EAV' => 'V',
	'EAVBU' => 'V',
	'EBHSG' => 'V',
	'EBOEC' => 'V',
	'EBOG4' => 'V',
	'EBOIC' => 'V',
	'EBORE' => 'V',
	'EBORR' => 'V',
	'EBORS' => 'V',
	'EBOSB' => 'V',
	'EBOSM' => 'V',
	'EBOSU' => 'V',
	'EBOZ5' => 'V',
	'EBOZM' => 'V',
	'EBV' => 'V',
	'EBVA8' => 'V',
	'EBVC' => 'V',
	'EBVG' => 'V',
	'EBVP3' => 'V',
	'EBVR' => 'V',
	'EC01F' => 'V',
	'EC05N' => 'V',
	'EC06C' => 'V',
	'EC09B' => 'V',
	'EC09H' => 'V',
	'EC11G' => 'V',
	'EC12T' => 'V',
	'EC16H' => 'V',
	'EC22H' => 'V',
	'EC23C' => 'V',
	'EC23W' => 'V',
	'EC30B' => 'V',
	'ECBEL' => 'E',
	'ECCSC' => 'E',
	'ECHAM' => 'E',
	'ECHCA' => 'E',
	'ECHCB' => 'E',
	'ECHCG' => 'E',
	'ECHCH' => 'E',
	'ECHCL' => 'E',
	'ECHCO' => 'E',
	'ECHCR' => 'E',
	'ECHCS' => 'E',
	'ECHDE' => 'E',
	'ECHDI' => 'E',
	'ECHES' => 'E',
	'ECHEX' => 'E',
	'ECHGA' => 'E',
	'ECHGR' => 'E',
	'ECHGY' => 'E',
	'ECHKA' => 'E',
	'ECHLO' => 'E',
	'ECHMA' => 'E',
	'ECHML' => 'E',
	'ECHMU' => 'E',
	'ECHNA' => 'E',
	'ECHO9' => 'V',
	'ECHOC' => 'E',
	'ECHOL' => 'E',
	'ECHPL' => 'E',
	'ECHRU' => 'E',
	'ECHTE' => 'E',
	'ECHVU' => 'E',
	'ECLPR' => 'E',
	'ECO11' => 'B',
	'ECO27' => 'B',
	'ECO57' => 'B',
	'ECOL5' => 'B',
	'ECOL6' => 'B',
	'ECOLI' => 'B',
	'ECOUT' => 'B',
	'ECTAL' => 'E',
	'ECTHA' => 'B',
	'ECTHL' => 'B',
	'ECTMO' => 'B',
	'ECTSI' => 'E',
	'ECTTU' => 'E',
	'ECTVA' => 'B',
	'ECTVM' => 'V',
	'ECTVR' => 'E',
	'EDWIC' => 'B',
	'EDWTA' => 'B',
	'EEEV' => 'V',
	'EEEV1' => 'V',
	'EEEV3' => 'V',
	'EEEV8' => 'V',
	'EEEVF' => 'V',
	'EENNA' => 'E',
	'EEVV3' => 'V',
	'EEVV8' => 'V',
	'EEVVC' => 'V',
	'EEVVE' => 'V',
	'EEVVM' => 'V',
	'EEVVP' => 'V',
	'EEVVT' => 'V',
	'EGRCA' => 'E',
	'EGRTH' => 'E',
	'EHDV1' => 'V',
	'EHDV2' => 'V',
	'EHDVA' => 'V',
	'EHRAN' => 'E',
	'EHRCA' => 'B',
	'EHRCH' => 'B',
	'EHRCJ' => 'B',
	'EHRCR' => 'B',
	'EHRRG' => 'B',
	'EHRRI' => 'B',
	'EHRRU' => 'B',
	'EHRRW' => 'B',
	'EHRSE' => 'B',
	'EHV1' => 'V',
	'EHV1A' => 'V',
	'EHV1B' => 'V',
	'EHV1D' => 'V',
	'EHV1H' => 'V',
	'EHV1K' => 'V',
	'EHV1V' => 'V',
	'EHV2' => 'V',
	'EHV2T' => 'V',
	'EHV4' => 'V',
	'EIAV1' => 'V',
	'EIAV2' => 'V',
	'EIAV3' => 'V',
	'EIAV5' => 'V',
	'EIAV9' => 'V',
	'EIAVC' => 'V',
	'EIAVW' => 'V',
	'EIAVY' => 'V',
	'EICCR' => 'E',
	'EIDHE' => 'E',
	'EIKCO' => 'B',
	'EIMAC' => 'E',
	'EIMBO' => 'E',
	'EIMMA' => 'E',
	'EIMTE' => 'E',
	'EIRBA' => 'E',
	'EISFO' => 'E',
	'EISHO' => 'E',
	'ELAAN' => 'E',
	'ELACE' => 'E',
	'ELADA' => 'E',
	'ELADI' => 'E',
	'ELAGV' => 'E',
	'ELANI' => 'E',
	'ELAOL' => 'E',
	'ELAQU' => 'E',
	'ELASE' => 'E',
	'ELAUM' => 'E',
	'ELAVU' => 'E',
	'ELEAL' => 'E',
	'ELEBR' => 'E',
	'ELECI' => 'E',
	'ELECO' => 'E',
	'ELECQ' => 'E',
	'ELEED' => 'E',
	'ELEEL' => 'E',
	'ELEGR' => 'E',
	'ELEIN' => 'E',
	'ELEMA' => 'E',
	'ELEMC' => 'E',
	'ELEMO' => 'E',
	'ELEMY' => 'E',
	'ELERU' => 'E',
	'ELGKI' => 'E',
	'ELGMU' => 'E',
	'ELIEL' => 'E',
	'ELIGR' => 'E',
	'ELIMA' => 'E',
	'ELIMI' => 'E',
	'ELIMO' => 'E',
	'ELIMR' => 'B',
	'ELIMY' => 'E',
	'ELIQU' => 'E',
	'ELITY' => 'E',
	'ELIWE' => 'E',
	'ELLBR' => 'E',
	'ELLDI' => 'E',
	'ELLLU' => 'E',
	'ELLPA' => 'E',
	'ELLPY' => 'E',
	'ELLRA' => 'E',
	'ELLTA' => 'E',
	'ELMPH' => 'B',
	'ELOSA' => 'E',
	'ELSME' => 'E',
	'ELSST' => 'E',
	'ELV' => 'V',
	'ELYCA' => 'E',
	'ELYCH' => 'E',
	'ELYCL' => 'E',
	'ELYEP' => 'B',
	'ELYHY' => 'E',
	'ELYRE' => 'E',
	'ELYTI' => 'E',
	'EMBAL' => 'E',
	'EMBAT' => 'E',
	'EMBJA' => 'E',
	'EMBMO' => 'E',
	'EMBRU' => 'E',
	'EMBVA' => 'E',
	'EMCV' => 'V',
	'EMCVB' => 'V',
	'EMCVD' => 'V',
	'EMENI' => 'E',
	'EMIHU' => 'E',
	'EMMPE' => 'E',
	'EMOCA' => 'E',
	'EMOCO' => 'E',
	'EMOCY' => 'E',
	'EMOIM' => 'E',
	'EMPAT' => 'E',
	'EMPEA' => 'E',
	'EMPFL' => 'E',
	'EMPHE' => 'E',
	'EMPMI' => 'E',
	'EMPNI' => 'E',
	'EMPRU' => 'E',
	'EMYBL' => 'E',
	'EMYOR' => 'E',
	'ENABO' => 'E',
	'ENACA' => 'E',
	'ENACI' => 'E',
	'ENACY' => 'E',
	'ENADO' => 'E',
	'ENASI' => 'E',
	'ENCAL' => 'E',
	'ENCAR' => 'E',
	'ENCBU' => 'E',
	'ENCCA' => 'E',
	'ENCCL' => 'E',
	'ENCCO' => 'E',
	'ENCCU' => 'E',
	'ENCEM' => 'E',
	'ENCFO' => 'E',
	'ENCHE' => 'E',
	'ENCHO' => 'E',
	'ENCIN' => 'E',
	'ENCLA' => 'E',
	'ENCLE' => 'E',
	'ENCTA' => 'E',
	'ENDIN' => 'E',
	'ENDMA' => 'E',
	'ENGPE' => 'E',
	'ENHLU' => 'E',
	'ENHSC' => 'E',
	'ENKCA' => 'E',
	'ENKCH' => 'E',
	'ENMG3' => 'V',
	'ENMGO' => 'V',
	'ENSMI' => 'E',
	'ENSVE' => 'E',
	'ENTAE' => 'B',
	'ENTAG' => 'B',
	'ENTAM' => 'B',
	'ENTAS' => 'B',
	'ENTCA' => 'B',
	'ENTCL' => 'B',
	'ENTCO' => 'E',
	'ENTCP' => 'E',
	'ENTDI' => 'E',
	'ENTFA' => 'B',
	'ENTFC' => 'B',
	'ENTGA' => 'B',
	'ENTGE' => 'B',
	'ENTHI' => 'E',
	'ENTHR' => 'B',
	'ENTHU' => 'E',
	'ENTIN' => 'E',
	'ENTIT' => 'B',
	'ENTIV' => 'E',
	'ENTMU' => 'B',
	'ENTPR' => 'E',
	'ENTS2' => 'B',
	'ENTSA' => 'B',
	'ENTSP' => 'B',
	'ENYLA' => 'E',
	'ENYSE' => 'E',
	'EONSP' => 'E',
	'EOSBA' => 'E',
	'EOSCA' => 'E',
	'EOSRO' => 'E',
	'EOSRU' => 'E',
	'EPASP' => 'E',
	'EPHAL' => 'E',
	'EPHAS' => 'E',
	'EPHEQ' => 'E',
	'EPHMU' => 'E',
	'EPHSE' => 'E',
	'EPHSI' => 'E',
	'EPHTW' => 'E',
	'EPHVI' => 'E',
	'EPIAC' => 'E',
	'EPIAE' => 'E',
	'EPIAK' => 'E',
	'EPIAL' => 'E',
	'EPIAN' => 'E',
	'EPIAT' => 'E',
	'EPIAW' => 'E',
	'EPIBA' => 'E',
	'EPICA' => 'E',
	'EPICE' => 'E',
	'EPICN' => 'E',
	'EPICO' => 'E',
	'EPIEL' => 'E',
	'EPIEX' => 'E',
	'EPIFA' => 'E',
	'EPIFL' => 'E',
	'EPIFO' => 'E',
	'EPIHA' => 'E',
	'EPIHE' => 'E',
	'EPILE' => 'E',
	'EPIMA' => 'E',
	'EPIMC' => 'E',
	'EPIMO' => 'E',
	'EPINE' => 'E',
	'EPIPO' => 'E',
	'EPIPU' => 'E',
	'EPIRE' => 'E',
	'EPIRI' => 'E',
	'EPISA' => 'E',
	'EPISC' => 'E',
	'EPISF' => 'E',
	'EPISM' => 'E',
	'EPISS' => 'E',
	'EPIST' => 'E',
	'EPISU' => 'E',
	'EPITR' => 'E',
	'EPITY' => 'E',
	'EPIVI' => 'E',
	'EPMV' => 'V',
	'EPOFR' => 'E',
	'EPOGA' => 'E',
	'EPOMI' => 'E',
	'EPOWA' => 'E',
	'EPTBN' => 'E',
	'EPTBR' => 'E',
	'EPTBU' => 'E',
	'EPTCA' => 'E',
	'EPTFU' => 'E',
	'EPTNI' => 'E',
	'EPTSE' => 'E',
	'EPTST' => 'E',
	'EQUAR' => 'E',
	'EQUAS' => 'E',
	'EQUBA' => 'E',
	'EQUBO' => 'E',
	'EQUBU' => 'E',
	'EQUFL' => 'E',
	'EQUGI' => 'E',
	'EQUGR' => 'E',
	'EQUHE' => 'E',
	'EQUHM' => 'E',
	'EQUHY' => 'E',
	'EQULA' => 'E',
	'EQUPA' => 'E',
	'EQUPR' => 'E',
	'EQUPT' => 'E',
	'EQUSC' => 'E',
	'EQUSY' => 'E',
	'EQUTE' => 'E',
	'EQUVA' => 'E',
	'EQUZE' => 'E',
	'EREAL' => 'E',
	'ERECI' => 'E',
	'EREDI' => 'E',
	'EREDO' => 'E',
	'EREIM' => 'E',
	'EREMA' => 'E',
	'ERESA' => 'E',
	'ERETR' => 'E',
	'ERIAN' => 'E',
	'ERIAQ' => 'E',
	'ERIAU' => 'E',
	'ERIBA' => 'E',
	'ERIBU' => 'E',
	'ERICA' => 'E',
	'ERICN' => 'E',
	'ERICO' => 'E',
	'ERICR' => 'E',
	'ERIEU' => 'E',
	'ERIFL' => 'E',
	'ERIHY' => 'E',
	'ERIMA' => 'E',
	'ERINI' => 'E',
	'ERIRU' => 'E',
	'ERISC' => 'E',
	'ERISI' => 'E',
	'ERIST' => 'E',
	'ERITE' => 'E',
	'ERITN' => 'E',
	'ERITO' => 'E',
	'ERIVA' => 'E',
	'EROBO' => 'E',
	'EROSE' => 'E',
	'EROTE' => 'E',
	'ERPCA' => 'E',
	'ERUAB' => 'E',
	'ERUGA' => 'E',
	'ERUSA' => 'E',
	'ERUST' => 'E',
	'ERUVE' => 'E',
	'ERWAM' => 'B',
	'ERWAP' => 'B',
	'ERWCA' => 'B',
	'ERWCH' => 'B',
	'ERWCI' => 'B',
	'ERWCT' => 'B',
	'ERWPY' => 'B',
	'ERWST' => 'B',
	'ERYCA' => 'E',
	'ERYCB' => 'E',
	'ERYCC' => 'E',
	'ERYCE' => 'E',
	'ERYCG' => 'E',
	'ERYCH' => 'E',
	'ERYCL' => 'E',
	'ERYCO' => 'E',
	'ERYCP' => 'E',
	'ERYDE' => 'E',
	'ERYEL' => 'E',
	'ERYGA' => 'E',
	'ERYGO' => 'E',
	'ERYGR' => 'E',
	'ERYHA' => 'E',
	'ERYJA' => 'E',
	'ERYLA' => 'E',
	'ERYLO' => 'B',
	'ERYMI' => 'E',
	'ERYMN' => 'E',
	'ERYPA' => 'E',
	'ERYPI' => 'E',
	'ERYRE' => 'E',
	'ERYRH' => 'B',
	'ERYTA' => 'E',
	'ERYVA' => 'E',
	'ERYYU' => 'E',
	'ESCBL' => 'B',
	'ESCCA' => 'E',
	'ESCFE' => 'B',
	'ESCGI' => 'E',
	'ESCHE' => 'B',
	'ESCIN' => 'B',
	'ESCVU' => 'B',
	'ESOLU' => 'E',
	'ESTAC' => 'E',
	'EUAAM' => 'E',
	'EUBAC' => 'B',
	'EUBAS' => 'E',
	'EUBBA' => 'B',
	'EUBGL' => 'E',
	'EUBJA' => 'E',
	'EUBMA' => 'E',
	'EUBOX' => 'B',
	'EUBSP' => 'B',
	'EUCBI' => 'E',
	'EUCBO' => 'E',
	'EUCCA' => 'E',
	'EUCCI' => 'E',
	'EUCCL' => 'E',
	'EUCCS' => 'E',
	'EUCDE' => 'E',
	'EUCDL' => 'E',
	'EUCER' => 'E',
	'EUCEX' => 'E',
	'EUCFI' => 'E',
	'EUCFO' => 'E',
	'EUCGA' => 'E',
	'EUCGG' => 'E',
	'EUCGL' => 'E',
	'EUCGR' => 'E',
	'EUCGU' => 'E',
	'EUCLU' => 'E',
	'EUCME' => 'E',
	'EUCMO' => 'E',
	'EUCSE' => 'E',
	'EUCTR' => 'E',
	'EUCUL' => 'E',
	'EUCZA' => 'E',
	'EUDCH' => 'E',
	'EUDCR' => 'E',
	'EUDCY' => 'E',
	'EUDEL' => 'E',
	'EUDMI' => 'E',
	'EUDPA' => 'E',
	'EUDSC' => 'E',
	'EUDVA' => 'E',
	'EUEIS' => 'E',
	'EUGAN' => 'E',
	'EUGDE' => 'E',
	'EUGGA' => 'E',
	'EUGGE' => 'E',
	'EUGGR' => 'E',
	'EUGMU' => 'E',
	'EUGMY' => 'E',
	'EUGPI' => 'E',
	'EUGSA' => 'E',
	'EUGST' => 'E',
	'EUGVI' => 'E',
	'EULCO' => 'E',
	'EULDI' => 'E',
	'EULFC' => 'E',
	'EULFU' => 'E',
	'EULHO' => 'E',
	'EULJU' => 'E',
	'EULMA' => 'E',
	'EULMF' => 'E',
	'EULMM' => 'E',
	'EULMO' => 'E',
	'EULRU' => 'E',
	'EUMAU' => 'E',
	'EUMEG' => 'E',
	'EUMFA' => 'E',
	'EUMGL' => 'E',
	'EUMIN' => 'E',
	'EUMJU' => 'E',
	'EUMLA' => 'E',
	'EUMLT' => 'E',
	'EUMPE' => 'E',
	'EUMSE' => 'E',
	'EUMSK' => 'E',
	'EUNCA' => 'E',
	'EUNCO' => 'E',
	'EUNMU' => 'E',
	'EUNNO' => 'E',
	'EUNUV' => 'E',
	'EUOAL' => 'E',
	'EUOBU' => 'E',
	'EUOEL' => 'E',
	'EUOEU' => 'E',
	'EUOMA' => 'E',
	'EUPAE' => 'E',
	'EUPAT' => 'E',
	'EUPCA' => 'E',
	'EUPCH' => 'E',
	'EUPCI' => 'E',
	'EUPCL' => 'E',
	'EUPCO' => 'E',
	'EUPCR' => 'E',
	'EUPCU' => 'E',
	'EUPCY' => 'E',
	'EUPDU' => 'E',
	'EUPES' => 'E',
	'EUPEU' => 'E',
	'EUPFO' => 'E',
	'EUPLA' => 'E',
	'EUPMA' => 'E',
	'EUPMC' => 'E',
	'EUPMI' => 'E',
	'EUPNE' => 'E',
	'EUPNO' => 'E',
	'EUPOC' => 'E',
	'EUPPH' => 'E',
	'EUPRA' => 'E',
	'EUPSE' => 'E',
	'EUPSX' => 'E',
	'EUPTI' => 'E',
	'EUPVA' => 'E',
	'EURCA' => 'E',
	'EURFE' => 'E',
	'EURFL' => 'E',
	'EURLI' => 'E',
	'EURMA' => 'E',
	'EURMC' => 'E',
	'EURMI' => 'E',
	'EURMR' => 'E',
	'EURNI' => 'E',
	'EURSO' => 'E',
	'EURSP' => 'E',
	'EUSDA' => 'E',
	'EUSGR' => 'E',
	'EUSPL' => 'E',
	'EUTAQ' => 'E',
	'EUTBR' => 'E',
	'EUTDO' => 'E',
	'EUTPA' => 'E',
	'EUTWA' => 'E',
	'EVAHO' => 'E',
	'EVATR' => 'E',
	'EVIAF' => 'E',
	'EXAAF' => 'E',
	'EXERO' => 'E',
	'EXICO' => 'E',
	'EXIEI' => 'E',
	'EXIEX' => 'E',
	'EXODE' => 'E',
	'EXOJE' => 'E',
	'EXOOR' => 'E',
	'EXTTI' => 'E',
	'FAGCR' => 'E',
	'FAGES' => 'E',
	'FAGHA' => 'E',
	'FAGJA' => 'E',
	'FAGSY' => 'E',
	'FAGTA' => 'E',
	'FALCA' => 'E',
	'FALCO' => 'E',
	'FALFE' => 'E',
	'FALNA' => 'E',
	'FALPA' => 'E',
	'FALPE' => 'E',
	'FALSP' => 'E',
	'FARAB' => 'E',
	'FARNO' => 'E',
	'FARPA' => 'E',
	'FASGI' => 'E',
	'FASHE' => 'E',
	'FASTU' => 'E',
	'FBNY1' => 'V',
	'FBNY2' => 'V',
	'FBNYS' => 'V',
	'FCVC6' => 'V',
	'FCVF4' => 'V',
	'FCVF9' => 'V',
	'FCVUR' => 'V',
	'FELBI' => 'E',
	'FELCA' => 'E',
	'FELCH' => 'E',
	'FELLI' => 'E',
	'FELMA' => 'E',
	'FELNI' => 'E',
	'FELSI' => 'E',
	'FENME' => 'E',
	'FENV1' => 'V',
	'FERAC' => 'A',
	'FERAT' => 'E',
	'FERGO' => 'B',
	'FERIS' => 'B',
	'FERPE' => 'B',
	'FERPL' => 'A',
	'FESAR' => 'E',
	'FESFE' => 'E',
	'FESGI' => 'E',
	'FESPR' => 'E',
	'FESRU' => 'E',
	'FESSE' => 'E',
	'FFV' => 'V',
	'FHV' => 'V',
	'FHV1' => 'V',
	'FIBSU' => 'B',
	'FICAL' => 'E',
	'FICAW' => 'E',
	'FICCA' => 'E',
	'FICHY' => 'E',
	'FICNA' => 'E',
	'FICPA' => 'E',
	'FICSE' => 'E',
	'FILMA' => 'E',
	'FIPV' => 'V',
	'FISMU' => 'B',
	'FISSU' => 'B',
	'FIVPE' => 'V',
	'FIVSD' => 'V',
	'FIVT2' => 'V',
	'FIVU1' => 'V',
	'FIVU2' => 'V',
	'FIVU8' => 'V',
	'FIVWO' => 'V',
	'FLAAF' => 'E',
	'FLAAN' => 'E',
	'FLAAU' => 'E',
	'FLABI' => 'E',
	'FLABR' => 'E',
	'FLACH' => 'E',
	'FLACR' => 'E',
	'FLADO' => 'B',
	'FLAFE' => 'B',
	'FLAFL' => 'E',
	'FLALI' => 'E',
	'FLALU' => 'B',
	'FLAME' => 'B',
	'FLAOK' => 'B',
	'FLAPA' => 'E',
	'FLAPE' => 'E',
	'FLAPR' => 'E',
	'FLAPU' => 'E',
	'FLARA' => 'E',
	'FLARO' => 'E',
	'FLAS1' => 'B',
	'FLAS2' => 'B',
	'FLAS3' => 'B',
	'FLASK' => 'B',
	'FLASP' => 'B',
	'FLASS' => 'B',
	'FLASU' => 'B',
	'FLATR' => 'E',
	'FLAVE' => 'E',
	'FLAVR' => 'E',
	'FLDV' => 'V',
	'FLEAB' => 'E',
	'FLEAR' => 'E',
	'FLECA' => 'B',
	'FLEEL' => 'B',
	'FLEFI' => 'B',
	'FLEJA' => 'B',
	'FLESA' => 'E',
	'FLESI' => 'B',
	'FLOPE' => 'E',
	'FLOPR' => 'E',
	'FLV' => 'V',
	'FLVC1' => 'V',
	'FLVC6' => 'V',
	'FLVCA' => 'V',
	'FLVCS' => 'V',
	'FLVGL' => 'V',
	'FLVLB' => 'V',
	'FLVSA' => 'V',
	'FLVTT' => 'V',
	'FMDV1' => 'V',
	'FMDV5' => 'V',
	'FMDVA' => 'V',
	'FMDVC' => 'V',
	'FMDVI' => 'V',
	'FMDVO' => 'V',
	'FMDVS' => 'V',
	'FMDVT' => 'V',
	'FMDVZ' => 'V',
	'FMVD' => 'V',
	'FOAMV' => 'V',
	'FOEVU' => 'E',
	'FORAU' => 'E',
	'FORFL' => 'E',
	'FORFU' => 'E',
	'FORIN' => 'E',
	'FORRU' => 'E',
	'FOSFO' => 'E',
	'FOUSP' => 'E',
	'FOWPV' => 'V',
	'FPV' => 'V',
	'FPV19' => 'V',
	'FPVL' => 'V',
	'FRAAF' => 'E',
	'FRAAL' => 'B',
	'FRAAN' => 'E',
	'FRAAR' => 'E',
	'FRACI' => 'E',
	'FRACO' => 'E',
	'FRACR' => 'E',
	'FRAER' => 'E',
	'FRAEX' => 'E',
	'FRAFR' => 'E',
	'FRANO' => 'B',
	'FRAOC' => 'E',
	'FRAPO' => 'E',
	'FRASA' => 'E',
	'FRASC' => 'B',
	'FRASE' => 'B',
	'FRASP' => 'B',
	'FRAT1' => 'B',
	'FRATH' => 'B',
	'FRATO' => 'B',
	'FRATR' => 'E',
	'FRATT' => 'B',
	'FRATU' => 'B',
	'FRAVE' => 'E',
	'FRAVI' => 'E',
	'FRECA' => 'E',
	'FREDI' => 'B',
	'FREGA' => 'E',
	'FRESP' => 'E',
	'FRETR' => 'E',
	'FRG3V' => 'V',
	'FRIAG' => 'E',
	'FRILI' => 'E',
	'FRIME' => 'E',
	'FRMCV' => 'V',
	'FROFL' => 'E',
	'FROGR' => 'E',
	'FROIN' => 'E',
	'FROPY' => 'E',
	'FRSF5' => 'V',
	'FRSFB' => 'V',
	'FRSFL' => 'V',
	'FRSFV' => 'V',
	'FRUDI' => 'E',
	'FRUPO' => 'E',
	'FRUTA' => 'E',
	'FSVGA' => 'V',
	'FSVGR' => 'V',
	'FSVHY' => 'V',
	'FSVHZ' => 'V',
	'FSVMD' => 'V',
	'FSVSM' => 'V',
	'FSVST' => 'V',
	'FUCDI' => 'E',
	'FUCSE' => 'E',
	'FUCVE' => 'E',
	'FUGRU' => 'E',
	'FUJSV' => 'V',
	'FULAM' => 'E',
	'FULAT' => 'E',
	'FULGA' => 'E',
	'FULGL' => 'E',
	'FUNCA' => 'E',
	'FUNHE' => 'E',
	'FUNHY' => 'E',
	'FUNPA' => 'E',
	'FUNPE' => 'E',
	'FUNPL' => 'E',
	'FUNPY' => 'E',
	'FURAN' => 'E',
	'FURBA' => 'E',
	'FURBE' => 'E',
	'FURBI' => 'E',
	'FURCA' => 'E',
	'FURGI' => 'E',
	'FURHO' => 'E',
	'FURLA' => 'E',
	'FURLT' => 'E',
	'FURMI' => 'E',
	'FUROU' => 'E',
	'FURPA' => 'E',
	'FURPE' => 'E',
	'FUSAC' => 'E',
	'FUSAS' => 'E',
	'FUSAU' => 'E',
	'FUSBO' => 'E',
	'FUSCE' => 'E',
	'FUSCO' => 'E',
	'FUSCU' => 'E',
	'FUSEQ' => 'E',
	'FUSFE' => 'E',
	'FUSHO' => 'E',
	'FUSLU' => 'E',
	'FUSME' => 'E',
	'FUSMI' => 'E',
	'FUSMR' => 'B',
	'FUSNN' => 'B',
	'FUSNP' => 'B',
	'FUSNU' => 'B',
	'FUSNV' => 'B',
	'FUSOX' => 'E',
	'FUSPO' => 'E',
	'FUSPS' => 'E',
	'FUSRE' => 'E',
	'FUSSC' => 'E',
	'FUSSH' => 'E',
	'FUSSI' => 'B',
	'FUSSO' => 'E',
	'FUSSP' => 'E',
	'FUSVA' => 'B',
	'FXMV' => 'V',
	'GADCA' => 'E',
	'GADMO' => 'E',
	'GADOC' => 'E',
	'GAEGA' => 'E',
	'GAEGR' => 'E',
	'GAGLU' => 'E',
	'GAGMI' => 'E',
	'GAHVB' => 'V',
	'GAHVG' => 'V',
	'GAHVH' => 'V',
	'GAHVM' => 'V',
	'GAHVN' => 'V',
	'GAHVR' => 'V',
	'GALAL' => 'E',
	'GALAP' => 'E',
	'GALAS' => 'E',
	'GALBE' => 'E',
	'GALBO' => 'E',
	'GALCA' => 'E',
	'GALCH' => 'E',
	'GALCO' => 'E',
	'GALCR' => 'E',
	'GALCU' => 'E',
	'GALDE' => 'E',
	'GALDV' => 'E',
	'GALEE' => 'E',
	'GALEL' => 'E',
	'GALEW' => 'E',
	'GALFA' => 'E',
	'GALGA' => 'E',
	'GALGB' => 'E',
	'GALGL' => 'E',
	'GALGR' => 'E',
	'GALJA' => 'E',
	'GALLA' => 'E',
	'GALLI' => 'E',
	'GALLU' => 'E',
	'GALMA' => 'E',
	'GALME' => 'E',
	'GALML' => 'E',
	'GALMO' => 'E',
	'GALMU' => 'E',
	'GALNI' => 'E',
	'GALOD' => 'E',
	'GALOW' => 'E',
	'GALPA' => 'E',
	'GALPH' => 'E',
	'GALPL' => 'E',
	'GALPR' => 'E',
	'GALPT' => 'E',
	'GALPU' => 'E',
	'GALPV' => 'E',
	'GALPY' => 'E',
	'GALQU' => 'E',
	'GALSC' => 'E',
	'GALSE' => 'E',
	'GALSO' => 'E',
	'GALSU' => 'E',
	'GALSY' => 'E',
	'GALTO' => 'E',
	'GALV' => 'V',
	'GALVA' => 'E',
	'GALVI' => 'E',
	'GAMAF' => 'E',
	'GAMHO' => 'E',
	'GAMWI' => 'E',
	'GANLU' => 'E',
	'GANMI' => 'E',
	'GANTS' => 'E',
	'GAREL' => 'E',
	'GARGL' => 'E',
	'GARLE' => 'E',
	'GARLI' => 'E',
	'GARNE' => 'E',
	'GARVA' => 'B',
	'GASAC' => 'E',
	'GASAT' => 'E',
	'GASCO' => 'E',
	'GASCY' => 'E',
	'GASMA' => 'E',
	'GAULI' => 'E',
	'GAUPR' => 'E',
	'GAVGA' => 'E',
	'GAVIM' => 'E',
	'GAVST' => 'E',
	'GAZBE' => 'E',
	'GAZCU' => 'E',
	'GAZDA' => 'E',
	'GAZDO' => 'E',
	'GAZGA' => 'E',
	'GAZGR' => 'E',
	'GAZLE' => 'E',
	'GAZRU' => 'E',
	'GAZSA' => 'E',
	'GAZSO' => 'E',
	'GAZSP' => 'E',
	'GAZSU' => 'E',
	'GAZTH' => 'E',
	'GBVB' => 'V',
	'GCMV' => 'V',
	'GECGE' => 'E',
	'GECJA' => 'E',
	'GECLA' => 'E',
	'GELLA' => 'E',
	'GELMU' => 'E',
	'GELPL' => 'E',
	'GELPU' => 'E',
	'GELSE' => 'E',
	'GELSP' => 'E',
	'GELSS' => 'E',
	'GEMPE' => 'E',
	'GENAS' => 'E',
	'GENGE' => 'E',
	'GENJO' => 'E',
	'GENLA' => 'E',
	'GENLU' => 'E',
	'GENMA' => 'E',
	'GENME' => 'E',
	'GENPA' => 'E',
	'GENSE' => 'E',
	'GENTG' => 'E',
	'GENTH' => 'E',
	'GENTI' => 'E',
	'GENTR' => 'E',
	'GEOAE' => 'E',
	'GEOAR' => 'E',
	'GEOAT' => 'E',
	'GEOBE' => 'E',
	'GEOBR' => 'E',
	'GEOBU' => 'E',
	'GEOCA' => 'E',
	'GEOCN' => 'E',
	'GEOCO' => 'E',
	'GEOCP' => 'E',
	'GEOCR' => 'E',
	'GEOCY' => 'E',
	'GEODE' => 'E',
	'GEOEL' => 'E',
	'GEOFE' => 'E',
	'GEOKA' => 'B',
	'GEOKN' => 'E',
	'GEOLU' => 'E',
	'GEOME' => 'B',
	'GEOMG' => 'B',
	'GEONI' => 'E',
	'GEOOC' => 'E',
	'GEOPA' => 'E',
	'GEOPE' => 'E',
	'GEOPI' => 'E',
	'GEORA' => 'E',
	'GEOSD' => 'E',
	'GEOSL' => 'B',
	'GEOST' => 'E',
	'GEOSU' => 'E',
	'GEOTE' => 'E',
	'GEOTH' => 'B',
	'GEOTO' => 'E',
	'GEOTR' => 'E',
	'GERCA' => 'E',
	'GERCL' => 'E',
	'GERER' => 'E',
	'GERGE' => 'E',
	'GERGR' => 'E',
	'GERHY' => 'E',
	'GERJA' => 'E',
	'GERLA' => 'E',
	'GERNI' => 'E',
	'GERPU' => 'E',
	'GERQU' => 'E',
	'GERRE' => 'E',
	'GERSP' => 'E',
	'GERVA' => 'E',
	'GETCI' => 'E',
	'GETV' => 'V',
	'GEUBO' => 'E',
	'GEUCH' => 'E',
	'GEUDE' => 'E',
	'GEUUR' => 'E',
	'GFLV' => 'V',
	'GFLVN' => 'V',
	'GGNNV' => 'V',
	'GIALA' => 'E',
	'GIAMU' => 'E',
	'GIBBA' => 'E',
	'GIBCI' => 'E',
	'GIBFU' => 'E',
	'GIBGE' => 'E',
	'GIBIN' => 'E',
	'GIBMO' => 'E',
	'GIBNY' => 'E',
	'GIBPU' => 'E',
	'GIBSA' => 'E',
	'GIBSU' => 'E',
	'GIBTH' => 'E',
	'GIBZE' => 'E',
	'GIGMA' => 'E',
	'GILMI' => 'E',
	'GILSE' => 'E',
	'GINBI' => 'E',
	'GINCI' => 'E',
	'GIRCA' => 'E',
	'GISPH' => 'E',
	'GLABO' => 'E',
	'GLABR' => 'E',
	'GLACA' => 'E',
	'GLACH' => 'E',
	'GLACO' => 'E',
	'GLACP' => 'E',
	'GLAFL' => 'E',
	'GLAGN' => 'E',
	'GLAGR' => 'E',
	'GLAGU' => 'E',
	'GLAHA' => 'E',
	'GLAHI' => 'E',
	'GLAJA' => 'E',
	'GLAMA' => 'E',
	'GLAMI' => 'E',
	'GLAMU' => 'E',
	'GLANA' => 'E',
	'GLANU' => 'E',
	'GLAPA' => 'E',
	'GLAPE' => 'E',
	'GLAPR' => 'E',
	'GLAPS' => 'E',
	'GLAPT' => 'E',
	'GLASA' => 'E',
	'GLASF' => 'E',
	'GLATE' => 'E',
	'GLATU' => 'E',
	'GLAVO' => 'E',
	'GLECO' => 'E',
	'GLEHE' => 'E',
	'GLEJA' => 'E',
	'GLETR' => 'E',
	'GLIJA' => 'E',
	'GLIVE' => 'E',
	'GLOAC' => 'E',
	'GLOAT' => 'E',
	'GLOCO' => 'E',
	'GLOIN' => 'E',
	'GLOLA' => 'E',
	'GLOLE' => 'E',
	'GLOLO' => 'E',
	'GLOMA' => 'E',
	'GLOME' => 'E',
	'GLOMN' => 'E',
	'GLOMO' => 'E',
	'GLOMR' => 'E',
	'GLOPA' => 'E',
	'GLOPY' => 'E',
	'GLORO' => 'E',
	'GLOS1' => 'B',
	'GLOSO' => 'E',
	'GLOSR' => 'E',
	'GLOSU' => 'E',
	'GLOTR' => 'E',
	'GLOVI' => 'B',
	'GLUAM' => 'E',
	'GLUOX' => 'B',
	'GLYBA' => 'E',
	'GLYDA' => 'E',
	'GLYDE' => 'E',
	'GLYDI' => 'E',
	'GLYDO' => 'E',
	'GLYEC' => 'E',
	'GLYFL' => 'E',
	'GLYGL' => 'E',
	'GLYGR' => 'E',
	'GLYSA' => 'E',
	'GLYSI' => 'E',
	'GLYSO' => 'E',
	'GLYST' => 'E',
	'GLYTA' => 'E',
	'GLYTO' => 'E',
	'GMDNV' => 'V',
	'GNEGN' => 'E',
	'GNOCH' => 'E',
	'GOBCO' => 'E',
	'GOBGI' => 'E',
	'GOBHI' => 'E',
	'GOBNI' => 'E',
	'GOMHA' => 'E',
	'GOMPU' => 'E',
	'GOMVA' => 'E',
	'GONAT' => 'E',
	'GONCL' => 'E',
	'GONGR' => 'E',
	'GONIN' => 'E',
	'GONIT' => 'E',
	'GONLI' => 'E',
	'GONNO' => 'E',
	'GONOL' => 'E',
	'GONPA' => 'E',
	'GONPE' => 'E',
	'GONPO' => 'E',
	'GONRH' => 'E',
	'GONTE' => 'E',
	'GONVI' => 'E',
	'GONVM' => 'E',
	'GOOOV' => 'E',
	'GOOPU' => 'E',
	'GOPPO' => 'E',
	'GORBE' => 'E',
	'GORGO' => 'E',
	'GORLA' => 'E',
	'GOSAR' => 'E',
	'GOSBA' => 'E',
	'GOSDA' => 'E',
	'GOSGO' => 'E',
	'GOSHI' => 'E',
	'GOSMU' => 'E',
	'GOSSC' => 'E',
	'GOSTO' => 'E',
	'GOSTU' => 'E',
	'GOUCR' => 'E',
	'GPCMV' => 'V',
	'GRAAC' => 'E',
	'GRAAG' => 'E',
	'GRABC' => 'B',
	'GRABE' => 'E',
	'GRABR' => 'E',
	'GRACC' => 'E',
	'GRACH' => 'E',
	'GRACO' => 'E',
	'GRADO' => 'E',
	'GRAEB' => 'E',
	'GRAEM' => 'E',
	'GRAGE' => 'E',
	'GRAGI' => 'E',
	'GRAGR' => 'E',
	'GRALE' => 'E',
	'GRALO' => 'E',
	'GRAMC' => 'E',
	'GRAMI' => 'E',
	'GRAMU' => 'E',
	'GRANE' => 'E',
	'GRANI' => 'E',
	'GRAOC' => 'E',
	'GRAOF' => 'E',
	'GRAPA' => 'E',
	'GRAPI' => 'E',
	'GRAPL' => 'E',
	'GRARI' => 'E',
	'GRASE' => 'E',
	'GRASI' => 'E',
	'GRASP' => 'E',
	'GRASX' => 'E',
	'GRATE' => 'E',
	'GRATI' => 'E',
	'GRATL' => 'E',
	'GRAVE' => 'E',
	'GRAVI' => 'E',
	'GRENI' => 'E',
	'GREOB' => 'E',
	'GREPO' => 'E',
	'GRERA' => 'E',
	'GRERE' => 'E',
	'GRIER' => 'E',
	'GRIFR' => 'E',
	'GRIHY' => 'E',
	'GRIJA' => 'E',
	'GRIMO' => 'E',
	'GRIPA' => 'E',
	'GRISI' => 'E',
	'GRISQ' => 'E',
	'GROPO' => 'E',
	'GRUAM' => 'E',
	'GRUAN' => 'E',
	'GRUCA' => 'E',
	'GRUJA' => 'E',
	'GRULE' => 'E',
	'GRUMO' => 'E',
	'GRUNI' => 'E',
	'GRUPA' => 'E',
	'GRURU' => 'E',
	'GRUVI' => 'E',
	'GRYBI' => 'E',
	'GRYOR' => 'E',
	'GRYPE' => 'E',
	'GSMV' => 'V',
	'GUAAE' => 'E',
	'GUADU' => 'E',
	'GUAGU' => 'E',
	'GUALA' => 'E',
	'GUATU' => 'E',
	'GUIAB' => 'E',
	'GUIFL' => 'E',
	'GUIGU' => 'E',
	'GUITH' => 'E',
	'GULGU' => 'E',
	'GUNCH' => 'E',
	'GUTPU' => 'E',
	'GVAO' => 'V',
	'GVAS' => 'V',
	'GVCF' => 'V',
	'GVCL' => 'V',
	'GVCP' => 'V',
	'GVHA' => 'V',
	'GVHB' => 'V',
	'GVLO' => 'V',
	'GVPB' => 'V',
	'GVPU' => 'V',
	'GVTN' => 'V',
	'GVXN' => 'V',
	'GYMAC' => 'E',
	'GYMCA' => 'E',
	'GYMCH' => 'E',
	'GYMCY' => 'E',
	'GYMDI' => 'E',
	'GYMFL' => 'E',
	'GYMGY' => 'E',
	'GYMKI' => 'E',
	'GYMLE' => 'E',
	'GYMME' => 'E',
	'GYMMI' => 'E',
	'GYMRO' => 'E',
	'GYMSI' => 'E',
	'GYMST' => 'E',
	'GYMSY' => 'E',
	'GYMTI' => 'E',
	'GYMUN' => 'E',
	'GYNPE' => 'E',
	'GYPBE' => 'E',
	'GYPCO' => 'E',
	'GYPRU' => 'E',
	'GYRIN' => 'E',
	'GYRSA' => 'E',
	'GYRTH' => 'E',
	'HABLO' => 'E',
	'HABRE' => 'E',
	'HADAR' => 'E',
	'HADAZ' => 'E',
	'HADGE' => 'E',
	'HADIN' => 'E',
	'HADSP' => 'E',
	'HADVE' => 'E',
	'HAEAE' => 'B',
	'HAEAP' => 'B',
	'HAECL' => 'E',
	'HAECO' => 'E',
	'HAEDU' => 'B',
	'HAEGA' => 'B',
	'HAEGH' => 'E',
	'HAEHA' => 'B',
	'HAEI8' => 'B',
	'HAEIE' => 'E',
	'HAEIN' => 'B',
	'HAEIR' => 'E',
	'HAEKO' => 'E',
	'HAELO' => 'E',
	'HAEMA' => 'E',
	'HAEMJ' => 'E',
	'HAEOF' => 'E',
	'HAEOS' => 'E',
	'HAEPA' => 'B',
	'HAEPH' => 'B',
	'HAEPL' => 'E',
	'HAEPR' => 'B',
	'HAEPT' => 'E',
	'HAEPU' => 'E',
	'HAEPV' => 'V',
	'HAES1' => 'B',
	'HAESO' => 'B',
	'HAESY' => 'E',
	'HAFAL' => 'B',
	'HAHCH' => 'B',
	'HAL17' => 'A',
	'HALAL' => 'E',
	'HALAR' => 'A',
	'HALAS' => 'A',
	'HALAU' => 'E',
	'HALBI' => 'E',
	'HALBO' => 'E',
	'HALCA' => 'E',
	'HALCL' => 'E',
	'HALCO' => 'E',
	'HALCR' => 'E',
	'HALDD' => 'E',
	'HALDI' => 'E',
	'HALDO' => 'A',
	'HALDP' => 'E',
	'HALDV' => 'E',
	'HALEL' => 'B',
	'HALER' => 'B',
	'HALEU' => 'B',
	'HALFU' => 'E',
	'HALGA' => 'E',
	'HALGN' => 'E',
	'HALGR' => 'E',
	'HALHI' => 'A',
	'HALHM' => 'A',
	'HALHP' => 'A',
	'HALHS' => 'A',
	'HALIN' => 'E',
	'HALJA' => 'E',
	'HALJP' => 'A',
	'HALKA' => 'E',
	'HALLA' => 'E',
	'HALLE' => 'E',
	'HALLI' => 'E',
	'HALLU' => 'E',
	'HALMA' => 'A',
	'HALMC' => 'E',
	'HALME' => 'A',
	'HALMI' => 'E',
	'HALMO' => 'A',
	'HALMR' => 'B',
	'HALOC' => 'E',
	'HALOK' => 'E',
	'HALPA' => 'E',
	'HALPR' => 'B',
	'HALRB' => 'E',
	'HALRE' => 'E',
	'HALRI' => 'E',
	'HALRO' => 'E',
	'HALRU' => 'E',
	'HALS1' => 'A',
	'HALS2' => 'A',
	'HALS4' => 'A',
	'HALS8' => 'A',
	'HALSA' => 'A',
	'HALSD' => 'A',
	'HALSN' => 'A',
	'HALSO' => 'E',
	'HALSP' => 'A',
	'HALSQ' => 'A',
	'HALSR' => 'A',
	'HALSS' => 'A',
	'HALTR' => 'E',
	'HALVA' => 'A',
	'HALVC' => 'E',
	'HALVO' => 'A',
	'HALVR' => 'E',
	'HALWA' => 'E',
	'HALWD' => 'B',
	'HAMAP' => 'E',
	'HAMHE' => 'E',
	'HAMJA' => 'E',
	'HAMMO' => 'E',
	'HAMVI' => 'E',
	'HANAN' => 'E',
	'HANFA' => 'E',
	'HANTB' => 'V',
	'HANTH' => 'V',
	'HANTL' => 'V',
	'HANTV' => 'V',
	'HANUV' => 'E',
	'HAPAU' => 'E',
	'HAPBU' => 'E',
	'HAPFI' => 'E',
	'HAPGR' => 'E',
	'HAPHO' => 'E',
	'HAPMA' => 'E',
	'HAPNU' => 'E',
	'HAPSI' => 'E',
	'HAPXE' => 'E',
	'HARAF' => 'E',
	'HARAN' => 'E',
	'HARAR' => 'E',
	'HARAX' => 'E',
	'HARDI' => 'E',
	'HARGR' => 'E',
	'HARMO' => 'E',
	'HARV' => 'V',
	'HAV18' => 'V',
	'HAV24' => 'V',
	'HAV43' => 'V',
	'HAVCR' => 'V',
	'HAVGA' => 'V',
	'HAVHM' => 'V',
	'HAVLA' => 'V',
	'HAVLC' => 'V',
	'HAVMB' => 'V',
	'HAZVJ' => 'V',
	'HBV' => 'V',
	'HBVA4' => 'V',
	'HBVAD' => 'V',
	'HBVAR' => 'V',
	'HBVAW' => 'V',
	'HBVAY' => 'V',
	'HBVD4' => 'V',
	'HBVDM' => 'V',
	'HBVDN' => 'V',
	'HBVDR' => 'V',
	'HBVIA' => 'V',
	'HBVIL' => 'V',
	'HBVW2' => 'V',
	'HBVW9' => 'V',
	'HBVWI' => 'V',
	'HBVWJ' => 'V',
	'HBVWO' => 'V',
	'HBVWP' => 'V',
	'HBVWS' => 'V',
	'HBVYW' => 'V',
	'HCMV' => 'V',
	'HCMV1' => 'V',
	'HCMV2' => 'V',
	'HCMV3' => 'V',
	'HCMV4' => 'V',
	'HCMV5' => 'V',
	'HCMV6' => 'V',
	'HCMV7' => 'V',
	'HCMV8' => 'V',
	'HCMVA' => 'V',
	'HCMVE' => 'V',
	'HCMVM' => 'V',
	'HCMVO' => 'V',
	'HCMVP' => 'V',
	'HCMVT' => 'V',
	'HCV1' => 'V',
	'HCV6A' => 'V',
	'HCVBB' => 'V',
	'HCVBK' => 'V',
	'HCVCO' => 'V',
	'HCVE0' => 'V',
	'HCVE1' => 'V',
	'HCVED' => 'V',
	'HCVEU' => 'V',
	'HCVEV' => 'V',
	'HCVGL' => 'V',
	'HCVH' => 'V',
	'HCVH4' => 'V',
	'HCVH7' => 'V',
	'HCVH8' => 'V',
	'HCVH9' => 'V',
	'HCVHK' => 'V',
	'HCVIN' => 'V',
	'HCVJ2' => 'V',
	'HCVJ5' => 'V',
	'HCVJ6' => 'V',
	'HCVJ7' => 'V',
	'HCVJ8' => 'V',
	'HCVJA' => 'V',
	'HCVJF' => 'V',
	'HCVJK' => 'V',
	'HCVJL' => 'V',
	'HCVJP' => 'V',
	'HCVJT' => 'V',
	'HCVK3' => 'V',
	'HCVNZ' => 'V',
	'HCVSA' => 'V',
	'HCVT5' => 'V',
	'HCVTH' => 'V',
	'HCVTR' => 'V',
	'HCVTW' => 'V',
	'HCVVA' => 'V',
	'HCVVN' => 'V',
	'HCVVO' => 'V',
	'HCVVP' => 'V',
	'HDV' => 'V',
	'HDV83' => 'V',
	'HDVAM' => 'V',
	'HDVD3' => 'V',
	'HDVIT' => 'V',
	'HDVL1' => 'V',
	'HDVM1' => 'V',
	'HDVM2' => 'V',
	'HDVNA' => 'V',
	'HDVP1' => 'V',
	'HDVS1' => 'V',
	'HDVS2' => 'V',
	'HDVTW' => 'V',
	'HDVU2' => 'V',
	'HDVV1' => 'V',
	'HDVV2' => 'V',
	'HDVV3' => 'V',
	'HDVWO' => 'V',
	'HE701' => 'V',
	'HE71B' => 'V',
	'HE71M' => 'V',
	'HEAMA' => 'E',
	'HEBCY' => 'E',
	'HEBGL' => 'E',
	'HEDAL' => 'E',
	'HEDGA' => 'E',
	'HEDHE' => 'E',
	'HELAC' => 'B',
	'HELAG' => 'E',
	'HELAL' => 'E',
	'HELAM' => 'E',
	'HELAN' => 'E',
	'HELAR' => 'E',
	'HELAS' => 'E',
	'HELAU' => 'E',
	'HELBA' => 'E',
	'HELBG' => 'E',
	'HELBI' => 'B',
	'HELBU' => 'E',
	'HELCH' => 'E',
	'HELCL' => 'B',
	'HELDI' => 'E',
	'HELEL' => 'E',
	'HELER' => 'E',
	'HELFE' => 'B',
	'HELFU' => 'E',
	'HELGE' => 'B',
	'HELGL' => 'E',
	'HELHA' => 'E',
	'HELHC' => 'E',
	'HELHE' => 'B',
	'HELHO' => 'E',
	'HELHP' => 'B',
	'HELHR' => 'E',
	'HELLU' => 'E',
	'HELMO' => 'B',
	'HELMU' => 'B',
	'HELNU' => 'E',
	'HELPD' => 'E',
	'HELPE' => 'E',
	'HELPH' => 'B',
	'HELPJ' => 'B',
	'HELPN' => 'E',
	'HELPO' => 'E',
	'HELPU' => 'E',
	'HELPY' => 'B',
	'HELRO' => 'E',
	'HELRS' => 'E',
	'HELRU' => 'E',
	'HELSA' => 'E',
	'HELSJ' => 'E',
	'HELSU' => 'E',
	'HELTB' => 'E',
	'HELTI' => 'E',
	'HELTR' => 'E',
	'HELTU' => 'E',
	'HELUN' => 'E',
	'HELVE' => 'E',
	'HELVI' => 'E',
	'HELVO' => 'E',
	'HELVS' => 'V',
	'HELZE' => 'E',
	'HEMAM' => 'E',
	'HEMAU' => 'E',
	'HEMDE' => 'E',
	'HEMFC' => 'E',
	'HEMFR' => 'E',
	'HEMFU' => 'E',
	'HEMHA' => 'E',
	'HEMHY' => 'E',
	'HEMJA' => 'E',
	'HEMJE' => 'E',
	'HEMLI' => 'E',
	'HEMMA' => 'E',
	'HEMMU' => 'E',
	'HEMPO' => 'E',
	'HEMPU' => 'E',
	'HEMSA' => 'E',
	'HEMSP' => 'E',
	'HEMTH' => 'E',
	'HEMZO' => 'E',
	'HENAC' => 'E',
	'HENCH' => 'E',
	'HENDV' => 'V',
	'HENPL' => 'E',
	'HENVA' => 'E',
	'HEPNO' => 'E',
	'HERAU' => 'B',
	'HERCA' => 'E',
	'HERED' => 'E',
	'HERFE' => 'E',
	'HERHE' => 'E',
	'HERIC' => 'E',
	'HERJA' => 'E',
	'HERLA' => 'E',
	'HERMA' => 'E',
	'HERME' => 'E',
	'HERMO' => 'E',
	'HERMU' => 'E',
	'HERNA' => 'E',
	'HERSE' => 'B',
	'HERYA' => 'E',
	'HESDE' => 'E',
	'HETAL' => 'E',
	'HETAM' => 'E',
	'HETAN' => 'E',
	'HETAO' => 'E',
	'HETAR' => 'E',
	'HETBR' => 'E',
	'HETCA' => 'E',
	'HETCI' => 'E',
	'HETFO' => 'E',
	'HETFR' => 'E',
	'HETFU' => 'E',
	'HETGA' => 'E',
	'HETGL' => 'E',
	'HETGU' => 'E',
	'HETMA' => 'E',
	'HETMC' => 'E',
	'HETNI' => 'E',
	'HETPI' => 'E',
	'HETPL' => 'E',
	'HETPO' => 'E',
	'HETPY' => 'E',
	'HETRO' => 'E',
	'HETSC' => 'E',
	'HETSI' => 'E',
	'HETSP' => 'E',
	'HETTR' => 'E',
	'HETVE' => 'E',
	'HEUMI' => 'E',
	'HEVBR' => 'E',
	'HEVBU' => 'V',
	'HEVME' => 'V',
	'HEVMY' => 'V',
	'HEVPA' => 'V',
	'HEVRH' => 'V',
	'HEXLI' => 'E',
	'HHBV' => 'V',
	'HHV1' => 'V',
	'HHV11' => 'V',
	'HHV14' => 'V',
	'HHV19' => 'V',
	'HHV1A' => 'V',
	'HHV1C' => 'V',
	'HHV1D' => 'V',
	'HHV1E' => 'V',
	'HHV1F' => 'V',
	'HHV1H' => 'V',
	'HHV1K' => 'V',
	'HHV1M' => 'V',
	'HHV1N' => 'V',
	'HHV1P' => 'V',
	'HHV1R' => 'V',
	'HHV1S' => 'V',
	'HHV2' => 'V',
	'HHV21' => 'V',
	'HHV23' => 'V',
	'HHV2B' => 'V',
	'HHV2G' => 'V',
	'HHV2H' => 'V',
	'HHV3' => 'V',
	'HHV6G' => 'V',
	'HHV6U' => 'V',
	'HHV6Z' => 'V',
	'HHV7J' => 'V',
	'HHV7M' => 'V',
	'HHV7R' => 'V',
	'HHV8' => 'V',
	'HIBSY' => 'E',
	'HIEPI' => 'E',
	'HIMCH' => 'E',
	'HIMGE' => 'E',
	'HIMHI' => 'E',
	'HIMME' => 'E',
	'HIMSI' => 'E',
	'HIPAB' => 'E',
	'HIPAL' => 'E',
	'HIPAM' => 'E',
	'HIPBA' => 'E',
	'HIPBR' => 'E',
	'HIPCA' => 'E',
	'HIPCE' => 'E',
	'HIPCM' => 'E',
	'HIPCN' => 'E',
	'HIPCO' => 'E',
	'HIPCP' => 'E',
	'HIPCR' => 'E',
	'HIPDI' => 'E',
	'HIPEM' => 'E',
	'HIPEQ' => 'E',
	'HIPER' => 'E',
	'HIPGU' => 'E',
	'HIPHI' => 'E',
	'HIPHP' => 'E',
	'HIPHS' => 'E',
	'HIPKU' => 'E',
	'HIPMO' => 'E',
	'HIPNI' => 'E',
	'HIPPA' => 'E',
	'HIPRI' => 'E',
	'HIPRU' => 'E',
	'HIPST' => 'E',
	'HIPSU' => 'E',
	'HIPTE' => 'E',
	'HIPVU' => 'E',
	'HIRIN' => 'E',
	'HIRMA' => 'E',
	'HIRME' => 'E',
	'HIRNI' => 'E',
	'HIRPI' => 'E',
	'HIRRU' => 'E',
	'HIRTH' => 'E',
	'HISCA' => 'E',
	'HISHI' => 'E',
	'HOFFA' => 'E',
	'HOGCA' => 'E',
	'HOLBR' => 'E',
	'HOLCU' => 'E',
	'HOLDI' => 'E',
	'HOLLA' => 'E',
	'HOLMA' => 'E',
	'HOLOB' => 'B',
	'HOLRU' => 'E',
	'HOLSA' => 'E',
	'HOLTU' => 'E',
	'HOMAM' => 'E',
	'HOMCO' => 'E',
	'HOMGA' => 'E',
	'HOMLA' => 'E',
	'HOMNE' => 'E',
	'HOOLU' => 'E',
	'HOPLI' => 'E',
	'HOPSP' => 'E',
	'HOPST' => 'E',
	'HOPTI' => 'E',
	'HORBU' => 'E',
	'HORCH' => 'E',
	'HORCU' => 'E',
	'HORJU' => 'E',
	'HORLE' => 'E',
	'HORMA' => 'E',
	'HORML' => 'E',
	'HORPY' => 'E',
	'HORRE' => 'E',
	'HORSA' => 'E',
	'HORSE' => 'E',
	'HORSP' => 'E',
	'HORVD' => 'E',
	'HORVU' => 'E',
	'HORWE' => 'E',
	'HOTPA' => 'E',
	'HOUBE' => 'E',
	'HOUCO' => 'E',
	'HPAVS' => 'V',
	'HPAVT' => 'V',
	'HPBDB' => 'V',
	'HPBDC' => 'V',
	'HPBDU' => 'V',
	'HPBDW' => 'V',
	'HPBGS' => 'V',
	'HPV' => 'V',
	'HPV03' => 'V',
	'HPV04' => 'V',
	'HPV05' => 'V',
	'HPV07' => 'V',
	'HPV08' => 'V',
	'HPV09' => 'V',
	'HPV10' => 'V',
	'HPV11' => 'V',
	'HPV12' => 'V',
	'HPV13' => 'V',
	'HPV14' => 'V',
	'HPV15' => 'V',
	'HPV16' => 'V',
	'HPV17' => 'V',
	'HPV18' => 'V',
	'HPV19' => 'V',
	'HPV1A' => 'V',
	'HPV20' => 'V',
	'HPV21' => 'V',
	'HPV22' => 'V',
	'HPV23' => 'V',
	'HPV24' => 'V',
	'HPV25' => 'V',
	'HPV26' => 'V',
	'HPV27' => 'V',
	'HPV28' => 'V',
	'HPV29' => 'V',
	'HPV2A' => 'V',
	'HPV30' => 'V',
	'HPV31' => 'V',
	'HPV32' => 'V',
	'HPV33' => 'V',
	'HPV34' => 'V',
	'HPV35' => 'V',
	'HPV36' => 'V',
	'HPV37' => 'V',
	'HPV38' => 'V',
	'HPV39' => 'V',
	'HPV40' => 'V',
	'HPV41' => 'V',
	'HPV42' => 'V',
	'HPV43' => 'V',
	'HPV44' => 'V',
	'HPV45' => 'V',
	'HPV47' => 'V',
	'HPV48' => 'V',
	'HPV49' => 'V',
	'HPV50' => 'V',
	'HPV51' => 'V',
	'HPV52' => 'V',
	'HPV53' => 'V',
	'HPV54' => 'V',
	'HPV55' => 'V',
	'HPV56' => 'V',
	'HPV57' => 'V',
	'HPV58' => 'V',
	'HPV59' => 'V',
	'HPV5B' => 'V',
	'HPV60' => 'V',
	'HPV61' => 'V',
	'HPV62' => 'V',
	'HPV63' => 'V',
	'HPV64' => 'V',
	'HPV65' => 'V',
	'HPV66' => 'V',
	'HPV67' => 'V',
	'HPV68' => 'V',
	'HPV69' => 'V',
	'HPV6A' => 'V',
	'HPV6B' => 'V',
	'HPV6C' => 'V',
	'HPV70' => 'V',
	'HPV72' => 'V',
	'HPV73' => 'V',
	'HPV82' => 'V',
	'HPV94' => 'V',
	'HPVCO' => 'V',
	'HPVID' => 'V',
	'HPVKS' => 'V',
	'HPVME' => 'V',
	'HPVR7' => 'V',
	'HPVTX' => 'V',
	'HPVUT' => 'V',
	'HRSV' => 'V',
	'HRSV1' => 'V',
	'HRSV2' => 'V',
	'HRSV3' => 'V',
	'HRSV4' => 'V',
	'HRSV5' => 'V',
	'HRSV6' => 'V',
	'HRSV7' => 'V',
	'HRSV8' => 'V',
	'HRSVA' => 'V',
	'HRSVB' => 'V',
	'HRSVL' => 'V',
	'HRSVR' => 'V',
	'HRV14' => 'V',
	'HRV16' => 'V',
	'HRV1A' => 'V',
	'HRV1B' => 'V',
	'HRV2' => 'V',
	'HRV23' => 'V',
	'HRV3' => 'V',
	'HRV89' => 'V',
	'HSV2S' => 'V',
	'HSVA1' => 'V',
	'HSVAB' => 'V',
	'HSVAT' => 'V',
	'HSVBM' => 'V',
	'HTL1A' => 'V',
	'HTL1C' => 'V',
	'HTL1F' => 'V',
	'HTL1L' => 'V',
	'HTL1M' => 'V',
	'HTL1N' => 'V',
	'HTL32' => 'V',
	'HTLPY' => 'V',
	'HTLV2' => 'V',
	'HTLV3' => 'V',
	'HULAL' => 'E',
	'HUMAN' => 'E',
	'HUMBA' => 'E',
	'HUMGT' => 'E',
	'HUMIN' => 'E',
	'HUMJA' => 'E',
	'HUMLT' => 'E',
	'HUMLU' => 'E',
	'HUPLU' => 'E',
	'HUPSE' => 'E',
	'HUPSQ' => 'E',
	'HUTV' => 'V',
	'HV112' => 'V',
	'HV190' => 'V',
	'HV192' => 'V',
	'HV193' => 'V',
	'HV196' => 'V',
	'HV197' => 'V',
	'HV19N' => 'V',
	'HV1A2' => 'V',
	'HV1AN' => 'V',
	'HV1B1' => 'V',
	'HV1B5' => 'V',
	'HV1B8' => 'V',
	'HV1B9' => 'V',
	'HV1BN' => 'V',
	'HV1BR' => 'V',
	'HV1C4' => 'V',
	'HV1EL' => 'V',
	'HV1ET' => 'V',
	'HV1H2' => 'V',
	'HV1H3' => 'V',
	'HV1J3' => 'V',
	'HV1JR' => 'V',
	'HV1KB' => 'V',
	'HV1LA' => 'V',
	'HV1LW' => 'V',
	'HV1M2' => 'V',
	'HV1MA' => 'V',
	'HV1MF' => 'V',
	'HV1MN' => 'V',
	'HV1MP' => 'V',
	'HV1MV' => 'V',
	'HV1N5' => 'V',
	'HV1NA' => 'V',
	'HV1ND' => 'V',
	'HV1OY' => 'V',
	'HV1PV' => 'V',
	'HV1RH' => 'V',
	'HV1S1' => 'V',
	'HV1S2' => 'V',
	'HV1S3' => 'V',
	'HV1S9' => 'V',
	'HV1SC' => 'V',
	'HV1SE' => 'V',
	'HV1U4' => 'V',
	'HV1V9' => 'V',
	'HV1VI' => 'V',
	'HV1W1' => 'V',
	'HV1W2' => 'V',
	'HV1Y2' => 'V',
	'HV1YB' => 'V',
	'HV1YF' => 'V',
	'HV1Z2' => 'V',
	'HV1Z3' => 'V',
	'HV1Z6' => 'V',
	'HV1Z8' => 'V',
	'HV1ZH' => 'V',
	'HV2BE' => 'V',
	'HV2CA' => 'V',
	'HV2D1' => 'V',
	'HV2D2' => 'V',
	'HV2EH' => 'V',
	'HV2G1' => 'V',
	'HV2KR' => 'V',
	'HV2NZ' => 'V',
	'HV2RO' => 'V',
	'HV2S2' => 'V',
	'HV2SB' => 'V',
	'HV2ST' => 'V',
	'HV2UC' => 'V',
	'HYACE' => 'E',
	'HYACU' => 'E',
	'HYAHI' => 'E',
	'HYAHY' => 'E',
	'HYANO' => 'E',
	'HYAOR' => 'E',
	'HYBBI' => 'E',
	'HYBFE' => 'E',
	'HYBFL' => 'E',
	'HYBPA' => 'E',
	'HYBUN' => 'E',
	'HYDAF' => 'E',
	'HYDAR' => 'E',
	'HYDAT' => 'E',
	'HYDCA' => 'E',
	'HYDCH' => 'E',
	'HYDCO' => 'E',
	'HYDCY' => 'E',
	'HYDEC' => 'E',
	'HYDFO' => 'E',
	'HYDGI' => 'E',
	'HYDHY' => 'E',
	'HYDIN' => 'E',
	'HYDLA' => 'E',
	'HYDLE' => 'E',
	'HYDMA' => 'E',
	'HYDMC' => 'E',
	'HYDMO' => 'E',
	'HYDMR' => 'B',
	'HYDOL' => 'E',
	'HYDOR' => 'E',
	'HYDPE' => 'E',
	'HYDPS' => 'B',
	'HYDQU' => 'E',
	'HYDRE' => 'E',
	'HYDSE' => 'E',
	'HYDSY' => 'E',
	'HYDTH' => 'B',
	'HYDVE' => 'E',
	'HYDVI' => 'E',
	'HYDVR' => 'E',
	'HYLAB' => 'E',
	'HYLAG' => 'E',
	'HYLAL' => 'E',
	'HYLAR' => 'E',
	'HYLBE' => 'E',
	'HYLBI' => 'E',
	'HYLCH' => 'E',
	'HYLCO' => 'E',
	'HYLCR' => 'E',
	'HYLEB' => 'E',
	'HYLFI' => 'E',
	'HYLFU' => 'E',
	'HYLHY' => 'E',
	'HYLJA' => 'E',
	'HYLKL' => 'E',
	'HYLLA' => 'E',
	'HYLLB' => 'E',
	'HYLLE' => 'E',
	'HYLLI' => 'E',
	'HYLLM' => 'E',
	'HYLLP' => 'E',
	'HYLLU' => 'E',
	'HYLMA' => 'E',
	'HYLME' => 'E',
	'HYLML' => 'E',
	'HYLMO' => 'E',
	'HYLMU' => 'E',
	'HYLNI' => 'E',
	'HYLPA' => 'E',
	'HYLPH' => 'E',
	'HYLPI' => 'E',
	'HYLPR' => 'E',
	'HYLPU' => 'E',
	'HYLSA' => 'E',
	'HYLSP' => 'E',
	'HYLSY' => 'E',
	'HYLUN' => 'E',
	'HYMCA' => 'E',
	'HYMDI' => 'E',
	'HYMFF' => 'E',
	'HYMLA' => 'E',
	'HYMLE' => 'E',
	'HYMLI' => 'E',
	'HYMNA' => 'E',
	'HYMPE' => 'E',
	'HYMSA' => 'E',
	'HYMTU' => 'E',
	'HYMWR' => 'E',
	'HYNLE' => 'E',
	'HYNRE' => 'E',
	'HYOLA' => 'E',
	'HYOMU' => 'E',
	'HYONI' => 'E',
	'HYPAL' => 'E',
	'HYPAM' => 'E',
	'HYPAN' => 'E',
	'HYPAP' => 'E',
	'HYPAR' => 'E',
	'HYPBA' => 'E',
	'HYPBL' => 'E',
	'HYPBO' => 'E',
	'HYPCE' => 'E',
	'HYPCM' => 'E',
	'HYPCO' => 'E',
	'HYPCP' => 'E',
	'HYPCU' => 'E',
	'HYPDI' => 'E',
	'HYPDL' => 'E',
	'HYPEL' => 'E',
	'HYPFI' => 'E',
	'HYPHO' => 'E',
	'HYPHY' => 'E',
	'HYPLA' => 'E',
	'HYPLI' => 'E',
	'HYPMC' => 'E',
	'HYPME' => 'B',
	'HYPMO' => 'E',
	'HYPMS' => 'E',
	'HYPMU' => 'E',
	'HYPNA' => 'B',
	'HYPNO' => 'E',
	'HYPOR' => 'E',
	'HYPPE' => 'E',
	'HYPSA' => 'E',
	'HYPSC' => 'E',
	'HYPSP' => 'E',
	'HYPSU' => 'E',
	'HYPSX' => 'B',
	'HYPTE' => 'E',
	'HYPTO' => 'E',
	'HYSAF' => 'E',
	'HYSBR' => 'E',
	'HYSCR' => 'E',
	'HYSGI' => 'E',
	'HYSOF' => 'E',
	'IAAIC' => 'V',
	'IAALA' => 'V',
	'IAANA' => 'V',
	'IAANN' => 'V',
	'IAB37' => 'V',
	'IAB39' => 'V',
	'IAB52' => 'V',
	'IAB53' => 'V',
	'IABAN' => 'V',
	'IABDA' => 'V',
	'IABEI' => 'V',
	'IABER' => 'V',
	'IABH3' => 'V',
	'IABLU' => 'V',
	'IABRA' => 'V',
	'IABUD' => 'V',
	'IACAL' => 'V',
	'IACAM' => 'V',
	'IACAN' => 'V',
	'IACAO' => 'V',
	'IACHI' => 'V',
	'IACKA' => 'V',
	'IACKB' => 'V',
	'IACKG' => 'V',
	'IACKH' => 'V',
	'IACKJ' => 'V',
	'IACKP' => 'V',
	'IACKQ' => 'V',
	'IACKR' => 'V',
	'IACKS' => 'V',
	'IACKV' => 'V',
	'IADA1' => 'V',
	'IADA2' => 'V',
	'IADA3' => 'V',
	'IADA4' => 'V',
	'IADAU' => 'V',
	'IADBA' => 'V',
	'IADBE' => 'V',
	'IADBU' => 'V',
	'IADCH' => 'V',
	'IADCZ' => 'V',
	'IADE1' => 'V',
	'IADE2' => 'V',
	'IADGE' => 'V',
	'IADH1' => 'V',
	'IADH2' => 'V',
	'IADH3' => 'V',
	'IADH4' => 'V',
	'IADH5' => 'V',
	'IADH6' => 'V',
	'IADH7' => 'V',
	'IADHK' => 'V',
	'IADHL' => 'V',
	'IADHM' => 'V',
	'IADIR' => 'V',
	'IADM1' => 'V',
	'IADM2' => 'V',
	'IADMA' => 'V',
	'IADNY' => 'V',
	'IADNZ' => 'V',
	'IADPE' => 'V',
	'IADS3' => 'V',
	'IADU1' => 'V',
	'IADU2' => 'V',
	'IADU3' => 'V',
	'IADUN' => 'V',
	'IAEN5' => 'V',
	'IAEN6' => 'V',
	'IAEN7' => 'V',
	'IAEN8' => 'V',
	'IAFOM' => 'V',
	'IAFOW' => 'V',
	'IAFPD' => 'V',
	'IAFPR' => 'V',
	'IAFPW' => 'V',
	'IAGD7' => 'V',
	'IAGD8' => 'V',
	'IAGD9' => 'V',
	'IAGFN' => 'V',
	'IAGGD' => 'V',
	'IAGHK' => 'V',
	'IAGRE' => 'V',
	'IAGU1' => 'V',
	'IAGU2' => 'V',
	'IAGU3' => 'V',
	'IAGU4' => 'V',
	'IAGUA' => 'V',
	'IAGUM' => 'V',
	'IAGUN' => 'V',
	'IAHA1' => 'V',
	'IAHAL' => 'V',
	'IAHAR' => 'V',
	'IAHC6' => 'V',
	'IAHC7' => 'V',
	'IAHCD' => 'V',
	'IAHCO' => 'V',
	'IAHDE' => 'V',
	'IAHFO' => 'V',
	'IAHGD' => 'V',
	'IAHIC' => 'V',
	'IAHJI' => 'V',
	'IAHK1' => 'V',
	'IAHK6' => 'V',
	'IAHK7' => 'V',
	'IAHLE' => 'V',
	'IAHLO' => 'V',
	'IAHMI' => 'V',
	'IAHNM' => 'V',
	'IAHNN' => 'V',
	'IAHNO' => 'V',
	'IAHO1' => 'V',
	'IAHO2' => 'V',
	'IAHO3' => 'V',
	'IAHO4' => 'V',
	'IAHPR' => 'V',
	'IAHRO' => 'V',
	'IAHSA' => 'V',
	'IAHSO' => 'V',
	'IAHSP' => 'V',
	'IAHSU' => 'V',
	'IAHSW' => 'V',
	'IAHTE' => 'V',
	'IAHTO' => 'V',
	'IAHUR' => 'V',
	'IAIND' => 'V',
	'IAJAP' => 'V',
	'IAKIE' => 'V',
	'IAKIT' => 'V',
	'IAKOR' => 'V',
	'IALAC' => 'V',
	'IALE1' => 'V',
	'IALE2' => 'V',
	'IALE3' => 'V',
	'IALEN' => 'V',
	'IALOY' => 'V',
	'IAMA6' => 'V',
	'IAMA7' => 'V',
	'IAMA8' => 'V',
	'IAMAA' => 'V',
	'IAMAB' => 'V',
	'IAMAE' => 'V',
	'IAMAN' => 'V',
	'IAMAO' => 'V',
	'IAMAP' => 'V',
	'IAMAY' => 'V',
	'IAME1' => 'V',
	'IAME2' => 'V',
	'IAME3' => 'V',
	'IAME4' => 'V',
	'IAME5' => 'V',
	'IAME6' => 'V',
	'IAME8' => 'V',
	'IAMEA' => 'V',
	'IAMEB' => 'V',
	'IAMEC' => 'V',
	'IAMED' => 'V',
	'IAMEE' => 'V',
	'IAMEF' => 'V',
	'IAMEG' => 'V',
	'IAMIN' => 'V',
	'IAMON' => 'V',
	'IAMYN' => 'V',
	'IANEJ' => 'V',
	'IANII' => 'V',
	'IANT6' => 'V',
	'IAOHI' => 'V',
	'IAPAR' => 'V',
	'IAPI0' => 'V',
	'IAPI1' => 'V',
	'IAPI2' => 'V',
	'IAPI3' => 'V',
	'IAPOC' => 'V',
	'IAPP2' => 'V',
	'IAPUE' => 'V',
	'IAQIT' => 'V',
	'IAQU7' => 'V',
	'IARI5' => 'V',
	'IARUD' => 'V',
	'IARUE' => 'V',
	'IAS06' => 'V',
	'IAS11' => 'V',
	'IAS16' => 'V',
	'IAS31' => 'V',
	'IASE0' => 'V',
	'IASE2' => 'V',
	'IASH2' => 'V',
	'IASH5' => 'V',
	'IASIN' => 'V',
	'IASTA' => 'V',
	'IATAI' => 'V',
	'IATEI' => 'V',
	'IATKB' => 'V',
	'IATKC' => 'V',
	'IATKI' => 'V',
	'IATKL' => 'V',
	'IATKM' => 'V',
	'IATKN' => 'V',
	'IATKO' => 'V',
	'IATKP' => 'V',
	'IATKR' => 'V',
	'IATKW' => 'V',
	'IATOK' => 'V',
	'IATRA' => 'V',
	'IATRS' => 'V',
	'IATRT' => 'V',
	'IATX6' => 'V',
	'IATX7' => 'V',
	'IAUDO' => 'V',
	'IAUSS' => 'V',
	'IAVI6' => 'V',
	'IAVI7' => 'V',
	'IAWA1' => 'V',
	'IAWHM' => 'V',
	'IAWHN' => 'V',
	'IAWHP' => 'V',
	'IAWIL' => 'V',
	'IAWIS' => 'V',
	'IAX31' => 'V',
	'IAXIA' => 'V',
	'IAZ29' => 'V',
	'IAZ41' => 'V',
	'IAZCA' => 'V',
	'IAZCO' => 'V',
	'IAZDA' => 'V',
	'IAZGE' => 'V',
	'IAZH0' => 'V',
	'IAZH1' => 'V',
	'IAZH2' => 'V',
	'IAZH3' => 'V',
	'IAZH4' => 'V',
	'IAZH5' => 'V',
	'IAZI1' => 'V',
	'IAZI2' => 'V',
	'IAZI3' => 'V',
	'IAZI4' => 'V',
	'IAZIN' => 'V',
	'IAZJ1' => 'V',
	'IAZJ2' => 'V',
	'IAZJ3' => 'V',
	'IAZJ4' => 'V',
	'IAZJA' => 'V',
	'IAZKA' => 'V',
	'IAZMA' => 'V',
	'IAZNE' => 'V',
	'IAZNJ' => 'V',
	'IAZOH' => 'V',
	'IAZON' => 'V',
	'IAZTE' => 'V',
	'IAZTF' => 'V',
	'IAZUK' => 'V',
	'IAZW1' => 'V',
	'IAZW2' => 'V',
	'IBDV' => 'V',
	'IBDV5' => 'V',
	'IBDVA' => 'V',
	'IBDVC' => 'V',
	'IBDVE' => 'V',
	'IBDVO' => 'V',
	'IBDVP' => 'V',
	'IBDVS' => 'V',
	'IBEAM' => 'E',
	'IBEOP' => 'E',
	'IBILU' => 'E',
	'IBV41' => 'V',
	'IBV6' => 'V',
	'IBVAR' => 'V',
	'IBVB' => 'V',
	'IBVB2' => 'V',
	'IBVBC' => 'V',
	'IBVBU' => 'V',
	'IBVD1' => 'V',
	'IBVD2' => 'V',
	'IBVD3' => 'V',
	'IBVDE' => 'V',
	'IBVG' => 'V',
	'IBVH1' => 'V',
	'IBVH5' => 'V',
	'IBVK' => 'V',
	'IBVM' => 'V',
	'IBVP3' => 'V',
	'IBVSA' => 'V',
	'IBVU1' => 'V',
	'IBVU2' => 'V',
	'IBVU3' => 'V',
	'IBVU4' => 'V',
	'IBVU5' => 'V',
	'IBVV1' => 'V',
	'IBVVI' => 'V',
	'ICAMA' => 'E',
	'ICASP' => 'E',
	'ICHAL' => 'E',
	'ICHBA' => 'E',
	'ICHMU' => 'E',
	'ICHTE' => 'E',
	'ICHUN' => 'E',
	'ICHV1' => 'V',
	'ICMV' => 'V',
	'ICTAU' => 'E',
	'ICTBL' => 'E',
	'ICTBU' => 'E',
	'ICTCA' => 'E',
	'ICTCU' => 'E',
	'ICTDO' => 'E',
	'ICTGA' => 'E',
	'ICTGR' => 'E',
	'ICTIC' => 'E',
	'ICTLE' => 'E',
	'ICTME' => 'E',
	'ICTNI' => 'E',
	'ICTOB' => 'E',
	'ICTPA' => 'E',
	'ICTPU' => 'E',
	'ICTSP' => 'E',
	'ICTST' => 'E',
	'ICTVI' => 'E',
	'IDAAV' => 'E',
	'IDASC' => 'E',
	'IDEDE' => 'B',
	'IDELE' => 'E',
	'IDEPO' => 'E',
	'IDIAU' => 'E',
	'IDILO' => 'B',
	'IDIMA' => 'E',
	'IDIPH' => 'E',
	'IDIQU' => 'E',
	'IGUDE' => 'E',
	'IGUIG' => 'E',
	'IHHNH' => 'V',
	'IHHNV' => 'V',
	'IHNV' => 'V',
	'ILEAQ' => 'E',
	'ILECI' => 'E',
	'ILECR' => 'E',
	'ILEDE' => 'E',
	'ILEGL' => 'E',
	'ILEOP' => 'E',
	'ILEPE' => 'E',
	'ILERO' => 'E',
	'ILEVE' => 'E',
	'ILEVO' => 'E',
	'ILLAR' => 'E',
	'ILLPA' => 'E',
	'ILTV6' => 'V',
	'ILTVS' => 'V',
	'ILTVT' => 'V',
	'ILYFU' => 'E',
	'ILYQU' => 'E',
	'IMPBA' => 'E',
	'IMPCA' => 'E',
	'IMPCY' => 'E',
	'INAIO' => 'E',
	'INBAA' => 'V',
	'INBAC' => 'V',
	'INBAD' => 'V',
	'INBBA' => 'V',
	'INBBE' => 'V',
	'INBBK' => 'V',
	'INBBO' => 'V',
	'INBEN' => 'V',
	'INBF1' => 'V',
	'INBF2' => 'V',
	'INBF3' => 'V',
	'INBF4' => 'V',
	'INBF5' => 'V',
	'INBF6' => 'V',
	'INBF7' => 'V',
	'INBF8' => 'V',
	'INBF9' => 'V',
	'INBFU' => 'V',
	'INBGA' => 'V',
	'INBGD' => 'V',
	'INBGL' => 'V',
	'INBHK' => 'V',
	'INBHL' => 'V',
	'INBHM' => 'V',
	'INBHT' => 'V',
	'INBIB' => 'V',
	'INBID' => 'V',
	'INBIN' => 'V',
	'INBLE' => 'V',
	'INBLN' => 'V',
	'INBMD' => 'V',
	'INBME' => 'V',
	'INBMF' => 'V',
	'INBMP' => 'V',
	'INBNA' => 'V',
	'INBNY' => 'V',
	'INBOR' => 'V',
	'INBP3' => 'V',
	'INBP9' => 'V',
	'INBPA' => 'V',
	'INBRU' => 'V',
	'INBSD' => 'V',
	'INBSI' => 'V',
	'INBSJ' => 'V',
	'INBTE' => 'V',
	'INBTF' => 'V',
	'INBUS' => 'V',
	'INBVI' => 'V',
	'INBVJ' => 'V',
	'INBVK' => 'V',
	'INBVL' => 'V',
	'INBVM' => 'V',
	'INBYA' => 'V',
	'INBYB' => 'V',
	'INCAA' => 'V',
	'INCBE' => 'V',
	'INCCA' => 'V',
	'INCEN' => 'V',
	'INCGL' => 'V',
	'INCHY' => 'V',
	'INCJH' => 'V',
	'INCJJ' => 'V',
	'INCKY' => 'V',
	'INCMI' => 'V',
	'INCNA' => 'V',
	'INCNB' => 'V',
	'INCP1' => 'V',
	'INCP2' => 'V',
	'INCP3' => 'V',
	'INCTA' => 'V',
	'INCY6' => 'V',
	'INCYA' => 'V',
	'INCYB' => 'V',
	'INDIN' => 'E',
	'INDPA' => 'E',
	'INIGE' => 'E',
	'INSV' => 'V',
	'INSVN' => 'V',
	'INUBR' => 'E',
	'INUHE' => 'E',
	'IONAB' => 'E',
	'IONAC' => 'E',
	'IONPR' => 'E',
	'IPHA' => 'V',
	'IPHEL' => 'E',
	'IPMA' => 'V',
	'IPMAE' => 'V',
	'IPMAI' => 'V',
	'IPNVJ' => 'V',
	'IPNVN' => 'V',
	'IPNVS' => 'V',
	'IPOAL' => 'E',
	'IPOAQ' => 'E',
	'IPOBA' => 'E',
	'IPOCC' => 'E',
	'IPOCO' => 'E',
	'IPOHE' => 'E',
	'IPOLA' => 'E',
	'IPONI' => 'E',
	'IPOOB' => 'E',
	'IPOPC' => 'E',
	'IPOPL' => 'E',
	'IPOPU' => 'E',
	'IPOQU' => 'E',
	'IPOSE' => 'E',
	'IPOTF' => 'E',
	'IPOTI' => 'E',
	'IPOTR' => 'E',
	'IPOWR' => 'E',
	'IPSPE' => 'E',
	'IPSPI' => 'E',
	'IPSTY' => 'E',
	'IRECY' => 'E',
	'IREHE' => 'E',
	'IRIBR' => 'E',
	'IRICH' => 'E',
	'IRICR' => 'E',
	'IRIDA' => 'E',
	'IRIDO' => 'E',
	'IRIEN' => 'E',
	'IRIFE' => 'E',
	'IRIGE' => 'E',
	'IRIHA' => 'E',
	'IRIHO' => 'E',
	'IRIIN' => 'E',
	'IRILU' => 'E',
	'IRIMA' => 'E',
	'IRIOR' => 'E',
	'IRIPA' => 'E',
	'IRIPS' => 'E',
	'IRIPU' => 'E',
	'IRISA' => 'E',
	'IRISE' => 'E',
	'IRITE' => 'E',
	'IRPLA' => 'E',
	'IRV1' => 'V',
	'IRV16' => 'V',
	'IRV22' => 'V',
	'IRV6' => 'V',
	'IRV9' => 'V',
	'ISATI' => 'E',
	'ISCCE' => 'E',
	'ISCPE' => 'E',
	'ISCRA' => 'E',
	'ISCVE' => 'E',
	'ISMLO' => 'E',
	'ISOAR' => 'E',
	'ISOBI' => 'E',
	'ISODA' => 'E',
	'ISOEC' => 'E',
	'ISOEN' => 'E',
	'ISOFR' => 'E',
	'ISOGA' => 'E',
	'ISOHY' => 'E',
	'ISOLA' => 'E',
	'ISOMA' => 'E',
	'ISOME' => 'E',
	'ISOOB' => 'E',
	'ISOSI' => 'E',
	'ISOTA' => 'E',
	'ISOVE' => 'E',
	'ISSLA' => 'E',
	'ISSOR' => 'E',
	'ISTPI' => 'E',
	'ISTPL' => 'E',
	'ISUOX' => 'E',
	'ISUPA' => 'E',
	'ISYOB' => 'E',
	'IXEBR' => 'E',
	'IXOEX' => 'E',
	'IXOHE' => 'E',
	'IXOPE' => 'E',
	'IXORI' => 'E',
	'IXOSC' => 'E',
	'IXOSI' => 'E',
	'JACJA' => 'E',
	'JACJC' => 'E',
	'JACME' => 'E',
	'JACMI' => 'E',
	'JACOR' => 'E',
	'JAEHI' => 'E',
	'JAEV1' => 'V',
	'JAEV5' => 'V',
	'JAEVJ' => 'V',
	'JAEVN' => 'V',
	'JAMAU' => 'E',
	'JANCR' => 'E',
	'JANSC' => 'B',
	'JASLA' => 'E',
	'JASNU' => 'E',
	'JASSU' => 'E',
	'JATMU' => 'E',
	'JAUCA' => 'E',
	'JCDNV' => 'V',
	'JEFDI' => 'E',
	'JORTO' => 'E',
	'JSRV' => 'V',
	'JUAAU' => 'E',
	'JUGNI' => 'E',
	'JULRE' => 'E',
	'JUNAS' => 'E',
	'JUNBU' => 'E',
	'JUNCM' => 'E',
	'JUNCO' => 'E',
	'JUNEF' => 'E',
	'JUNHY' => 'E',
	'JUNIN' => 'V',
	'JUNIP' => 'E',
	'JUNOX' => 'E',
	'JUNSQ' => 'E',
	'JUNVI' => 'E',
	'JURCY' => 'E',
	'JUSAM' => 'E',
	'JUSOD' => 'E',
	'KALAN' => 'E',
	'KALDA' => 'E',
	'KALLA' => 'E',
	'KALLE' => 'E',
	'KALPI' => 'E',
	'KALPO' => 'E',
	'KARBR' => 'E',
	'KARMI' => 'E',
	'KASMA' => 'E',
	'KASSE' => 'E',
	'KATPE' => 'E',
	'KATTU' => 'E',
	'KECCO' => 'E',
	'KERRU' => 'E',
	'KETDA' => 'E',
	'KETKE' => 'E',
	'KETZE' => 'E',
	'KIBAR' => 'B',
	'KIGAF' => 'E',
	'KINPA' => 'E',
	'KINRA' => 'B',
	'KITGR' => 'B',
	'KLEAE' => 'B',
	'KLEBI' => 'E',
	'KLEFL' => 'E',
	'KLENI' => 'E',
	'KLEOR' => 'B',
	'KLEOX' => 'B',
	'KLEPL' => 'B',
	'KLEPN' => 'B',
	'KLEPO' => 'B',
	'KLEPR' => 'B',
	'KLESP' => 'B',
	'KLETE' => 'B',
	'KLEVA' => 'B',
	'KLUCI' => 'B',
	'KLUDE' => 'E',
	'KLULA' => 'E',
	'KLUMA' => 'E',
	'KLUTH' => 'E',
	'KLUWA' => 'E',
	'KNAAR' => 'E',
	'KNIUV' => 'E',
	'KOBEL' => 'E',
	'KOBKO' => 'E',
	'KOBME' => 'E',
	'KOBVA' => 'E',
	'KOCPR' => 'E',
	'KOCRH' => 'B',
	'KOCSC' => 'E',
	'KOEPA' => 'E',
	'KOGBR' => 'E',
	'KOGSI' => 'E',
	'KOKDR' => 'E',
	'KOLAM' => 'E',
	'KOPFR' => 'E',
	'KORV' => 'V',
	'KOSVI' => 'E',
	'KRYAS' => 'B',
	'KUKHI' => 'E',
	'KUNAM' => 'E',
	'KUNBA' => 'E',
	'KUNCA' => 'E',
	'KUNER' => 'E',
	'KUNJM' => 'V',
	'KUNPU' => 'E',
	'KUNTO' => 'E',
	'KYMVJ' => 'V',
	'KYPCI' => 'E',
	'KYPVA' => 'E',
	'LABAL' => 'E',
	'LABOS' => 'E',
	'LABRO' => 'E',
	'LABTH' => 'E',
	'LACAC' => 'B',
	'LACAG' => 'E',
	'LACAM' => 'B',
	'LACBE' => 'E',
	'LACBI' => 'E',
	'LACBL' => 'E',
	'LACBR' => 'B',
	'LACBU' => 'B',
	'LACCA' => 'B',
	'LACCH' => 'E',
	'LACCL' => 'B',
	'LACCO' => 'B',
	'LACCU' => 'B',
	'LACDA' => 'B',
	'LACDC' => 'E',
	'LACDE' => 'B',
	'LACDL' => 'B',
	'LACDT' => 'E',
	'LACFE' => 'B',
	'LACFR' => 'E',
	'LACHE' => 'B',
	'LACHI' => 'B',
	'LACIN' => 'E',
	'LACJO' => 'B',
	'LACLA' => 'B',
	'LACLC' => 'B',
	'LACLE' => 'B',
	'LACLP' => 'E',
	'LACMU' => 'E',
	'LACPA' => 'B',
	'LACPE' => 'B',
	'LACPL' => 'B',
	'LACPU' => 'E',
	'LACRE' => 'B',
	'LACRH' => 'B',
	'LACS1' => 'B',
	'LACS3' => 'B',
	'LACSA' => 'E',
	'LACSK' => 'B',
	'LACSL' => 'B',
	'LACSN' => 'B',
	'LACSS' => 'B',
	'LACST' => 'E',
	'LACSU' => 'E',
	'LACTA' => 'E',
	'LACVI' => 'B',
	'LACVR' => 'E',
	'LACVV' => 'E',
	'LACZE' => 'B',
	'LADDE' => 'E',
	'LAEWI' => 'E',
	'LAFLA' => 'E',
	'LAGAC' => 'E',
	'LAGAL' => 'E',
	'LAGAU' => 'E',
	'LAGCO' => 'E',
	'LAGCR' => 'E',
	'LAGFA' => 'E',
	'LAGHI' => 'E',
	'LAGHO' => 'E',
	'LAGLA' => 'E',
	'LAGLE' => 'E',
	'LAGLG' => 'E',
	'LAGLU' => 'E',
	'LAGMA' => 'E',
	'LAGOB' => 'E',
	'LAGOL' => 'E',
	'LAGRA' => 'E',
	'LAGSP' => 'E',
	'LAMAB' => 'E',
	'LAMAE' => 'E',
	'LAMAL' => 'E',
	'LAMAM' => 'E',
	'LAMAN' => 'E',
	'LAMAP' => 'E',
	'LAMAU' => 'E',
	'LAMAY' => 'E',
	'LAMBD' => 'V',
	'LAMBR' => 'E',
	'LAMCA' => 'E',
	'LAMCR' => 'E',
	'LAMFL' => 'E',
	'LAMGA' => 'E',
	'LAMGL' => 'E',
	'LAMGT' => 'E',
	'LAMGU' => 'E',
	'LAMHY' => 'E',
	'LAMIN' => 'E',
	'LAMJA' => 'E',
	'LAMNA' => 'E',
	'LAMPA' => 'E',
	'LAMPL' => 'E',
	'LAMPU' => 'E',
	'LAMRE' => 'E',
	'LAMRI' => 'E',
	'LAMRU' => 'E',
	'LAMSP' => 'E',
	'LAMTA' => 'E',
	'LAMTR' => 'E',
	'LAMVI' => 'E',
	'LANCA' => 'E',
	'LANCL' => 'E',
	'LANCO' => 'E',
	'LANEL' => 'E',
	'LANEX' => 'E',
	'LANLI' => 'E',
	'LANLU' => 'E',
	'LANSE' => 'E',
	'LANSP' => 'E',
	'LANTI' => 'E',
	'LANVT' => 'V',
	'LANVY' => 'V',
	'LAPHA' => 'E',
	'LAPMA' => 'E',
	'LAPNE' => 'E',
	'LAPSQ' => 'E',
	'LARAR' => 'E',
	'LARAU' => 'E',
	'LARBU' => 'E',
	'LARCA' => 'E',
	'LARCI' => 'E',
	'LARCN' => 'E',
	'LARDC' => 'E',
	'LARDE' => 'E',
	'LARDO' => 'E',
	'LARFU' => 'E',
	'LARHY' => 'E',
	'LARLA' => 'E',
	'LARMA' => 'E',
	'LARMC' => 'E',
	'LARNO' => 'E',
	'LAROX' => 'E',
	'LARRI' => 'E',
	'LARTR' => 'E',
	'LASCA' => 'E',
	'LASFU' => 'E',
	'LASMA' => 'E',
	'LASME' => 'E',
	'LASNI' => 'E',
	'LASNO' => 'E',
	'LASPA' => 'E',
	'LASPU' => 'E',
	'LASSG' => 'V',
	'LASSI' => 'E',
	'LASSJ' => 'V',
	'LASSP' => 'E',
	'LATAP' => 'E',
	'LATAR' => 'E',
	'LATCA' => 'E',
	'LATCH' => 'E',
	'LATCI' => 'E',
	'LATCL' => 'E',
	'LATCO' => 'E',
	'LATCR' => 'E',
	'LATHI' => 'E',
	'LATJA' => 'E',
	'LATLA' => 'E',
	'LATMA' => 'E',
	'LATME' => 'E',
	'LATOC' => 'E',
	'LATOD' => 'E',
	'LATSA' => 'E',
	'LATSE' => 'E',
	'LATSP' => 'E',
	'LATTI' => 'E',
	'LATVE' => 'E',
	'LAVAN' => 'E',
	'LAVLA' => 'E',
	'LAWIN' => 'B',
	'LAWIP' => 'B',
	'LAXSP' => 'E',
	'LAYHE' => 'E',
	'LDV' => 'V',
	'LDVC' => 'V',
	'LDVP' => 'V',
	'LEAAL' => 'E',
	'LEACR' => 'E',
	'LEAST' => 'E',
	'LEATO' => 'E',
	'LEAUN' => 'E',
	'LECMI' => 'E',
	'LECMU' => 'E',
	'LECPS' => 'E',
	'LEDGR' => 'E',
	'LEDGU' => 'E',
	'LEDPA' => 'E',
	'LEDSO' => 'E',
	'LEEGU' => 'E',
	'LEGBO' => 'B',
	'LEGER' => 'B',
	'LEGFO' => 'E',
	'LEGHA' => 'B',
	'LEGLO' => 'B',
	'LEGMI' => 'B',
	'LEGPA' => 'B',
	'LEGPH' => 'B',
	'LEGPL' => 'B',
	'LEGPN' => 'B',
	'LEGSP' => 'B',
	'LEIAM' => 'E',
	'LEIAN' => 'E',
	'LEIAQ' => 'B',
	'LEIAR' => 'E',
	'LEIBE' => 'E',
	'LEIBR' => 'E',
	'LEIBU' => 'E',
	'LEICH' => 'E',
	'LEIDO' => 'E',
	'LEIEN' => 'E',
	'LEIGU' => 'E',
	'LEIHA' => 'E',
	'LEIHO' => 'E',
	'LEIIN' => 'E',
	'LEILU' => 'E',
	'LEIMA' => 'E',
	'LEIME' => 'E',
	'LEIMI' => 'E',
	'LEIOC' => 'E',
	'LEIPA' => 'E',
	'LEIPE' => 'E',
	'LEIPI' => 'E',
	'LEIQH' => 'E',
	'LEIQU' => 'E',
	'LEITA' => 'E',
	'LEITR' => 'E',
	'LEIXA' => 'E',
	'LEIXC' => 'B',
	'LEIXX' => 'B',
	'LEMAE' => 'E',
	'LEMBA' => 'E',
	'LEMCA' => 'E',
	'LEMGI' => 'E',
	'LEMMI' => 'E',
	'LEMMN' => 'E',
	'LEMTI' => 'E',
	'LEMTR' => 'E',
	'LEMVA' => 'E',
	'LENCC' => 'E',
	'LENCO' => 'E',
	'LENCT' => 'E',
	'LENCU' => 'E',
	'LENED' => 'E',
	'LENER' => 'E',
	'LEOAR' => 'E',
	'LEOCH' => 'E',
	'LEOCM' => 'E',
	'LEOCY' => 'E',
	'LEOED' => 'E',
	'LEOOV' => 'E',
	'LEOPA' => 'E',
	'LEORO' => 'E',
	'LEOSA' => 'E',
	'LEOTI' => 'E',
	'LEOWI' => 'E',
	'LEPAC' => 'E',
	'LEPAE' => 'E',
	'LEPAF' => 'E',
	'LEPAI' => 'E',
	'LEPAL' => 'E',
	'LEPAM' => 'E',
	'LEPAN' => 'E',
	'LEPAP' => 'E',
	'LEPAR' => 'E',
	'LEPAS' => 'E',
	'LEPAU' => 'E',
	'LEPBC' => 'E',
	'LEPBI' => 'B',
	'LEPBN' => 'E',
	'LEPBO' => 'B',
	'LEPBR' => 'E',
	'LEPBU' => 'E',
	'LEPCA' => 'E',
	'LEPCB' => 'E',
	'LEPCE' => 'E',
	'LEPCL' => 'E',
	'LEPCM' => 'E',
	'LEPCO' => 'E',
	'LEPCR' => 'E',
	'LEPCS' => 'E',
	'LEPCU' => 'E',
	'LEPCY' => 'E',
	'LEPDA' => 'E',
	'LEPDC' => 'E',
	'LEPDE' => 'E',
	'LEPDI' => 'B',
	'LEPDN' => 'E',
	'LEPDO' => 'E',
	'LEPDS' => 'E',
	'LEPDU' => 'E',
	'LEPDV' => 'E',
	'LEPED' => 'E',
	'LEPEU' => 'E',
	'LEPFA' => 'E',
	'LEPFE' => 'E',
	'LEPFL' => 'E',
	'LEPFR' => 'E',
	'LEPFX' => 'E',
	'LEPGA' => 'E',
	'LEPGR' => 'E',
	'LEPHE' => 'E',
	'LEPHY' => 'E',
	'LEPIC' => 'B',
	'LEPIN' => 'B',
	'LEPJA' => 'E',
	'LEPJU' => 'E',
	'LEPKE' => 'E',
	'LEPLA' => 'E',
	'LEPLC' => 'E',
	'LEPLE' => 'E',
	'LEPLS' => 'E',
	'LEPLT' => 'E',
	'LEPLU' => 'E',
	'LEPMA' => 'E',
	'LEPMC' => 'E',
	'LEPME' => 'B',
	'LEPMI' => 'E',
	'LEPMN' => 'E',
	'LEPMO' => 'E',
	'LEPMP' => 'E',
	'LEPMR' => 'E',
	'LEPMT' => 'E',
	'LEPMU' => 'E',
	'LEPMY' => 'E',
	'LEPNI' => 'E',
	'LEPNU' => 'E',
	'LEPOB' => 'E',
	'LEPOC' => 'E',
	'LEPOE' => 'E',
	'LEPOI' => 'E',
	'LEPOL' => 'E',
	'LEPOS' => 'E',
	'LEPOT' => 'E',
	'LEPPA' => 'E',
	'LEPPE' => 'E',
	'LEPPF' => 'E',
	'LEPPI' => 'E',
	'LEPPR' => 'E',
	'LEPPS' => 'E',
	'LEPQU' => 'E',
	'LEPRA' => 'E',
	'LEPRD' => 'E',
	'LEPRU' => 'E',
	'LEPSA' => 'E',
	'LEPSE' => 'E',
	'LEPSH' => 'E',
	'LEPSI' => 'E',
	'LEPSP' => 'E',
	'LEPSR' => 'E',
	'LEPST' => 'E',
	'LEPSV' => 'E',
	'LEPSX' => 'E',
	'LEPTI' => 'E',
	'LEPTL' => 'E',
	'LEPTO' => 'E',
	'LEPVI' => 'E',
	'LEPVR' => 'E',
	'LEPWE' => 'E',
	'LESCU' => 'E',
	'LESFE' => 'E',
	'LESHA' => 'E',
	'LESIN' => 'E',
	'LESNU' => 'E',
	'LETAL' => 'E',
	'LETAT' => 'E',
	'LETBO' => 'E',
	'LETER' => 'E',
	'LETEY' => 'E',
	'LETGE' => 'E',
	'LETHA' => 'E',
	'LETLA' => 'E',
	'LETLE' => 'E',
	'LETMI' => 'E',
	'LETNE' => 'E',
	'LETOB' => 'E',
	'LETOL' => 'E',
	'LETOR' => 'E',
	'LETRE' => 'E',
	'LETRU' => 'E',
	'LETSE' => 'E',
	'LETVU' => 'E',
	'LEUAE' => 'E',
	'LEUCA' => 'B',
	'LEUCE' => 'E',
	'LEUCI' => 'B',
	'LEUCU' => 'E',
	'LEUDU' => 'E',
	'LEUFR' => 'E',
	'LEUGE' => 'B',
	'LEUGL' => 'E',
	'LEULA' => 'B',
	'LEULO' => 'E',
	'LEUMA' => 'E',
	'LEUMC' => 'B',
	'LEUME' => 'B',
	'LEUMU' => 'B',
	'LEUPS' => 'B',
	'LEURO' => 'E',
	'LEUSC' => 'E',
	'LEUSI' => 'E',
	'LEUTO' => 'E',
	'LEUVE' => 'E',
	'LEUVU' => 'E',
	'LEVOF' => 'E',
	'LIAAL' => 'E',
	'LIABU' => 'E',
	'LIACH' => 'E',
	'LIAMA' => 'E',
	'LIAMS' => 'E',
	'LIAOV' => 'E',
	'LIAPA' => 'E',
	'LIBAC' => 'B',
	'LIBAF' => 'B',
	'LIBAS' => 'B',
	'LIBAU' => 'E',
	'LIBBA' => 'E',
	'LIBCA' => 'E',
	'LIBCY' => 'E',
	'LIBEM' => 'E',
	'LIBFO' => 'E',
	'LIBFR' => 'E',
	'LIBLU' => 'E',
	'LIBPU' => 'E',
	'LIBQU' => 'E',
	'LIBSA' => 'E',
	'LIBSE' => 'E',
	'LIBVI' => 'E',
	'LICGR' => 'E',
	'LIGJA' => 'E',
	'LIGOV' => 'E',
	'LIGSC' => 'E',
	'LIGVU' => 'E',
	'LILCA' => 'E',
	'LILCR' => 'E',
	'LILDA' => 'E',
	'LILHE' => 'E',
	'LILLO' => 'E',
	'LILMI' => 'E',
	'LILNZ' => 'E',
	'LILRE' => 'E',
	'LILSU' => 'E',
	'LILTS' => 'E',
	'LIMAL' => 'E',
	'LIMAU' => 'E',
	'LIMBE' => 'E',
	'LIMCL' => 'E',
	'LIMDO' => 'E',
	'LIMDU' => 'E',
	'LIMFE' => 'E',
	'LIMFL' => 'E',
	'LIMFR' => 'E',
	'LIMFT' => 'E',
	'LIMFU' => 'E',
	'LIMHI' => 'E',
	'LIMIN' => 'E',
	'LIMLI' => 'E',
	'LIMLM' => 'E',
	'LIMPA' => 'E',
	'LIMPO' => 'E',
	'LIMSA' => 'E',
	'LIMTE' => 'E',
	'LINAR' => 'E',
	'LINBE' => 'E',
	'LINBO' => 'E',
	'LINCA' => 'E',
	'LINCO' => 'E',
	'LINDI' => 'E',
	'LINHU' => 'E',
	'LINLA' => 'E',
	'LINMU' => 'E',
	'LINPE' => 'E',
	'LINPO' => 'E',
	'LINRE' => 'E',
	'LINSA' => 'E',
	'LINTI' => 'E',
	'LINUN' => 'E',
	'LINUS' => 'E',
	'LINVU' => 'E',
	'LIOAD' => 'E',
	'LIODE' => 'E',
	'LIOHO' => 'E',
	'LIOJA' => 'E',
	'LIOMA' => 'E',
	'LIOMI' => 'E',
	'LIOSE' => 'E',
	'LIOSP' => 'E',
	'LIPIN' => 'E',
	'LIPKO' => 'E',
	'LIPST' => 'E',
	'LIPVE' => 'E',
	'LIQFO' => 'E',
	'LIQOR' => 'E',
	'LIQST' => 'E',
	'LIRCH' => 'E',
	'LIRPL' => 'E',
	'LIRTU' => 'E',
	'LISBO' => 'E',
	'LISDA' => 'B',
	'LISGR' => 'B',
	'LISIN' => 'B',
	'LISIV' => 'B',
	'LISME' => 'E',
	'LISMF' => 'B',
	'LISMO' => 'B',
	'LISPE' => 'E',
	'LISSE' => 'B',
	'LISWE' => 'B',
	'LITAU' => 'E',
	'LITCA' => 'E',
	'LITCE' => 'E',
	'LITCH' => 'E',
	'LITCI' => 'E',
	'LITCN' => 'E',
	'LITDA' => 'E',
	'LITER' => 'E',
	'LITEW' => 'E',
	'LITFO' => 'E',
	'LITGE' => 'E',
	'LITGI' => 'E',
	'LITIN' => 'E',
	'LITLI' => 'E',
	'LITMO' => 'E',
	'LITOB' => 'E',
	'LITPL' => 'E',
	'LITRA' => 'E',
	'LITRU' => 'E',
	'LITSC' => 'E',
	'LITSE' => 'E',
	'LITSH' => 'E',
	'LITSI' => 'E',
	'LITSP' => 'E',
	'LITST' => 'E',
	'LITWA' => 'E',
	'LITXA' => 'E',
	'LIV' => 'V',
	'LIV31' => 'V',
	'LIVCH' => 'E',
	'LIVK' => 'V',
	'LIVN1' => 'V',
	'LIVNO' => 'V',
	'LIVSB' => 'V',
	'LIZAU' => 'E',
	'LIZSA' => 'E',
	'LMV0' => 'V',
	'LMVE' => 'V',
	'LOACH' => 'E',
	'LOALO' => 'E',
	'LOBCA' => 'E',
	'LOBCR' => 'E',
	'LOBCS' => 'E',
	'LOBER' => 'E',
	'LOBMA' => 'E',
	'LOBSE' => 'E',
	'LOBSP' => 'E',
	'LOCCA' => 'E',
	'LOCMI' => 'E',
	'LOESC' => 'E',
	'LOIPR' => 'E',
	'LOLBL' => 'E',
	'LOLFO' => 'E',
	'LOLMU' => 'E',
	'LOLOP' => 'E',
	'LOLPE' => 'E',
	'LOLPR' => 'E',
	'LOLRI' => 'E',
	'LOLSU' => 'E',
	'LOLTE' => 'E',
	'LOLVU' => 'E',
	'LOMDA' => 'E',
	'LONAC' => 'E',
	'LONAU' => 'E',
	'LONCA' => 'E',
	'LONCH' => 'E',
	'LONCN' => 'E',
	'LONFE' => 'E',
	'LONHI' => 'E',
	'LONIN' => 'E',
	'LONJA' => 'E',
	'LONLO' => 'E',
	'LONMO' => 'E',
	'LONON' => 'E',
	'LONRO' => 'E',
	'LONSE' => 'E',
	'LONTH' => 'E',
	'LOPAA' => 'E',
	'LOPAM' => 'E',
	'LOPAT' => 'E',
	'LOPBU' => 'E',
	'LOPCA' => 'E',
	'LOPCH' => 'E',
	'LOPCI' => 'E',
	'LOPCO' => 'E',
	'LOPCR' => 'E',
	'LOPCS' => 'E',
	'LOPDC' => 'E',
	'LOPDI' => 'E',
	'LOPED' => 'E',
	'LOPEL' => 'E',
	'LOPER' => 'E',
	'LOPFL' => 'E',
	'LOPGA' => 'E',
	'LOPHA' => 'E',
	'LOPIG' => 'E',
	'LOPIM' => 'E',
	'LOPLE' => 'E',
	'LOPLI' => 'E',
	'LOPLO' => 'E',
	'LOPNY' => 'E',
	'LOPPI' => 'E',
	'LOPSP' => 'E',
	'LOPST' => 'E',
	'LOPSW' => 'E',
	'LORDV' => 'V',
	'LORGA' => 'E',
	'LORTA' => 'E',
	'LOTCO' => 'E',
	'LOTJA' => 'E',
	'LOTPU' => 'E',
	'LOTTE' => 'E',
	'LOWBP' => 'B',
	'LOXAF' => 'E',
	'LOXAL' => 'E',
	'LOXAR' => 'E',
	'LOXBI' => 'E',
	'LOXCO' => 'E',
	'LOXCU' => 'E',
	'LOXGA' => 'E',
	'LOXIN' => 'E',
	'LOXLA' => 'E',
	'LOXLE' => 'E',
	'LOXNO' => 'E',
	'LOXRE' => 'E',
	'LOXSI' => 'E',
	'LOXST' => 'E',
	'LPMV' => 'V',
	'LSDV' => 'V',
	'LSV' => 'V',
	'LUCCA' => 'E',
	'LUCCE' => 'E',
	'LUCCR' => 'E',
	'LUCCU' => 'E',
	'LUCLA' => 'E',
	'LUCMI' => 'E',
	'LUCPE' => 'E',
	'LUCSE' => 'E',
	'LUDPE' => 'E',
	'LUFAC' => 'E',
	'LUFCY' => 'E',
	'LUMRU' => 'E',
	'LUMTE' => 'E',
	'LUNAN' => 'E',
	'LUNJA' => 'E',
	'LUNRE' => 'E',
	'LUPAA' => 'E',
	'LUPAB' => 'E',
	'LUPAD' => 'E',
	'LUPAE' => 'E',
	'LUPAG' => 'E',
	'LUPAL' => 'E',
	'LUPAN' => 'E',
	'LUPAR' => 'E',
	'LUPAT' => 'E',
	'LUPAU' => 'E',
	'LUPCO' => 'E',
	'LUPDE' => 'E',
	'LUPDI' => 'E',
	'LUPGR' => 'E',
	'LUPHI' => 'E',
	'LUPLA' => 'E',
	'LUPLU' => 'E',
	'LUPMC' => 'E',
	'LUPMI' => 'E',
	'LUPMU' => 'E',
	'LUPNA' => 'E',
	'LUPNO' => 'E',
	'LUPPA' => 'E',
	'LUPPE' => 'E',
	'LUPPI' => 'E',
	'LUPPO' => 'E',
	'LUPPR' => 'E',
	'LUPRI' => 'E',
	'LUPSE' => 'E',
	'LUPTE' => 'E',
	'LURNA' => 'E',
	'LUTCA' => 'E',
	'LUTCR' => 'E',
	'LUTDE' => 'E',
	'LUTLO' => 'E',
	'LUTLU' => 'E',
	'LUTMA' => 'E',
	'LUZCA' => 'E',
	'LUZMU' => 'E',
	'LVX' => 'V',
	'LYCAL' => 'E',
	'LYCAN' => 'E',
	'LYCAO' => 'E',
	'LYCAU' => 'E',
	'LYCBA' => 'E',
	'LYCCE' => 'E',
	'LYCCH' => 'E',
	'LYCCL' => 'E',
	'LYCCN' => 'E',
	'LYCCO' => 'E',
	'LYCCR' => 'E',
	'LYCDE' => 'E',
	'LYCDI' => 'E',
	'LYCFA' => 'E',
	'LYCFE' => 'E',
	'LYCMU' => 'E',
	'LYCOB' => 'E',
	'LYCPI' => 'E',
	'LYCPO' => 'E',
	'LYCRA' => 'E',
	'LYCRD' => 'E',
	'LYCRU' => 'E',
	'LYCSA' => 'E',
	'LYCSC' => 'E',
	'LYCSN' => 'E',
	'LYCSQ' => 'E',
	'LYCSR' => 'E',
	'LYCTO' => 'E',
	'LYCVA' => 'V',
	'LYCVH' => 'E',
	'LYCVO' => 'E',
	'LYCVP' => 'V',
	'LYCVT' => 'V',
	'LYCVW' => 'V',
	'LYGJA' => 'E',
	'LYGLI' => 'E',
	'LYGSP' => 'E',
	'LYMDI' => 'E',
	'LYMST' => 'E',
	'LYNCA' => 'E',
	'LYNLY' => 'E',
	'LYNPA' => 'E',
	'LYNRU' => 'E',
	'LYOFE' => 'E',
	'LYOHY' => 'E',
	'LYOLI' => 'E',
	'LYOLU' => 'E',
	'LYOOV' => 'E',
	'LYOSH' => 'E',
	'LYSCI' => 'E',
	'LYSEN' => 'B',
	'LYSLA' => 'B',
	'LYSNE' => 'E',
	'LYSVU' => 'E',
	'LYTPI' => 'E',
	'LYTSA' => 'E',
	'LYTVA' => 'E',
	'MABVM' => 'V',
	'MABVP' => 'V',
	'MACAG' => 'E',
	'MACAM' => 'E',
	'MACAN' => 'E',
	'MACAR' => 'E',
	'MACAS' => 'E',
	'MACBA' => 'E',
	'MACBR' => 'E',
	'MACCA' => 'E',
	'MACCH' => 'E',
	'MACCO' => 'E',
	'MACDE' => 'E',
	'MACEU' => 'E',
	'MACFA' => 'E',
	'MACFL' => 'E',
	'MACFS' => 'E',
	'MACFU' => 'E',
	'MACGA' => 'E',
	'MACGG' => 'E',
	'MACGI' => 'E',
	'MACGS' => 'E',
	'MACHA' => 'E',
	'MACHE' => 'E',
	'MACHU' => 'V',
	'MACIM' => 'E',
	'MACIN' => 'E',
	'MACIR' => 'E',
	'MACLA' => 'E',
	'MACLE' => 'E',
	'MACMA' => 'E',
	'MACMC' => 'E',
	'MACMI' => 'E',
	'MACML' => 'E',
	'MACMR' => 'E',
	'MACMU' => 'E',
	'MACNE' => 'E',
	'MACNG' => 'E',
	'MACNI' => 'E',
	'MACNR' => 'E',
	'MACOC' => 'E',
	'MACPA' => 'E',
	'MACPG' => 'E',
	'MACPO' => 'E',
	'MACPR' => 'E',
	'MACPY' => 'E',
	'MACRA' => 'E',
	'MACRG' => 'E',
	'MACRO' => 'E',
	'MACRS' => 'E',
	'MACRU' => 'E',
	'MACRV' => 'E',
	'MACSB' => 'E',
	'MACSI' => 'E',
	'MACSL' => 'E',
	'MACSP' => 'E',
	'MACSU' => 'E',
	'MACSY' => 'E',
	'MACTE' => 'E',
	'MACTH' => 'E',
	'MACTO' => 'E',
	'MACTR' => 'E',
	'MACUC' => 'E',
	'MACWA' => 'E',
	'MADEL' => 'E',
	'MADGU' => 'E',
	'MADKI' => 'E',
	'MADMI' => 'E',
	'MADSA' => 'E',
	'MAGAC' => 'E',
	'MAGGA' => 'E',
	'MAGGR' => 'E',
	'MAGLA' => 'E',
	'MAGLI' => 'E',
	'MAGMA' => 'E',
	'MAGMG' => 'B',
	'MAGMM' => 'B',
	'MAGPO' => 'E',
	'MAGPY' => 'E',
	'MAGSA' => 'B',
	'MAGSE' => 'E',
	'MAGSL' => 'E',
	'MAGSO' => 'E',
	'MAGST' => 'E',
	'MAGTR' => 'E',
	'MAGV' => 'V',
	'MAGVI' => 'E',
	'MAHBE' => 'E',
	'MAIDI' => 'E',
	'MAIPO' => 'E',
	'MAIRA' => 'E',
	'MAISE' => 'E',
	'MAISQ' => 'E',
	'MAIZE' => 'E',
	'MAJHO' => 'E',
	'MAKNI' => 'E',
	'MALAM' => 'E',
	'MALAR' => 'E',
	'MALDI' => 'E',
	'MALDO' => 'E',
	'MALFU' => 'E',
	'MALGL' => 'E',
	'MALLA' => 'E',
	'MALLO' => 'E',
	'MALMI' => 'E',
	'MALMO' => 'E',
	'MALNE' => 'E',
	'MALNG' => 'E',
	'MALPA' => 'E',
	'MALPL' => 'E',
	'MALPU' => 'E',
	'MALRU' => 'B',
	'MALSM' => 'E',
	'MALSP' => 'E',
	'MALSU' => 'E',
	'MALSY' => 'E',
	'MALTE' => 'E',
	'MALTY' => 'E',
	'MALXI' => 'E',
	'MAMAM' => 'E',
	'MAMBR' => 'E',
	'MAMHA' => 'E',
	'MAMPR' => 'E',
	'MANCO' => 'E',
	'MANCV' => 'V',
	'MANES' => 'E',
	'MANGL' => 'B',
	'MANIN' => 'E',
	'MANJA' => 'E',
	'MANLE' => 'E',
	'MANME' => 'E',
	'MANOF' => 'E',
	'MANSE' => 'E',
	'MANSM' => 'B',
	'MANSP' => 'E',
	'MANSQ' => 'E',
	'MANTE' => 'E',
	'MANZA' => 'E',
	'MARAM' => 'E',
	'MARAN' => 'E',
	'MARBA' => 'E',
	'MARBB' => 'E',
	'MARBI' => 'E',
	'MARBO' => 'E',
	'MARBR' => 'E',
	'MARCA' => 'E',
	'MARCE' => 'E',
	'MARCU' => 'E',
	'MARDR' => 'E',
	'MARFA' => 'E',
	'MARFL' => 'E',
	'MARFO' => 'E',
	'MARGL' => 'E',
	'MARHA' => 'B',
	'MARHI' => 'E',
	'MARHY' => 'B',
	'MARIC' => 'E',
	'MARIM' => 'E',
	'MARIN' => 'E',
	'MARLE' => 'E',
	'MARMA' => 'E',
	'MARMC' => 'E',
	'MARME' => 'E',
	'MARMG' => 'E',
	'MARMI' => 'E',
	'MARMM' => 'B',
	'MARMN' => 'E',
	'MARMO' => 'E',
	'MARMR' => 'E',
	'MARMT' => 'E',
	'MARMU' => 'E',
	'MARMX' => 'E',
	'MARNO' => 'E',
	'MAROL' => 'E',
	'MARPA' => 'E',
	'MARPE' => 'E',
	'MARPI' => 'E',
	'MARPL' => 'E',
	'MARPO' => 'E',
	'MARPR' => 'E',
	'MARPU' => 'B',
	'MARPV' => 'E',
	'MARQU' => 'E',
	'MARRO' => 'E',
	'MARRU' => 'E',
	'MARSC' => 'E',
	'MARSI' => 'E',
	'MARVA' => 'E',
	'MARVE' => 'E',
	'MARVU' => 'E',
	'MARZI' => 'E',
	'MASBA' => 'E',
	'MASCO' => 'E',
	'MASDE' => 'E',
	'MASGI' => 'E',
	'MASHI' => 'E',
	'MASLA' => 'B',
	'MASMZ' => 'E',
	'MASRA' => 'E',
	'MASST' => 'E',
	'MATBI' => 'E',
	'MATIN' => 'E',
	'MATMA' => 'E',
	'MATRE' => 'E',
	'MATST' => 'E',
	'MATTR' => 'E',
	'MAXBA' => 'E',
	'MAXSU' => 'E',
	'MAYAB' => 'V',
	'MAYDE' => 'E',
	'MAZAM' => 'E',
	'MAZLI' => 'E',
	'MAZPU' => 'E',
	'MAZRE' => 'E',
	'MAZST' => 'E',
	'MCFA' => 'V',
	'MCFF' => 'V',
	'MCFF3' => 'V',
	'MCMV' => 'V',
	'MCMVK' => 'V',
	'MCMVS' => 'V',
	'MCV1' => 'V',
	'MCV2' => 'V',
	'MDMV' => 'V',
	'MDV1' => 'V',
	'MDV9' => 'V',
	'MEASA' => 'V',
	'MEASB' => 'V',
	'MEASE' => 'V',
	'MEASF' => 'V',
	'MEASH' => 'V',
	'MEASI' => 'V',
	'MEASL' => 'V',
	'MEASM' => 'V',
	'MEASP' => 'V',
	'MEASU' => 'V',
	'MEASY' => 'V',
	'MEASZ' => 'V',
	'MECPR' => 'E',
	'MEDFA' => 'E',
	'MEDSA' => 'E',
	'MEDSC' => 'E',
	'MEDTR' => 'E',
	'MEDVA' => 'E',
	'MEDVI' => 'E',
	'MEGAM' => 'E',
	'MEGAN' => 'E',
	'MEGAT' => 'E',
	'MEGCR' => 'E',
	'MEGCU' => 'E',
	'MEGCY' => 'E',
	'MEGDE' => 'E',
	'MEGEC' => 'E',
	'MEGEL' => 'B',
	'MEGER' => 'E',
	'MEGFL' => 'E',
	'MEGFO' => 'E',
	'MEGFR' => 'E',
	'MEGGG' => 'E',
	'MEGGI' => 'E',
	'MEGLA' => 'E',
	'MEGLY' => 'E',
	'MEGNI' => 'E',
	'MEGNO' => 'E',
	'MEGPE' => 'E',
	'MEGPI' => 'E',
	'MEGPL' => 'E',
	'MEGPO' => 'E',
	'MEGPR' => 'E',
	'MEGPY' => 'E',
	'MEGRE' => 'E',
	'MEGRO' => 'E',
	'MEGSC' => 'E',
	'MEGSI' => 'E',
	'MEGSP' => 'E',
	'MEGTE' => 'E',
	'MEGTR' => 'E',
	'MEGVI' => 'E',
	'MEGVU' => 'E',
	'MEGWO' => 'E',
	'MEHV1' => 'V',
	'MEHVF' => 'V',
	'MEHVH' => 'V',
	'MEIRU' => 'B',
	'MEITR' => 'E',
	'MELAB' => 'E',
	'MELAE' => 'E',
	'MELAL' => 'E',
	'MELAN' => 'E',
	'MELAO' => 'E',
	'MELAP' => 'E',
	'MELAR' => 'E',
	'MELAS' => 'E',
	'MELAT' => 'E',
	'MELAU' => 'E',
	'MELAZ' => 'E',
	'MELBI' => 'E',
	'MELBR' => 'E',
	'MELCA' => 'E',
	'MELCB' => 'E',
	'MELCH' => 'E',
	'MELCI' => 'E',
	'MELCN' => 'E',
	'MELCO' => 'E',
	'MELCP' => 'E',
	'MELCR' => 'E',
	'MELCU' => 'E',
	'MELDA' => 'E',
	'MELDE' => 'E',
	'MELDI' => 'E',
	'MELDP' => 'E',
	'MELFA' => 'E',
	'MELFE' => 'E',
	'MELFU' => 'E',
	'MELGA' => 'E',
	'MELGE' => 'E',
	'MELGI' => 'E',
	'MELGL' => 'E',
	'MELHA' => 'E',
	'MELIC' => 'E',
	'MELID' => 'E',
	'MELIN' => 'E',
	'MELIT' => 'E',
	'MELJA' => 'E',
	'MELKE' => 'E',
	'MELLA' => 'E',
	'MELLE' => 'E',
	'MELLI' => 'E',
	'MELLN' => 'E',
	'MELLU' => 'E',
	'MELMA' => 'E',
	'MELME' => 'E',
	'MELMI' => 'E',
	'MELML' => 'E',
	'MELMN' => 'E',
	'MELMO' => 'E',
	'MELMS' => 'E',
	'MELMU' => 'E',
	'MELMY' => 'E',
	'MELNG' => 'E',
	'MELNI' => 'E',
	'MELNV' => 'E',
	'MELOC' => 'E',
	'MELOF' => 'E',
	'MELOI' => 'E',
	'MELPA' => 'E',
	'MELRI' => 'E',
	'MELRU' => 'E',
	'MELSA' => 'E',
	'MELSC' => 'E',
	'MELTU' => 'E',
	'MELUD' => 'E',
	'MELUN' => 'E',
	'MELVI' => 'E',
	'MELZU' => 'E',
	'MEMEL' => 'E',
	'MEMME' => 'E',
	'MEMTE' => 'E',
	'MENAQ' => 'E',
	'MENAR' => 'E',
	'MENAU' => 'E',
	'MENCE' => 'E',
	'MENCU' => 'E',
	'MENDI' => 'E',
	'MENGR' => 'E',
	'MENLA' => 'E',
	'MENLI' => 'E',
	'MENLO' => 'E',
	'MENPI' => 'E',
	'MENPU' => 'E',
	'MENRE' => 'E',
	'MENSA' => 'E',
	'MENSP' => 'E',
	'MENSU' => 'E',
	'MENTR' => 'E',
	'MEPME' => 'E',
	'MERAN' => 'E',
	'MERBI' => 'E',
	'MERCA' => 'E',
	'MERCU' => 'E',
	'MERMC' => 'E',
	'MERME' => 'E',
	'MERMR' => 'E',
	'MERNU' => 'E',
	'MERPE' => 'E',
	'MERSH' => 'E',
	'MERTU' => 'E',
	'MERUN' => 'E',
	'MERVI' => 'E',
	'MESAU' => 'E',
	'MESBI' => 'E',
	'MESBR' => 'E',
	'MESCA' => 'E',
	'MESCR' => 'E',
	'MESFL' => 'B',
	'MESHI' => 'E',
	'MESMA' => 'E',
	'MESMC' => 'E',
	'MESPE' => 'E',
	'MESPL' => 'B',
	'MESS7' => 'B',
	'MESSB' => 'B',
	'MESST' => 'E',
	'MESTA' => 'E',
	'MESVI' => 'E',
	'METAC' => 'A',
	'METAE' => 'E',
	'METAI' => 'B',
	'METAL' => 'B',
	'METAM' => 'B',
	'METAN' => 'E',
	'METAO' => 'B',
	'METBA' => 'A',
	'METBF' => 'A',
	'METBO' => 'E',
	'METBR' => 'A',
	'METBU' => 'A',
	'METBW' => 'E',
	'METCA' => 'B',
	'METCH' => 'B',
	'METCL' => 'B',
	'METDI' => 'B',
	'METEN' => 'E',
	'METEU' => 'E',
	'METEX' => 'B',
	'METFE' => 'A',
	'METFK' => 'B',
	'METFL' => 'B',
	'METFO' => 'A',
	'METGL' => 'B',
	'METGY' => 'E',
	'METHJ' => 'B',
	'METHU' => 'A',
	'METIG' => 'A',
	'METIN' => 'E',
	'METIV' => 'A',
	'METJ' => 'B',
	'METJA' => 'A',
	'METKA' => 'A',
	'METMA' => 'A',
	'METME' => 'B',
	'METMP' => 'A',
	'METMR' => 'B',
	'METMT' => 'A',
	'METNO' => 'B',
	'METNU' => 'E',
	'METOD' => 'E',
	'METOG' => 'A',
	'METOR' => 'B',
	'METPA' => 'E',
	'METPH' => 'E',
	'METPL' => 'B',
	'METPR' => 'A',
	'METRU' => 'B',
	'METS1' => 'B',
	'METSC' => 'A',
	'METSE' => 'E',
	'METSI' => 'B',
	'METSK' => 'B',
	'METSM' => 'A',
	'METSO' => 'A',
	'METSP' => 'B',
	'METSR' => 'B',
	'METSS' => 'B',
	'METST' => 'B',
	'METTE' => 'A',
	'METTF' => 'A',
	'METTH' => 'A',
	'METTI' => 'A',
	'METTL' => 'A',
	'METTM' => 'A',
	'METTO' => 'B',
	'METTR' => 'B',
	'METTS' => 'E',
	'METTU' => 'B',
	'METTW' => 'A',
	'METTY' => 'E',
	'METVA' => 'A',
	'METVO' => 'A',
	'METWO' => 'A',
	'MEVA' => 'V',
	'MHV68' => 'V',
	'MICAB' => 'E',
	'MICAE' => 'B',
	'MICAG' => 'E',
	'MICAL' => 'E',
	'MICAM' => 'B',
	'MICAR' => 'E',
	'MICBC' => 'B',
	'MICBE' => 'E',
	'MICBI' => 'B',
	'MICBR' => 'E',
	'MICCA' => 'E',
	'MICCB' => 'E',
	'MICCF' => 'E',
	'MICCH' => 'B',
	'MICCL' => 'E',
	'MICCM' => 'E',
	'MICCN' => 'E',
	'MICCO' => 'E',
	'MICCR' => 'E',
	'MICCT' => 'E',
	'MICDE' => 'E',
	'MICDU' => 'E',
	'MICEC' => 'B',
	'MICEU' => 'E',
	'MICFA' => 'E',
	'MICFE' => 'E',
	'MICFI' => 'E',
	'MICFL' => 'E',
	'MICFM' => 'E',
	'MICFN' => 'E',
	'MICFO' => 'E',
	'MICFR' => 'E',
	'MICFU' => 'B',
	'MICGA' => 'E',
	'MICGE' => 'E',
	'MICGG' => 'E',
	'MICGI' => 'E',
	'MICGL' => 'B',
	'MICGN' => 'E',
	'MICGO' => 'E',
	'MICGR' => 'B',
	'MICGU' => 'E',
	'MICHI' => 'E',
	'MICHO' => 'E',
	'MICIB' => 'E',
	'MICIK' => 'E',
	'MICJL' => 'E',
	'MICJO' => 'E',
	'MICJU' => 'E',
	'MICKI' => 'E',
	'MICLA' => 'E',
	'MICLE' => 'E',
	'MICLH' => 'E',
	'MICLI' => 'E',
	'MICLN' => 'E',
	'MICLO' => 'E',
	'MICLS' => 'E',
	'MICLT' => 'B',
	'MICLU' => 'B',
	'MICMA' => 'E',
	'MICMC' => 'E',
	'MICMD' => 'E',
	'MICME' => 'E',
	'MICMG' => 'E',
	'MICMI' => 'E',
	'MICMJ' => 'E',
	'MICMN' => 'E',
	'MICMO' => 'E',
	'MICMR' => 'E',
	'MICMS' => 'E',
	'MICMT' => 'E',
	'MICMU' => 'E',
	'MICMY' => 'E',
	'MICNI' => 'E',
	'MICNV' => 'E',
	'MICOA' => 'E',
	'MICOC' => 'E',
	'MICOE' => 'E',
	'MICOH' => 'E',
	'MICOL' => 'B',
	'MICOR' => 'E',
	'MICPA' => 'E',
	'MICPE' => 'E',
	'MICPF' => 'E',
	'MICPI' => 'E',
	'MICPL' => 'E',
	'MICPR' => 'E',
	'MICPU' => 'E',
	'MICQU' => 'E',
	'MICRA' => 'E',
	'MICRE' => 'E',
	'MICRF' => 'E',
	'MICRI' => 'E',
	'MICRO' => 'B',
	'MICRS' => 'E',
	'MICRU' => 'B',
	'MICS1' => 'B',
	'MICSA' => 'E',
	'MICSC' => 'E',
	'MICSI' => 'E',
	'MICSM' => 'E',
	'MICSO' => 'E',
	'MICSP' => 'B',
	'MICSY' => 'E',
	'MICSZ' => 'E',
	'MICTA' => 'E',
	'MICTO' => 'E',
	'MICTT' => 'E',
	'MICTV' => 'E',
	'MICTW' => 'E',
	'MICUM' => 'E',
	'MICUN' => 'E',
	'MICVA' => 'B',
	'MICVI' => 'B',
	'MICVM' => 'E',
	'MICWH' => 'E',
	'MICXA' => 'E',
	'MIDDV' => 'V',
	'MILCH' => 'E',
	'MILPH' => 'E',
	'MILQU' => 'E',
	'MILWA' => 'E',
	'MIMAU' => 'E',
	'MIMCR' => 'E',
	'MIMGR' => 'E',
	'MIMGU' => 'E',
	'MIMIV' => 'V',
	'MIMKE' => 'E',
	'MIMLA' => 'E',
	'MIMLE' => 'E',
	'MIMNA' => 'E',
	'MIMNO' => 'E',
	'MIMNU' => 'E',
	'MIMPL' => 'E',
	'MIMPO' => 'E',
	'MIMPU' => 'E',
	'MIMRI' => 'E',
	'MIMTI' => 'E',
	'MINFR' => 'E',
	'MINFU' => 'E',
	'MINLO' => 'E',
	'MINSC' => 'E',
	'MIOTA' => 'E',
	'MIRAN' => 'E',
	'MIRCO' => 'E',
	'MIRJA' => 'E',
	'MIRLE' => 'E',
	'MIRNY' => 'E',
	'MIRZA' => 'E',
	'MISAN' => 'E',
	'MISBR' => 'E',
	'MISFO' => 'E',
	'MISMI' => 'E',
	'MISRO' => 'E',
	'MISSI' => 'E',
	'MISV' => 'V',
	'MITCE' => 'E',
	'MITMI' => 'E',
	'MITRE' => 'E',
	'MLVAB' => 'V',
	'MLVAT' => 'V',
	'MLVAV' => 'V',
	'MLVBM' => 'V',
	'MLVCB' => 'V',
	'MLVCN' => 'V',
	'MLVDE' => 'V',
	'MLVDU' => 'V',
	'MLVF5' => 'V',
	'MLVFF' => 'V',
	'MLVFP' => 'V',
	'MLVFR' => 'V',
	'MLVHO' => 'V',
	'MLVKI' => 'V',
	'MLVMO' => 'V',
	'MLVRA' => 'V',
	'MLVRD' => 'V',
	'MLVRK' => 'V',
	'MMPV' => 'V',
	'MMTVB' => 'V',
	'MMTVC' => 'V',
	'MMTVG' => 'V',
	'MNELE' => 'E',
	'MNIVA' => 'E',
	'MNPV' => 'V',
	'MNSV' => 'V',
	'MOBAS' => 'B',
	'MODAM' => 'E',
	'MODBR' => 'E',
	'MODME' => 'E',
	'MODMO' => 'E',
	'MODNI' => 'E',
	'MOGAD' => 'E',
	'MOGIM' => 'E',
	'MOGIN' => 'E',
	'MOGTO' => 'E',
	'MOGWO' => 'E',
	'MOLAE' => 'E',
	'MOLAN' => 'E',
	'MOLAT' => 'E',
	'MOLBO' => 'E',
	'MOLCA' => 'E',
	'MOLHO' => 'E',
	'MOLMO' => 'E',
	'MOLOC' => 'E',
	'MOLOR' => 'E',
	'MOLRU' => 'E',
	'MOLVE' => 'E',
	'MOMBA' => 'E',
	'MOMCH' => 'E',
	'MOMCO' => 'E',
	'MOMEN' => 'E',
	'MOMME' => 'E',
	'MOMMO' => 'E',
	'MOMRE' => 'E',
	'MONAD' => 'E',
	'MONAG' => 'E',
	'MONAL' => 'E',
	'MONAN' => 'E',
	'MONAR' => 'E',
	'MONAX' => 'E',
	'MONBE' => 'E',
	'MONBR' => 'E',
	'MONBV' => 'E',
	'MONCA' => 'E',
	'MONCO' => 'E',
	'MONDI' => 'E',
	'MONDO' => 'E',
	'MONEF' => 'E',
	'MONEM' => 'E',
	'MONEX' => 'E',
	'MONFI' => 'E',
	'MONFO' => 'E',
	'MONFR' => 'E',
	'MONGR' => 'E',
	'MONKU' => 'E',
	'MONMI' => 'E',
	'MONMN' => 'E',
	'MONMO' => 'E',
	'MONNI' => 'E',
	'MONPA' => 'E',
	'MONPL' => 'E',
	'MONPV' => 'V',
	'MONRE' => 'E',
	'MONRV' => 'E',
	'MONSC' => 'E',
	'MONSK' => 'E',
	'MONSO' => 'E',
	'MONSP' => 'E',
	'MONTH' => 'E',
	'MONUN' => 'E',
	'MOOTA' => 'B',
	'MOOTH' => 'B',
	'MOPEI' => 'V',
	'MORAB' => 'B',
	'MORAE' => 'E',
	'MORAL' => 'E',
	'MORAM' => 'E',
	'MORAP' => 'E',
	'MORAR' => 'E',
	'MORBA' => 'E',
	'MORBE' => 'E',
	'MORBL' => 'E',
	'MORBO' => 'B',
	'MORCA' => 'B',
	'MORCH' => 'E',
	'MORCI' => 'E',
	'MORCP' => 'E',
	'MORCS' => 'E',
	'MORIN' => 'E',
	'MORIS' => 'E',
	'MORJA' => 'B',
	'MORKA' => 'E',
	'MORLA' => 'B',
	'MORLO' => 'E',
	'MORME' => 'E',
	'MORMO' => 'B',
	'MORMR' => 'E',
	'MORNO' => 'B',
	'MOROL' => 'E',
	'MORPE' => 'E',
	'MORPR' => 'B',
	'MORPT' => 'E',
	'MORRU' => 'E',
	'MORS1' => 'B',
	'MORS2' => 'B',
	'MORS3' => 'B',
	'MORS5' => 'B',
	'MORSA' => 'E',
	'MORSB' => 'B',
	'MORSC' => 'B',
	'MORSE' => 'B',
	'MORSP' => 'B',
	'MORST' => 'E',
	'MORVI' => 'E',
	'MOSBE' => 'E',
	'MOSCH' => 'E',
	'MOSFU' => 'E',
	'MOSJA' => 'E',
	'MOSLE' => 'E',
	'MOSMO' => 'E',
	'MOTAG' => 'E',
	'MOTAL' => 'E',
	'MOTCA' => 'E',
	'MOTCI' => 'E',
	'MOTCL' => 'E',
	'MOTCT' => 'E',
	'MOTFL' => 'E',
	'MOTLU' => 'E',
	'MOTMA' => 'E',
	'MOUSC' => 'E',
	'MOUSE' => 'E',
	'MPLV' => 'V',
	'MPMV' => 'V',
	'MPV15' => 'V',
	'MRDV' => 'V',
	'MRNV' => 'V',
	'MSEPV' => 'V',
	'MSTV' => 'V',
	'MSV' => 'V',
	'MSV36' => 'V',
	'MSVFB' => 'V',
	'MSVFR' => 'V',
	'MSVHA' => 'V',
	'MSVK' => 'V',
	'MSVKI' => 'V',
	'MSVMH' => 'V',
	'MSVMM' => 'V',
	'MSVMO' => 'V',
	'MSVMT' => 'V',
	'MSVN' => 'V',
	'MSVNS' => 'V',
	'MSVS' => 'V',
	'MSVTS' => 'V',
	'MUCCI' => 'E',
	'MUCDE' => 'E',
	'MUCHA' => 'E',
	'MUCJA' => 'E',
	'MUCMU' => 'E',
	'MUCRO' => 'E',
	'MUGCA' => 'E',
	'MUGCE' => 'E',
	'MUICL' => 'E',
	'MUICO' => 'E',
	'MUIMA' => 'E',
	'MUITR' => 'E',
	'MULSU' => 'E',
	'MUMIM' => 'V',
	'MUMIV' => 'V',
	'MUMP1' => 'V',
	'MUMP2' => 'V',
	'MUMP4' => 'V',
	'MUMP6' => 'V',
	'MUMPA' => 'V',
	'MUMPB' => 'V',
	'MUMPE' => 'V',
	'MUMPJ' => 'V',
	'MUMPK' => 'V',
	'MUMPL' => 'V',
	'MUMPM' => 'V',
	'MUMPR' => 'V',
	'MUMPS' => 'V',
	'MUMPT' => 'V',
	'MUMPU' => 'V',
	'MUNCR' => 'E',
	'MUNDE' => 'E',
	'MUNFE' => 'E',
	'MUNGO' => 'E',
	'MUNMN' => 'E',
	'MUNMU' => 'E',
	'MUNRE' => 'E',
	'MUNVU' => 'E',
	'MURBR' => 'E',
	'MURCI' => 'E',
	'MURCY' => 'E',
	'MURFL' => 'E',
	'MURHE' => 'E',
	'MURLE' => 'E',
	'MURLO' => 'E',
	'MURRO' => 'E',
	'MURSU' => 'E',
	'MUSAC' => 'E',
	'MUSAL' => 'E',
	'MUSAN' => 'E',
	'MUSAR' => 'E',
	'MUSAU' => 'E',
	'MUSAV' => 'E',
	'MUSBA' => 'E',
	'MUSBE' => 'E',
	'MUSBN' => 'E',
	'MUSBO' => 'E',
	'MUSCA' => 'E',
	'MUSCE' => 'E',
	'MUSCM' => 'E',
	'MUSCO' => 'E',
	'MUSCR' => 'E',
	'MUSDO' => 'E',
	'MUSDU' => 'E',
	'MUSER' => 'E',
	'MUSEV' => 'E',
	'MUSFR' => 'E',
	'MUSGR' => 'E',
	'MUSHA' => 'E',
	'MUSIT' => 'E',
	'MUSKA' => 'E',
	'MUSLA' => 'E',
	'MUSLU' => 'E',
	'MUSMA' => 'E',
	'MUSMB' => 'E',
	'MUSMC' => 'E',
	'MUSMI' => 'E',
	'MUSMM' => 'E',
	'MUSNA' => 'E',
	'MUSNE' => 'E',
	'MUSNI' => 'E',
	'MUSOR' => 'E',
	'MUSPA' => 'E',
	'MUSPF' => 'E',
	'MUSPL' => 'E',
	'MUSPO' => 'E',
	'MUSPR' => 'E',
	'MUSPU' => 'E',
	'MUSSA' => 'E',
	'MUSSB' => 'E',
	'MUSSI' => 'E',
	'MUSSP' => 'E',
	'MUSST' => 'E',
	'MUSTE' => 'E',
	'MUSVI' => 'E',
	'MUSVO' => 'E',
	'MUTAC' => 'E',
	'MVDV' => 'V',
	'MVEV5' => 'V',
	'MWLMV' => 'V',
	'MYAAR' => 'E',
	'MYCAA' => 'B',
	'MYCAB' => 'B',
	'MYCAG' => 'B',
	'MYCAM' => 'E',
	'MYCAR' => 'B',
	'MYCAS' => 'B',
	'MYCAT' => 'B',
	'MYCAU' => 'B',
	'MYCAV' => 'B',
	'MYCBO' => 'B',
	'MYCBV' => 'B',
	'MYCCA' => 'B',
	'MYCCC' => 'B',
	'MYCCE' => 'B',
	'MYCCH' => 'B',
	'MYCCI' => 'B',
	'MYCCT' => 'B',
	'MYCDI' => 'B',
	'MYCFA' => 'B',
	'MYCFE' => 'B',
	'MYCFL' => 'B',
	'MYCFO' => 'B',
	'MYCFV' => 'B',
	'MYCGA' => 'B',
	'MYCGE' => 'B',
	'MYCGN' => 'B',
	'MYCGO' => 'B',
	'MYCGR' => 'E',
	'MYCGS' => 'B',
	'MYCH2' => 'B',
	'MYCH7' => 'B',
	'MYCHA' => 'B',
	'MYCHJ' => 'B',
	'MYCHO' => 'B',
	'MYCHR' => 'B',
	'MYCHY' => 'B',
	'MYCIN' => 'B',
	'MYCIO' => 'B',
	'MYCIT' => 'B',
	'MYCKA' => 'B',
	'MYCLE' => 'B',
	'MYCLP' => 'B',
	'MYCMA' => 'B',
	'MYCMC' => 'B',
	'MYCML' => 'B',
	'MYCMO' => 'B',
	'MYCMR' => 'B',
	'MYCMS' => 'B',
	'MYCMY' => 'B',
	'MYCNE' => 'B',
	'MYCNO' => 'B',
	'MYCPA' => 'B',
	'MYCPE' => 'B',
	'MYCPF' => 'B',
	'MYCPH' => 'B',
	'MYCPI' => 'B',
	'MYCPJ' => 'E',
	'MYCPN' => 'B',
	'MYCPO' => 'E',
	'MYCPR' => 'B',
	'MYCPU' => 'B',
	'MYCPV' => 'B',
	'MYCRA' => 'B',
	'MYCRH' => 'B',
	'MYCS5' => 'B',
	'MYCSA' => 'B',
	'MYCSC' => 'B',
	'MYCSH' => 'B',
	'MYCSM' => 'B',
	'MYCSP' => 'B',
	'MYCSS' => 'B',
	'MYCSX' => 'B',
	'MYCSY' => 'B',
	'MYCSZ' => 'B',
	'MYCTH' => 'B',
	'MYCTU' => 'B',
	'MYCUL' => 'B',
	'MYCVA' => 'B',
	'MYCVI' => 'E',
	'MYCVN' => 'B',
	'MYCXE' => 'B',
	'MYLDA' => 'E',
	'MYLPI' => 'E',
	'MYOAC' => 'E',
	'MYOAD' => 'E',
	'MYOAE' => 'E',
	'MYOAL' => 'E',
	'MYOAN' => 'E',
	'MYOAO' => 'E',
	'MYOAR' => 'E',
	'MYOAS' => 'E',
	'MYOBA' => 'E',
	'MYOBC' => 'E',
	'MYOBE' => 'E',
	'MYOBI' => 'E',
	'MYOBL' => 'E',
	'MYOBO' => 'E',
	'MYOBR' => 'E',
	'MYOCA' => 'E',
	'MYOCH' => 'E',
	'MYOCO' => 'E',
	'MYODA' => 'E',
	'MYODO' => 'E',
	'MYODS' => 'E',
	'MYODY' => 'E',
	'MYOEM' => 'E',
	'MYOEV' => 'E',
	'MYOFO' => 'E',
	'MYOFR' => 'E',
	'MYOGL' => 'E',
	'MYOGO' => 'E',
	'MYOHA' => 'E',
	'MYOHO' => 'E',
	'MYOKE' => 'E',
	'MYOKI' => 'E',
	'MYOLE' => 'E',
	'MYOLS' => 'E',
	'MYOLU' => 'E',
	'MYOLV' => 'E',
	'MYOMA' => 'E',
	'MYOMC' => 'E',
	'MYOME' => 'E',
	'MYOMO' => 'E',
	'MYOMS' => 'E',
	'MYOMY' => 'E',
	'MYONA' => 'E',
	'MYONI' => 'E',
	'MYOOC' => 'E',
	'MYOOX' => 'E',
	'MYOPA' => 'E',
	'MYOPR' => 'E',
	'MYOPS' => 'E',
	'MYORE' => 'E',
	'MYORI' => 'E',
	'MYORP' => 'E',
	'MYORU' => 'E',
	'MYOSA' => 'E',
	'MYOSC' => 'E',
	'MYOSE' => 'E',
	'MYOSH' => 'E',
	'MYOSI' => 'E',
	'MYOSO' => 'E',
	'MYOTH' => 'E',
	'MYOTO' => 'E',
	'MYOTR' => 'E',
	'MYOVE' => 'E',
	'MYOVI' => 'E',
	'MYOVO' => 'E',
	'MYOWA' => 'E',
	'MYOWE' => 'E',
	'MYOYA' => 'E',
	'MYOYU' => 'E',
	'MYRAX' => 'E',
	'MYRBA' => 'E',
	'MYRBE' => 'E',
	'MYRBR' => 'E',
	'MYRCE' => 'E',
	'MYRCR' => 'E',
	'MYRFA' => 'E',
	'MYRFG' => 'E',
	'MYRFO' => 'E',
	'MYRFR' => 'E',
	'MYRFU' => 'E',
	'MYRGU' => 'E',
	'MYRHA' => 'E',
	'MYRLE' => 'E',
	'MYRLO' => 'E',
	'MYRNI' => 'E',
	'MYRPA' => 'E',
	'MYRPC' => 'E',
	'MYRPI' => 'E',
	'MYRPY' => 'E',
	'MYRRO' => 'E',
	'MYRRU' => 'E',
	'MYRTR' => 'E',
	'MYRVE' => 'E',
	'MYRVI' => 'E',
	'MYSAL' => 'E',
	'MYSTU' => 'E',
	'MYTCA' => 'E',
	'MYTCH' => 'E',
	'MYTCO' => 'E',
	'MYTED' => 'E',
	'MYTGA' => 'E',
	'MYTTR' => 'E',
	'MYXAS' => 'E',
	'MYXCO' => 'B',
	'MYXFU' => 'B',
	'MYXGL' => 'E',
	'MYXVL' => 'V',
	'MYXVT' => 'V',
	'MYXVU' => 'V',
	'MYXXA' => 'B',
	'MYXXD' => 'B',
	'MYZAU' => 'E',
	'MYZPE' => 'E',
	'NAECA' => 'E',
	'NAEFO' => 'E',
	'NAEGR' => 'E',
	'NAELO' => 'E',
	'NAJAT' => 'E',
	'NAJHA' => 'E',
	'NAJHC' => 'E',
	'NAJHH' => 'E',
	'NAJKA' => 'E',
	'NAJME' => 'E',
	'NAJMO' => 'E',
	'NAJNA' => 'E',
	'NAJNG' => 'E',
	'NAJNI' => 'E',
	'NAJOX' => 'E',
	'NAJPA' => 'E',
	'NAJPH' => 'E',
	'NAJSA' => 'E',
	'NAJSG' => 'E',
	'NAJSP' => 'E',
	'NANAN' => 'E',
	'NANAT' => 'E',
	'NANBA' => 'E',
	'NANBI' => 'E',
	'NANDO' => 'E',
	'NANEQ' => 'A',
	'NAPIN' => 'E',
	'NARAN' => 'E',
	'NARBU' => 'E',
	'NAREL' => 'E',
	'NARJA' => 'E',
	'NARJO' => 'E',
	'NARNO' => 'E',
	'NAROD' => 'E',
	'NARPA' => 'E',
	'NARPS' => 'E',
	'NARST' => 'E',
	'NARTA' => 'E',
	'NASLA' => 'E',
	'NASMU' => 'E',
	'NASNA' => 'E',
	'NASOF' => 'E',
	'NASRE' => 'E',
	'NASVI' => 'E',
	'NATJA' => 'E',
	'NATMA' => 'A',
	'NATMI' => 'E',
	'NATMJ' => 'E',
	'NATMU' => 'E',
	'NATNA' => 'E',
	'NATPD' => 'B',
	'NATPH' => 'A',
	'NATST' => 'E',
	'NATTE' => 'E',
	'NATTU' => 'E',
	'NATVU' => 'A',
	'NAUCI' => 'E',
	'NAUOR' => 'E',
	'NCDV' => 'V',
	'NDVA' => 'V',
	'NDVAF' => 'V',
	'NDVB' => 'V',
	'NDVC' => 'V',
	'NDVD' => 'V',
	'NDVH3' => 'V',
	'NDVH4' => 'V',
	'NDVI' => 'V',
	'NDVJ' => 'V',
	'NDVK' => 'V',
	'NDVL' => 'V',
	'NDVM' => 'V',
	'NDVQ' => 'V',
	'NDVT' => 'V',
	'NDVTG' => 'V',
	'NDVU' => 'V',
	'NDVU2' => 'V',
	'NECAM' => 'E',
	'NECCR' => 'E',
	'NECEL' => 'E',
	'NECHA' => 'E',
	'NECHY' => 'E',
	'NECLU' => 'E',
	'NECMA' => 'E',
	'NECMO' => 'E',
	'NECOC' => 'E',
	'NECPU' => 'E',
	'NEGBR' => 'E',
	'NEIAN' => 'B',
	'NEICI' => 'B',
	'NEIDE' => 'B',
	'NEIEG' => 'B',
	'NEIEL' => 'B',
	'NEIFL' => 'B',
	'NEIFV' => 'B',
	'NEIG1' => 'B',
	'NEIGO' => 'B',
	'NEILA' => 'B',
	'NEIMA' => 'B',
	'NEIMB' => 'B',
	'NEIMC' => 'B',
	'NEIME' => 'B',
	'NEIMU' => 'B',
	'NEIPE' => 'B',
	'NEIPH' => 'B',
	'NEIPO' => 'B',
	'NEISI' => 'B',
	'NEISU' => 'B',
	'NELBR' => 'E',
	'NELCA' => 'E',
	'NELLU' => 'E',
	'NELNE' => 'E',
	'NELNU' => 'E',
	'NEMAL' => 'E',
	'NEMGO' => 'E',
	'NEMMA' => 'E',
	'NEMME' => 'E',
	'NEMMU' => 'E',
	'NEOAL' => 'E',
	'NEOAN' => 'E',
	'NEOAO' => 'E',
	'NEOAQ' => 'E',
	'NEOAR' => 'E',
	'NEOAS' => 'E',
	'NEOAU' => 'E',
	'NEOBR' => 'E',
	'NEOCA' => 'E',
	'NEOCI' => 'E',
	'NEOCY' => 'E',
	'NEOEL' => 'E',
	'NEOFL' => 'E',
	'NEOFO' => 'E',
	'NEOFR' => 'E',
	'NEOFS' => 'E',
	'NEOFU' => 'E',
	'NEOHU' => 'E',
	'NEOJU' => 'E',
	'NEOLE' => 'E',
	'NEOLO' => 'E',
	'NEOME' => 'E',
	'NEOMI' => 'E',
	'NEOML' => 'E',
	'NEOMO' => 'E',
	'NEONE' => 'E',
	'NEONU' => 'E',
	'NEOPA' => 'E',
	'NEOPH' => 'E',
	'NEORH' => 'E',
	'NEORO' => 'E',
	'NEOSA' => 'E',
	'NEOSM' => 'B',
	'NEOSP' => 'E',
	'NEOTE' => 'E',
	'NEOUN' => 'E',
	'NEPAL' => 'E',
	'NEPAN' => 'E',
	'NEPCA' => 'E',
	'NEPCL' => 'E',
	'NEPCV' => 'E',
	'NEPDI' => 'E',
	'NEPEX' => 'E',
	'NEPFA' => 'E',
	'NEPFE' => 'E',
	'NEPGR' => 'E',
	'NEPMA' => 'E',
	'NEPMI' => 'E',
	'NEPNO' => 'E',
	'NEPOL' => 'E',
	'NEPRA' => 'E',
	'NEPTU' => 'E',
	'NERBO' => 'E',
	'NERDI' => 'E',
	'NEROL' => 'E',
	'NERRA' => 'E',
	'NERVI' => 'E',
	'NESAU' => 'E',
	'NESNI' => 'E',
	'NETPU' => 'E',
	'NETRU' => 'E',
	'NEUAF' => 'E',
	'NEUCR' => 'E',
	'NEUGI' => 'E',
	'NEUIN' => 'E',
	'NEULO' => 'E',
	'NEUMU' => 'E',
	'NEUSI' => 'E',
	'NEUTE' => 'E',
	'NEUTT' => 'E',
	'NICAC' => 'E',
	'NICAL' => 'E',
	'NICBE' => 'E',
	'NICBI' => 'E',
	'NICCL' => 'E',
	'NICDE' => 'E',
	'NICGL' => 'E',
	'NICGU' => 'E',
	'NICLS' => 'E',
	'NICOR' => 'E',
	'NICOT' => 'E',
	'NICPA' => 'E',
	'NICPH' => 'E',
	'NICPL' => 'E',
	'NICRU' => 'E',
	'NICSP' => 'E',
	'NICSY' => 'E',
	'NICTM' => 'E',
	'NICTO' => 'E',
	'NIGDA' => 'E',
	'NIGSP' => 'V',
	'NILLU' => 'E',
	'NINCO' => 'E',
	'NINNA' => 'E',
	'NINNO' => 'E',
	'NINPH' => 'E',
	'NINRI' => 'E',
	'NINRU' => 'E',
	'NINSC' => 'E',
	'NINSQ' => 'E',
	'NINST' => 'E',
	'NINTI' => 'E',
	'NINYV' => 'E',
	'NIPAV' => 'V',
	'NIPBR' => 'E',
	'NIPNI' => 'E',
	'NITAL' => 'E',
	'NITEU' => 'B',
	'NITFL' => 'E',
	'NITHA' => 'B',
	'NITHX' => 'B',
	'NITMU' => 'B',
	'NITOC' => 'B',
	'NITS1' => 'B',
	'NITS4' => 'B',
	'NITST' => 'B',
	'NITVU' => 'B',
	'NITWI' => 'B',
	'NITWN' => 'B',
	'NIVCR' => 'E',
	'NIVCU' => 'E',
	'NMV' => 'V',
	'NOCAE' => 'B',
	'NOCAL' => 'E',
	'NOCAS' => 'B',
	'NOCDA' => 'B',
	'NOCFA' => 'B',
	'NOCGL' => 'B',
	'NOCLA' => 'B',
	'NOCLE' => 'E',
	'NOCSI' => 'B',
	'NOCSK' => 'B',
	'NOCSP' => 'B',
	'NODAV' => 'V',
	'NODSP' => 'B',
	'NOEBA' => 'E',
	'NOEOL' => 'E',
	'NOEPO' => 'E',
	'NOLHU' => 'E',
	'NOLSP' => 'E',
	'NOMGA' => 'E',
	'NORMA' => 'E',
	'NOSCO' => 'B',
	'NOSEL' => 'B',
	'NOSLI' => 'B',
	'NOSMU' => 'B',
	'NOSPU' => 'B',
	'NOSS6' => 'B',
	'NOSS7' => 'B',
	'NOSS8' => 'B',
	'NOSS9' => 'B',
	'NOSSM' => 'B',
	'NOSSN' => 'B',
	'NOSSP' => 'B',
	'NOTAH' => 'E',
	'NOTAL' => 'E',
	'NOTAN' => 'E',
	'NOTAT' => 'E',
	'NOTBI' => 'E',
	'NOTCA' => 'E',
	'NOTCC' => 'E',
	'NOTCH' => 'E',
	'NOTCI' => 'E',
	'NOTCO' => 'E',
	'NOTCU' => 'E',
	'NOTDE' => 'E',
	'NOTED' => 'E',
	'NOTFE' => 'E',
	'NOTGO' => 'E',
	'NOTGY' => 'E',
	'NOTMA' => 'E',
	'NOTPE' => 'E',
	'NOTSC' => 'E',
	'NOTSH' => 'E',
	'NOTST' => 'E',
	'NOTSU' => 'E',
	'NOTSY' => 'E',
	'NOTTY' => 'E',
	'NOTVI' => 'E',
	'NOVAD' => 'B',
	'NPVAC' => 'V',
	'NPVAG' => 'V',
	'NPVAH' => 'V',
	'NPVAP' => 'V',
	'NPVAS' => 'V',
	'NPVBM' => 'V',
	'NPVBS' => 'V',
	'NPVCD' => 'V',
	'NPVCF' => 'V',
	'NPVEP' => 'V',
	'NPVGM' => 'V',
	'NPVHC' => 'V',
	'NPVHZ' => 'V',
	'NPVLD' => 'V',
	'NPVLS' => 'V',
	'NPVMB' => 'V',
	'NPVMC' => 'V',
	'NPVMN' => 'V',
	'NPVOP' => 'V',
	'NPVOS' => 'V',
	'NPVPD' => 'V',
	'NPVPF' => 'V',
	'NPVRO' => 'V',
	'NPVSE' => 'V',
	'NPVSF' => 'V',
	'NPVSL' => 'V',
	'NPVST' => 'V',
	'NUCCA' => 'E',
	'NUCEM' => 'E',
	'NUCLA' => 'E',
	'NUCLP' => 'E',
	'NUMME' => 'E',
	'NUPVA' => 'E',
	'NVMV' => 'V',
	'NYCAE' => 'E',
	'NYCAL' => 'E',
	'NYCAR' => 'E',
	'NYCAU' => 'E',
	'NYCBE' => 'E',
	'NYCCE' => 'E',
	'NYCCO' => 'E',
	'NYCCR' => 'E',
	'NYCHU' => 'E',
	'NYCLA' => 'E',
	'NYCLE' => 'E',
	'NYCLS' => 'E',
	'NYCMA' => 'E',
	'NYCMC' => 'E',
	'NYCNO' => 'E',
	'NYCNY' => 'E',
	'NYCOV' => 'E',
	'NYCPR' => 'E',
	'NYCPY' => 'E',
	'NYCRO' => 'E',
	'NYCSC' => 'E',
	'NYCSU' => 'E',
	'NYCTH' => 'E',
	'NYCVE' => 'E',
	'NYCVI' => 'E',
	'NYCVZ' => 'E',
	'NYMAL' => 'E',
	'NYMAN' => 'E',
	'NYMCA' => 'E',
	'NYMHO' => 'E',
	'NYMOD' => 'E',
	'NYPFR' => 'E',
	'NYSOG' => 'E',
	'NYV' => 'V',
	'OBEGE' => 'E',
	'OBELO' => 'E',
	'OBLMI' => 'E',
	'OCEFU' => 'E',
	'OCEIH' => 'B',
	'OCELI' => 'B',
	'OCEMA' => 'E',
	'OCEOC' => 'E',
	'OCETE' => 'E',
	'OCETR' => 'E',
	'OCHAE' => 'E',
	'OCHAL' => 'E',
	'OCHAN' => 'B',
	'OCHCO' => 'E',
	'OCHCU' => 'E',
	'OCHDA' => 'E',
	'OCHDN' => 'E',
	'OCHER' => 'E',
	'OCHFO' => 'E',
	'OCHHI' => 'E',
	'OCHHU' => 'E',
	'OCHHY' => 'E',
	'OCHIL' => 'E',
	'OCHIM' => 'E',
	'OCHKO' => 'E',
	'OCHLA' => 'E',
	'OCHNB' => 'E',
	'OCHNE' => 'E',
	'OCHNU' => 'E',
	'OCHPA' => 'E',
	'OCHPR' => 'E',
	'OCHPU' => 'E',
	'OCHPY' => 'E',
	'OCHRO' => 'E',
	'OCHRU' => 'E',
	'OCHSY' => 'E',
	'OCHTH' => 'E',
	'OCHTI' => 'E',
	'OCIBA' => 'E',
	'OCTDE' => 'E',
	'OCTDO' => 'E',
	'OCTGL' => 'E',
	'OCTMI' => 'E',
	'OCTVU' => 'E',
	'ODOAR' => 'E',
	'ODODO' => 'E',
	'ODOHE' => 'E',
	'ODORO' => 'E',
	'ODORR' => 'E',
	'ODOSC' => 'E',
	'ODOSI' => 'E',
	'ODOTA' => 'E',
	'ODOVI' => 'E',
	'OECBI' => 'E',
	'OEDTR' => 'E',
	'OENAM' => 'E',
	'OENAR' => 'E',
	'OENBE' => 'E',
	'OENBI' => 'E',
	'OENDE' => 'E',
	'OENFR' => 'E',
	'OENHO' => 'E',
	'OENHY' => 'E',
	'OENJA' => 'E',
	'OENME' => 'E',
	'OENOD' => 'E',
	'OENOE' => 'B',
	'OENON' => 'E',
	'OENOR' => 'E',
	'OENPI' => 'E',
	'OENPM' => 'E',
	'OENPO' => 'E',
	'OENSA' => 'E',
	'OENSP' => 'E',
	'OENVI' => 'E',
	'OIKDI' => 'E',
	'OIKKI' => 'E',
	'OKAJO' => 'E',
	'OLDAF' => 'E',
	'OLEAN' => 'B',
	'OLEEU' => 'E',
	'OLICA' => 'B',
	'OLILO' => 'E',
	'OLILU' => 'E',
	'OLIMA' => 'E',
	'OLINI' => 'E',
	'OLIOR' => 'E',
	'OLIPU' => 'E',
	'OLISA' => 'E',
	'OLTVI' => 'E',
	'OMMRO' => 'E',
	'OMMSL' => 'E',
	'OMOVI' => 'E',
	'OMPOL' => 'E',
	'OMV' => 'V',
	'OMVVS' => 'V',
	'ONCAM' => 'E',
	'ONCCH' => 'E',
	'ONCCL' => 'E',
	'ONCCO' => 'E',
	'ONCCR' => 'E',
	'ONCDU' => 'E',
	'ONCEX' => 'E',
	'ONCFA' => 'E',
	'ONCFR' => 'E',
	'ONCGE' => 'E',
	'ONCGI' => 'E',
	'ONCGO' => 'E',
	'ONCGU' => 'E',
	'ONCHC' => 'E',
	'ONCIN' => 'E',
	'ONCKE' => 'E',
	'ONCKI' => 'E',
	'ONCMA' => 'E',
	'ONCMU' => 'E',
	'ONCMY' => 'E',
	'ONCNE' => 'E',
	'ONCOC' => 'E',
	'ONCSP' => 'E',
	'ONCTS' => 'E',
	'ONCVE' => 'B',
	'ONCVO' => 'E',
	'ONDZI' => 'E',
	'ONNVG' => 'V',
	'ONNVI' => 'V',
	'ONNVS' => 'V',
	'ONOAC' => 'E',
	'ONOSE' => 'E',
	'ONOSP' => 'E',
	'ONOVI' => 'E',
	'ONYAR' => 'E',
	'ONYJA' => 'E',
	'ONYLE' => 'E',
	'ONYPE' => 'B',
	'ONYUN' => 'E',
	'OOCSP' => 'E',
	'OPHAP' => 'E',
	'OPHAT' => 'E',
	'OPHBI' => 'E',
	'OPHFL' => 'E',
	'OPHGR' => 'E',
	'OPHHA' => 'E',
	'OPHNO' => 'E',
	'OPHPI' => 'E',
	'OPHPO' => 'E',
	'OPHUL' => 'E',
	'OPHVE' => 'E',
	'OPHVN' => 'E',
	'OPICA' => 'E',
	'OPIFE' => 'E',
	'OPIHO' => 'E',
	'OPIMA' => 'E',
	'OPISI' => 'E',
	'OPLCU' => 'E',
	'OPLQU' => 'E',
	'OPOGL' => 'E',
	'OPSTA' => 'E',
	'OPUCA' => 'E',
	'OPUMI' => 'E',
	'OPUQU' => 'E',
	'ORCAU' => 'E',
	'ORCBR' => 'E',
	'ORCCA' => 'E',
	'ORCLI' => 'E',
	'ORCOR' => 'E',
	'ORCSI' => 'E',
	'ORCVI' => 'E',
	'OREAM' => 'E',
	'OREAU' => 'E',
	'OREBA' => 'E',
	'OREBI' => 'E',
	'OREBO' => 'E',
	'ORECA' => 'E',
	'ORECO' => 'E',
	'OREDE' => 'E',
	'OREEL' => 'E',
	'OREFR' => 'E',
	'OREGL' => 'E',
	'ORELE' => 'E',
	'OREMA' => 'E',
	'OREMO' => 'E',
	'ORENI' => 'E',
	'ORENO' => 'E',
	'OREOR' => 'E',
	'OREPI' => 'E',
	'ORERU' => 'E',
	'ORESE' => 'E',
	'ORESP' => 'E',
	'OREVI' => 'E',
	'OREVR' => 'E',
	'ORFN2' => 'V',
	'ORFN7' => 'V',
	'ORGLE' => 'E',
	'ORGPS' => 'E',
	'ORIAU' => 'E',
	'ORILA' => 'E',
	'ORILE' => 'E',
	'ORIOR' => 'E',
	'ORIVU' => 'E',
	'ORIXA' => 'E',
	'ORNAN' => 'E',
	'ORNBR' => 'E',
	'ORNCA' => 'E',
	'ORNHU' => 'E',
	'ORNJU' => 'E',
	'ORNKO' => 'E',
	'ORNMO' => 'E',
	'ORNPA' => 'E',
	'ORNUM' => 'E',
	'OROAQ' => 'E',
	'OROFA' => 'E',
	'OROIN' => 'E',
	'OROMI' => 'E',
	'ORPSP' => 'E',
	'ORSVC' => 'V',
	'ORSVJ' => 'V',
	'ORSVS' => 'V',
	'ORSVW' => 'V',
	'ORTCH' => 'E',
	'ORTCR' => 'E',
	'ORTFE' => 'E',
	'ORTGR' => 'E',
	'ORTHB' => 'E',
	'ORTHE' => 'E',
	'ORTHI' => 'E',
	'ORTSC' => 'E',
	'ORTSP' => 'E',
	'ORTUN' => 'E',
	'ORTVE' => 'E',
	'ORYAF' => 'E',
	'ORYAL' => 'E',
	'ORYCO' => 'E',
	'ORYCU' => 'E',
	'ORYDA' => 'E',
	'ORYGA' => 'E',
	'ORYGL' => 'E',
	'ORYGR' => 'E',
	'ORYJA' => 'E',
	'ORYLA' => 'E',
	'ORYLE' => 'E',
	'ORYLO' => 'E',
	'ORYLU' => 'E',
	'ORYME' => 'E',
	'ORYNI' => 'E',
	'ORYPA' => 'E',
	'ORYPU' => 'E',
	'ORYRH' => 'E',
	'ORYRU' => 'E',
	'ORYSA' => 'E',
	'ORYSU' => 'E',
	'ORYTA' => 'E',
	'ORYVI' => 'E',
	'OSCAG' => 'B',
	'OSCBR' => 'E',
	'OSEMU' => 'E',
	'OSGBA' => 'E',
	'OSMCI' => 'E',
	'OSMCL' => 'E',
	'OSMLO' => 'E',
	'OSMMO' => 'E',
	'OSMRE' => 'E',
	'OSMTE' => 'E',
	'OSTED' => 'E',
	'OSTNU' => 'E',
	'OSTOS' => 'E',
	'OSTTA' => 'E',
	'OSTTE' => 'E',
	'OSTVI' => 'E',
	'OTAAC' => 'E',
	'OTABY' => 'E',
	'OTACA' => 'E',
	'OTESC' => 'E',
	'OTHCA' => 'E',
	'OTHSI' => 'E',
	'OTISI' => 'E',
	'OTITA' => 'E',
	'OTOGA' => 'E',
	'OTOHE' => 'E',
	'OTOIR' => 'E',
	'OTOMA' => 'E',
	'OTOME' => 'E',
	'OTOMR' => 'E',
	'OTUAL' => 'E',
	'OTUAS' => 'E',
	'OTUAT' => 'E',
	'OTUBA' => 'E',
	'OTUBR' => 'E',
	'OTUCH' => 'E',
	'OTUFL' => 'E',
	'OTUGU' => 'E',
	'OTUHO' => 'E',
	'OTUKE' => 'E',
	'OTULE' => 'E',
	'OTULM' => 'E',
	'OTULO' => 'E',
	'OTULT' => 'E',
	'OTUME' => 'E',
	'OTUPE' => 'E',
	'OTURO' => 'E',
	'OTUSA' => 'E',
	'OTUSC' => 'E',
	'OTUSP' => 'E',
	'OTUUS' => 'E',
	'OTUWA' => 'E',
	'OULOR' => 'E',
	'OUROU' => 'E',
	'OVIAD' => 'E',
	'OVICA' => 'E',
	'OVIDA' => 'E',
	'OVIMO' => 'E',
	'OVIMU' => 'E',
	'OVIVI' => 'E',
	'OWEFU' => 'E',
	'OXACO' => 'E',
	'OXADI' => 'E',
	'OXAFO' => 'B',
	'OXAME' => 'E',
	'OXARE' => 'E',
	'OXASP' => 'E',
	'OXAST' => 'E',
	'OXATU' => 'E',
	'OXYAE' => 'E',
	'OXYFA' => 'E',
	'OXYGR' => 'E',
	'OXYIH' => 'E',
	'OXYJA' => 'E',
	'OXYKI' => 'E',
	'OXYLE' => 'E',
	'OXYLI' => 'E',
	'OXYMA' => 'E',
	'OXYMI' => 'E',
	'OXYNO' => 'E',
	'OXYPC' => 'E',
	'OXYPI' => 'E',
	'OXYRU' => 'E',
	'OXYSA' => 'E',
	'OXYSB' => 'E',
	'OXYSC' => 'E',
	'OXYSY' => 'E',
	'OXYTR' => 'E',
	'OXYVI' => 'E',
	'OYEVE' => 'E',
	'OYMV' => 'V',
	'P1AMV' => 'V',
	'PACAQ' => 'E',
	'PACAR' => 'E',
	'PACAU' => 'E',
	'PACBR' => 'E',
	'PACCA' => 'E',
	'PACDA' => 'E',
	'PACGO' => 'E',
	'PACLA' => 'E',
	'PACLE' => 'E',
	'PACLO' => 'E',
	'PACMA' => 'E',
	'PACMO' => 'E',
	'PACMR' => 'E',
	'PACPE' => 'E',
	'PACPR' => 'E',
	'PACSA' => 'E',
	'PACSC' => 'E',
	'PACSO' => 'E',
	'PACTA' => 'E',
	'PACTU' => 'E',
	'PACVE' => 'E',
	'PAEAL' => 'B',
	'PAEAZ' => 'B',
	'PAECA' => 'E',
	'PAELA' => 'B',
	'PAELC' => 'E',
	'PAEMA' => 'B',
	'PAEOF' => 'E',
	'PAEPE' => 'E',
	'PAEPO' => 'B',
	'PAEPP' => 'B',
	'PAERU' => 'E',
	'PAESC' => 'E',
	'PAESI' => 'E',
	'PAESU' => 'E',
	'PAETE' => 'E',
	'PAETN' => 'E',
	'PAEVA' => 'E',
	'PAGBE' => 'E',
	'PAGBO' => 'E',
	'PAGLA' => 'E',
	'PAGLO' => 'E',
	'PAGMA' => 'E',
	'PAGPA' => 'E',
	'PALAR' => 'E',
	'PALCO' => 'E',
	'PALDO' => 'E',
	'PALPA' => 'E',
	'PALPL' => 'E',
	'PALPR' => 'E',
	'PALVE' => 'E',
	'PALVU' => 'E',
	'PAMV' => 'V',
	'PANAL' => 'E',
	'PANAN' => 'B',
	'PANAR' => 'E',
	'PANAY' => 'B',
	'PANBA' => 'E',
	'PANBI' => 'E',
	'PANBO' => 'E',
	'PANBU' => 'E',
	'PANCA' => 'E',
	'PANCG' => 'E',
	'PANCI' => 'B',
	'PANCO' => 'E',
	'PANFL' => 'E',
	'PANGG' => 'E',
	'PANGI' => 'E',
	'PANHA' => 'E',
	'PANHE' => 'E',
	'PANHO' => 'E',
	'PANIM' => 'E',
	'PANIN' => 'E',
	'PANJA' => 'E',
	'PANJS' => 'E',
	'PANLE' => 'E',
	'PANMI' => 'E',
	'PANMO' => 'E',
	'PANOB' => 'E',
	'PANON' => 'E',
	'PANOS' => 'E',
	'PANPA' => 'E',
	'PANPG' => 'E',
	'PANPO' => 'E',
	'PANPR' => 'E',
	'PANPS' => 'E',
	'PANQU' => 'E',
	'PANRE' => 'E',
	'PANRP' => 'E',
	'PANST' => 'E',
	'PANTA' => 'E',
	'PANTH' => 'B',
	'PANTI' => 'E',
	'PANTR' => 'E',
	'PANTS' => 'E',
	'PANTT' => 'E',
	'PANVE' => 'E',
	'PANVI' => 'E',
	'PANVR' => 'E',
	'PAOEX' => 'E',
	'PAOMY' => 'E',
	'PAPAB' => 'E',
	'PAPAN' => 'E',
	'PAPBE' => 'E',
	'PAPBR' => 'E',
	'PAPBU' => 'E',
	'PAPCA' => 'E',
	'PAPCL' => 'E',
	'PAPCR' => 'E',
	'PAPCY' => 'E',
	'PAPDA' => 'E',
	'PAPDE' => 'E',
	'PAPGL' => 'E',
	'PAPHA' => 'E',
	'PAPHU' => 'E',
	'PAPME' => 'E',
	'PAPNU' => 'E',
	'PAPOR' => 'E',
	'PAPPA' => 'E',
	'PAPPO' => 'E',
	'PAPSO' => 'E',
	'PAPSP' => 'E',
	'PAPSU' => 'E',
	'PAPTR' => 'E',
	'PAPVD' => 'V',
	'PAPVE' => 'V',
	'PAPVR' => 'V',
	'PAPZE' => 'E',
	'PARAC' => 'E',
	'PARAD' => 'E',
	'PARAI' => 'E',
	'PARAL' => 'E',
	'PARAM' => 'E',
	'PARAN' => 'E',
	'PARAO' => 'E',
	'PARAP' => 'E',
	'PARAR' => 'E',
	'PARAT' => 'E',
	'PARAU' => 'E',
	'PARAX' => 'E',
	'PARBE' => 'E',
	'PARBI' => 'E',
	'PARBR' => 'E',
	'PARBU' => 'E',
	'PARCA' => 'E',
	'PARCE' => 'E',
	'PARCH' => 'E',
	'PARCI' => 'E',
	'PARCL' => 'E',
	'PARCM' => 'E',
	'PARCO' => 'E',
	'PARCP' => 'E',
	'PARCR' => 'E',
	'PARCT' => 'E',
	'PARCU' => 'E',
	'PARCV' => 'E',
	'PARDA' => 'E',
	'PARDE' => 'B',
	'PARDN' => 'B',
	'PARDR' => 'E',
	'PAREP' => 'E',
	'PARFI' => 'E',
	'PARFO' => 'E',
	'PARGA' => 'E',
	'PARGR' => 'E',
	'PARGU' => 'E',
	'PARHA' => 'B',
	'PARHE' => 'E',
	'PARHY' => 'E',
	'PARID' => 'E',
	'PARIN' => 'E',
	'PARJU' => 'E',
	'PARKN' => 'E',
	'PARLI' => 'E',
	'PARLO' => 'E',
	'PARLU' => 'E',
	'PARMA' => 'E',
	'PARMG' => 'E',
	'PARMI' => 'E',
	'PARMJ' => 'E',
	'PARML' => 'E',
	'PARMT' => 'E',
	'PARMU' => 'E',
	'PAROC' => 'E',
	'PAROL' => 'E',
	'PARPA' => 'E',
	'PARPC' => 'E',
	'PARPH' => 'E',
	'PARPL' => 'E',
	'PARPN' => 'B',
	'PARPO' => 'E',
	'PARPR' => 'E',
	'PARPV' => 'E',
	'PARRA' => 'E',
	'PARRB' => 'E',
	'PARRI' => 'E',
	'PARRP' => 'E',
	'PARRU' => 'E',
	'PARS1' => 'B',
	'PARSC' => 'E',
	'PARSN' => 'B',
	'PARSP' => 'B',
	'PARSR' => 'E',
	'PARST' => 'E',
	'PARTA' => 'E',
	'PARTE' => 'E',
	'PARTH' => 'E',
	'PARTI' => 'E',
	'PARTN' => 'E',
	'PARTR' => 'E',
	'PARTT' => 'E',
	'PARUN' => 'E',
	'PARUW' => 'B',
	'PARVE' => 'B',
	'PARVI' => 'E',
	'PARVX' => 'E',
	'PARWE' => 'E',
	'PARZE' => 'B',
	'PASAA' => 'E',
	'PASAB' => 'E',
	'PASAC' => 'E',
	'PASAD' => 'E',
	'PASAE' => 'B',
	'PASAI' => 'E',
	'PASAL' => 'E',
	'PASAM' => 'E',
	'PASAN' => 'E',
	'PASAO' => 'E',
	'PASAR' => 'E',
	'PASAT' => 'E',
	'PASAU' => 'E',
	'PASAV' => 'B',
	'PASBI' => 'E',
	'PASCA' => 'E',
	'PASCB' => 'E',
	'PASCC' => 'E',
	'PASCD' => 'E',
	'PASCE' => 'E',
	'PASCI' => 'E',
	'PASCN' => 'E',
	'PASCO' => 'E',
	'PASCP' => 'E',
	'PASCR' => 'E',
	'PASCS' => 'E',
	'PASCT' => 'E',
	'PASCY' => 'E',
	'PASDO' => 'E',
	'PASED' => 'E',
	'PASEI' => 'E',
	'PASEM' => 'E',
	'PASEX' => 'E',
	'PASFL' => 'E',
	'PASFO' => 'E',
	'PASGA' => 'B',
	'PASGB' => 'E',
	'PASGC' => 'E',
	'PASGE' => 'E',
	'PASGL' => 'E',
	'PASGR' => 'E',
	'PASGU' => 'E',
	'PASHA' => 'B',
	'PASHB' => 'E',
	'PASHE' => 'E',
	'PASHH' => 'E',
	'PASHI' => 'E',
	'PASHR' => 'E',
	'PASID' => 'E',
	'PASIL' => 'E',
	'PASIN' => 'E',
	'PASJO' => 'E',
	'PASKA' => 'E',
	'PASKE' => 'E',
	'PASKR' => 'E',
	'PASLA' => 'E',
	'PASLI' => 'E',
	'PASLR' => 'E',
	'PASLU' => 'E',
	'PASMA' => 'E',
	'PASMC' => 'E',
	'PASME' => 'E',
	'PASMF' => 'E',
	'PASMI' => 'E',
	'PASML' => 'E',
	'PASMM' => 'E',
	'PASMN' => 'E',
	'PASMO' => 'E',
	'PASMP' => 'E',
	'PASMR' => 'E',
	'PASMS' => 'E',
	'PASMT' => 'E',
	'PASMU' => 'B',
	'PASNE' => 'E',
	'PASNI' => 'E',
	'PASOE' => 'E',
	'PASON' => 'E',
	'PASOR' => 'E',
	'PASPE' => 'B',
	'PASPI' => 'B',
	'PASPL' => 'E',
	'PASPN' => 'E',
	'PASPO' => 'E',
	'PASPR' => 'E',
	'PASPT' => 'E',
	'PASPU' => 'E',
	'PASRA' => 'E',
	'PASRB' => 'E',
	'PASRE' => 'E',
	'PASRI' => 'E',
	'PASRU' => 'E',
	'PASSA' => 'E',
	'PASSB' => 'E',
	'PASSC' => 'E',
	'PASSE' => 'E',
	'PASSG' => 'E',
	'PASSM' => 'E',
	'PASSN' => 'E',
	'PASSP' => 'B',
	'PASSR' => 'E',
	'PASST' => 'E',
	'PASSU' => 'E',
	'PASSX' => 'E',
	'PASTA' => 'E',
	'PASTE' => 'E',
	'PASTF' => 'E',
	'PASTI' => 'E',
	'PASTN' => 'E',
	'PASTR' => 'B',
	'PASTS' => 'E',
	'PASTU' => 'E',
	'PASUM' => 'E',
	'PASVE' => 'E',
	'PASVI' => 'E',
	'PASVK' => 'V',
	'PASVO' => 'B',
	'PASVT' => 'E',
	'PATBR' => 'E',
	'PATCA' => 'E',
	'PATEX' => 'E',
	'PATFR' => 'E',
	'PATGR' => 'E',
	'PATGU' => 'E',
	'PATPS' => 'E',
	'PATRE' => 'E',
	'PATSP' => 'E',
	'PATSQ' => 'E',
	'PATTE' => 'E',
	'PATVI' => 'E',
	'PATVU' => 'E',
	'PATYE' => 'E',
	'PAUKA' => 'E',
	'PAUPA' => 'E',
	'PAUTO' => 'E',
	'PAV' => 'V',
	'PAVBO' => 'V',
	'PAVC' => 'V',
	'PAVC2' => 'V',
	'PAVC7' => 'V',
	'PAVCB' => 'V',
	'PAVCD' => 'V',
	'PAVCN' => 'V',
	'PAVCR' => 'E',
	'PAVHA' => 'E',
	'PAVHB' => 'V',
	'PAVHH' => 'V',
	'PAVL3' => 'V',
	'PAVLU' => 'E',
	'PAVML' => 'E',
	'PAVMU' => 'E',
	'PAVP9' => 'V',
	'PAVPK' => 'V',
	'PAVPN' => 'V',
	'PAXIN' => 'E',
	'PBCV1' => 'V',
	'PBCVC' => 'V',
	'PBCVI' => 'V',
	'PBCVN' => 'V',
	'PBCVX' => 'V',
	'PCPV1' => 'V',
	'PCV1' => 'V',
	'PCV2' => 'V',
	'PEA' => 'E',
	'PEAMV' => 'V',
	'PEBV' => 'V',
	'PECCC' => 'B',
	'PECCY' => 'B',
	'PECEL' => 'E',
	'PECFR' => 'B',
	'PECGO' => 'E',
	'PECGU' => 'E',
	'PECLI' => 'E',
	'PECMA' => 'E',
	'PECPA' => 'E',
	'PECPR' => 'E',
	'PEDAC' => 'B',
	'PEDBO' => 'E',
	'PEDCA' => 'E',
	'PEDDU' => 'E',
	'PEDHE' => 'B',
	'PEDMN' => 'E',
	'PEDPE' => 'B',
	'PEDSP' => 'E',
	'PEDV7' => 'V',
	'PEDVB' => 'V',
	'PEITU' => 'E',
	'PELAC' => 'B',
	'PELAG' => 'E',
	'PELAN' => 'E',
	'PELAR' => 'E',
	'PELCA' => 'B',
	'PELCD' => 'B',
	'PELCP' => 'E',
	'PELFA' => 'E',
	'PELFU' => 'E',
	'PELGA' => 'E',
	'PELGE' => 'E',
	'PELHO' => 'E',
	'PELHU' => 'E',
	'PELJA' => 'E',
	'PELLD' => 'B',
	'PELLU' => 'B',
	'PELMA' => 'E',
	'PELMG' => 'E',
	'PELMT' => 'E',
	'PELNE' => 'E',
	'PELOC' => 'E',
	'PELPL' => 'E',
	'PELPU' => 'E',
	'PELRO' => 'E',
	'PELSH' => 'E',
	'PELSJ' => 'E',
	'PELSU' => 'E',
	'PELUB' => 'B',
	'PELUR' => 'E',
	'PELVI' => 'E',
	'PEMV' => 'V',
	'PEMVC' => 'V',
	'PEMVM' => 'V',
	'PENAG' => 'E',
	'PENAM' => 'E',
	'PENBA' => 'E',
	'PENBB' => 'E',
	'PENBR' => 'E',
	'PENCA' => 'E',
	'PENCH' => 'E',
	'PENCI' => 'E',
	'PENCL' => 'E',
	'PENCY' => 'E',
	'PENDI' => 'E',
	'PENDO' => 'E',
	'PENEC' => 'E',
	'PENEL' => 'E',
	'PENEN' => 'E',
	'PENFN' => 'E',
	'PENFU' => 'E',
	'PENGR' => 'E',
	'PENHE' => 'E',
	'PENIT' => 'E',
	'PENJA' => 'E',
	'PENJC' => 'E',
	'PENJP' => 'E',
	'PENMA' => 'E',
	'PENMI' => 'E',
	'PENMO' => 'E',
	'PENNA' => 'E',
	'PENOL' => 'E',
	'PENPA' => 'E',
	'PENPM' => 'E',
	'PENPU' => 'E',
	'PENPX' => 'E',
	'PENRO' => 'E',
	'PENRU' => 'E',
	'PENSE' => 'E',
	'PENSG' => 'E',
	'PENSI' => 'E',
	'PENSP' => 'E',
	'PENSQ' => 'E',
	'PENSU' => 'E',
	'PENSV' => 'V',
	'PENUR' => 'E',
	'PENVA' => 'E',
	'PENVI' => 'E',
	'PEPAR' => 'E',
	'PEPAS' => 'B',
	'PEPCA' => 'E',
	'PEPGL' => 'B',
	'PEPGR' => 'E',
	'PEPHI' => 'E',
	'PEPMA' => 'B',
	'PEPNI' => 'B',
	'PEPOB' => 'E',
	'PEPPO' => 'E',
	'PEPSE' => 'E',
	'PERAB' => 'E',
	'PERAC' => 'E',
	'PERAE' => 'E',
	'PERAH' => 'E',
	'PERAI' => 'E',
	'PERAL' => 'E',
	'PERAM' => 'E',
	'PERAN' => 'E',
	'PERAP' => 'E',
	'PERAT' => 'E',
	'PERAU' => 'E',
	'PERAV' => 'E',
	'PERBI' => 'E',
	'PERBO' => 'E',
	'PERBR' => 'E',
	'PERCA' => 'E',
	'PERCD' => 'E',
	'PERCN' => 'E',
	'PERCO' => 'E',
	'PERCU' => 'E',
	'PERDA' => 'E',
	'PERER' => 'E',
	'PERFA' => 'E',
	'PERFE' => 'E',
	'PERFL' => 'E',
	'PERFO' => 'E',
	'PERFR' => 'E',
	'PERFS' => 'E',
	'PERFU' => 'E',
	'PERFV' => 'E',
	'PERGA' => 'E',
	'PERGO' => 'E',
	'PERGR' => 'E',
	'PERGU' => 'E',
	'PERIN' => 'E',
	'PERIO' => 'E',
	'PERKA' => 'E',
	'PERKE' => 'E',
	'PERLA' => 'E',
	'PERLE' => 'E',
	'PERLI' => 'E',
	'PERLO' => 'E',
	'PERLT' => 'E',
	'PERMA' => 'E',
	'PERMC' => 'E',
	'PERME' => 'E',
	'PERMI' => 'E',
	'PERMO' => 'E',
	'PERMR' => 'E',
	'PERMS' => 'E',
	'PERMX' => 'E',
	'PERNA' => 'E',
	'PEROL' => 'E',
	'PEROV' => 'E',
	'PERPA' => 'E',
	'PERPE' => 'E',
	'PERPL' => 'E',
	'PERPO' => 'E',
	'PERSE' => 'E',
	'PERSJ' => 'E',
	'PERSL' => 'E',
	'PERSP' => 'E',
	'PERTA' => 'E',
	'PERTR' => 'E',
	'PERTU' => 'E',
	'PERVI' => 'E',
	'PERVR' => 'E',
	'PERVT' => 'E',
	'PERWI' => 'E',
	'PESMI' => 'E',
	'PETAB' => 'E',
	'PETAL' => 'E',
	'PETAS' => 'E',
	'PETBA' => 'E',
	'PETBR' => 'E',
	'PETCE' => 'E',
	'PETCO' => 'E',
	'PETCR' => 'E',
	'PETEL' => 'E',
	'PETFA' => 'E',
	'PETFR' => 'E',
	'PETGO' => 'E',
	'PETHA' => 'E',
	'PETHB' => 'E',
	'PETHE' => 'E',
	'PETHY' => 'E',
	'PETIN' => 'E',
	'PETIO' => 'E',
	'PETJA' => 'E',
	'PETLE' => 'E',
	'PETMA' => 'E',
	'PETMR' => 'E',
	'PETNO' => 'E',
	'PETPA' => 'E',
	'PETPE' => 'E',
	'PETPH' => 'E',
	'PETPR' => 'E',
	'PETPT' => 'E',
	'PETPY' => 'E',
	'PETRA' => 'E',
	'PETSH' => 'E',
	'PETSP' => 'E',
	'PETTE' => 'E',
	'PETTH' => 'E',
	'PETTR' => 'E',
	'PETVE' => 'E',
	'PETXA' => 'E',
	'PETXN' => 'E',
	'PETYU' => 'E',
	'PEUSC' => 'E',
	'PEV9U' => 'V',
	'PEWBP' => 'B',
	'PEZWA' => 'E',
	'PHAAA' => 'E',
	'PHAAC' => 'E',
	'PHAAD' => 'E',
	'PHAAE' => 'E',
	'PHAAF' => 'E',
	'PHAAI' => 'E',
	'PHAAL' => 'E',
	'PHAAN' => 'E',
	'PHAAO' => 'E',
	'PHAAQ' => 'E',
	'PHAAR' => 'E',
	'PHAAS' => 'E',
	'PHAAT' => 'E',
	'PHAAU' => 'E',
	'PHABO' => 'E',
	'PHACA' => 'E',
	'PHACC' => 'E',
	'PHACE' => 'E',
	'PHACG' => 'E',
	'PHACH' => 'E',
	'PHACI' => 'E',
	'PHACL' => 'E',
	'PHACM' => 'E',
	'PHACN' => 'E',
	'PHACO' => 'E',
	'PHADO' => 'E',
	'PHADU' => 'E',
	'PHAEQ' => 'E',
	'PHAEU' => 'E',
	'PHAEX' => 'E',
	'PHAFI' => 'E',
	'PHAFU' => 'E',
	'PHAGO' => 'E',
	'PHAGY' => 'E',
	'PHALL' => 'E',
	'PHALU' => 'E',
	'PHAMA' => 'E',
	'PHAME' => 'E',
	'PHANO' => 'E',
	'PHAON' => 'E',
	'PHAOR' => 'E',
	'PHAPA' => 'E',
	'PHAPE' => 'E',
	'PHAPR' => 'E',
	'PHARA' => 'E',
	'PHARH' => 'E',
	'PHARU' => 'E',
	'PHASA' => 'E',
	'PHASE' => 'E',
	'PHASI' => 'E',
	'PHASP' => 'E',
	'PHASR' => 'E',
	'PHASS' => 'E',
	'PHASU' => 'E',
	'PHATA' => 'E',
	'PHATN' => 'E',
	'PHATR' => 'E',
	'PHAVE' => 'E',
	'PHAVS' => 'E',
	'PHAVU' => 'E',
	'PHEAM' => 'E',
	'PHECO' => 'E',
	'PHEGU' => 'E',
	'PHEHI' => 'E',
	'PHEIM' => 'B',
	'PHEIN' => 'E',
	'PHELU' => 'E',
	'PHEMI' => 'E',
	'PHEMT' => 'E',
	'PHESE' => 'E',
	'PHEVI' => 'E',
	'PHIFR' => 'E',
	'PHIMC' => 'E',
	'PHIOP' => 'E',
	'PHISP' => 'E',
	'PHIVE' => 'E',
	'PHIZI' => 'E',
	'PHLDI' => 'E',
	'PHLDR' => 'E',
	'PHLDU' => 'E',
	'PHLDV' => 'E',
	'PHLGI' => 'E',
	'PHLGR' => 'E',
	'PHLLO' => 'E',
	'PHLPA' => 'E',
	'PHLPR' => 'E',
	'PHLRA' => 'E',
	'PHMV' => 'V',
	'PHOAD' => 'E',
	'PHOAG' => 'E',
	'PHOAN' => 'B',
	'PHOAZ' => 'B',
	'PHOCA' => 'E',
	'PHOCH' => 'E',
	'PHOCM' => 'E',
	'PHOCR' => 'E',
	'PHODA' => 'E',
	'PHODC' => 'E',
	'PHODT' => 'E',
	'PHODV' => 'V',
	'PHOEC' => 'B',
	'PHOFA' => 'E',
	'PHOFU' => 'E',
	'PHOGR' => 'E',
	'PHOGU' => 'E',
	'PHOHI' => 'E',
	'PHOKE' => 'E',
	'PHOLA' => 'B',
	'PHOLE' => 'B',
	'PHOLI' => 'E',
	'PHOLL' => 'B',
	'PHOLP' => 'B',
	'PHOLR' => 'E',
	'PHOLU' => 'B',
	'PHOMO' => 'B',
	'PHONA' => 'E',
	'PHONE' => 'E',
	'PHONI' => 'E',
	'PHOPA' => 'E',
	'PHOPE' => 'E',
	'PHOPH' => 'E',
	'PHOPL' => 'E',
	'PHOPN' => 'E',
	'PHOPO' => 'B',
	'PHOPR' => 'B',
	'PHOPY' => 'E',
	'PHORB' => 'E',
	'PHORE' => 'E',
	'PHORI' => 'E',
	'PHORO' => 'E',
	'PHORU' => 'E',
	'PHOS4' => 'B',
	'PHOSE' => 'E',
	'PHOSI' => 'E',
	'PHOSN' => 'E',
	'PHOSS' => 'E',
	'PHOST' => 'E',
	'PHOSU' => 'E',
	'PHOTE' => 'B',
	'PHOTN' => 'E',
	'PHOTO' => 'E',
	'PHOVI' => 'E',
	'PHOVR' => 'E',
	'PHRAU' => 'E',
	'PHRCO' => 'E',
	'PHRGE' => 'E',
	'PHRGI' => 'E',
	'PHRHE' => 'E',
	'PHRHI' => 'E',
	'PHRLA' => 'E',
	'PHRLE' => 'E',
	'PHRNA' => 'E',
	'PHRPL' => 'E',
	'PHRSC' => 'E',
	'PHRVE' => 'E',
	'PHRVI' => 'E',
	'PHUV' => 'V',
	'PHV' => 'V',
	'PHYAC' => 'E',
	'PHYAE' => 'E',
	'PHYAF' => 'E',
	'PHYAH' => 'E',
	'PHYAI' => 'E',
	'PHYAL' => 'E',
	'PHYAM' => 'E',
	'PHYAP' => 'E',
	'PHYBA' => 'E',
	'PHYBC' => 'E',
	'PHYBE' => 'E',
	'PHYBI' => 'E',
	'PHYBL' => 'E',
	'PHYBN' => 'E',
	'PHYBO' => 'E',
	'PHYBR' => 'E',
	'PHYCA' => 'E',
	'PHYCB' => 'E',
	'PHYCC' => 'E',
	'PHYCE' => 'E',
	'PHYCH' => 'E',
	'PHYCI' => 'E',
	'PHYCN' => 'E',
	'PHYCO' => 'E',
	'PHYCP' => 'E',
	'PHYCR' => 'E',
	'PHYCS' => 'E',
	'PHYCT' => 'E',
	'PHYCU' => 'E',
	'PHYDA' => 'E',
	'PHYDI' => 'E',
	'PHYDR' => 'E',
	'PHYDS' => 'E',
	'PHYDU' => 'E',
	'PHYDV' => 'E',
	'PHYEL' => 'E',
	'PHYEM' => 'E',
	'PHYEO' => 'E',
	'PHYES' => 'E',
	'PHYFA' => 'E',
	'PHYFL' => 'E',
	'PHYFS' => 'E',
	'PHYFU' => 'E',
	'PHYGR' => 'E',
	'PHYHA' => 'E',
	'PHYHU' => 'E',
	'PHYHY' => 'E',
	'PHYHZ' => 'E',
	'PHYIJ' => 'E',
	'PHYIM' => 'E',
	'PHYIN' => 'E',
	'PHYIO' => 'E',
	'PHYJA' => 'E',
	'PHYKA' => 'E',
	'PHYLA' => 'E',
	'PHYLE' => 'E',
	'PHYLI' => 'E',
	'PHYLO' => 'E',
	'PHYMA' => 'E',
	'PHYME' => 'E',
	'PHYMG' => 'E',
	'PHYMO' => 'E',
	'PHYNI' => 'E',
	'PHYNP' => 'E',
	'PHYNT' => 'E',
	'PHYOC' => 'E',
	'PHYOI' => 'E',
	'PHYOR' => 'E',
	'PHYPA' => 'E',
	'PHYPC' => 'E',
	'PHYPE' => 'E',
	'PHYPH' => 'E',
	'PHYPI' => 'E',
	'PHYPL' => 'E',
	'PHYPO' => 'E',
	'PHYPR' => 'E',
	'PHYPU' => 'E',
	'PHYPY' => 'B',
	'PHYRA' => 'E',
	'PHYRE' => 'E',
	'PHYRO' => 'E',
	'PHYS1' => 'B',
	'PHYS2' => 'B',
	'PHYSA' => 'E',
	'PHYSC' => 'E',
	'PHYSE' => 'E',
	'PHYSI' => 'E',
	'PHYSN' => 'E',
	'PHYST' => 'E',
	'PHYTA' => 'E',
	'PHYTC' => 'E',
	'PHYTE' => 'E',
	'PHYTH' => 'E',
	'PHYTN' => 'E',
	'PHYTO' => 'E',
	'PHYTR' => 'E',
	'PHYTS' => 'E',
	'PHYTY' => 'E',
	'PHYVI' => 'E',
	'PHYVR' => 'E',
	'PHYXA' => 'E',
	'PHYYU' => 'E',
	'PI1HA' => 'V',
	'PI1HB' => 'V',
	'PI1HC' => 'V',
	'PI1HD' => 'V',
	'PI1HE' => 'V',
	'PI1HW' => 'V',
	'PI2H' => 'V',
	'PI2HG' => 'V',
	'PI2HT' => 'V',
	'PI3B' => 'V',
	'PI3H4' => 'V',
	'PI3HA' => 'V',
	'PI3HT' => 'V',
	'PI3HU' => 'V',
	'PI3HV' => 'V',
	'PI3HW' => 'V',
	'PI3HX' => 'V',
	'PI4HA' => 'V',
	'PI4HB' => 'V',
	'PIACA' => 'E',
	'PIAME' => 'E',
	'PIARV' => 'V',
	'PICAB' => 'E',
	'PICAN' => 'E',
	'PICAR' => 'E',
	'PICCA' => 'E',
	'PICCI' => 'E',
	'PICEN' => 'E',
	'PICET' => 'E',
	'PICFA' => 'E',
	'PICGL' => 'E',
	'PICGU' => 'E',
	'PICGY' => 'E',
	'PICHU' => 'E',
	'PICJA' => 'E',
	'PICKL' => 'E',
	'PICMA' => 'E',
	'PICME' => 'E',
	'PICMX' => 'E',
	'PICPA' => 'E',
	'PICPB' => 'E',
	'PICPC' => 'E',
	'PICPI' => 'E',
	'PICPJ' => 'E',
	'PICPU' => 'E',
	'PICRU' => 'E',
	'PICSI' => 'E',
	'PICST' => 'E',
	'PICTO' => 'A',
	'PICTR' => 'E',
	'PICVI' => 'E',
	'PIEBR' => 'E',
	'PIENA' => 'E',
	'PIERA' => 'E',
	'PIG' => 'E',
	'PILAM' => 'E',
	'PILPU' => 'E',
	'PILTE' => 'E',
	'PIMBR' => 'E',
	'PIMHY' => 'E',
	'PIMSR' => 'B',
	'PINAR' => 'E',
	'PINAT' => 'E',
	'PINBA' => 'E',
	'PINBN' => 'E',
	'PINBU' => 'E',
	'PINCA' => 'E',
	'PINCE' => 'E',
	'PINCL' => 'E',
	'PINCO' => 'E',
	'PINCU' => 'E',
	'PINDE' => 'E',
	'PINEC' => 'E',
	'PINED' => 'E',
	'PINEG' => 'E',
	'PINEL' => 'E',
	'PINEN' => 'E',
	'PINFU' => 'E',
	'PINGE' => 'E',
	'PINHA' => 'E',
	'PINIM' => 'E',
	'PININ' => 'E',
	'PINKO' => 'E',
	'PINKR' => 'E',
	'PINLA' => 'E',
	'PINLE' => 'E',
	'PINLO' => 'E',
	'PINLU' => 'E',
	'PINMO' => 'E',
	'PINMR' => 'E',
	'PINMU' => 'E',
	'PINNO' => 'E',
	'PINPA' => 'E',
	'PINPE' => 'E',
	'PINPI' => 'E',
	'PINPN' => 'E',
	'PINPO' => 'E',
	'PINPR' => 'E',
	'PINPS' => 'E',
	'PINPT' => 'E',
	'PINPU' => 'E',
	'PINRA' => 'E',
	'PINRE' => 'E',
	'PINRI' => 'E',
	'PINRO' => 'E',
	'PINRZ' => 'E',
	'PINSI' => 'E',
	'PINST' => 'E',
	'PINSY' => 'E',
	'PINTA' => 'E',
	'PINTB' => 'E',
	'PINTH' => 'E',
	'PINTO' => 'E',
	'PINUN' => 'E',
	'PINVI' => 'E',
	'PINWA' => 'E',
	'PINYU' => 'E',
	'PIOME' => 'E',
	'PIPAB' => 'E',
	'PIPAR' => 'E',
	'PIPCE' => 'E',
	'PIPCH' => 'E',
	'PIPCL' => 'E',
	'PIPER' => 'E',
	'PIPFA' => 'E',
	'PIPHE' => 'E',
	'PIPJA' => 'E',
	'PIPKU' => 'E',
	'PIPNA' => 'E',
	'PIPPI' => 'E',
	'PIPRU' => 'E',
	'PIPSA' => 'E',
	'PIPSU' => 'E',
	'PIREQ' => 'E',
	'PIRIN' => 'E',
	'PIRLU' => 'E',
	'PIROL' => 'E',
	'PIRSP' => 'E',
	'PIRYV' => 'V',
	'PISBR' => 'E',
	'PISME' => 'E',
	'PISOC' => 'E',
	'PISSA' => 'B',
	'PISST' => 'E',
	'PISTI' => 'E',
	'PISVE' => 'E',
	'PITBA' => 'E',
	'PITDI' => 'E',
	'PITIR' => 'E',
	'PITKI' => 'E',
	'PITME' => 'E',
	'PITPI' => 'E',
	'PITSA' => 'E',
	'PITSO' => 'E',
	'PITSU' => 'E',
	'PLAAC' => 'E',
	'PLAAD' => 'E',
	'PLAAE' => 'E',
	'PLAAR' => 'E',
	'PLABA' => 'E',
	'PLABE' => 'E',
	'PLABI' => 'E',
	'PLABR' => 'E',
	'PLACA' => 'E',
	'PLACB' => 'E',
	'PLACC' => 'E',
	'PLACG' => 'E',
	'PLACH' => 'E',
	'PLACI' => 'E',
	'PLACL' => 'E',
	'PLACM' => 'E',
	'PLADA' => 'E',
	'PLADU' => 'E',
	'PLAEL' => 'E',
	'PLAEX' => 'E',
	'PLAF1' => 'E',
	'PLAF2' => 'E',
	'PLAF3' => 'E',
	'PLAF4' => 'E',
	'PLAF5' => 'E',
	'PLAF6' => 'E',
	'PLAF7' => 'E',
	'PLAF8' => 'E',
	'PLAF9' => 'E',
	'PLAFA' => 'E',
	'PLAFB' => 'E',
	'PLAFC' => 'E',
	'PLAFD' => 'E',
	'PLAFE' => 'E',
	'PLAFF' => 'E',
	'PLAFG' => 'E',
	'PLAFH' => 'E',
	'PLAFI' => 'E',
	'PLAFJ' => 'E',
	'PLAFK' => 'E',
	'PLAFL' => 'E',
	'PLAFM' => 'E',
	'PLAFN' => 'E',
	'PLAFO' => 'E',
	'PLAFP' => 'E',
	'PLAFQ' => 'E',
	'PLAFR' => 'E',
	'PLAFS' => 'E',
	'PLAFT' => 'E',
	'PLAFU' => 'E',
	'PLAFV' => 'E',
	'PLAFW' => 'E',
	'PLAFX' => 'E',
	'PLAFZ' => 'E',
	'PLAGA' => 'E',
	'PLAGE' => 'E',
	'PLAGI' => 'E',
	'PLAGN' => 'E',
	'PLAGO' => 'E',
	'PLAHE' => 'E',
	'PLAHY' => 'E',
	'PLAIC' => 'E',
	'PLAIN' => 'E',
	'PLAJU' => 'E',
	'PLAKH' => 'E',
	'PLAKN' => 'E',
	'PLAKU' => 'E',
	'PLALA' => 'E',
	'PLALI' => 'B',
	'PLALO' => 'E',
	'PLAMA' => 'E',
	'PLAMC' => 'E',
	'PLAMG' => 'E',
	'PLAMI' => 'E',
	'PLAMJ' => 'E',
	'PLAMM' => 'E',
	'PLAMN' => 'E',
	'PLAMS' => 'E',
	'PLAMU' => 'E',
	'PLANO' => 'E',
	'PLANU' => 'E',
	'PLAOC' => 'E',
	'PLAOR' => 'E',
	'PLAOV' => 'E',
	'PLAPE' => 'E',
	'PLAPL' => 'E',
	'PLARE' => 'E',
	'PLARL' => 'E',
	'PLARO' => 'B',
	'PLARP' => 'E',
	'PLARU' => 'B',
	'PLASE' => 'E',
	'PLASI' => 'E',
	'PLASM' => 'E',
	'PLASU' => 'E',
	'PLATE' => 'E',
	'PLAVB' => 'E',
	'PLAVC' => 'E',
	'PLAVE' => 'B',
	'PLAVG' => 'E',
	'PLAVI' => 'E',
	'PLAVN' => 'E',
	'PLAVR' => 'E',
	'PLAVS' => 'E',
	'PLAYO' => 'E',
	'PLEAS' => 'E',
	'PLEAT' => 'E',
	'PLEAU' => 'E',
	'PLEBO' => 'B',
	'PLECA' => 'E',
	'PLECE' => 'E',
	'PLECI' => 'E',
	'PLECO' => 'E',
	'PLEER' => 'E',
	'PLEFA' => 'E',
	'PLEFO' => 'E',
	'PLEGI' => 'E',
	'PLEGU' => 'E',
	'PLEHA' => 'E',
	'PLEHO' => 'E',
	'PLEJO' => 'E',
	'PLENI' => 'E',
	'PLEOS' => 'E',
	'PLEPL' => 'E',
	'PLERA' => 'E',
	'PLERI' => 'E',
	'PLESA' => 'E',
	'PLESC' => 'E',
	'PLESH' => 'B',
	'PLETI' => 'E',
	'PLETO' => 'E',
	'PLETR' => 'E',
	'PLETU' => 'E',
	'PLEWA' => 'E',
	'PLEYO' => 'E',
	'PLOCA' => 'E',
	'PLOIN' => 'E',
	'PLRV' => 'V',
	'PLRV1' => 'V',
	'PLRVR' => 'V',
	'PLRVW' => 'V',
	'PLUAU' => 'E',
	'PLUDI' => 'E',
	'PLUDO' => 'E',
	'PLUSO' => 'E',
	'PLUSQ' => 'E',
	'PLUXY' => 'E',
	'PLV' => 'V',
	'PMMV' => 'V',
	'PMMV0' => 'V',
	'PMMV1' => 'V',
	'PMMV2' => 'V',
	'PMMVI' => 'V',
	'PMMVJ' => 'V',
	'PMMVS' => 'V',
	'PMV' => 'V',
	'PNECA' => 'E',
	'PNEJI' => 'E',
	'POAAN' => 'E',
	'POAFE' => 'E',
	'POANE' => 'E',
	'POAPA' => 'E',
	'POAPR' => 'E',
	'POASE' => 'E',
	'POATR' => 'E',
	'PODAC' => 'E',
	'PODAN' => 'E',
	'PODAU' => 'E',
	'PODCA' => 'E',
	'PODCU' => 'E',
	'PODEM' => 'E',
	'PODFL' => 'E',
	'PODGR' => 'E',
	'PODHE' => 'E',
	'PODHI' => 'E',
	'PODMA' => 'E',
	'PODMU' => 'E',
	'PODNI' => 'E',
	'PODNV' => 'E',
	'PODPE' => 'E',
	'PODPL' => 'E',
	'PODPO' => 'E',
	'PODRI' => 'E',
	'PODSI' => 'E',
	'PODST' => 'E',
	'PODTI' => 'E',
	'POECU' => 'E',
	'POEGU' => 'E',
	'POELU' => 'E',
	'POEOC' => 'E',
	'POERE' => 'E',
	'POEVI' => 'E',
	'POGBA' => 'E',
	'POGBR' => 'E',
	'POGCA' => 'E',
	'POGOP' => 'E',
	'POGPU' => 'E',
	'POIRI' => 'E',
	'POL1M' => 'V',
	'POL1S' => 'V',
	'POL2L' => 'V',
	'POL2W' => 'V',
	'POL32' => 'V',
	'POL3L' => 'V',
	'POLAB' => 'E',
	'POLAC' => 'E',
	'POLAE' => 'E',
	'POLAG' => 'E',
	'POLAL' => 'E',
	'POLAN' => 'E',
	'POLAT' => 'E',
	'POLAU' => 'E',
	'POLAV' => 'E',
	'POLBI' => 'E',
	'POLBO' => 'E',
	'POLBS' => 'E',
	'POLCA' => 'E',
	'POLCB' => 'B',
	'POLCE' => 'E',
	'POLCH' => 'E',
	'POLCI' => 'E',
	'POLCL' => 'E',
	'POLCM' => 'E',
	'POLCN' => 'E',
	'POLCO' => 'E',
	'POLCR' => 'E',
	'POLCS' => 'E',
	'POLCU' => 'E',
	'POLDI' => 'E',
	'POLDO' => 'E',
	'POLEM' => 'E',
	'POLEX' => 'E',
	'POLFA' => 'E',
	'POLFU' => 'E',
	'POLGA' => 'E',
	'POLGE' => 'E',
	'POLGL' => 'E',
	'POLGR' => 'E',
	'POLHA' => 'E',
	'POLHE' => 'E',
	'POLHS' => 'E',
	'POLHY' => 'E',
	'POLIC' => 'E',
	'POLIN' => 'E',
	'POLJA' => 'E',
	'POLLA' => 'E',
	'POLMA' => 'E',
	'POLMI' => 'E',
	'POLML' => 'E',
	'POLMU' => 'E',
	'POLNE' => 'E',
	'POLOD' => 'E',
	'POLOR' => 'E',
	'POLPA' => 'E',
	'POLPE' => 'E',
	'POLPI' => 'E',
	'POLPL' => 'E',
	'POLPO' => 'E',
	'POLPR' => 'E',
	'POLPU' => 'E',
	'POLPY' => 'E',
	'POLQU' => 'E',
	'POLRA' => 'E',
	'POLRE' => 'E',
	'POLRO' => 'E',
	'POLSA' => 'E',
	'POLSE' => 'E',
	'POLSI' => 'E',
	'POLSJ' => 'B',
	'POLSP' => 'E',
	'POLSR' => 'E',
	'POLSX' => 'E',
	'POLSY' => 'E',
	'POLTB' => 'E',
	'POLUR' => 'E',
	'POLVU' => 'E',
	'POMAN' => 'E',
	'POMAR' => 'E',
	'POMFL' => 'E',
	'POMIM' => 'E',
	'POMIP' => 'E',
	'POMIS' => 'E',
	'POMMI' => 'E',
	'POMNA' => 'E',
	'POMNI' => 'E',
	'POMPA' => 'E',
	'POMRU' => 'E',
	'POMSE' => 'E',
	'POMSU' => 'E',
	'POMSX' => 'E',
	'POMTE' => 'E',
	'POMXA' => 'E',
	'PONBL' => 'E',
	'PONCO' => 'E',
	'PONLE' => 'E',
	'PONPA' => 'E',
	'PONPP' => 'E',
	'PONPR' => 'E',
	'PONPY' => 'E',
	'PONTR' => 'E',
	'POOAL' => 'E',
	'POOGA' => 'E',
	'POPAL' => 'E',
	'POPCA' => 'E',
	'POPDE' => 'E',
	'POPEU' => 'E',
	'POPJA' => 'E',
	'POPKI' => 'E',
	'POPMV' => 'V',
	'POPNI' => 'E',
	'POPSP' => 'E',
	'POPTM' => 'E',
	'POPTN' => 'E',
	'POPTR' => 'E',
	'PORAE' => 'E',
	'PORAF' => 'E',
	'PORAR' => 'E',
	'PORAS' => 'E',
	'PORCA' => 'E',
	'PORCN' => 'B',
	'PORCR' => 'E',
	'PORDI' => 'E',
	'PORGI' => 'B',
	'PORGR' => 'E',
	'PORHY' => 'E',
	'PORMA' => 'E',
	'PORNA' => 'E',
	'PORNO' => 'E',
	'POROL' => 'E',
	'POROP' => 'E',
	'PORPE' => 'E',
	'PORPO' => 'E',
	'PORPR' => 'E',
	'PORPS' => 'E',
	'PORPU' => 'E',
	'PORSC' => 'E',
	'PORSO' => 'E',
	'PORTE' => 'E',
	'PORUM' => 'E',
	'PORYE' => 'E',
	'POTAN' => 'E',
	'POTFL' => 'E',
	'POTFR' => 'E',
	'POTGI' => 'E',
	'POTLA' => 'E',
	'POTLO' => 'E',
	'POTPO' => 'E',
	'POTPR' => 'E',
	'POTTR' => 'E',
	'POUCA' => 'E',
	'POVBA' => 'V',
	'POVBK' => 'V',
	'POVBO' => 'V',
	'POVHA' => 'V',
	'POVJC' => 'V',
	'POVLY' => 'V',
	'POVM3' => 'V',
	'POVMA' => 'V',
	'POVMC' => 'V',
	'POVMK' => 'V',
	'POVMP' => 'V',
	'POWVL' => 'V',
	'PPRV' => 'V',
	'PPVD' => 'V',
	'PPVEA' => 'V',
	'PPVNA' => 'V',
	'PPVRA' => 'V',
	'PPVSK' => 'V',
	'PPWBP' => 'B',
	'PRADI' => 'E',
	'PRAJA' => 'E',
	'PRANA' => 'E',
	'PRAPE' => 'E',
	'PRASC' => 'E',
	'PRATA' => 'E',
	'PRATU' => 'E',
	'PRB01' => 'B',
	'PRB02' => 'B',
	'PREBI' => 'E',
	'PREBR' => 'B',
	'PRECO' => 'E',
	'PRECR' => 'E',
	'PREFR' => 'E',
	'PREIN' => 'B',
	'PRELO' => 'B',
	'PREME' => 'E',
	'PREOB' => 'E',
	'PRERU' => 'B',
	'PRIAN' => 'E',
	'PRIBE' => 'E',
	'PRICA' => 'E',
	'PRICE' => 'E',
	'PRIGL' => 'E',
	'PRIIN' => 'E',
	'PRILA' => 'E',
	'PRILI' => 'E',
	'PRILY' => 'E',
	'PRIMA' => 'E',
	'PRIMR' => 'E',
	'PRINE' => 'E',
	'PRIPA' => 'E',
	'PRIPL' => 'E',
	'PRIPR' => 'E',
	'PRIRA' => 'E',
	'PRITE' => 'E',
	'PRIVE' => 'E',
	'PRIVI' => 'E',
	'PROAC' => 'B',
	'PROAE' => 'B',
	'PROAL' => 'E',
	'PROAM' => 'E',
	'PROAN' => 'E',
	'PROAP' => 'E',
	'PROAR' => 'E',
	'PROAT' => 'E',
	'PROAU' => 'E',
	'PROBO' => 'E',
	'PROBT' => 'E',
	'PROCA' => 'E',
	'PROCE' => 'E',
	'PROCL' => 'E',
	'PROCR' => 'E',
	'PROCS' => 'E',
	'PROCU' => 'E',
	'PROCY' => 'E',
	'PRODD' => 'E',
	'PRODI' => 'B',
	'PRODO' => 'E',
	'PROEX' => 'E',
	'PROFF' => 'B',
	'PROFR' => 'B',
	'PROGU' => 'E',
	'PROHA' => 'E',
	'PROHO' => 'B',
	'PROIN' => 'B',
	'PROJE' => 'E',
	'PROJU' => 'E',
	'PROLA' => 'E',
	'PROLO' => 'E',
	'PROLU' => 'E',
	'PROM9' => 'B',
	'PROMA' => 'B',
	'PROMC' => 'E',
	'PROMG' => 'E',
	'PROMI' => 'B',
	'PROML' => 'E',
	'PROMM' => 'B',
	'PROMN' => 'E',
	'PROMO' => 'B',
	'PROMP' => 'B',
	'PROMT' => 'B',
	'PROOR' => 'E',
	'PROPA' => 'E',
	'PRORA' => 'E',
	'PRORE' => 'B',
	'PRORP' => 'E',
	'PRORT' => 'E',
	'PRORU' => 'E',
	'PROS9' => 'B',
	'PROSA' => 'E',
	'PROSC' => 'B',
	'PROSE' => 'E',
	'PROSI' => 'E',
	'PROSL' => 'B',
	'PROSN' => 'E',
	'PROSP' => 'B',
	'PROSR' => 'E',
	'PROST' => 'B',
	'PROSU' => 'E',
	'PROSY' => 'E',
	'PROTA' => 'E',
	'PROTE' => 'E',
	'PROTO' => 'E',
	'PROTR' => 'E',
	'PROV1' => 'B',
	'PROVC' => 'E',
	'PROVE' => 'E',
	'PROVU' => 'B',
	'PROWE' => 'E',
	'PROWI' => 'E',
	'PRRS1' => 'V',
	'PRRSB' => 'V',
	'PRRSL' => 'V',
	'PRRSR' => 'V',
	'PRRSV' => 'V',
	'PRSVH' => 'V',
	'PRSVP' => 'V',
	'PRSVW' => 'V',
	'PRUAA' => 'E',
	'PRUAM' => 'E',
	'PRUAP' => 'B',
	'PRUAR' => 'E',
	'PRUAV' => 'E',
	'PRUDO' => 'E',
	'PRUDU' => 'E',
	'PRUEM' => 'E',
	'PRUFR' => 'E',
	'PRUGR' => 'E',
	'PRULA' => 'E',
	'PRUMO' => 'E',
	'PRUMU' => 'E',
	'PRUPE' => 'E',
	'PRUSE' => 'E',
	'PRUSP' => 'E',
	'PRUTE' => 'E',
	'PRUVU' => 'E',
	'PRUYE' => 'E',
	'PRV' => 'V',
	'PRVIF' => 'V',
	'PRVIS' => 'V',
	'PRVKA' => 'V',
	'PRVN3' => 'V',
	'PRVRI' => 'V',
	'PSAAL' => 'E',
	'PSAAN' => 'E',
	'PSAAT' => 'E',
	'PSACA' => 'E',
	'PSADE' => 'E',
	'PSAFR' => 'E',
	'PSAHI' => 'E',
	'PSAJU' => 'E',
	'PSALA' => 'E',
	'PSALI' => 'E',
	'PSAMI' => 'E',
	'PSAOB' => 'E',
	'PSARU' => 'E',
	'PSAST' => 'E',
	'PSAVE' => 'E',
	'PSAYU' => 'E',
	'PSBMV' => 'V',
	'PSE14' => 'B',
	'PSEA6' => 'B',
	'PSEA9' => 'B',
	'PSEAA' => 'B',
	'PSEAC' => 'B',
	'PSEAE' => 'B',
	'PSEAG' => 'B',
	'PSEAK' => 'E',
	'PSEAL' => 'B',
	'PSEAM' => 'E',
	'PSEAN' => 'B',
	'PSEAO' => 'B',
	'PSEAP' => 'B',
	'PSEAR' => 'E',
	'PSEAT' => 'E',
	'PSEAU' => 'E',
	'PSEAY' => 'B',
	'PSEBI' => 'E',
	'PSEBJ' => 'E',
	'PSEBR' => 'B',
	'PSECA' => 'B',
	'PSECH' => 'B',
	'PSECI' => 'B',
	'PSECL' => 'B',
	'PSECM' => 'E',
	'PSECO' => 'B',
	'PSECP' => 'E',
	'PSECR' => 'E',
	'PSECS' => 'E',
	'PSECU' => 'E',
	'PSECV' => 'E',
	'PSEDC' => 'E',
	'PSEDE' => 'B',
	'PSEDP' => 'E',
	'PSEE4' => 'B',
	'PSEF5' => 'B',
	'PSEFA' => 'B',
	'PSEFB' => 'B',
	'PSEFC' => 'B',
	'PSEFI' => 'E',
	'PSEFL' => 'B',
	'PSEFO' => 'E',
	'PSEFR' => 'B',
	'PSEFV' => 'E',
	'PSEGE' => 'E',
	'PSEGI' => 'E',
	'PSEGR' => 'E',
	'PSEGU' => 'E',
	'PSEGY' => 'E',
	'PSEHA' => 'B',
	'PSEHT' => 'B',
	'PSEHU' => 'E',
	'PSEHY' => 'B',
	'PSEIC' => 'E',
	'PSEIN' => 'B',
	'PSEJA' => 'E',
	'PSEJU' => 'E',
	'PSEKA' => 'E',
	'PSEKO' => 'E',
	'PSELE' => 'B',
	'PSELU' => 'B',
	'PSEMA' => 'B',
	'PSEMC' => 'E',
	'PSEMD' => 'E',
	'PSEME' => 'B',
	'PSEMO' => 'E',
	'PSEMR' => 'E',
	'PSEMV' => 'B',
	'PSEMZ' => 'E',
	'PSENA' => 'E',
	'PSENG' => 'E',
	'PSENI' => 'E',
	'PSENR' => 'E',
	'PSEOC' => 'B',
	'PSEOL' => 'B',
	'PSEPA' => 'B',
	'PSEPC' => 'E',
	'PSEPD' => 'E',
	'PSEPE' => 'E',
	'PSEPF' => 'B',
	'PSEPG' => 'B',
	'PSEPI' => 'E',
	'PSEPK' => 'B',
	'PSEPO' => 'E',
	'PSEPR' => 'E',
	'PSEPS' => 'B',
	'PSEPU' => 'B',
	'PSEPV' => 'B',
	'PSEPY' => 'B',
	'PSERE' => 'B',
	'PSERO' => 'E',
	'PSES0' => 'B',
	'PSES1' => 'B',
	'PSES2' => 'B',
	'PSES3' => 'B',
	'PSES4' => 'B',
	'PSES5' => 'B',
	'PSES6' => 'B',
	'PSES7' => 'B',
	'PSES8' => 'B',
	'PSES9' => 'B',
	'PSESA' => 'B',
	'PSESB' => 'B',
	'PSESC' => 'E',
	'PSESD' => 'B',
	'PSESE' => 'E',
	'PSESF' => 'B',
	'PSESG' => 'B',
	'PSESH' => 'B',
	'PSESI' => 'B',
	'PSESJ' => 'B',
	'PSESK' => 'B',
	'PSESL' => 'B',
	'PSESM' => 'B',
	'PSESN' => 'B',
	'PSESO' => 'B',
	'PSESP' => 'B',
	'PSESQ' => 'B',
	'PSESR' => 'B',
	'PSESS' => 'B',
	'PSEST' => 'B',
	'PSESU' => 'E',
	'PSESV' => 'B',
	'PSESW' => 'E',
	'PSESX' => 'B',
	'PSESY' => 'B',
	'PSESZ' => 'B',
	'PSETE' => 'E',
	'PSETH' => 'B',
	'PSETO' => 'B',
	'PSEU0' => 'B',
	'PSEU1' => 'B',
	'PSEU2' => 'B',
	'PSEU4' => 'B',
	'PSEU7' => 'B',
	'PSEU8' => 'B',
	'PSEUA' => 'B',
	'PSEUC' => 'B',
	'PSEUD' => 'B',
	'PSEUE' => 'B',
	'PSEUF' => 'B',
	'PSEUG' => 'B',
	'PSEUH' => 'B',
	'PSEUI' => 'E',
	'PSEUJ' => 'B',
	'PSEUK' => 'B',
	'PSEUM' => 'B',
	'PSEUN' => 'B',
	'PSEUO' => 'B',
	'PSEUR' => 'E',
	'PSEUS' => 'E',
	'PSEUY' => 'B',
	'PSEVE' => 'E',
	'PSEVI' => 'B',
	'PSEVR' => 'E',
	'PSEWI' => 'B',
	'PSEWO' => 'E',
	'PSEXY' => 'B',
	'PSEYM' => 'B',
	'PSEYS' => 'B',
	'PSIBA' => 'E',
	'PSIBO' => 'E',
	'PSIDE' => 'E',
	'PSIER' => 'E',
	'PSIFU' => 'E',
	'PSIGN' => 'E',
	'PSIGU' => 'E',
	'PSIKR' => 'E',
	'PSINU' => 'E',
	'PSIRO' => 'E',
	'PSIRU' => 'E',
	'PSISY' => 'E',
	'PSIVE' => 'E',
	'PSOOV' => 'E',
	'PSOSC' => 'E',
	'PSOTE' => 'E',
	'PSVJ' => 'V',
	'PSYAR' => 'B',
	'PSYCI' => 'E',
	'PSYCK' => 'B',
	'PSYIM' => 'B',
	'PSYLO' => 'E',
	'PSYS1' => 'B',
	'PSYT1' => 'B',
	'PSYTA' => 'B',
	'PTEAD' => 'E',
	'PTEAE' => 'E',
	'PTEAL' => 'E',
	'PTEAN' => 'E',
	'PTEAQ' => 'E',
	'PTEAT' => 'E',
	'PTEAX' => 'E',
	'PTEBA' => 'E',
	'PTEBR' => 'E',
	'PTECA' => 'E',
	'PTECN' => 'E',
	'PTECO' => 'E',
	'PTEDA' => 'E',
	'PTEDV' => 'E',
	'PTEES' => 'E',
	'PTEEX' => 'E',
	'PTEGI' => 'E',
	'PTEGY' => 'E',
	'PTEHA' => 'E',
	'PTEHE' => 'E',
	'PTEHP' => 'E',
	'PTEHY' => 'E',
	'PTEIN' => 'E',
	'PTEJA' => 'E',
	'PTELU' => 'E',
	'PTELY' => 'E',
	'PTEMA' => 'E',
	'PTEMD' => 'E',
	'PTEME' => 'E',
	'PTEMG' => 'E',
	'PTEMI' => 'E',
	'PTEML' => 'E',
	'PTEMM' => 'E',
	'PTEMO' => 'E',
	'PTENE' => 'E',
	'PTENG' => 'E',
	'PTENI' => 'E',
	'PTENO' => 'E',
	'PTENR' => 'E',
	'PTEOC' => 'E',
	'PTEOR' => 'E',
	'PTEPA' => 'E',
	'PTEPE' => 'E',
	'PTEPH' => 'E',
	'PTEPO' => 'E',
	'PTEPR' => 'E',
	'PTEPS' => 'E',
	'PTEPU' => 'E',
	'PTEQU' => 'E',
	'PTERA' => 'E',
	'PTERF' => 'E',
	'PTERO' => 'E',
	'PTERU' => 'E',
	'PTESA' => 'E',
	'PTESC' => 'E',
	'PTESM' => 'E',
	'PTESO' => 'E',
	'PTESP' => 'E',
	'PTETE' => 'E',
	'PTETO' => 'E',
	'PTEVA' => 'E',
	'PTEVE' => 'E',
	'PTEVI' => 'E',
	'PTEVO' => 'E',
	'PTEWO' => 'E',
	'PTEZE' => 'E',
	'PTIAF' => 'E',
	'PTIOC' => 'E',
	'PTIPL' => 'E',
	'PTPV' => 'V',
	'PTV10' => 'V',
	'PTYAL' => 'E',
	'PTYGA' => 'E',
	'PUCDI' => 'E',
	'PUCGR' => 'E',
	'PUCMA' => 'E',
	'PUDPU' => 'E',
	'PUELO' => 'E',
	'PUFAU' => 'E',
	'PUFBU' => 'E',
	'PUFHU' => 'E',
	'PUFNA' => 'E',
	'PUFOP' => 'E',
	'PUFTE' => 'E',
	'PULDE' => 'E',
	'PULKO' => 'E',
	'PULPE' => 'E',
	'PUMCO' => 'E',
	'PUNCO' => 'E',
	'PUNGR' => 'E',
	'PUNTE' => 'E',
	'PURTR' => 'E',
	'PUUMB' => 'V',
	'PUUME' => 'V',
	'PUUMH' => 'V',
	'PUUMK' => 'V',
	'PUUMP' => 'V',
	'PUUMS' => 'V',
	'PUUMU' => 'V',
	'PVMA' => 'V',
	'PVMG' => 'V',
	'PVMR' => 'V',
	'PVSP' => 'V',
	'PVX' => 'V',
	'PVXCP' => 'V',
	'PVXHB' => 'V',
	'PVXU3' => 'V',
	'PVXX3' => 'V',
	'PVXXC' => 'V',
	'PVYC' => 'V',
	'PVYCH' => 'V',
	'PVYHU' => 'V',
	'PVYN' => 'V',
	'PVYO' => 'V',
	'PVYYO' => 'V',
	'PWVMI' => 'V',
	'PWVSE' => 'V',
	'PWVTB' => 'V',
	'PYCCI' => 'E',
	'PYCCO' => 'E',
	'PYCHE' => 'E',
	'PYCSU' => 'E',
	'PYETR' => 'E',
	'PYFV1' => 'V',
	'PYGAD' => 'E',
	'PYGAN' => 'E',
	'PYGAV' => 'E',
	'PYGBI' => 'E',
	'PYGBL' => 'E',
	'PYGDI' => 'E',
	'PYGNE' => 'E',
	'PYGPA' => 'E',
	'PYGRO' => 'E',
	'PYLLI' => 'E',
	'PYMVV' => 'V',
	'PYRAB' => 'A',
	'PYRAE' => 'A',
	'PYRAP' => 'E',
	'PYRBR' => 'E',
	'PYRCM' => 'E',
	'PYRCO' => 'E',
	'PYREN' => 'A',
	'PYREX' => 'E',
	'PYRFU' => 'A',
	'PYRGA' => 'E',
	'PYRGR' => 'E',
	'PYRHO' => 'A',
	'PYRIS' => 'A',
	'PYRKO' => 'A',
	'PYRLT' => 'E',
	'PYRLU' => 'E',
	'PYRNO' => 'E',
	'PYROC' => 'A',
	'PYRPH' => 'E',
	'PYRPI' => 'E',
	'PYRPR' => 'E',
	'PYRPU' => 'E',
	'PYRPY' => 'E',
	'PYRRU' => 'E',
	'PYRSA' => 'E',
	'PYRSC' => 'E',
	'PYRSD' => 'A',
	'PYRSG' => 'A',
	'PYRSS' => 'A',
	'PYRST' => 'E',
	'PYRVE' => 'E',
	'PYRWO' => 'A',
	'PYTHP' => 'E',
	'PYTHY' => 'E',
	'PYTIN' => 'E',
	'PYTMO' => 'E',
	'PYTRE' => 'E',
	'PYTRG' => 'E',
	'PYTSE' => 'E',
	'PYUSP' => 'E',
	'PYUST' => 'E',
	'PYXAD' => 'E',
	'PYXPL' => 'E',
	'QUEAC' => 'E',
	'QUEAG' => 'E',
	'QUEAL' => 'E',
	'QUECE' => 'E',
	'QUECH' => 'E',
	'QUECO' => 'E',
	'QUEEN' => 'E',
	'QUEGA' => 'E',
	'QUEIL' => 'E',
	'QUEIM' => 'E',
	'QUEKE' => 'E',
	'QUELO' => 'E',
	'QUELY' => 'E',
	'QUEMY' => 'E',
	'QUEPA' => 'E',
	'QUEPE' => 'E',
	'QUERO' => 'E',
	'QUERU' => 'E',
	'QUESU' => 'E',
	'QUETO' => 'E',
	'QUETU' => 'E',
	'QUEVA' => 'E',
	'QUEVI' => 'E',
	'QUEWI' => 'E',
	'QUIIN' => 'E',
	'QUIQU' => 'E',
	'RABIT' => 'E',
	'RABPU' => 'V',
	'RABVA' => 'V',
	'RABVC' => 'V',
	'RABVE' => 'V',
	'RABVF' => 'V',
	'RABVH' => 'V',
	'RABVM' => 'V',
	'RABVN' => 'V',
	'RABVP' => 'V',
	'RABVS' => 'V',
	'RABVT' => 'V',
	'RABVU' => 'V',
	'RABVV' => 'V',
	'RACVI' => 'V',
	'RADMA' => 'E',
	'RADMG' => 'E',
	'RADPA' => 'E',
	'RAHAQ' => 'B',
	'RAIAR' => 'E',
	'RAJCL' => 'E',
	'RAJEG' => 'E',
	'RAJER' => 'E',
	'RAJOC' => 'E',
	'RAJRA' => 'E',
	'RAJRH' => 'E',
	'RALEJ' => 'B',
	'RALEU' => 'B',
	'RALLI' => 'E',
	'RALME' => 'B',
	'RALSO' => 'B',
	'RAMBR' => 'E',
	'RAMCA' => 'E',
	'RAMCU' => 'E',
	'RAMTO' => 'E',
	'RANAC' => 'E',
	'RANAD' => 'E',
	'RANAE' => 'E',
	'RANAM' => 'E',
	'RANAU' => 'E',
	'RANBE' => 'E',
	'RANBO' => 'E',
	'RANBP' => 'E',
	'RANBU' => 'E',
	'RANCA' => 'E',
	'RANCL' => 'E',
	'RANCR' => 'E',
	'RANCU' => 'E',
	'RANDA' => 'E',
	'RANDI' => 'E',
	'RANDY' => 'E',
	'RANEN' => 'E',
	'RANES' => 'E',
	'RANFI' => 'E',
	'RANGL' => 'E',
	'RANGU' => 'E',
	'RANHU' => 'E',
	'RANJA' => 'E',
	'RANLE' => 'E',
	'RANLI' => 'E',
	'RANLU' => 'E',
	'RANLY' => 'E',
	'RANMA' => 'E',
	'RANNI' => 'E',
	'RANPA' => 'E',
	'RANPE' => 'E',
	'RANPI' => 'E',
	'RANPL' => 'E',
	'RANRE' => 'E',
	'RANRI' => 'E',
	'RANRU' => 'E',
	'RANSA' => 'E',
	'RANSE' => 'E',
	'RANSI' => 'E',
	'RANSP' => 'E',
	'RANSV' => 'E',
	'RANSY' => 'E',
	'RANTA' => 'E',
	'RANTE' => 'E',
	'RANTR' => 'E',
	'RAPCA' => 'E',
	'RAPCU' => 'E',
	'RAPLA' => 'E',
	'RAPME' => 'E',
	'RAPRA' => 'E',
	'RAPSA' => 'E',
	'RAPSH' => 'E',
	'RAPTH' => 'E',
	'RARFA' => 'B',
	'RASEL' => 'E',
	'RASHE' => 'E',
	'RASKA' => 'E',
	'RASPA' => 'E',
	'RAT' => 'E',
	'RATAF' => 'E',
	'RATAR' => 'E',
	'RATBI' => 'E',
	'RATCL' => 'E',
	'RATCO' => 'E',
	'RATEV' => 'E',
	'RATEX' => 'E',
	'RATFU' => 'E',
	'RATLE' => 'E',
	'RATRA' => 'B',
	'RATRT' => 'E',
	'RATSO' => 'E',
	'RATTA' => 'E',
	'RATTI' => 'E',
	'RATTU' => 'E',
	'RATVI' => 'E',
	'RAUMA' => 'E',
	'RAUSE' => 'E',
	'RAVRI' => 'E',
	'RBDV' => 'V',
	'RBSDV' => 'V',
	'RCMV' => 'V',
	'RCMVM' => 'V',
	'RCNMV' => 'V',
	'RDV' => 'V',
	'RDVA' => 'V',
	'RDVF' => 'V',
	'RDVO' => 'V',
	'RDVS' => 'V',
	'RECAE' => 'E',
	'RECAM' => 'E',
	'RECAV' => 'E',
	'REDAR' => 'E',
	'REDFU' => 'E',
	'REDRE' => 'E',
	'REGCA' => 'E',
	'REGRE' => 'E',
	'REGSA' => 'E',
	'REIAU' => 'E',
	'REIFU' => 'E',
	'REIHU' => 'E',
	'REIME' => 'E',
	'REIMX' => 'E',
	'REIRA' => 'E',
	'REISU' => 'E',
	'REMPE' => 'E',
	'RENKO' => 'E',
	'RENMU' => 'E',
	'RENRE' => 'E',
	'RENSA' => 'B',
	'RENSL' => 'E',
	'REOVD' => 'V',
	'REOVJ' => 'V',
	'REOVL' => 'V',
	'RETFI' => 'E',
	'RETFL' => 'E',
	'RETTI' => 'E',
	'RGDV' => 'V',
	'RHABA' => 'E',
	'RHABR' => 'E',
	'RHACA' => 'E',
	'RHACO' => 'E',
	'RHAFU' => 'E',
	'RHAHU' => 'E',
	'RHAPO' => 'E',
	'RHAPU' => 'E',
	'RHASA' => 'E',
	'RHASC' => 'E',
	'RHASP' => 'E',
	'RHATT' => 'E',
	'RHCM6' => 'V',
	'RHDV' => 'V',
	'RHDV3' => 'V',
	'RHDVA' => 'V',
	'RHDVB' => 'V',
	'RHDVF' => 'V',
	'RHDVR' => 'V',
	'RHDVS' => 'V',
	'RHEAM' => 'E',
	'RHEMA' => 'E',
	'RHEOC' => 'E',
	'RHEVI' => 'E',
	'RHIAF' => 'E',
	'RHIAL' => 'E',
	'RHIAP' => 'E',
	'RHIAT' => 'E',
	'RHIBL' => 'E',
	'RHIBU' => 'E',
	'RHICA' => 'E',
	'RHICH' => 'E',
	'RHICP' => 'B',
	'RHICY' => 'E',
	'RHIDA' => 'E',
	'RHIDE' => 'E',
	'RHIEC' => 'B',
	'RHIET' => 'B',
	'RHIEU' => 'E',
	'RHIFE' => 'E',
	'RHIFI' => 'E',
	'RHIFR' => 'B',
	'RHIGA' => 'B',
	'RHIHA' => 'E',
	'RHIHE' => 'B',
	'RHIHI' => 'E',
	'RHIJA' => 'E',
	'RHIL3' => 'B',
	'RHILC' => 'E',
	'RHILE' => 'B',
	'RHILO' => 'B',
	'RHILP' => 'B',
	'RHILT' => 'B',
	'RHILU' => 'B',
	'RHILV' => 'B',
	'RHIMA' => 'E',
	'RHIMC' => 'E',
	'RHIME' => 'B',
	'RHIMI' => 'E',
	'RHIMO' => 'E',
	'RHIMS' => 'E',
	'RHINI' => 'E',
	'RHIOL' => 'E',
	'RHIOR' => 'E',
	'RHIPI' => 'E',
	'RHIPL' => 'E',
	'RHIPM' => 'E',
	'RHIPU' => 'E',
	'RHIRA' => 'E',
	'RHIS1' => 'B',
	'RHIS3' => 'B',
	'RHISA' => 'E',
	'RHISB' => 'B',
	'RHISH' => 'B',
	'RHISI' => 'E',
	'RHISM' => 'B',
	'RHISN' => 'B',
	'RHISO' => 'E',
	'RHISP' => 'B',
	'RHIST' => 'E',
	'RHISY' => 'E',
	'RHITR' => 'B',
	'RHIUN' => 'E',
	'RHIWE' => 'E',
	'RHOAA' => 'E',
	'RHOAB' => 'E',
	'RHOAC' => 'B',
	'RHOAL' => 'E',
	'RHOAM' => 'E',
	'RHOAR' => 'E',
	'RHOAT' => 'E',
	'RHOAU' => 'E',
	'RHOBA' => 'B',
	'RHOBL' => 'B',
	'RHOBR' => 'E',
	'RHOCA' => 'B',
	'RHOCD' => 'E',
	'RHOCE' => 'B',
	'RHOCH' => 'E',
	'RHOCM' => 'E',
	'RHOCN' => 'E',
	'RHOCO' => 'B',
	'RHOCT' => 'E',
	'RHOCU' => 'E',
	'RHODI' => 'E',
	'RHOE4' => 'B',
	'RHOEI' => 'E',
	'RHOER' => 'B',
	'RHOFA' => 'B',
	'RHOFB' => 'E',
	'RHOFD' => 'B',
	'RHOFE' => 'B',
	'RHOFL' => 'E',
	'RHOFO' => 'E',
	'RHOFR' => 'E',
	'RHOFU' => 'B',
	'RHOGA' => 'E',
	'RHOGE' => 'B',
	'RHOGL' => 'B',
	'RHOGO' => 'B',
	'RHOGR' => 'E',
	'RHOGU' => 'E',
	'RHOHI' => 'E',
	'RHOHO' => 'E',
	'RHOHY' => 'E',
	'RHOIM' => 'E',
	'RHOIN' => 'E',
	'RHOKA' => 'E',
	'RHOKI' => 'E',
	'RHOLU' => 'E',
	'RHOMA' => 'B',
	'RHOMC' => 'E',
	'RHOML' => 'E',
	'RHOMN' => 'E',
	'RHOMO' => 'B',
	'RHOMR' => 'B',
	'RHOMS' => 'E',
	'RHOMU' => 'E',
	'RHOMX' => 'E',
	'RHONE' => 'E',
	'RHONO' => 'E',
	'RHOOC' => 'E',
	'RHOOP' => 'B',
	'RHOP2' => 'B',
	'RHOPA' => 'B',
	'RHOPB' => 'B',
	'RHOPC' => 'E',
	'RHOPD' => 'E',
	'RHOPE' => 'E',
	'RHOPH' => 'B',
	'RHOPI' => 'E',
	'RHOPL' => 'E',
	'RHOPN' => 'E',
	'RHOPO' => 'E',
	'RHOPR' => 'E',
	'RHOPS' => 'B',
	'RHORA' => 'E',
	'RHORB' => 'E',
	'RHORE' => 'E',
	'RHORH' => 'B',
	'RHORT' => 'B',
	'RHORU' => 'B',
	'RHOS2' => 'E',
	'RHOS4' => 'B',
	'RHOS7' => 'B',
	'RHOSA' => 'B',
	'RHOSB' => 'E',
	'RHOSC' => 'E',
	'RHOSD' => 'B',
	'RHOSE' => 'E',
	'RHOSF' => 'E',
	'RHOSG' => 'B',
	'RHOSH' => 'B',
	'RHOSI' => 'B',
	'RHOSJ' => 'E',
	'RHOSL' => 'E',
	'RHOSM' => 'B',
	'RHOSN' => 'E',
	'RHOSO' => 'B',
	'RHOSP' => 'B',
	'RHOSQ' => 'B',
	'RHOSR' => 'B',
	'RHOSS' => 'E',
	'RHOST' => 'B',
	'RHOSU' => 'B',
	'RHOSY' => 'E',
	'RHOTA' => 'E',
	'RHOTE' => 'B',
	'RHOTN' => 'E',
	'RHOTO' => 'E',
	'RHOTR' => 'E',
	'RHOTS' => 'E',
	'RHOUN' => 'E',
	'RHOVA' => 'B',
	'RHOVI' => 'B',
	'RHOVL' => 'E',
	'RHOVR' => 'E',
	'RHOWA' => 'E',
	'RHPV1' => 'V',
	'RHUAM' => 'E',
	'RHUAR' => 'E',
	'RHUCH' => 'E',
	'RHUCO' => 'E',
	'RHUCR' => 'E',
	'RHUGL' => 'E',
	'RHUIN' => 'E',
	'RHUKE' => 'E',
	'RHULA' => 'E',
	'RHUMC' => 'E',
	'RHUMI' => 'E',
	'RHUOV' => 'E',
	'RHUPU' => 'E',
	'RHUSA' => 'E',
	'RHUTR' => 'E',
	'RHUTY' => 'E',
	'RHUVE' => 'E',
	'RHUVI' => 'E',
	'RHYAM' => 'E',
	'RHYDO' => 'E',
	'RHYFU' => 'E',
	'RHYIS' => 'E',
	'RHYNA' => 'E',
	'RHYOR' => 'E',
	'RHYRA' => 'E',
	'RHYSE' => 'E',
	'RIBAM' => 'E',
	'RIBCA' => 'E',
	'RIBIN' => 'E',
	'RIBNI' => 'E',
	'RIBSP' => 'E',
	'RICAF' => 'B',
	'RICAK' => 'B',
	'RICAM' => 'B',
	'RICAU' => 'B',
	'RICBE' => 'B',
	'RICBR' => 'B',
	'RICCA' => 'B',
	'RICCN' => 'B',
	'RICCO' => 'E',
	'RICDU' => 'E',
	'RICFE' => 'B',
	'RICFL' => 'E',
	'RICHE' => 'B',
	'RICJA' => 'B',
	'RICMA' => 'B',
	'RICMN' => 'B',
	'RICMO' => 'B',
	'RICNA' => 'E',
	'RICPA' => 'B',
	'RICPR' => 'B',
	'RICRH' => 'B',
	'RICRI' => 'B',
	'RICSI' => 'B',
	'RICSL' => 'B',
	'RICTS' => 'B',
	'RICTY' => 'B',
	'RIEAN' => 'B',
	'RIEOB' => 'E',
	'RIFPA' => 'E',
	'RIFPS' => 'B',
	'RINDB' => 'V',
	'RINDK' => 'V',
	'RINDL' => 'V',
	'RINDR' => 'V',
	'RINDU' => 'V',
	'RIPCL' => 'E',
	'RIPRI' => 'E',
	'RISTR' => 'E',
	'RIVHU' => 'E',
	'RIVMA' => 'E',
	'RIVPR' => 'E',
	'RMCFV' => 'V',
	'RMV' => 'V',
	'RMVCA' => 'V',
	'RMVHR' => 'V',
	'ROBPS' => 'E',
	'ROBSA' => 'E',
	'ROBSP' => 'E',
	'RODSP' => 'E',
	'ROJSU' => 'E',
	'ROLRO' => 'E',
	'ROMCO' => 'E',
	'ROMCU' => 'E',
	'ROMDI' => 'E',
	'ROMGU' => 'E',
	'ROMMI' => 'E',
	'ROMRE' => 'E',
	'RORAM' => 'E',
	'RORCU' => 'E',
	'RORGA' => 'E',
	'RORGO' => 'E',
	'RORIN' => 'E',
	'RORPA' => 'E',
	'RORSY' => 'E',
	'ROSAC' => 'E',
	'ROSCA' => 'E',
	'ROSCE' => 'B',
	'ROSCH' => 'E',
	'ROSCL' => 'E',
	'ROSCN' => 'E',
	'ROSDA' => 'E',
	'ROSDO' => 'B',
	'ROSFO' => 'E',
	'ROSGI' => 'E',
	'ROSHC' => 'E',
	'ROSMU' => 'E',
	'ROSNE' => 'E',
	'ROSOF' => 'E',
	'ROSPA' => 'E',
	'ROSPL' => 'E',
	'ROSRU' => 'E',
	'ROSST' => 'E',
	'ROTA1' => 'V',
	'ROTB4' => 'V',
	'ROTB5' => 'V',
	'ROTB6' => 'V',
	'ROTB9' => 'V',
	'ROTBA' => 'V',
	'ROTBB' => 'V',
	'ROTBC' => 'V',
	'ROTBJ' => 'V',
	'ROTBK' => 'V',
	'ROTBN' => 'V',
	'ROTBR' => 'V',
	'ROTBS' => 'V',
	'ROTBT' => 'V',
	'ROTBU' => 'V',
	'ROTBV' => 'V',
	'ROTCC' => 'V',
	'ROTD9' => 'V',
	'ROTE1' => 'V',
	'ROTE2' => 'V',
	'ROTEH' => 'V',
	'ROTEL' => 'V',
	'ROTEO' => 'V',
	'ROTF1' => 'V',
	'ROTF6' => 'V',
	'ROTGA' => 'V',
	'ROTGI' => 'V',
	'ROTH1' => 'V',
	'ROTH2' => 'V',
	'ROTH3' => 'V',
	'ROTH4' => 'V',
	'ROTH5' => 'V',
	'ROTH6' => 'V',
	'ROTH7' => 'V',
	'ROTH8' => 'V',
	'ROTH9' => 'V',
	'ROTHA' => 'V',
	'ROTHB' => 'V',
	'ROTHC' => 'V',
	'ROTHD' => 'V',
	'ROTHE' => 'V',
	'ROTHF' => 'V',
	'ROTHG' => 'V',
	'ROTHH' => 'V',
	'ROTHI' => 'V',
	'ROTHJ' => 'V',
	'ROTHK' => 'V',
	'ROTHL' => 'V',
	'ROTHM' => 'V',
	'ROTHN' => 'V',
	'ROTHO' => 'V',
	'ROTHP' => 'V',
	'ROTHQ' => 'V',
	'ROTHR' => 'V',
	'ROTHS' => 'V',
	'ROTHT' => 'V',
	'ROTHU' => 'V',
	'ROTHV' => 'V',
	'ROTHW' => 'V',
	'ROTHX' => 'V',
	'ROTHY' => 'V',
	'ROTOR' => 'E',
	'ROTP2' => 'V',
	'ROTP3' => 'V',
	'ROTP5' => 'V',
	'ROTP6' => 'V',
	'ROTPB' => 'V',
	'ROTPC' => 'V',
	'ROTPG' => 'V',
	'ROTPK' => 'V',
	'ROTPM' => 'V',
	'ROTPY' => 'V',
	'ROTRA' => 'V',
	'ROTRE' => 'E',
	'ROTRH' => 'V',
	'ROTS1' => 'V',
	'ROTS4' => 'V',
	'ROTSF' => 'V',
	'ROTSP' => 'V',
	'ROTSR' => 'V',
	'ROTSS' => 'V',
	'ROUAE' => 'E',
	'ROUAM' => 'E',
	'ROUAN' => 'E',
	'ROULA' => 'E',
	'ROULE' => 'E',
	'ROUMA' => 'E',
	'ROYOL' => 'E',
	'ROYRE' => 'E',
	'RRASV' => 'V',
	'RRV2' => 'V',
	'RRVC' => 'V',
	'RRVN' => 'V',
	'RRVS' => 'V',
	'RRVT' => 'V',
	'RSFFV' => 'V',
	'RSIV' => 'V',
	'RSVH1' => 'V',
	'RSVM' => 'V',
	'RSVP' => 'V',
	'RSVPA' => 'V',
	'RSVSA' => 'V',
	'RSVSB' => 'V',
	'RSVSE' => 'V',
	'RSVSR' => 'V',
	'RSVT' => 'V',
	'RTBVP' => 'V',
	'RTRV' => 'V',
	'RTSVA' => 'V',
	'RTSVT' => 'V',
	'RUBAR' => 'E',
	'RUBID' => 'E',
	'RUBNI' => 'E',
	'RUBOD' => 'E',
	'RUBST' => 'B',
	'RUBTI' => 'E',
	'RUBUR' => 'E',
	'RUBV' => 'V',
	'RUBVB' => 'V',
	'RUBVC' => 'V',
	'RUBVD' => 'V',
	'RUBVH' => 'V',
	'RUBVM' => 'V',
	'RUBVN' => 'V',
	'RUBVO' => 'V',
	'RUBVR' => 'V',
	'RUBVT' => 'V',
	'RUBVV' => 'V',
	'RUBXD' => 'B',
	'RUDHI' => 'E',
	'RUDSA' => 'E',
	'RUEGE' => 'B',
	'RUMAC' => 'E',
	'RUMAL' => 'B',
	'RUMFL' => 'B',
	'RUMGN' => 'B',
	'RUMHA' => 'B',
	'RUMOB' => 'E',
	'RUMPE' => 'E',
	'RUPPY' => 'E',
	'RUPRP' => 'E',
	'RUPRU' => 'E',
	'RUSAC' => 'E',
	'RUTFR' => 'E',
	'RUTGR' => 'E',
	'RUTRU' => 'E',
	'RVFV' => 'V',
	'RVFVZ' => 'V',
	'SABAN' => 'E',
	'SABDO' => 'E',
	'SABMA' => 'E',
	'SABSP' => 'E',
	'SACBA' => 'E',
	'SACBI' => 'E',
	'SACBR' => 'E',
	'SACCA' => 'E',
	'SACD2' => 'B',
	'SACDI' => 'E',
	'SACDO' => 'E',
	'SACED' => 'E',
	'SACER' => 'B',
	'SACEX' => 'E',
	'SACFI' => 'E',
	'SACHI' => 'B',
	'SACHY' => 'E',
	'SACKL' => 'E',
	'SACKO' => 'E',
	'SACKU' => 'E',
	'SACLE' => 'E',
	'SACMI' => 'E',
	'SACMO' => 'E',
	'SACOF' => 'E',
	'SACPA' => 'E',
	'SACPS' => 'E',
	'SACRO' => 'E',
	'SACSE' => 'E',
	'SACSI' => 'E',
	'SACSP' => 'E',
	'SAGBB' => 'E',
	'SAGBM' => 'E',
	'SAGFU' => 'E',
	'SAGGE' => 'E',
	'SAGIM' => 'E',
	'SAGLA' => 'E',
	'SAGLB' => 'E',
	'SAGLE' => 'E',
	'SAGMI' => 'E',
	'SAGMM' => 'E',
	'SAGMN' => 'E',
	'SAGMO' => 'E',
	'SAGMY' => 'E',
	'SAGNI' => 'E',
	'SAGOE' => 'E',
	'SAGRO' => 'E',
	'SAGSA' => 'E',
	'SAGV' => 'V',
	'SAIBB' => 'E',
	'SAIOE' => 'E',
	'SAISC' => 'E',
	'SAITA' => 'E',
	'SAIUS' => 'E',
	'SALAB' => 'B',
	'SALAE' => 'B',
	'SALAL' => 'E',
	'SALAN' => 'B',
	'SALAS' => 'B',
	'SALAT' => 'E',
	'SALAU' => 'E',
	'SALBA' => 'E',
	'SALBE' => 'B',
	'SALBI' => 'E',
	'SALBL' => 'B',
	'SALBN' => 'B',
	'SALBO' => 'B',
	'SALBU' => 'B',
	'SALCC' => 'E',
	'SALCH' => 'B',
	'SALCL' => 'E',
	'SALCN' => 'E',
	'SALCO' => 'E',
	'SALDE' => 'B',
	'SALDI' => 'E',
	'SALDL' => 'E',
	'SALDU' => 'B',
	'SALDZ' => 'B',
	'SALEE' => 'B',
	'SALEN' => 'B',
	'SALET' => 'B',
	'SALEU' => 'E',
	'SALFO' => 'E',
	'SALGA' => 'E',
	'SALGL' => 'B',
	'SALGU' => 'E',
	'SALHA' => 'B',
	'SALHO' => 'B',
	'SALIN' => 'B',
	'SALKA' => 'E',
	'SALLE' => 'E',
	'SALMC' => 'B',
	'SALMI' => 'E',
	'SALMO' => 'B',
	'SALMS' => 'B',
	'SALMU' => 'B',
	'SALNA' => 'B',
	'SALNE' => 'B',
	'SALOF' => 'E',
	'SALON' => 'B',
	'SALOR' => 'B',
	'SALPA' => 'B',
	'SALPE' => 'E',
	'SALPL' => 'E',
	'SALPO' => 'B',
	'SALPR' => 'E',
	'SALPU' => 'B',
	'SALPV' => 'E',
	'SALRD' => 'B',
	'SALRE' => 'E',
	'SALRO' => 'B',
	'SALRU' => 'B',
	'SALSA' => 'E',
	'SALSC' => 'E',
	'SALSE' => 'B',
	'SALSL' => 'E',
	'SALSN' => 'E',
	'SALSP' => 'B',
	'SALTH' => 'B',
	'SALTI' => 'B',
	'SALTP' => 'B',
	'SALTR' => 'E',
	'SALTY' => 'B',
	'SALVI' => 'B',
	'SALVR' => 'E',
	'SALZA' => 'E',
	'SAMCA' => 'E',
	'SAMCE' => 'E',
	'SAMCR' => 'E',
	'SAMCY' => 'E',
	'SAMNI' => 'E',
	'SAMRA' => 'E',
	'SAMSA' => 'E',
	'SAMVA' => 'E',
	'SANAU' => 'E',
	'SANCA' => 'E',
	'SANCN' => 'E',
	'SANME' => 'E',
	'SANOF' => 'E',
	'SAPFE' => 'E',
	'SAPMO' => 'E',
	'SAPOF' => 'E',
	'SAPSA' => 'E',
	'SAPSE' => 'E',
	'SARBU' => 'E',
	'SARCA' => 'E',
	'SARCH' => 'E',
	'SARCR' => 'E',
	'SARDA' => 'E',
	'SARDI' => 'E',
	'SARFA' => 'E',
	'SARFL' => 'E',
	'SARFU' => 'E',
	'SARGA' => 'E',
	'SARGI' => 'E',
	'SARGL' => 'E',
	'SARHA' => 'E',
	'SARHE' => 'E',
	'SARLI' => 'E',
	'SARME' => 'E',
	'SARMI' => 'E',
	'SARMU' => 'E',
	'SARNE' => 'E',
	'SAROR' => 'E',
	'SARPA' => 'E',
	'SARPE' => 'E',
	'SARPI' => 'E',
	'SARPR' => 'E',
	'SARPU' => 'E',
	'SARSA' => 'E',
	'SARSC' => 'E',
	'SARSL' => 'E',
	'SARSP' => 'E',
	'SARTI' => 'E',
	'SARVA' => 'E',
	'SARVE' => 'B',
	'SARXA' => 'E',
	'SASAL' => 'E',
	'SATHO' => 'E',
	'SATJU' => 'E',
	'SATMO' => 'E',
	'SAUAT' => 'E',
	'SAUCE' => 'E',
	'SAUEL' => 'E',
	'SAUGU' => 'E',
	'SAUHI' => 'E',
	'SAUME' => 'E',
	'SAUUN' => 'E',
	'SAUVA' => 'E',
	'SAUWA' => 'E',
	'SAXCE' => 'E',
	'SAXDA' => 'E',
	'SAXFE' => 'E',
	'SAXIN' => 'E',
	'SAXME' => 'E',
	'SAXOP' => 'E',
	'SAXPU' => 'E',
	'SAXSQ' => 'E',
	'SAXST' => 'E',
	'SAXVI' => 'E',
	'SAYPH' => 'E',
	'SBMV' => 'V',
	'SBMVG' => 'V',
	'SBMVN' => 'V',
	'SCAAL' => 'E',
	'SCAAQ' => 'E',
	'SCACO' => 'E',
	'SCAFL' => 'E',
	'SCAFU' => 'E',
	'SCAGU' => 'E',
	'SCAIN' => 'E',
	'SCAIO' => 'B',
	'SCALA' => 'E',
	'SCAMI' => 'E',
	'SCAOR' => 'E',
	'SCAPL' => 'E',
	'SCAPY' => 'E',
	'SCARA' => 'E',
	'SCAST' => 'E',
	'SCATO' => 'E',
	'SCAVE' => 'E',
	'SCECA' => 'E',
	'SCEGA' => 'E',
	'SCEGR' => 'E',
	'SCEMA' => 'E',
	'SCEOB' => 'E',
	'SCEOC' => 'E',
	'SCEQU' => 'E',
	'SCEUN' => 'E',
	'SCEVI' => 'E',
	'SCEWO' => 'E',
	'SCHAM' => 'E',
	'SCHBO' => 'E',
	'SCHCH' => 'E',
	'SCHCO' => 'E',
	'SCHDU' => 'E',
	'SCHFR' => 'E',
	'SCHGA' => 'E',
	'SCHGR' => 'E',
	'SCHHA' => 'E',
	'SCHJA' => 'E',
	'SCHJP' => 'E',
	'SCHKA' => 'E',
	'SCHLA' => 'E',
	'SCHMA' => 'E',
	'SCHMD' => 'E',
	'SCHME' => 'E',
	'SCHMO' => 'E',
	'SCHNI' => 'E',
	'SCHOT' => 'E',
	'SCHPA' => 'E',
	'SCHPL' => 'E',
	'SCHPO' => 'E',
	'SCHPR' => 'E',
	'SCHSP' => 'E',
	'SCHTR' => 'E',
	'SCIAB' => 'E',
	'SCIAE' => 'E',
	'SCICA' => 'E',
	'SCICO' => 'E',
	'SCIDA' => 'E',
	'SCIGR' => 'E',
	'SCIIG' => 'E',
	'SCILI' => 'E',
	'SCINI' => 'E',
	'SCIOC' => 'E',
	'SCIPE' => 'E',
	'SCIPI' => 'E',
	'SCIST' => 'E',
	'SCIVE' => 'E',
	'SCIVU' => 'E',
	'SCLSC' => 'E',
	'SCMVC' => 'V',
	'SCOAU' => 'E',
	'SCOBI' => 'E',
	'SCOBR' => 'E',
	'SCOCA' => 'E',
	'SCOCI' => 'E',
	'SCOCO' => 'E',
	'SCODU' => 'E',
	'SCOGR' => 'E',
	'SCOGU' => 'E',
	'SCOHE' => 'E',
	'SCOJA' => 'E',
	'SCOJP' => 'E',
	'SCOJU' => 'E',
	'SCOMA' => 'E',
	'SCOMC' => 'E',
	'SCOMI' => 'E',
	'SCOMX' => 'E',
	'SCORE' => 'E',
	'SCOSC' => 'E',
	'SCOSI' => 'E',
	'SCOTE' => 'E',
	'SCOTR' => 'E',
	'SCOUM' => 'E',
	'SCOWA' => 'E',
	'SCOXE' => 'E',
	'SCRCA' => 'E',
	'SCRTR' => 'E',
	'SCSV' => 'V',
	'SCSVF' => 'V',
	'SCSVJ' => 'V',
	'SCUAL' => 'E',
	'SCUAT' => 'E',
	'SCUBA' => 'E',
	'SCUBO' => 'E',
	'SCUCO' => 'E',
	'SCUGA' => 'E',
	'SCUID' => 'E',
	'SCUIN' => 'E',
	'SCULA' => 'E',
	'SCVLA' => 'V',
	'SCVLB' => 'V',
	'SCVM1' => 'V',
	'SCYCA' => 'E',
	'SCYFE' => 'E',
	'SCYLA' => 'E',
	'SCYLI' => 'E',
	'SCYLO' => 'E',
	'SCYMA' => 'E',
	'SCYNO' => 'E',
	'SCYSC' => 'E',
	'SCYSE' => 'E',
	'SCYSP' => 'E',
	'SCYTO' => 'E',
	'SCYUN' => 'E',
	'SCYVI' => 'E',
	'SEBSA' => 'E',
	'SEBSC' => 'E',
	'SECCE' => 'E',
	'SECDI' => 'E',
	'SECED' => 'E',
	'SECST' => 'E',
	'SEDRU' => 'E',
	'SEGFL' => 'E',
	'SEIAU' => 'E',
	'SEIMO' => 'E',
	'SEINO' => 'E',
	'SELAP' => 'E',
	'SELAU' => 'E',
	'SELBO' => 'E',
	'SELBR' => 'E',
	'SELCR' => 'E',
	'SELDE' => 'E',
	'SELDO' => 'E',
	'SELHA' => 'E',
	'SELLE' => 'E',
	'SELLP' => 'E',
	'SELMA' => 'E',
	'SELME' => 'E',
	'SELMI' => 'E',
	'SELMO' => 'E',
	'SELOR' => 'E',
	'SELPE' => 'E',
	'SELRE' => 'E',
	'SELRF' => 'E',
	'SELRP' => 'E',
	'SELRU' => 'B',
	'SELSE' => 'E',
	'SELSL' => 'E',
	'SELTH' => 'E',
	'SELUN' => 'E',
	'SELVO' => 'E',
	'SEMEN' => 'E',
	'SEMPU' => 'E',
	'SENAN' => 'E',
	'SEND6' => 'V',
	'SENDA' => 'V',
	'SENDE' => 'V',
	'SENDF' => 'V',
	'SENDH' => 'V',
	'SENDN' => 'V',
	'SENDO' => 'V',
	'SENDZ' => 'V',
	'SENJA' => 'E',
	'SENMI' => 'E',
	'SENSQ' => 'E',
	'SENVE' => 'E',
	'SENVU' => 'E',
	'SEOU8' => 'V',
	'SEOUR' => 'V',
	'SEOUS' => 'V',
	'SEPAT' => 'E',
	'SEPFE' => 'E',
	'SEPLE' => 'E',
	'SEPLY' => 'E',
	'SEPOF' => 'E',
	'SEPPH' => 'E',
	'SEPSE' => 'E',
	'SEQSE' => 'E',
	'SERCA' => 'E',
	'SERCB' => 'E',
	'SERDU' => 'E',
	'SERFA' => 'E',
	'SERFI' => 'B',
	'SERFO' => 'B',
	'SERLI' => 'B',
	'SERMA' => 'B',
	'SEROD' => 'B',
	'SERPL' => 'B',
	'SERQU' => 'E',
	'SERRE' => 'E',
	'SERRU' => 'B',
	'SERSP' => 'B',
	'SESIN' => 'E',
	'SESPO' => 'E',
	'SESRO' => 'E',
	'SESSE' => 'E',
	'SETBR' => 'E',
	'SETCE' => 'E',
	'SETIT' => 'E',
	'SETPU' => 'E',
	'SETRO' => 'E',
	'SETRU' => 'E',
	'SETVI' => 'E',
	'SFSV' => 'V',
	'SFV' => 'V',
	'SFV1' => 'V',
	'SFV3L' => 'V',
	'SFVKA' => 'V',
	'SHEAR' => 'E',
	'SHECO' => 'B',
	'SHEDO' => 'B',
	'SHEEP' => 'E',
	'SHEFN' => 'B',
	'SHEFR' => 'B',
	'SHEGU' => 'E',
	'SHEHA' => 'B',
	'SHELA' => 'E',
	'SHELO' => 'E',
	'SHEMA' => 'B',
	'SHEMO' => 'E',
	'SHEON' => 'B',
	'SHEPU' => 'B',
	'SHESM' => 'B',
	'SHESP' => 'B',
	'SHESR' => 'B',
	'SHEVI' => 'B',
	'SHEVK' => 'V',
	'SHEVN' => 'V',
	'SHFV' => 'V',
	'SHIBO' => 'B',
	'SHIBS' => 'B',
	'SHIDS' => 'B',
	'SHIDY' => 'B',
	'SHIFL' => 'B',
	'SHISO' => 'B',
	'SHISS' => 'B',
	'SHMV' => 'V',
	'SHV1' => 'V',
	'SHV21' => 'V',
	'SHV24' => 'V',
	'SHV2C' => 'V',
	'SHV48' => 'V',
	'SHVX' => 'V',
	'SIALU' => 'E',
	'SIASI' => 'E',
	'SIBNE' => 'E',
	'SIDFU' => 'E',
	'SIGBL' => 'E',
	'SIGGU' => 'E',
	'SIGHI' => 'E',
	'SIGLI' => 'E',
	'SIGMA' => 'V',
	'SIGOC' => 'E',
	'SIGRI' => 'E',
	'SILAS' => 'E',
	'SILBA' => 'E',
	'SILCO' => 'E',
	'SILCU' => 'E',
	'SILDC' => 'E',
	'SILDI' => 'E',
	'SILGA' => 'E',
	'SILKE' => 'E',
	'SILLA' => 'E',
	'SILMA' => 'E',
	'SILME' => 'E',
	'SILOT' => 'E',
	'SILPE' => 'E',
	'SILPO' => 'B',
	'SILPR' => 'E',
	'SILST' => 'B',
	'SIMBU' => 'V',
	'SIMCH' => 'E',
	'SIMSO' => 'E',
	'SIMVI' => 'E',
	'SINAL' => 'E',
	'SINAR' => 'E',
	'SINDO' => 'V',
	'SINDV' => 'V',
	'SINKN' => 'E',
	'SINSA' => 'B',
	'SINSB' => 'B',
	'SINTE' => 'B',
	'SIOLI' => 'E',
	'SIPCU' => 'E',
	'SIPNU' => 'E',
	'SIRGR' => 'E',
	'SIRIM' => 'E',
	'SISAL' => 'E',
	'SISAN' => 'E',
	'SISBA' => 'E',
	'SISCT' => 'E',
	'SISIR' => 'E',
	'SISMI' => 'E',
	'SISMO' => 'E',
	'SISSP' => 'E',
	'SISST' => 'E',
	'SITCA' => 'E',
	'SITGR' => 'E',
	'SITLE' => 'E',
	'SITLI' => 'E',
	'SITOR' => 'E',
	'SITZE' => 'E',
	'SIUSU' => 'E',
	'SIVAM' => 'V',
	'SIVCZ' => 'V',
	'SIVEK' => 'V',
	'SIVG1' => 'V',
	'SIVGB' => 'V',
	'SIVM1' => 'V',
	'SIVM2' => 'V',
	'SIVMA' => 'V',
	'SIVMB' => 'V',
	'SIVMK' => 'V',
	'SIVML' => 'V',
	'SIVMS' => 'V',
	'SIVS4' => 'V',
	'SIVSA' => 'V',
	'SIVSP' => 'V',
	'SIVTA' => 'V',
	'SIVTN' => 'V',
	'SIVV1' => 'V',
	'SIVV2' => 'V',
	'SIVV3' => 'V',
	'SIVVG' => 'V',
	'SIVVT' => 'V',
	'SJNNV' => 'V',
	'SKECO' => 'E',
	'SLCV' => 'V',
	'SLDV' => 'V',
	'SMAMI' => 'E',
	'SMECE' => 'E',
	'SMIAI' => 'E',
	'SMIAR' => 'E',
	'SMIBI' => 'E',
	'SMICR' => 'E',
	'SMICU' => 'E',
	'SMIDL' => 'E',
	'SMIDO' => 'E',
	'SMIGA' => 'E',
	'SMIGI' => 'E',
	'SMIGR' => 'E',
	'SMIHI' => 'E',
	'SMILE' => 'E',
	'SMILO' => 'E',
	'SMIMA' => 'E',
	'SMIMU' => 'E',
	'SMINA' => 'E',
	'SMIOO' => 'E',
	'SMIPS' => 'E',
	'SMIVI' => 'E',
	'SMIYO' => 'E',
	'SMOAR' => 'E',
	'SMRVH' => 'V',
	'SMSV1' => 'V',
	'SMSV4' => 'V',
	'SMYEA' => 'V',
	'SOCMV' => 'V',
	'SODGL' => 'B',
	'SODGM' => 'B',
	'SOLAB' => 'E',
	'SOLAC' => 'E',
	'SOLAE' => 'E',
	'SOLAL' => 'E',
	'SOLAP' => 'E',
	'SOLBR' => 'E',
	'SOLBU' => 'E',
	'SOLCA' => 'E',
	'SOLCC' => 'E',
	'SOLCE' => 'E',
	'SOLCH' => 'E',
	'SOLCI' => 'E',
	'SOLCO' => 'E',
	'SOLCR' => 'E',
	'SOLCS' => 'E',
	'SOLDE' => 'E',
	'SOLDU' => 'E',
	'SOLEL' => 'E',
	'SOLGE' => 'E',
	'SOLGL' => 'E',
	'SOLGR' => 'E',
	'SOLHA' => 'E',
	'SOLIN' => 'E',
	'SOLLA' => 'E',
	'SOLLC' => 'E',
	'SOLLS' => 'E',
	'SOLLY' => 'E',
	'SOLMA' => 'E',
	'SOLME' => 'E',
	'SOLMM' => 'E',
	'SOLNI' => 'E',
	'SOLPE' => 'E',
	'SOLPI' => 'E',
	'SOLPN' => 'E',
	'SOLRI' => 'E',
	'SOLRO' => 'E',
	'SOLSA' => 'E',
	'SOLSC' => 'E',
	'SOLSE' => 'E',
	'SOLSG' => 'E',
	'SOLSO' => 'E',
	'SOLST' => 'E',
	'SOLTU' => 'E',
	'SOLUS' => 'B',
	'SOLVE' => 'E',
	'SOLVI' => 'E',
	'SOMMO' => 'E',
	'SONOL' => 'E',
	'SOPJA' => 'E',
	'SORAC' => 'E',
	'SORAL' => 'E',
	'SORAN' => 'E',
	'SORAR' => 'E',
	'SORAS' => 'E',
	'SORAU' => 'E',
	'SORBA' => 'E',
	'SORBE' => 'E',
	'SORBI' => 'E',
	'SORCA' => 'E',
	'SORCI' => 'E',
	'SORCM' => 'E',
	'SORCO' => 'E',
	'SORCY' => 'E',
	'SORDA' => 'E',
	'SOREQ' => 'E',
	'SOREX' => 'E',
	'SORFI' => 'E',
	'SORFM' => 'E',
	'SORFU' => 'E',
	'SORGA' => 'E',
	'SORGR' => 'E',
	'SORHA' => 'E',
	'SORHD' => 'E',
	'SORHL' => 'E',
	'SORHO' => 'E',
	'SORHY' => 'E',
	'SORIS' => 'E',
	'SORJA' => 'E',
	'SORLO' => 'E',
	'SORMA' => 'E',
	'SORMI' => 'E',
	'SORMN' => 'E',
	'SORMO' => 'E',
	'SORMR' => 'E',
	'SORNE' => 'E',
	'SORNI' => 'E',
	'SOROR' => 'E',
	'SORPA' => 'E',
	'SORPC' => 'E',
	'SORPE' => 'E',
	'SORPO' => 'E',
	'SORPR' => 'E',
	'SORRA' => 'E',
	'SORRO' => 'E',
	'SORSA' => 'E',
	'SORSH' => 'E',
	'SORSM' => 'E',
	'SORSO' => 'E',
	'SORSU' => 'E',
	'SORTE' => 'E',
	'SORTR' => 'E',
	'SORTU' => 'E',
	'SORUG' => 'E',
	'SORUN' => 'E',
	'SORVA' => 'E',
	'SOTFL' => 'E',
	'SOTGU' => 'E',
	'SOUCH' => 'E',
	'SOUV3' => 'V',
	'SOVGS' => 'B',
	'SOYBN' => 'E',
	'SPAAM' => 'E',
	'SPAAU' => 'E',
	'SPACA' => 'E',
	'SPACY' => 'E',
	'SPAEH' => 'E',
	'SPAEU' => 'E',
	'SPAGA' => 'E',
	'SPAGL' => 'E',
	'SPAGO' => 'E',
	'SPAJD' => 'E',
	'SPAJU' => 'E',
	'SPAPE' => 'E',
	'SPASP' => 'E',
	'SPAST' => 'E',
	'SPAWA' => 'E',
	'SPAZE' => 'E',
	'SPDV' => 'V',
	'SPEAD' => 'E',
	'SPEAI' => 'E',
	'SPEAL' => 'E',
	'SPEAN' => 'E',
	'SPEAR' => 'E',
	'SPEAT' => 'E',
	'SPEBE' => 'E',
	'SPECI' => 'E',
	'SPECO' => 'E',
	'SPECU' => 'E',
	'SPECY' => 'E',
	'SPEDA' => 'E',
	'SPEER' => 'E',
	'SPEFR' => 'E',
	'SPEFU' => 'E',
	'SPEID' => 'E',
	'SPELA' => 'E',
	'SPELE' => 'E',
	'SPEMA' => 'E',
	'SPEMD' => 'E',
	'SPEMO' => 'E',
	'SPEMU' => 'E',
	'SPEPA' => 'E',
	'SPEPE' => 'E',
	'SPEPL' => 'E',
	'SPEPY' => 'E',
	'SPERE' => 'E',
	'SPERI' => 'E',
	'SPESA' => 'E',
	'SPESI' => 'E',
	'SPESP' => 'E',
	'SPETE' => 'E',
	'SPETO' => 'E',
	'SPETR' => 'E',
	'SPEUN' => 'E',
	'SPEVA' => 'E',
	'SPEVE' => 'E',
	'SPEWA' => 'E',
	'SPEXA' => 'E',
	'SPHAB' => 'E',
	'SPHAG' => 'E',
	'SPHAL' => 'B',
	'SPHAN' => 'E',
	'SPHAR' => 'B',
	'SPHBA' => 'E',
	'SPHCH' => 'E',
	'SPHCL' => 'E',
	'SPHCO' => 'E',
	'SPHCR' => 'B',
	'SPHCU' => 'E',
	'SPHDO' => 'E',
	'SPHEL' => 'B',
	'SPHGR' => 'E',
	'SPHHU' => 'E',
	'SPHID' => 'E',
	'SPHLE' => 'E',
	'SPHLU' => 'E',
	'SPHMA' => 'E',
	'SPHME' => 'E',
	'SPHPA' => 'E',
	'SPHPU' => 'E',
	'SPHSC' => 'E',
	'SPHSH' => 'E',
	'SPHSP' => 'E',
	'SPHTO' => 'E',
	'SPHTR' => 'E',
	'SPHTT' => 'E',
	'SPHTV' => 'E',
	'SPHVA' => 'E',
	'SPHVG' => 'E',
	'SPHYA' => 'B',
	'SPIAL' => 'E',
	'SPIAP' => 'B',
	'SPIAR' => 'E',
	'SPIAU' => 'B',
	'SPIBA' => 'E',
	'SPIBR' => 'E',
	'SPICA' => 'E',
	'SPICC' => 'B',
	'SPICE' => 'E',
	'SPICI' => 'B',
	'SPIDE' => 'E',
	'SPIER' => 'E',
	'SPIFE' => 'E',
	'SPIIN' => 'E',
	'SPIKU' => 'B',
	'SPIMA' => 'B',
	'SPIMC' => 'E',
	'SPIME' => 'B',
	'SPIMR' => 'E',
	'SPIMU' => 'E',
	'SPIMX' => 'E',
	'SPINI' => 'E',
	'SPIOG' => 'E',
	'SPIOL' => 'E',
	'SPIPA' => 'E',
	'SPIPL' => 'B',
	'SPIPN' => 'E',
	'SPIPO' => 'E',
	'SPIPT' => 'E',
	'SPIPU' => 'E',
	'SPIRU' => 'E',
	'SPISA' => 'E',
	'SPISM' => 'E',
	'SPISO' => 'E',
	'SPISP' => 'B',
	'SPISQ' => 'B',
	'SPISU' => 'E',
	'SPIUR' => 'E',
	'SPIVE' => 'E',
	'SPIVO' => 'E',
	'SPLSP' => 'E',
	'SPMV' => 'V',
	'SPODU' => 'E',
	'SPOER' => 'E',
	'SPOEX' => 'E',
	'SPOFR' => 'E',
	'SPOHA' => 'B',
	'SPOIN' => 'E',
	'SPOLA' => 'E',
	'SPOLI' => 'E',
	'SPOLT' => 'E',
	'SPONI' => 'E',
	'SPOOR' => 'E',
	'SPOSA' => 'E',
	'SPOSC' => 'E',
	'SPOSI' => 'E',
	'SPOSQ' => 'E',
	'SPOST' => 'E',
	'SPOUR' => 'B',
	'SPV1R' => 'V',
	'SPV4' => 'V',
	'SQMVM' => 'V',
	'SQUAC' => 'E',
	'SQUKU' => 'E',
	'SQUSU' => 'E',
	'SRV1' => 'V',
	'SRV2' => 'V',
	'SRV2R' => 'V',
	'SSADV' => 'V',
	'SSV1' => 'V',
	'STAA3' => 'B',
	'STAA8' => 'B',
	'STAAB' => 'B',
	'STAAC' => 'B',
	'STAAM' => 'B',
	'STAAN' => 'B',
	'STAAR' => 'B',
	'STAAS' => 'B',
	'STAAU' => 'B',
	'STAAW' => 'B',
	'STACA' => 'B',
	'STACH' => 'E',
	'STACM' => 'E',
	'STACP' => 'B',
	'STACR' => 'B',
	'STAEP' => 'B',
	'STAEQ' => 'B',
	'STAER' => 'E',
	'STAES' => 'B',
	'STAGA' => 'B',
	'STAHA' => 'B',
	'STAHJ' => 'B',
	'STAHO' => 'B',
	'STAHY' => 'B',
	'STAIN' => 'B',
	'STALE' => 'B',
	'STALU' => 'B',
	'STAMA' => 'A',
	'STAPI' => 'E',
	'STAPU' => 'E',
	'STARE' => 'E',
	'STAS1' => 'B',
	'STAS9' => 'B',
	'STASA' => 'B',
	'STASC' => 'B',
	'STASI' => 'B',
	'STASP' => 'B',
	'STASR' => 'B',
	'STASS' => 'B',
	'STAST' => 'B',
	'STATI' => 'E',
	'STATR' => 'E',
	'STAWA' => 'B',
	'STAXY' => 'B',
	'STEAL' => 'E',
	'STEAT' => 'E',
	'STEBR' => 'E',
	'STECA' => 'E',
	'STECH' => 'E',
	'STECI' => 'E',
	'STECL' => 'E',
	'STECO' => 'E',
	'STEDU' => 'E',
	'STEFR' => 'E',
	'STEHA' => 'E',
	'STEHI' => 'E',
	'STEHS' => 'E',
	'STELO' => 'E',
	'STELP' => 'E',
	'STEME' => 'E',
	'STENE' => 'E',
	'STEPA' => 'E',
	'STEPS' => 'E',
	'STERE' => 'E',
	'STERU' => 'E',
	'STESO' => 'E',
	'STEVM' => 'V',
	'STIAU' => 'B',
	'STICA' => 'E',
	'STIGI' => 'E',
	'STIHE' => 'E',
	'STIJA' => 'E',
	'STITA' => 'E',
	'STIVI' => 'E',
	'STMV' => 'V',
	'STNV1' => 'V',
	'STNV2' => 'V',
	'STOCA' => 'E',
	'STOHE' => 'E',
	'STOLA' => 'E',
	'STOLO' => 'E',
	'STOVA' => 'E',
	'STRA1' => 'B',
	'STRA3' => 'B',
	'STRA5' => 'B',
	'STRAA' => 'B',
	'STRAB' => 'E',
	'STRAC' => 'B',
	'STRAD' => 'B',
	'STRAE' => 'B',
	'STRAG' => 'B',
	'STRAH' => 'B',
	'STRAI' => 'B',
	'STRAK' => 'B',
	'STRAL' => 'B',
	'STRAM' => 'B',
	'STRAN' => 'B',
	'STRAO' => 'B',
	'STRAP' => 'B',
	'STRAR' => 'B',
	'STRAS' => 'B',
	'STRAT' => 'B',
	'STRAU' => 'B',
	'STRAV' => 'B',
	'STRAW' => 'B',
	'STRAY' => 'B',
	'STRAZ' => 'B',
	'STRBA' => 'B',
	'STRBI' => 'B',
	'STRBO' => 'B',
	'STRBU' => 'E',
	'STRC1' => 'B',
	'STRCA' => 'E',
	'STRCB' => 'B',
	'STRCC' => 'B',
	'STRCD' => 'B',
	'STRCE' => 'B',
	'STRCF' => 'E',
	'STRCH' => 'B',
	'STRCI' => 'B',
	'STRCJ' => 'B',
	'STRCK' => 'B',
	'STRCL' => 'B',
	'STRCM' => 'B',
	'STRCN' => 'B',
	'STRCO' => 'B',
	'STRCP' => 'B',
	'STRCR' => 'B',
	'STRCS' => 'B',
	'STRCT' => 'B',
	'STRCU' => 'B',
	'STRCV' => 'B',
	'STRCX' => 'B',
	'STRCY' => 'B',
	'STRCZ' => 'B',
	'STRD7' => 'B',
	'STRDI' => 'B',
	'STRDO' => 'B',
	'STRDR' => 'E',
	'STRDY' => 'B',
	'STREQ' => 'B',
	'STREU' => 'B',
	'STREX' => 'B',
	'STRFI' => 'B',
	'STRFL' => 'B',
	'STRFN' => 'E',
	'STRFR' => 'B',
	'STRGA' => 'B',
	'STRGB' => 'B',
	'STRGC' => 'B',
	'STRGD' => 'B',
	'STRGI' => 'B',
	'STRGL' => 'B',
	'STRGN' => 'B',
	'STRGO' => 'B',
	'STRGP' => 'B',
	'STRGR' => 'B',
	'STRGS' => 'B',
	'STRGT' => 'B',
	'STRGV' => 'B',
	'STRGW' => 'B',
	'STRGY' => 'B',
	'STRHA' => 'B',
	'STRHB' => 'E',
	'STRHE' => 'E',
	'STRHI' => 'B',
	'STRHY' => 'B',
	'STRIE' => 'E',
	'STRIN' => 'B',
	'STRIT' => 'B',
	'STRJU' => 'B',
	'STRKA' => 'B',
	'STRKN' => 'B',
	'STRLA' => 'B',
	'STRLC' => 'E',
	'STRLE' => 'E',
	'STRLH' => 'E',
	'STRLI' => 'B',
	'STRLM' => 'B',
	'STRLN' => 'B',
	'STRLO' => 'B',
	'STRLT' => 'B',
	'STRLU' => 'B',
	'STRLV' => 'B',
	'STRMA' => 'B',
	'STRMB' => 'B',
	'STRMC' => 'B',
	'STRME' => 'E',
	'STRMI' => 'B',
	'STRML' => 'B',
	'STRMO' => 'B',
	'STRMR' => 'B',
	'STRMT' => 'B',
	'STRMU' => 'B',
	'STRMY' => 'B',
	'STRNB' => 'E',
	'STRNE' => 'B',
	'STRNI' => 'B',
	'STRNO' => 'B',
	'STRNU' => 'E',
	'STRNX' => 'E',
	'STROE' => 'E',
	'STROI' => 'B',
	'STROL' => 'B',
	'STRON' => 'B',
	'STROR' => 'B',
	'STRP1' => 'B',
	'STRP3' => 'B',
	'STRP5' => 'B',
	'STRP6' => 'B',
	'STRP8' => 'B',
	'STRP9' => 'B',
	'STRPA' => 'B',
	'STRPB' => 'B',
	'STRPC' => 'B',
	'STRPD' => 'B',
	'STRPE' => 'B',
	'STRPF' => 'B',
	'STRPH' => 'B',
	'STRPL' => 'B',
	'STRPM' => 'B',
	'STRPN' => 'B',
	'STRPO' => 'B',
	'STRPR' => 'B',
	'STRPT' => 'B',
	'STRPU' => 'E',
	'STRPY' => 'B',
	'STRR6' => 'B',
	'STRRA' => 'B',
	'STRRE' => 'B',
	'STRRF' => 'E',
	'STRRI' => 'B',
	'STRRM' => 'B',
	'STRRO' => 'B',
	'STRRS' => 'B',
	'STRRT' => 'B',
	'STRRU' => 'B',
	'STRRY' => 'B',
	'STRS0' => 'B',
	'STRS1' => 'B',
	'STRS3' => 'B',
	'STRS5' => 'B',
	'STRS6' => 'B',
	'STRS8' => 'B',
	'STRS9' => 'B',
	'STRSA' => 'B',
	'STRSB' => 'B',
	'STRSC' => 'B',
	'STRSD' => 'B',
	'STRSE' => 'B',
	'STRSF' => 'B',
	'STRSG' => 'B',
	'STRSH' => 'B',
	'STRSI' => 'B',
	'STRSJ' => 'B',
	'STRSK' => 'B',
	'STRSL' => 'B',
	'STRSM' => 'B',
	'STRSN' => 'B',
	'STRSO' => 'B',
	'STRSP' => 'B',
	'STRSQ' => 'B',
	'STRSR' => 'B',
	'STRSS' => 'B',
	'STRST' => 'B',
	'STRSU' => 'B',
	'STRSZ' => 'B',
	'STRT1' => 'B',
	'STRT2' => 'B',
	'STRTC' => 'E',
	'STRTE' => 'B',
	'STRTH' => 'B',
	'STRTI' => 'B',
	'STRTL' => 'B',
	'STRTM' => 'B',
	'STRTO' => 'B',
	'STRTR' => 'B',
	'STRTT' => 'E',
	'STRUB' => 'B',
	'STRUR' => 'E',
	'STRVA' => 'E',
	'STRVD' => 'B',
	'STRVE' => 'B',
	'STRVF' => 'B',
	'STRVG' => 'B',
	'STRVI' => 'B',
	'STRVL' => 'B',
	'STRVN' => 'B',
	'STRVO' => 'B',
	'STRVR' => 'B',
	'STRWE' => 'B',
	'STRWO' => 'E',
	'STUAR' => 'E',
	'STUBE' => 'E',
	'STUBI' => 'E',
	'STUBO' => 'E',
	'STUCI' => 'E',
	'STUER' => 'E',
	'STULI' => 'E',
	'STULS' => 'E',
	'STULU' => 'E',
	'STUMA' => 'E',
	'STUMG' => 'E',
	'STUMI' => 'E',
	'STUMO' => 'E',
	'STUNA' => 'E',
	'STUNE' => 'E',
	'STUOP' => 'E',
	'STUTI' => 'E',
	'STUVU' => 'E',
	'STYCL' => 'E',
	'STYDI' => 'E',
	'STYHA' => 'E',
	'STYHU' => 'E',
	'STYJA' => 'E',
	'STYLE' => 'E',
	'STYLO' => 'E',
	'STYMT' => 'E',
	'STYMY' => 'E',
	'STYOF' => 'E',
	'STYPL' => 'E',
	'STYPU' => 'E',
	'STYZE' => 'E',
	'SUAMA' => 'E',
	'SUBDO' => 'E',
	'SUBFI' => 'E',
	'SUIBO' => 'E',
	'SULAC' => 'A',
	'SULDE' => 'B',
	'SULDI' => 'E',
	'SULIS' => 'A',
	'SULME' => 'A',
	'SULOH' => 'A',
	'SULSH' => 'A',
	'SULSO' => 'A',
	'SULSP' => 'A',
	'SULSR' => 'A',
	'SULSU' => 'E',
	'SULTO' => 'A',
	'SUMVS' => 'V',
	'SUNBR' => 'E',
	'SUNET' => 'E',
	'SUNME' => 'E',
	'SUNMU' => 'E',
	'SUNPH' => 'E',
	'SUNST' => 'E',
	'SURSU' => 'E',
	'SURUL' => 'E',
	'SUSBA' => 'E',
	'SUSCE' => 'E',
	'SUSCL' => 'E',
	'SUSPH' => 'E',
	'SUSVE' => 'E',
	'SV40' => 'V',
	'SV41' => 'V',
	'SV5' => 'V',
	'SV5CM' => 'V',
	'SV5CP' => 'V',
	'SV5LN' => 'V',
	'SV5WR' => 'V',
	'SVCV' => 'V',
	'SVDVH' => 'V',
	'SVDVU' => 'V',
	'SWEBI' => 'E',
	'SWEPE' => 'E',
	'SWPV' => 'V',
	'SWPV1' => 'V',
	'SWPVK' => 'V',
	'SYCAU' => 'E',
	'SYLAQ' => 'E',
	'SYLAU' => 'E',
	'SYLBO' => 'E',
	'SYLFL' => 'E',
	'SYLGA' => 'E',
	'SYLGR' => 'E',
	'SYLHO' => 'E',
	'SYLJO' => 'E',
	'SYLLU' => 'E',
	'SYLME' => 'E',
	'SYLNU' => 'E',
	'SYLOB' => 'E',
	'SYLOL' => 'E',
	'SYLPA' => 'E',
	'SYLTR' => 'E',
	'SYMAL' => 'E',
	'SYMFO' => 'E',
	'SYMKA' => 'E',
	'SYMMI' => 'E',
	'SYMMU' => 'E',
	'SYMOR' => 'E',
	'SYMPI' => 'E',
	'SYMPU' => 'E',
	'SYMS1' => 'B',
	'SYMSP' => 'E',
	'SYMST' => 'E',
	'SYMTH' => 'B',
	'SYNAN' => 'E',
	'SYNAS' => 'B',
	'SYNBE' => 'E',
	'SYNBO' => 'E',
	'SYNBR' => 'E',
	'SYNCA' => 'E',
	'SYNCO' => 'E',
	'SYNCR' => 'E',
	'SYNCU' => 'E',
	'SYNEL' => 'B',
	'SYNEN' => 'B',
	'SYNEX' => 'E',
	'SYNHO' => 'E',
	'SYNHY' => 'E',
	'SYNJA' => 'B',
	'SYNJB' => 'B',
	'SYNLE' => 'B',
	'SYNLI' => 'B',
	'SYNMA' => 'E',
	'SYNNO' => 'E',
	'SYNP1' => 'B',
	'SYNP2' => 'B',
	'SYNP3' => 'B',
	'SYNP4' => 'B',
	'SYNP6' => 'B',
	'SYNP7' => 'B',
	'SYNP8' => 'B',
	'SYNPA' => 'E',
	'SYNPL' => 'E',
	'SYNPV' => 'B',
	'SYNPW' => 'B',
	'SYNPX' => 'B',
	'SYNPY' => 'B',
	'SYNPZ' => 'B',
	'SYNRA' => 'E',
	'SYNS3' => 'B',
	'SYNS9' => 'B',
	'SYNSC' => 'B',
	'SYNSH' => 'E',
	'SYNSP' => 'B',
	'SYNV' => 'V',
	'SYNVE' => 'E',
	'SYNVU' => 'B',
	'SYNWU' => 'E',
	'SYNWW' => 'B',
	'SYNY1' => 'B',
	'SYNY3' => 'B',
	'SYNY4' => 'B',
	'SYNY8' => 'B',
	'SYPIN' => 'E',
	'SYREL' => 'E',
	'SYREM' => 'E',
	'SYRHU' => 'E',
	'SYRMI' => 'E',
	'SYRPI' => 'E',
	'SYRRE' => 'E',
	'SYRSO' => 'E',
	'SYRVI' => 'E',
	'SYRVU' => 'E',
	'SYZAU' => 'E',
	'SYZCU' => 'E',
	'SYZSA' => 'E',
	'TABAT' => 'E',
	'TABCH' => 'E',
	'TABDI' => 'E',
	'TABHE' => 'E',
	'TACAC' => 'E',
	'TACBI' => 'E',
	'TACCH' => 'E',
	'TACCY' => 'E',
	'TACEU' => 'E',
	'TACGI' => 'E',
	'TACSP' => 'E',
	'TACTR' => 'E',
	'TACV' => 'V',
	'TACV5' => 'V',
	'TACV7' => 'V',
	'TACVT' => 'V',
	'TADBR' => 'E',
	'TADIN' => 'E',
	'TADRA' => 'E',
	'TADTA' => 'E',
	'TADTE' => 'E',
	'TAECM' => 'E',
	'TAEEQ' => 'E',
	'TAEIC' => 'E',
	'TAEIN' => 'E',
	'TAELY' => 'E',
	'TAEOV' => 'E',
	'TAESA' => 'E',
	'TAESO' => 'E',
	'TAETA' => 'E',
	'TAGCA' => 'E',
	'TAGLU' => 'E',
	'TAGMI' => 'E',
	'TAGPA' => 'E',
	'TAKLE' => 'E',
	'TAKPA' => 'E',
	'TALAL' => 'E',
	'TALCA' => 'E',
	'TALEM' => 'E',
	'TALEU' => 'E',
	'TALFL' => 'E',
	'TALOC' => 'E',
	'TALRO' => 'E',
	'TALTH' => 'E',
	'TALTR' => 'E',
	'TAMAM' => 'E',
	'TAMBU' => 'E',
	'TAMCA' => 'E',
	'TAMCI' => 'E',
	'TAMDO' => 'E',
	'TAMDR' => 'E',
	'TAMDU' => 'E',
	'TAMGA' => 'E',
	'TAMHU' => 'E',
	'TAMIN' => 'E',
	'TAMMA' => 'E',
	'TAMME' => 'E',
	'TAMMI' => 'E',
	'TAMMR' => 'E',
	'TAMOB' => 'E',
	'TAMOC' => 'E',
	'TAMPA' => 'E',
	'TAMPL' => 'E',
	'TAMQA' => 'E',
	'TAMQU' => 'E',
	'TAMRF' => 'E',
	'TAMRU' => 'E',
	'TAMSE' => 'E',
	'TAMSI' => 'E',
	'TAMSO' => 'E',
	'TAMSP' => 'E',
	'TAMSS' => 'E',
	'TAMST' => 'E',
	'TAMSW' => 'E',
	'TAMTE' => 'E',
	'TAMTO' => 'E',
	'TAMUM' => 'E',
	'TAMV' => 'V',
	'TANAL' => 'E',
	'TANCH' => 'E',
	'TANIR' => 'E',
	'TANRE' => 'E',
	'TAPBA' => 'E',
	'TAPGE' => 'E',
	'TAPIN' => 'E',
	'TAPMA' => 'E',
	'TAPME' => 'E',
	'TAPNU' => 'E',
	'TAPPI' => 'E',
	'TAPPR' => 'E',
	'TAPTE' => 'E',
	'TARBA' => 'E',
	'TARCY' => 'E',
	'TARER' => 'E',
	'TARGR' => 'E',
	'TARMA' => 'E',
	'TAROF' => 'E',
	'TARRO' => 'E',
	'TARSY' => 'E',
	'TARTO' => 'E',
	'TASIN' => 'E',
	'TASSH' => 'E',
	'TATEM' => 'E',
	'TATKG' => 'E',
	'TATRO' => 'E',
	'TAUBU' => 'E',
	'TAUCO' => 'E',
	'TAUDE' => 'E',
	'TAUER' => 'E',
	'TAUHA' => 'E',
	'TAULE' => 'E',
	'TAULU' => 'E',
	'TAUON' => 'E',
	'TAV' => 'V',
	'TAXBA' => 'E',
	'TAXBR' => 'E',
	'TAXCA' => 'E',
	'TAXCH' => 'E',
	'TAXCU' => 'E',
	'TAXOC' => 'B',
	'TAXTA' => 'E',
	'TAYPE' => 'E',
	'TAYTA' => 'E',
	'TBEVH' => 'V',
	'TBEVS' => 'V',
	'TBEVW' => 'V',
	'TBRVC' => 'V',
	'TBRVE' => 'V',
	'TBRVL' => 'V',
	'TBRVM' => 'V',
	'TBSV8' => 'V',
	'TBSVA' => 'V',
	'TBSVB' => 'V',
	'TBSVC' => 'V',
	'TBSVJ' => 'V',
	'TBSVK' => 'V',
	'TBSVT' => 'V',
	'TCV' => 'V',
	'TECAU' => 'E',
	'TECDE' => 'E',
	'TECST' => 'E',
	'TECTE' => 'E',
	'TEDIG' => 'E',
	'TEGAG' => 'E',
	'TEGFU' => 'E',
	'TEGPF' => 'E',
	'TELGR' => 'E',
	'TELPE' => 'E',
	'TENAR' => 'E',
	'TENEC' => 'E',
	'TENMO' => 'E',
	'TERCA' => 'E',
	'TERCO' => 'E',
	'TERCT' => 'E',
	'TERJA' => 'E',
	'TERNA' => 'E',
	'TERNE' => 'E',
	'TEROR' => 'E',
	'TERSU' => 'E',
	'TETAC' => 'E',
	'TETAD' => 'E',
	'TETAM' => 'E',
	'TETAR' => 'E',
	'TETAU' => 'E',
	'TETBA' => 'E',
	'TETBI' => 'E',
	'TETBO' => 'E',
	'TETCA' => 'E',
	'TETCL' => 'E',
	'TETCN' => 'E',
	'TETCO' => 'E',
	'TETCU' => 'E',
	'TETEL' => 'E',
	'TETFE' => 'E',
	'TETFL' => 'E',
	'TETFU' => 'E',
	'TETHA' => 'B',
	'TETHY' => 'E',
	'TETLE' => 'E',
	'TETMA' => 'E',
	'TETMI' => 'E',
	'TETMU' => 'E',
	'TETNA' => 'E',
	'TETNG' => 'E',
	'TETNI' => 'E',
	'TETOR' => 'E',
	'TETPA' => 'E',
	'TETPI' => 'E',
	'TETPR' => 'E',
	'TETPY' => 'E',
	'TETQU' => 'E',
	'TETRE' => 'E',
	'TETRO' => 'E',
	'TETSO' => 'E',
	'TETST' => 'E',
	'TETTE' => 'E',
	'TETTH' => 'E',
	'TETTR' => 'E',
	'TETTT' => 'E',
	'TETUR' => 'E',
	'TEUCH' => 'E',
	'TEV' => 'V',
	'TGMV' => 'V',
	'THAAN' => 'E',
	'THAAR' => 'B',
	'THAAT' => 'E',
	'THABR' => 'E',
	'THACE' => 'E',
	'THACO' => 'E',
	'THACU' => 'E',
	'THADA' => 'E',
	'THAER' => 'E',
	'THAFU' => 'E',
	'THAIM' => 'E',
	'THALA' => 'E',
	'THAMA' => 'E',
	'THANI' => 'E',
	'THANO' => 'E',
	'THAOC' => 'E',
	'THASC' => 'E',
	'THASE' => 'B',
	'THAWE' => 'E',
	'THEAC' => 'A',
	'THEAG' => 'A',
	'THEAL' => 'B',
	'THEAN' => 'E',
	'THEAQ' => 'B',
	'THEAT' => 'E',
	'THEAU' => 'E',
	'THEBL' => 'E',
	'THEBO' => 'B',
	'THEBR' => 'B',
	'THEBU' => 'E',
	'THECA' => 'B',
	'THECC' => 'E',
	'THECE' => 'A',
	'THECH' => 'E',
	'THECR' => 'E',
	'THECU' => 'B',
	'THECV' => 'E',
	'THEDY' => 'E',
	'THEET' => 'B',
	'THEFI' => 'B',
	'THEFM' => 'A',
	'THEFU' => 'B',
	'THEFY' => 'B',
	'THEG8' => 'A',
	'THEGA' => 'E',
	'THEGE' => 'E',
	'THEGO' => 'A',
	'THEHA' => 'E',
	'THEHY' => 'A',
	'THEIN' => 'B',
	'THEK1' => 'A',
	'THEK8' => 'A',
	'THELA' => 'E',
	'THELE' => 'E',
	'THELG' => 'E',
	'THELI' => 'A',
	'THEMA' => 'B',
	'THEMI' => 'E',
	'THEMR' => 'E',
	'THEMU' => 'E',
	'THENE' => 'B',
	'THEOR' => 'E',
	'THEOS' => 'B',
	'THEPA' => 'E',
	'THEPE' => 'A',
	'THEPN' => 'E',
	'THEPO' => 'E',
	'THEPR' => 'A',
	'THERO' => 'B',
	'THES2' => 'B',
	'THES7' => 'B',
	'THES9' => 'A',
	'THESA' => 'B',
	'THESC' => 'B',
	'THESD' => 'B',
	'THESE' => 'E',
	'THESH' => 'B',
	'THESI' => 'A',
	'THESJ' => 'B',
	'THESK' => 'B',
	'THESL' => 'E',
	'THESP' => 'B',
	'THESR' => 'B',
	'THESU' => 'A',
	'THESY' => 'B',
	'THET2' => 'B',
	'THET8' => 'B',
	'THETA' => 'E',
	'THETE' => 'A',
	'THETH' => 'B',
	'THETI' => 'B',
	'THETN' => 'B',
	'THETP' => 'B',
	'THETS' => 'E',
	'THETU' => 'B',
	'THETY' => 'B',
	'THEVO' => 'A',
	'THEVU' => 'B',
	'THEYO' => 'B',
	'THEZI' => 'A',
	'THEZO' => 'E',
	'THIAC' => 'B',
	'THIBE' => 'E',
	'THICR' => 'B',
	'THICU' => 'B',
	'THIDA' => 'B',
	'THIDE' => 'B',
	'THIDN' => 'B',
	'THIFE' => 'B',
	'THIHE' => 'E',
	'THIIN' => 'B',
	'THINE' => 'B',
	'THINO' => 'B',
	'THIPE' => 'B',
	'THIPF' => 'B',
	'THIRO' => 'B',
	'THIRU' => 'E',
	'THITH' => 'B',
	'THITI' => 'B',
	'THIVI' => 'B',
	'THLAR' => 'E',
	'THLCA' => 'E',
	'THLGO' => 'E',
	'THLJA' => 'E',
	'THOBO' => 'E',
	'THOBU' => 'E',
	'THODA' => 'E',
	'THOGR' => 'E',
	'THOGV' => 'V',
	'THOHE' => 'E',
	'THOIS' => 'E',
	'THOMA' => 'E',
	'THOME' => 'E',
	'THOMO' => 'E',
	'THONI' => 'E',
	'THONO' => 'E',
	'THOOR' => 'E',
	'THOTA' => 'E',
	'THOTO' => 'E',
	'THOUM' => 'E',
	'THRAP' => 'E',
	'THRDO' => 'E',
	'THREP' => 'E',
	'THRIM' => 'E',
	'THRPA' => 'E',
	'THRPR' => 'E',
	'THRSA' => 'E',
	'THRSE' => 'E',
	'THRSW' => 'E',
	'THUAA' => 'E',
	'THUAL' => 'E',
	'THUDO' => 'E',
	'THUHO' => 'E',
	'THUOB' => 'E',
	'THUOC' => 'E',
	'THUPL' => 'E',
	'THUTH' => 'E',
	'THUTO' => 'E',
	'THYAR' => 'E',
	'THYBI' => 'E',
	'THYBR' => 'E',
	'THYCI' => 'E',
	'THYCY' => 'E',
	'THYEL' => 'E',
	'THYST' => 'E',
	'THYSY' => 'E',
	'THYTH' => 'E',
	'THYTR' => 'E',
	'THYVU' => 'E',
	'TIGCA' => 'E',
	'TIGPA' => 'E',
	'TIGSP' => 'E',
	'TILAJ' => 'E',
	'TILAM' => 'E',
	'TILBA' => 'E',
	'TILPL' => 'E',
	'TIMCA' => 'E',
	'TIMCO' => 'E',
	'TIMGR' => 'E',
	'TIMTE' => 'E',
	'TINGU' => 'E',
	'TINLE' => 'E',
	'TINMA' => 'E',
	'TIPDI' => 'E',
	'TIPOL' => 'E',
	'TIPPA' => 'E',
	'TISCR' => 'B',
	'TITBA' => 'E',
	'TITCA' => 'E',
	'TITCO' => 'E',
	'TITDI' => 'E',
	'TITFA' => 'E',
	'TITPA' => 'E',
	'TITSE' => 'E',
	'TITST' => 'E',
	'TITTR' => 'E',
	'TITZU' => 'E',
	'TMEOB' => 'E',
	'TMEVB' => 'V',
	'TMEVD' => 'V',
	'TMEVG' => 'V',
	'TMGMV' => 'V',
	'TMOB' => 'V',
	'TMOV' => 'V',
	'TMV' => 'V',
	'TMV06' => 'V',
	'TMVB' => 'V',
	'TMVDA' => 'V',
	'TMVER' => 'V',
	'TMVKO' => 'V',
	'TMVKR' => 'V',
	'TMVO' => 'V',
	'TMVOM' => 'V',
	'TMVRA' => 'V',
	'TNVA' => 'V',
	'TNVD' => 'V',
	'TOBAC' => 'E',
	'TOBBP' => 'B',
	'TOBSV' => 'V',
	'TODAN' => 'E',
	'TODME' => 'E',
	'TODMU' => 'E',
	'TODPA' => 'E',
	'TODSU' => 'E',
	'TODTO' => 'E',
	'TOKOO' => 'E',
	'TOLIN' => 'E',
	'TOLMA' => 'E',
	'TOLSC' => 'B',
	'TOMK1' => 'V',
	'TOMK2' => 'V',
	'TOMKO' => 'V',
	'TOML' => 'V',
	'TOML2' => 'V',
	'TOMLA' => 'V',
	'TOMRA' => 'E',
	'TOMS1' => 'V',
	'TOMSC' => 'E',
	'TONBI' => 'E',
	'TONBR' => 'E',
	'TONEV' => 'E',
	'TONSC' => 'E',
	'TONSI' => 'E',
	'TORCA' => 'E',
	'TORCL' => 'E',
	'TORDE' => 'E',
	'TORMA' => 'E',
	'TOROC' => 'E',
	'TORPI' => 'E',
	'TORRU' => 'E',
	'TORTR' => 'E',
	'TORVR' => 'V',
	'TOSAU' => 'E',
	'TOSMA' => 'E',
	'TOSV' => 'V',
	'TOWHO' => 'E',
	'TOXCA' => 'E',
	'TOXCU' => 'E',
	'TOXDI' => 'E',
	'TOXGO' => 'E',
	'TOXGU' => 'E',
	'TOXPR' => 'E',
	'TOXRA' => 'E',
	'TOXRU' => 'E',
	'TOXSU' => 'E',
	'TPMV' => 'V',
	'TRAAN' => 'E',
	'TRAAU' => 'E',
	'TRABL' => 'E',
	'TRACA' => 'E',
	'TRACI' => 'E',
	'TRACR' => 'E',
	'TRADU' => 'E',
	'TRAEU' => 'E',
	'TRAFL' => 'E',
	'TRAFO' => 'E',
	'TRAFR' => 'E',
	'TRAGE' => 'E',
	'TRAHI' => 'E',
	'TRAIM' => 'E',
	'TRAJA' => 'E',
	'TRAJO' => 'E',
	'TRAJP' => 'E',
	'TRAJS' => 'E',
	'TRALA' => 'E',
	'TRALE' => 'E',
	'TRAME' => 'E',
	'TRAMY' => 'E',
	'TRANA' => 'E',
	'TRAOB' => 'E',
	'TRAOC' => 'E',
	'TRAOH' => 'E',
	'TRAOR' => 'E',
	'TRAPH' => 'E',
	'TRAPI' => 'E',
	'TRAPL' => 'E',
	'TRAPU' => 'E',
	'TRARA' => 'E',
	'TRARU' => 'E',
	'TRASA' => 'E',
	'TRASC' => 'E',
	'TRASP' => 'E',
	'TRASR' => 'E',
	'TRAST' => 'E',
	'TRATC' => 'E',
	'TRATE' => 'E',
	'TRATR' => 'E',
	'TRAVE' => 'E',
	'TRAVI' => 'E',
	'TRAVR' => 'E',
	'TRAVT' => 'E',
	'TREBR' => 'E',
	'TREDE' => 'B',
	'TREHA' => 'E',
	'TREHY' => 'B',
	'TRELE' => 'B',
	'TREMA' => 'B',
	'TREMD' => 'B',
	'TREME' => 'E',
	'TRENE' => 'E',
	'TREOR' => 'E',
	'TREPA' => 'B',
	'TREPE' => 'B',
	'TREPH' => 'B',
	'TREPR' => 'B',
	'TRESO' => 'B',
	'TRETO' => 'E',
	'TREVE' => 'E',
	'TRIAA' => 'E',
	'TRIAB' => 'E',
	'TRIAF' => 'E',
	'TRIAI' => 'E',
	'TRIAL' => 'E',
	'TRIAN' => 'E',
	'TRIAO' => 'E',
	'TRIAP' => 'E',
	'TRIAT' => 'E',
	'TRIAU' => 'E',
	'TRIBA' => 'E',
	'TRIBB' => 'E',
	'TRIBE' => 'E',
	'TRIBL' => 'E',
	'TRIBO' => 'E',
	'TRIBR' => 'E',
	'TRIBU' => 'E',
	'TRICA' => 'E',
	'TRICB' => 'E',
	'TRICC' => 'E',
	'TRICD' => 'E',
	'TRICE' => 'E',
	'TRICF' => 'E',
	'TRICG' => 'E',
	'TRICI' => 'E',
	'TRICM' => 'E',
	'TRICN' => 'E',
	'TRICO' => 'E',
	'TRICP' => 'E',
	'TRICR' => 'E',
	'TRICS' => 'E',
	'TRICT' => 'E',
	'TRICU' => 'E',
	'TRICY' => 'E',
	'TRIDA' => 'E',
	'TRIDE' => 'E',
	'TRIDI' => 'E',
	'TRIDM' => 'E',
	'TRIDS' => 'E',
	'TRIDU' => 'E',
	'TRIEA' => 'E',
	'TRIEE' => 'E',
	'TRIEI' => 'B',
	'TRIEL' => 'E',
	'TRIER' => 'B',
	'TRIEU' => 'E',
	'TRIFE' => 'E',
	'TRIFG' => 'E',
	'TRIFL' => 'E',
	'TRIFO' => 'E',
	'TRIFR' => 'E',
	'TRIGA' => 'E',
	'TRIGC' => 'E',
	'TRIGI' => 'E',
	'TRIGN' => 'E',
	'TRIGR' => 'E',
	'TRIHA' => 'E',
	'TRIHG' => 'E',
	'TRIHI' => 'E',
	'TRIHK' => 'E',
	'TRIHM' => 'E',
	'TRIHR' => 'E',
	'TRIHY' => 'E',
	'TRIIC' => 'E',
	'TRIIF' => 'E',
	'TRIIH' => 'E',
	'TRIIN' => 'E',
	'TRIJE' => 'E',
	'TRIKA' => 'E',
	'TRIKH' => 'E',
	'TRIKI' => 'E',
	'TRIKO' => 'E',
	'TRILA' => 'E',
	'TRILE' => 'E',
	'TRILO' => 'E',
	'TRILP' => 'E',
	'TRILU' => 'E',
	'TRIMA' => 'E',
	'TRIMC' => 'E',
	'TRIME' => 'E',
	'TRIMI' => 'E',
	'TRIMN' => 'E',
	'TRIMO' => 'E',
	'TRIMR' => 'E',
	'TRIMT' => 'E',
	'TRIMU' => 'E',
	'TRINA' => 'E',
	'TRINC' => 'E',
	'TRINI' => 'E',
	'TRIOC' => 'E',
	'TRIOH' => 'E',
	'TRIOK' => 'E',
	'TRIPA' => 'E',
	'TRIPB' => 'E',
	'TRIPI' => 'E',
	'TRIPN' => 'E',
	'TRIPO' => 'E',
	'TRIPP' => 'E',
	'TRIPR' => 'E',
	'TRIPS' => 'E',
	'TRIPT' => 'E',
	'TRIPU' => 'E',
	'TRIRE' => 'E',
	'TRIRO' => 'E',
	'TRIRP' => 'E',
	'TRIRS' => 'E',
	'TRIRU' => 'E',
	'TRIS1' => 'B',
	'TRISA' => 'E',
	'TRISC' => 'E',
	'TRISE' => 'E',
	'TRISF' => 'E',
	'TRISH' => 'E',
	'TRISI' => 'E',
	'TRISM' => 'E',
	'TRISO' => 'E',
	'TRISP' => 'E',
	'TRISR' => 'E',
	'TRIST' => 'E',
	'TRISU' => 'E',
	'TRITA' => 'E',
	'TRITC' => 'E',
	'TRITG' => 'E',
	'TRITH' => 'B',
	'TRITI' => 'E',
	'TRITL' => 'E',
	'TRITO' => 'E',
	'TRITP' => 'E',
	'TRITR' => 'E',
	'TRITU' => 'E',
	'TRIUN' => 'E',
	'TRIUR' => 'E',
	'TRIVA' => 'E',
	'TRIVE' => 'E',
	'TRIVG' => 'E',
	'TRIVI' => 'E',
	'TRIVL' => 'E',
	'TRIVR' => 'E',
	'TRIVS' => 'E',
	'TRIVU' => 'E',
	'TRIWA' => 'E',
	'TRIWI' => 'E',
	'TRIWO' => 'E',
	'TROAE' => 'E',
	'TROAR' => 'E',
	'TROCA' => 'E',
	'TROCM' => 'E',
	'TROCO' => 'E',
	'TROCU' => 'E',
	'TROEL' => 'E',
	'TROGR' => 'E',
	'TROHI' => 'E',
	'TROMA' => 'E',
	'TROME' => 'E',
	'TROML' => 'E',
	'TROMO' => 'E',
	'TROMR' => 'E',
	'TROMX' => 'E',
	'TROPE' => 'E',
	'TRORU' => 'E',
	'TROVI' => 'E',
	'TROVO' => 'E',
	'TROW8' => 'B',
	'TROWH' => 'B',
	'TROWT' => 'B',
	'TRSV' => 'V',
	'TRSVB' => 'V',
	'TRTV' => 'V',
	'TRVCA' => 'V',
	'TRVPL' => 'V',
	'TRVPS' => 'V',
	'TRVSY' => 'V',
	'TRVTC' => 'V',
	'TRYBB' => 'E',
	'TRYBG' => 'E',
	'TRYBO' => 'E',
	'TRYBR' => 'E',
	'TRYCO' => 'E',
	'TRYCR' => 'E',
	'TRYEQ' => 'E',
	'TRYLA' => 'E',
	'TRYLE' => 'E',
	'TRYRA' => 'E',
	'TRYVI' => 'E',
	'TSCTR' => 'E',
	'TSUCA' => 'E',
	'TSUHE' => 'E',
	'TSUPA' => 'B',
	'TSUTY' => 'B',
	'TSWV' => 'V',
	'TSWV1' => 'V',
	'TSWV3' => 'V',
	'TSWVD' => 'V',
	'TSWVH' => 'V',
	'TSWVL' => 'V',
	'TSWVR' => 'V',
	'TSWVS' => 'V',
	'TTV1' => 'V',
	'TTV1V' => 'V',
	'TUBBO' => 'E',
	'TUBDR' => 'E',
	'TUBSA' => 'E',
	'TUBTU' => 'E',
	'TUBUN' => 'E',
	'TUHV1' => 'V',
	'TUHV2' => 'V',
	'TULBA' => 'E',
	'TULGE' => 'E',
	'TUMVJ' => 'V',
	'TUMVQ' => 'V',
	'TUPCH' => 'E',
	'TUPGB' => 'E',
	'TUPGL' => 'E',
	'TUPMI' => 'E',
	'TUPTA' => 'E',
	'TUPTE' => 'E',
	'TURAD' => 'E',
	'TURCO' => 'E',
	'TURHO' => 'E',
	'TURMA' => 'E',
	'TURME' => 'E',
	'TURMI' => 'E',
	'TURNA' => 'E',
	'TUROL' => 'E',
	'TUROR' => 'E',
	'TURPA' => 'E',
	'TURPH' => 'E',
	'TURSE' => 'E',
	'TURSY' => 'E',
	'TURTR' => 'E',
	'TURVA' => 'E',
	'TUSFA' => 'E',
	'TVCV' => 'V',
	'TVMV' => 'V',
	'TYDVA' => 'V',
	'TYLCA' => 'V',
	'TYLCM' => 'V',
	'TYLCS' => 'V',
	'TYLCU' => 'V',
	'TYLCV' => 'V',
	'TYLHE' => 'E',
	'TYLPO' => 'E',
	'TYMBA' => 'E',
	'TYMCU' => 'E',
	'TYMLI' => 'E',
	'TYMV' => 'V',
	'TYMVA' => 'V',
	'TYMVC' => 'V',
	'TYPAN' => 'E',
	'TYPLA' => 'E',
	'TYPNA' => 'E',
	'TYPVE' => 'E',
	'TYRPU' => 'E',
	'TYRTY' => 'E',
	'TYTAL' => 'E',
	'TYYVF' => 'V',
	'UARAM' => 'E',
	'UCAPU' => 'E',
	'ULEEU' => 'E',
	'ULLTU' => 'E',
	'ULMAL' => 'E',
	'ULMAM' => 'E',
	'ULMPA' => 'E',
	'ULOBO' => 'E',
	'ULOOE' => 'E',
	'ULVAR' => 'E',
	'ULVPE' => 'E',
	'UMANO' => 'E',
	'UMASC' => 'E',
	'UMBCA' => 'E',
	'UMBCR' => 'E',
	'UMBRA' => 'E',
	'UMV4' => 'V',
	'UMV6' => 'V',
	'UNCNE' => 'E',
	'UNCUC' => 'E',
	'UNCUN' => 'E',
	'UNIGR' => 'E',
	'UNKP' => 'B',
	'UPEIN' => 'E',
	'UPEMA' => 'E',
	'UPEMJ' => 'E',
	'UPEMO' => 'E',
	'UPERU' => 'E',
	'UPUEP' => 'E',
	'URAJA' => 'E',
	'URARU' => 'E',
	'URECA' => 'E',
	'UREPA' => 'B',
	'UREUN' => 'E',
	'UREUR' => 'B',
	'URIAL' => 'E',
	'URILO' => 'E',
	'UROAC' => 'E',
	'UROAP' => 'E',
	'UROBI' => 'E',
	'UROCA' => 'E',
	'UROCI' => 'E',
	'UROER' => 'E',
	'UROFA' => 'E',
	'UROGR' => 'E',
	'UROHA' => 'E',
	'UROJA' => 'E',
	'UROMA' => 'E',
	'UROOR' => 'E',
	'UROPA' => 'E',
	'UROPI' => 'E',
	'UROTA' => 'E',
	'URSAM' => 'E',
	'URSAR' => 'E',
	'URSMA' => 'E',
	'URSML' => 'E',
	'URSSP' => 'E',
	'URSTH' => 'E',
	'URSUR' => 'E',
	'URTDI' => 'E',
	'URTFE' => 'E',
	'URTPI' => 'E',
	'USEUD' => 'E',
	'USTHO' => 'E',
	'USTMA' => 'E',
	'USTSP' => 'E',
	'USTVI' => 'E',
	'UTAST' => 'E',
	'UTRBI' => 'E',
	'UUK' => 'V',
	'UVUGR' => 'E',
	'UVUPE' => 'E',
	'VACC0' => 'V',
	'VACC6' => 'V',
	'VACC8' => 'V',
	'VACCA' => 'V',
	'VACCC' => 'V',
	'VACCD' => 'V',
	'VACCI' => 'V',
	'VACCL' => 'V',
	'VACCO' => 'E',
	'VACCP' => 'V',
	'VACCT' => 'V',
	'VACCU' => 'V',
	'VACCV' => 'V',
	'VACMA' => 'E',
	'VACMY' => 'E',
	'VACST' => 'E',
	'VACVI' => 'E',
	'VALLO' => 'E',
	'VALMU' => 'E',
	'VALOF' => 'E',
	'VALST' => 'E',
	'VAMBI' => 'E',
	'VAMBR' => 'E',
	'VAMCA' => 'E',
	'VAMPU' => 'E',
	'VAMSP' => 'E',
	'VANAT' => 'E',
	'VANCA' => 'E',
	'VANCH' => 'E',
	'VANCI' => 'E',
	'VANDA' => 'E',
	'VANLA' => 'E',
	'VANPL' => 'E',
	'VANSP' => 'E',
	'VANVA' => 'E',
	'VANVI' => 'E',
	'VARAC' => 'E',
	'VARBA' => 'E',
	'VARBB' => 'E',
	'VARBE' => 'E',
	'VARBN' => 'E',
	'VARBR' => 'E',
	'VARDO' => 'E',
	'VARDU' => 'E',
	'VARER' => 'E',
	'VAREX' => 'E',
	'VARFL' => 'E',
	'VARGI' => 'E',
	'VARGL' => 'E',
	'VARGO' => 'E',
	'VARHI' => 'E',
	'VARIN' => 'E',
	'VARJA' => 'E',
	'VARJO' => 'E',
	'VARKO' => 'E',
	'VARME' => 'E',
	'VARML' => 'E',
	'VARMX' => 'E',
	'VARNI' => 'E',
	'VAROL' => 'E',
	'VARPA' => 'E',
	'VARPD' => 'B',
	'VARPR' => 'E',
	'VARRU' => 'E',
	'VARSA' => 'E',
	'VARTI' => 'E',
	'VARV' => 'V',
	'VARVA' => 'E',
	'VARVR' => 'E',
	'VARVV' => 'E',
	'VATMA' => 'E',
	'VAUCA' => 'E',
	'VAUCO' => 'E',
	'VELBR' => 'E',
	'VENCA' => 'E',
	'VENIN' => 'E',
	'VERAA' => 'E',
	'VERAG' => 'E',
	'VERAL' => 'E',
	'VERAR' => 'E',
	'VERBL' => 'E',
	'VERBO' => 'E',
	'VERBR' => 'E',
	'VERCE' => 'E',
	'VERCH' => 'E',
	'VERDA' => 'E',
	'VERFO' => 'E',
	'VERGA' => 'E',
	'VERJA' => 'E',
	'VERLE' => 'E',
	'VERMO' => 'E',
	'VERNI' => 'E',
	'VERNO' => 'E',
	'VEROF' => 'E',
	'VEROI' => 'E',
	'VERPE' => 'E',
	'VERPR' => 'E',
	'VERRI' => 'E',
	'VERRU' => 'E',
	'VERTH' => 'E',
	'VERVA' => 'E',
	'VERVI' => 'E',
	'VESAN' => 'E',
	'VESBA' => 'E',
	'VESCR' => 'E',
	'VESFL' => 'E',
	'VESGE' => 'E',
	'VESLE' => 'E',
	'VESMA' => 'E',
	'VESMC' => 'E',
	'VESMG' => 'E',
	'VESMU' => 'E',
	'VESOR' => 'E',
	'VESPE' => 'E',
	'VESSQ' => 'E',
	'VESSU' => 'E',
	'VESTR' => 'E',
	'VESVI' => 'E',
	'VESVN' => 'E',
	'VESVU' => 'E',
	'VESXA' => 'E',
	'VHSV0' => 'V',
	'VHSVM' => 'V',
	'VIBAB' => 'B',
	'VIBAC' => 'E',
	'VIBAL' => 'B',
	'VIBAN' => 'B',
	'VIBCA' => 'E',
	'VIBCH' => 'B',
	'VIBCI' => 'B',
	'VIBCO' => 'B',
	'VIBDE' => 'E',
	'VIBDI' => 'B',
	'VIBED' => 'E',
	'VIBF1' => 'B',
	'VIBFI' => 'B',
	'VIBFL' => 'B',
	'VIBFU' => 'B',
	'VIBGA' => 'B',
	'VIBHA' => 'B',
	'VIBHO' => 'B',
	'VIBLA' => 'E',
	'VIBLN' => 'E',
	'VIBLO' => 'B',
	'VIBMA' => 'B',
	'VIBME' => 'B',
	'VIBMI' => 'B',
	'VIBNA' => 'B',
	'VIBNE' => 'B',
	'VIBOP' => 'E',
	'VIBOR' => 'B',
	'VIBPA' => 'B',
	'VIBPE' => 'B',
	'VIBPR' => 'B',
	'VIBRA' => 'E',
	'VIBS2' => 'B',
	'VIBS3' => 'B',
	'VIBS7' => 'B',
	'VIBSA' => 'B',
	'VIBSM' => 'B',
	'VIBSP' => 'B',
	'VIBSS' => 'B',
	'VIBVU' => 'B',
	'VIBVY' => 'B',
	'VICAN' => 'E',
	'VICCR' => 'E',
	'VICCZ' => 'E',
	'VICFA' => 'E',
	'VICNA' => 'E',
	'VICSA' => 'E',
	'VICVI' => 'E',
	'VIDCH' => 'E',
	'VIGAC' => 'E',
	'VIGMU' => 'E',
	'VIGSI' => 'E',
	'VIGSU' => 'E',
	'VIGUN' => 'E',
	'VIGUS' => 'E',
	'VILAC' => 'E',
	'VILCA' => 'E',
	'VILV' => 'V',
	'VILV1' => 'V',
	'VILV2' => 'V',
	'VILVK' => 'V',
	'VINAR' => 'E',
	'VIOAR' => 'E',
	'VIOCO' => 'E',
	'VIOCT' => 'E',
	'VIOHE' => 'E',
	'VIOOD' => 'E',
	'VIOSO' => 'E',
	'VIPAA' => 'E',
	'VIPAE' => 'E',
	'VIPAM' => 'E',
	'VIPAP' => 'E',
	'VIPAS' => 'E',
	'VIPAZ' => 'E',
	'VIPBB' => 'E',
	'VIPBO' => 'E',
	'VIPLE' => 'E',
	'VIPLO' => 'E',
	'VIPPA' => 'E',
	'VIPUR' => 'E',
	'VIRAL' => 'E',
	'VIRDI' => 'E',
	'VIRFL' => 'E',
	'VIRGR' => 'E',
	'VIRLA' => 'E',
	'VIROL' => 'E',
	'VIRPA' => 'B',
	'VIRPH' => 'E',
	'VISAL' => 'E',
	'VISVU' => 'E',
	'VITAC' => 'E',
	'VITAE' => 'E',
	'VITBE' => 'B',
	'VITFI' => 'B',
	'VITRI' => 'E',
	'VITS1' => 'B',
	'VITST' => 'B',
	'VITSX' => 'E',
	'VITVI' => 'E',
	'VIVGE' => 'E',
	'VIVIN' => 'E',
	'VIVME' => 'E',
	'VIVTA' => 'E',
	'VIVZI' => 'E',
	'VOAGY' => 'E',
	'VOLAU' => 'E',
	'VOLCA' => 'E',
	'VOLKI' => 'E',
	'VOLPE' => 'E',
	'VOMUR' => 'E',
	'VORPE' => 'E',
	'VSVIG' => 'V',
	'VSVIM' => 'V',
	'VSVJH' => 'V',
	'VSVJM' => 'V',
	'VSVJO' => 'V',
	'VSVO' => 'V',
	'VSVSJ' => 'V',
	'VULCH' => 'E',
	'VULCO' => 'E',
	'VULGR' => 'E',
	'VULMA' => 'E',
	'VULVU' => 'E',
	'VULZE' => 'E',
	'VZV4' => 'V',
	'VZV7' => 'V',
	'VZVD' => 'V',
	'VZVE' => 'V',
	'VZVG' => 'V',
	'VZVO' => 'V',
	'VZVP' => 'V',
	'VZVS' => 'V',
	'WALAE' => 'E',
	'WALBI' => 'E',
	'WALFR' => 'E',
	'WASMV' => 'V',
	'WASRO' => 'E',
	'WATAN' => 'E',
	'WATSC' => 'E',
	'WCMVM' => 'V',
	'WCMVO' => 'V',
	'WDV' => 'V',
	'WEDTE' => 'E',
	'WEEV' => 'V',
	'WEIFL' => 'E',
	'WEIHE' => 'B',
	'WEIHO' => 'E',
	'WEIPA' => 'B',
	'WEIPR' => 'E',
	'WEISI' => 'E',
	'WELCA' => 'E',
	'WELMI' => 'E',
	'WHEAT' => 'E',
	'WHIBI' => 'E',
	'WHV1' => 'V',
	'WHV2' => 'V',
	'WHV59' => 'V',
	'WHV7' => 'V',
	'WHV8' => 'V',
	'WHVW6' => 'V',
	'WIETR' => 'E',
	'WIGBR' => 'B',
	'WIGGL' => 'B',
	'WILCA' => 'E',
	'WILGY' => 'E',
	'WILMR' => 'E',
	'WILPU' => 'E',
	'WILSA' => 'E',
	'WISFL' => 'E',
	'WISFR' => 'E',
	'WMSV' => 'V',
	'WMV2A' => 'V',
	'WMV2T' => 'V',
	'WMV2U' => 'V',
	'WNV' => 'V',
	'WOLAR' => 'E',
	'WOLBI' => 'E',
	'WOLGL' => 'E',
	'WOLPI' => 'B',
	'WOLPM' => 'B',
	'WOLRE' => 'B',
	'WOLSP' => 'B',
	'WOLSU' => 'B',
	'WOLTE' => 'E',
	'WOLTR' => 'B',
	'WOORA' => 'E',
	'WOOUN' => 'E',
	'WSSV' => 'V',
	'WTV' => 'V',
	'WTVNJ' => 'V',
	'WUCBA' => 'E',
	'WYHV' => 'V',
	'WYUSQ' => 'E',
	'XANAC' => 'B',
	'XANAG' => 'B',
	'XANAL' => 'B',
	'XANAU' => 'B',
	'XANBE' => 'E',
	'XANC5' => 'B',
	'XANC8' => 'B',
	'XANCA' => 'B',
	'XANCC' => 'B',
	'XANCG' => 'B',
	'XANCH' => 'B',
	'XANCI' => 'B',
	'XANCJ' => 'B',
	'XANCM' => 'B',
	'XANCO' => 'B',
	'XANCP' => 'B',
	'XANCR' => 'B',
	'XANCT' => 'B',
	'XANCV' => 'B',
	'XANFE' => 'E',
	'XANFL' => 'B',
	'XANHE' => 'E',
	'XANMA' => 'B',
	'XANMF' => 'E',
	'XANMN' => 'B',
	'XANOM' => 'B',
	'XANOR' => 'B',
	'XANP2' => 'B',
	'XANS2' => 'B',
	'XANSI' => 'E',
	'XANVI' => 'E',
	'XANXA' => 'E',
	'XENAZ' => 'B',
	'XENBO' => 'E',
	'XENBV' => 'B',
	'XENCL' => 'E',
	'XENLA' => 'E',
	'XENNE' => 'B',
	'XENTR' => 'E',
	'XERER' => 'E',
	'XERIN' => 'E',
	'XERPR' => 'E',
	'XERRU' => 'E',
	'XERSP' => 'E',
	'XIPGL' => 'E',
	'XIPHE' => 'E',
	'XIPMA' => 'E',
	'XIPMO' => 'E',
	'XIPXI' => 'E',
	'XYLBA' => 'E',
	'XYLFA' => 'B',
	'XYLFL' => 'E',
	'XYLFT' => 'B',
	'XYLMI' => 'E',
	'XYLVI' => 'E',
	'XYRMA' => 'E',
	'XYRNO' => 'E',
	'XYRSP' => 'E',
	'YAMOH' => 'E',
	'YARLI' => 'E',
	'YEAST' => 'E',
	'YEFV1' => 'V',
	'YEFV2' => 'V',
	'YEFV8' => 'V',
	'YEFVA' => 'V',
	'YEFVC' => 'V',
	'YEFVE' => 'V',
	'YEFVF' => 'V',
	'YEFVI' => 'V',
	'YEFVN' => 'V',
	'YEFVT' => 'V',
	'YEFVU' => 'V',
	'YERAL' => 'B',
	'YERBE' => 'B',
	'YEREN' => 'B',
	'YERFR' => 'B',
	'YERIN' => 'B',
	'YERKR' => 'B',
	'YERMO' => 'B',
	'YERPA' => 'B',
	'YERPE' => 'B',
	'YERPN' => 'B',
	'YERPS' => 'B',
	'YERRO' => 'B',
	'YERRU' => 'B',
	'YLDV' => 'V',
	'YMTV' => 'V',
	'YOMV' => 'V',
	'YPOEV' => 'E',
	'YPOMA' => 'E',
	'YUCEL' => 'E',
	'YUCFI' => 'E',
	'YUCGL' => 'E',
	'YUCTR' => 'E',
	'YUCWH' => 'E',
	'ZAEPI' => 'E',
	'ZAGBR' => 'E',
	'ZALAR' => 'E',
	'ZALCA' => 'E',
	'ZALME' => 'E',
	'ZAMDR' => 'E',
	'ZAMFI' => 'E',
	'ZAMFL' => 'E',
	'ZAMFU' => 'E',
	'ZAMIN' => 'E',
	'ZAMLO' => 'E',
	'ZAMPU' => 'E',
	'ZAMSI' => 'E',
	'ZAMSK' => 'E',
	'ZAMSL' => 'E',
	'ZAMSP' => 'E',
	'ZAMZA' => 'E',
	'ZANAE' => 'E',
	'ZAODH' => 'E',
	'ZAPHU' => 'E',
	'ZAPPR' => 'E',
	'ZAPSE' => 'E',
	'ZAPTR' => 'E',
	'ZAPTU' => 'E',
	'ZASNI' => 'E',
	'ZEADI' => 'E',
	'ZEALU' => 'E',
	'ZEAMH' => 'E',
	'ZEAMM' => 'E',
	'ZEAMP' => 'E',
	'ZEAPE' => 'E',
	'ZEARA' => 'E',
	'ZELHI' => 'E',
	'ZELPU' => 'E',
	'ZELTA' => 'E',
	'ZENGR' => 'E',
	'ZENMA' => 'E',
	'ZENNE' => 'E',
	'ZERCE' => 'E',
	'ZEUFA' => 'E',
	'ZEXSE' => 'E',
	'ZHAMA' => 'E',
	'ZINEL' => 'E',
	'ZINJU' => 'E',
	'ZINMI' => 'E',
	'ZINOF' => 'E',
	'ZIPCA' => 'E',
	'ZIZAU' => 'E',
	'ZIZJU' => 'B',
	'ZIZOB' => 'E',
	'ZOASP' => 'E',
	'ZOAVI' => 'E',
	'ZONAL' => 'E',
	'ZOOAN' => 'E',
	'ZOODA' => 'E',
	'ZOOLU' => 'E',
	'ZOONE' => 'E',
	'ZOOPR' => 'E',
	'ZOORA' => 'B',
	'ZOPAT' => 'E',
	'ZOPRU' => 'E',
	'ZOSJA' => 'E',
	'ZOSMA' => 'E',
	'ZOSOP' => 'E',
	'ZOSPA' => 'E',
	'ZOSRO' => 'E',
	'ZUCRI' => 'E',
	'ZYGBA' => 'E',
	'ZYGBI' => 'E',
	'ZYGCI' => 'E',
	'ZYGCR' => 'E',
	'ZYGFE' => 'E',
	'ZYGIN' => 'E',
	'ZYGMR' => 'E',
	'ZYGRO' => 'E',
	'ZYGTR' => 'E',
	'ZYMMO' => 'B',
	'ZYMMP' => 'B',
	'ZYMVC' => 'V',
	'ZYMVR' => 'V',
	'ZYMVS' => 'V',
	'9ACAR' => 'E',
	'9ACTI' => 'E',
	'9ACTN' => 'B',
	'9ACTO' => 'B',
	'9ADEN' => 'V',
	'9AGAR' => 'E',
	'9ALPH' => 'V',
	'9ALTE' => 'B',
	'9ALVE' => 'E',
	'9AMIO' => 'E',
	'9AMPH' => 'E',
	'9ANNE' => 'E',
	'9ANUR' => 'E',
	'9APHY' => 'E',
	'9APIA' => 'E',
	'9APIC' => 'E',
	'9AQUA' => 'E',
	'9AQUI' => 'B',
	'9ARAC' => 'E',
	'9ARAE' => 'E',
	'9ARCH' => 'A',
	'9ARTH' => 'E',
	'9ASCI' => 'E',
	'9ASCO' => 'E',
	'9ASIL' => 'E',
	'9ASPA' => 'E',
	'9ASTE' => 'E',
	'9ASTR' => 'E',
	'9AVES' => 'E',
	'9BACE' => 'B',
	'9BACI' => 'B',
	'9BACL' => 'B',
	'9BACT' => 'B',
	'9BACU' => 'V',
	'9BASI' => 'E',
	'9BETA' => 'V',
	'9BETR' => 'V',
	'9BIFI' => 'B',
	'9BILA' => 'E',
	'9BIVA' => 'E',
	'9BORA' => 'E',
	'9BORD' => 'B',
	'9BRAD' => 'B',
	'9BRAN' => 'E',
	'9BRAS' => 'E',
	'9BROM' => 'V',
	'9BRYO' => 'E',
	'9BURK' => 'B',
	'9CAEN' => 'E',
	'9CALI' => 'V',
	'9CARA' => 'E',
	'9CARN' => 'E',
	'9CARY' => 'E',
	'9CAUD' => 'V',
	'9CAUL' => 'B',
	'9CELL' => 'B',
	'9CEST' => 'E',
	'9CETA' => 'E',
	'9CHAR' => 'E',
	'9CHEL' => 'E',
	'9CHIR' => 'E',
	'9CHLA' => 'B',
	'9CHLB' => 'B',
	'9CHLO' => 'E',
	'9CHLR' => 'B',
	'9CHON' => 'E',
	'9CHOR' => 'E',
	'9CHRO' => 'B',
	'9CICH' => 'E',
	'9CILI' => 'E',
	'9CIRC' => 'V',
	'9CLOS' => 'V',
	'9CLOT' => 'B',
	'9CNID' => 'E',
	'9COLE' => 'E',
	'9COLU' => 'E',
	'9COMO' => 'V',
	'9CONI' => 'E',
	'9CORO' => 'V',
	'9CORV' => 'E',
	'9CORY' => 'B',
	'9COXI' => 'B',
	'9CRAN' => 'E',
	'9CREN' => 'A',
	'9CRUS' => 'E',
	'9CRYP' => 'E',
	'9CRYT' => 'E',
	'9CUCU' => 'E',
	'9CYAN' => 'B',
	'9DEIN' => 'B',
	'9DEIO' => 'B',
	'9DELA' => 'V',
	'9DELT' => 'B',
	'9DEND' => 'E',
	'9DINO' => 'E',
	'9DIOP' => 'E',
	'9DIPS' => 'E',
	'9DIPT' => 'E',
	'9DYTI' => 'E',
	'9ECHI' => 'E',
	'9ECHN' => 'E',
	'9ECHO' => 'E',
	'9EIME' => 'E',
	'9EMBE' => 'E',
	'9EMBR' => 'E',
	'9ENTE' => 'B',
	'9ENTO' => 'V',
	'9ENTR' => 'B',
	'9ERIC' => 'E',
	'9ESCH' => 'B',
	'9EUCA' => 'E',
	'9EUGL' => 'E',
	'9EUKA' => 'E',
	'9EURO' => 'E',
	'9EURY' => 'A',
	'9EUTE' => 'E',
	'9EUTH' => 'E',
	'9FABA' => 'E',
	'9FALC' => 'E',
	'9FILI' => 'E',
	'9FIRM' => 'B',
	'9FLAO' => 'B',
	'9FLAV' => 'V',
	'9FLOR' => 'E',
	'9FRIN' => 'E',
	'9FUNG' => 'E',
	'9FURN' => 'E',
	'9FUSO' => 'B',
	'9GALL' => 'E',
	'9GAMA' => 'V',
	'9GAMM' => 'B',
	'9GAMR' => 'V',
	'9GAST' => 'E',
	'9GEMI' => 'V',
	'9GENT' => 'E',
	'9GOBI' => 'E',
	'9GRUI' => 'E',
	'9HELI' => 'B',
	'9HELO' => 'E',
	'9HEMI' => 'E',
	'9HEPA' => 'V',
	'9HEPC' => 'V',
	'9HERP' => 'V',
	'9HETE' => 'E',
	'9HEXA' => 'E',
	'9HIV1' => 'V',
	'9HIV2' => 'V',
	'9HOMO' => 'E',
	'9HYME' => 'E',
	'9HYMN' => 'E',
	'9HYPO' => 'E',
	'9HYST' => 'E',
	'9ICTE' => 'E',
	'9INFA' => 'V',
	'9INFB' => 'V',
	'9INSE' => 'E',
	'9LABR' => 'E',
	'9LACO' => 'B',
	'9LACT' => 'B',
	'9LAGO' => 'E',
	'9LAMI' => 'E',
	'9LECA' => 'E',
	'9LEPT' => 'B',
	'9LILI' => 'E',
	'9LIST' => 'B',
	'9LUTE' => 'V',
	'9MAGN' => 'E',
	'9MAMM' => 'E',
	'9MAND' => 'E',
	'9MARC' => 'E',
	'9MAXI' => 'E',
	'9META' => 'E',
	'9METZ' => 'E',
	'9MICC' => 'B',
	'9MICO' => 'B',
	'9MICR' => 'E',
	'9MOLL' => 'E',
	'9MOLU' => 'B',
	'9MONO' => 'V',
	'9MURI' => 'E',
	'9MYCE' => 'E',
	'9MYCO' => 'B',
	'9MYRI' => 'E',
	'9MYRT' => 'E',
	'9NEIS' => 'B',
	'9NEOB' => 'E',
	'9NEOP' => 'E',
	'9NIDO' => 'V',
	'9NOCA' => 'B',
	'9NOSO' => 'B',
	'9NOST' => 'B',
	'9NUCL' => 'V',
	'9ODON' => 'E',
	'9ORTH' => 'E',
	'9ORTO' => 'V',
	'9ORYZ' => 'E',
	'9PAPI' => 'V',
	'9PARA' => 'V',
	'9PARI' => 'E',
	'9PASE' => 'E',
	'9PASS' => 'E',
	'9PAST' => 'B',
	'9PELO' => 'E',
	'9PERC' => 'E',
	'9PERO' => 'E',
	'9PETR' => 'E',
	'9PEZI' => 'E',
	'9PHAE' => 'E',
	'9PHYC' => 'V',
	'9PICI' => 'E',
	'9PICO' => 'V',
	'9PIPI' => 'E',
	'9PLAN' => 'B',
	'9PLAT' => 'E',
	'9PLEO' => 'E',
	'9PLEU' => 'E',
	'9PLVG' => 'V',
	'9POAL' => 'E',
	'9POLY' => 'V',
	'9PORP' => 'B',
	'9POTV' => 'V',
	'9POTY' => 'V',
	'9POXV' => 'V',
	'9PRIM' => 'E',
	'9PROC' => 'B',
	'9PROT' => 'B',
	'9PSED' => 'B',
	'9PSEU' => 'B',
	'9PSIT' => 'E',
	'9PULM' => 'E',
	'9RALS' => 'B',
	'9REOV' => 'V',
	'9RETR' => 'V',
	'9RHAB' => 'V',
	'9RHIZ' => 'B',
	'9RHOB' => 'B',
	'9RHOD' => 'E',
	'9RHOO' => 'B',
	'9RICK' => 'B',
	'9RODE' => 'E',
	'9ROSA' => 'E',
	'9ROSI' => 'E',
	'9SACH' => 'E',
	'9SALA' => 'E',
	'9SARC' => 'E',
	'9SAUR' => 'E',
	'9SCAR' => 'E',
	'9SCHI' => 'E',
	'9SCIU' => 'E',
	'9SCOM' => 'E',
	'9SCOR' => 'E',
	'9SMEG' => 'E',
	'9SOLA' => 'E',
	'9SOLN' => 'E',
	'9SPER' => 'E',
	'9SPHI' => 'B',
	'9SPHN' => 'B',
	'9SPIO' => 'B',
	'9SPIR' => 'B',
	'9SPIT' => 'E',
	'9STAP' => 'B',
	'9STIC' => 'E',
	'9STL1' => 'V',
	'9STRA' => 'E',
	'9STRE' => 'B',
	'9STRI' => 'E',
	'9SYLV' => 'E',
	'9SYNC' => 'B',
	'9SYNE' => 'B',
	'9TELE' => 'E',
	'9TETR' => 'E',
	'9THEM' => 'B',
	'9THEO' => 'B',
	'9THER' => 'E',
	'9TOMB' => 'V',
	'9TRAC' => 'E',
	'9TREM' => 'E',
	'9TRYP' => 'E',
	'9TURB' => 'E',
	'9TURD' => 'E',
	'9TYRA' => 'E',
	'9UROC' => 'E',
	'9VERT' => 'E',
	'9VEST' => 'E',
	'9VIBR' => 'B',
	'9VIRI' => 'E',
	'9VIRU' => 'V',
	'9XANT' => 'B',
	'9ZYGM' => 'E',
	'9ZYGO' => 'E',
 
);


1;


	    
